/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(sb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function qb(rb){var s=rb.a;var t=s.a;var u=t.buffer;t.grow=ob;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=s.b;var O=s.c;var P=s.d;var Q=s.e;var R=s.f;var S=s.g;var T=s.h;var U=s.i;var V=s.j;var W=s.k;var X=s.l;var Y=s.m;var Z=s.n;var _=s.o;var $=s.p;var aa=s.q;var ba=s.r;var ca=s.s;var da=s.t;var ea=s.u;var fa=s.v;var ga=s.w;var ha=s.x;var ia=s.y;var ja=s.z;var ka=s.A;var la=s.B;var ma=s.C;var na=s.D;var oa=s.E;var pa=s.F;var qa=s.G;var ra=s.H;var sa=s.I;var ta=s.J;var ua=s.K;var va=s.L;var wa=s.M;var xa=s.N;var ya=s.O;var za=s.P;var Aa=s.Q;var Ba=s.R;var Ca=s.S;var Da=s.T;var Ea=s.U;var Fa=s.V;var Ga=s.W;var Ha=s.X;var Ia=s.Y;var Ja=s.Z;var Ka=s._;var La=s.$;var Ma=s.aa;var Na=s.ba;var Oa=s.ca;var Pa=s.da;var Qa=s.ea;var Ra=s.fa;var Sa=s.ga;var Ta=s.ha;var Ua=s.ia;var Va=s.ja;var Wa=s.ka;var Xa=s.la;var Ya=s.ma;var Za=s.na;var _a=s.oa;var $a=s.pa;var ab=s.qa;var bb=s.ra;var cb=s.sa;var db=s.ta;var eb=s.ua;var fb=567792;var gb=0;var hb=0;
// EMSCRIPTEN_START_FUNCS
function GM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,P=0,R=0,T=E(0),U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=E(0),ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=E(0),Fa=0;aa=fb-32|0;fb=aa;ba=aa+28|0;x[ba>>2]=48836;x[ba>>2]=48736;e=DB(aa+20|0);f=DB(aa+12|0);ca=b;ga=c;ha=x[e>>2];sa=y[e+4|0];ia=x[f>>2];ta=y[f+4|0];b=0;C=fb-96|0;fb=C;d=a;ja=a+24604|0;a=ja;a:{if(!x[a+16>>2]){break a}c=x[a+20>>2];if(c>>>0>4|!(1<<c&22)){break a}a=x[a+28>>2];if(a>>>0>4){break a}b=23>>>a&1}if(!b){a=C+80|0;aS(a,9149,13086,221,45);b=fb-48|0;fb=b;c=uc(b+24|0,18391);x[31609]=0;f=b+12|0;O(884,f|0,17467);e=x[31609];x[31609]=0;b:{c:{d:{e:{if((e|0)!=1){x[31609]=0;e=b+36|0;S(2,e|0,c|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}x[31609]=0;S(885,a|0,1,e|0);a=x[31609];x[31609]=0;if((a|0)!=1){break b}a=N()|0;tb(e);break d}a=N()|0;break c}a=N()|0}tb(b+12|0)}tb(c);Q(a|0);p()}tb(b+36|0);tb(b+12|0);tb(c);fb=b+48|0}ka=d+8204|0;la=d+397452|0;ma=d+397448|0;Z=d+393352|0;t=d+397456|0;W=d+12|0;ua=d+16396|0;va=d+1074376|0;while(1){f:{g:{b=x[d+480208>>2];if(!(!ca|b&512)){h:{if(x[d+1074380>>2]){break h}a=b|512;i:{if(b&256){break i}n=fb-48|0;fb=n;s=fb-32|0;fb=s;l=d+1074312|0;h=d+1074992|0;j=d+1298264|0;o=d+1074424|0;G=d+484360|0;m=d+1074448|0;q=d+1074376|0;a=x[d+1074392>>2];P=d+480210|0;j:{k:while(1){l:{a=a+1|0;x[d+1074392>>2]=a;if(Jl(q)>>>0>a>>>0){break l}xT(s+30|0,x[d+480180>>2],z[d+480188>>1],q,(x[d+480208>>2]&524288)>>>19|0);m:{n:{o:{p:{r=x[d+480208>>2];if(r&32){e=x[d+484348>>2];g=x[d+484344>>2];b=z[d+1074446>>1];break p}b=65535;I=Xb(x[d+484360>>2],y[d+484376|0]);i=x[I>>2];H=x[I+4>>2];f=$c(i,H);a=z[d+1074448>>1];if(f>>>0>a>>>0){b=z[ac(i,a)>>1]}w[d+1074446>>1]=b;q:{r:{c=b&65535;g=x[d+484344>>2];e=x[d+484348>>2];J=Xj(g,e);if(c>>>0>=J>>>0){break r}c=Wb(g,c);if(Ib(x[c>>2],x[c+4>>2])){break r}c=0;break q}c=1}while(1){if(!c){b=65534;w[d+1074446>>1]=65534;c=1;continue}c=z[I+28>>1];while(1){s:{t:{u:{k=b&65535;if(k>>>0>=J>>>0){b=a&65535;if(!((k|0)!=65535&f>>>0>b>>>0)){if(c){a=c;k=$c(i,H);break t}if(!(a&65535)|b>>>0>f>>>0){break u}while(1){a=b;b=a-1|0;if(!b){break u}if(z[ac(i,b)>>1]!=65535){continue}break}k=f;break t}a=a+1|0;w[m>>1]=a;b=a&65535;break s}w[d+1074450>>1]=a;break p}a=0;k=f}w[d+1074448>>1]=a;r=r&-524289;x[d+480208>>2]=r;while(1){b=a&65535;if(k>>>0<=b>>>0){break o}if(z[ac(i,b)>>1]==65534){a=a+1|0;w[m>>1]=a;continue}break}if(!Wi(I,a&65535)){break o}}if(b>>>0>=f>>>0){b=65535;w[d+1074446>>1]=65535;continue}b=z[ac(i,b)>>1];w[d+1074446>>1]=b;if(b>>>0>=J>>>0){continue}k=Wb(g,b);if(Ib(x[k>>2],x[k+4>>2])){continue}break}c=0;continue}}b=b&65535;if(!Je(g,e,b)){break n}a=x[o>>2];if(a>>>0>=A[Wb(g,b)+12>>2]){x[o>>2]=0;a=0}if(r&32?x[d+480272>>2]!=-1:0){break m}if(!Yu(j,z[m>>1],a,Jq(s+20|0,h),y[s+30|0])){break m}a=x[d+480272>>2];if(a){if((a|0)>0){x[d+480272>>2]=a-1}Mo(j,1);Yu(j,z[m>>1],x[o>>2],Jq(s+20|0,h),y[s+30|0]);break m}if(!(y[P|0]&64)){break o}if(!Wu(j,m,o)){x[d+1074424>>2]=0;x[d+1074428>>2]=0;x[d+1074448>>2]=0;b=Gj(x[d+484360>>2],x[d+484364>>2])-1|0;a=y[d+484376|0];if((b|0)<=(a|0)){Vj(G,0);break o}Vj(G,a+1&255);Mo(j,1)}a=0;while(1)if((a|0)==256){TR(d);x[d+1074416>>2]=x[d+480196>>2];x[d+1074420>>2]=x[d+480204>>2];x[d+1074456>>2]=x[d+480200>>2];a=z[d+1074448>>1];w[d+1074450>>1]=a;b=x[d+1074424>>2];x[d+1074428>>2]=b;c=Xb(x[d+484360>>2],y[d+484376|0]);e=x[c>>2];if($c(e,x[c+4>>2])>>>0>a>>>0){Ca=d,Da=z[ac(e,a)>>1],w[Ca+1074446>>1]=Da}Yu(j,a,b,Jq(s+20|0,h),y[s+30|0]);if(!Je(x[d+484344>>2],x[d+484348>>2],z[d+1074446>>1])){break n}break m}else{Qo(h+D(a,872)|0,d,a&65535,67108864);a=a+1|0;continue}}Mo(j,1)}a=0;break j}wT(d,q,(x[d+480208>>2]&32)>>>5|0);a=Wb(x[d+484344>>2],z[d+1074446>>1]);b=md(x[a>>2],x[x[a+48>>2]+12>>2],x[d+1074424>>2],0);e=h+D(z[d+480188>>1],872)|0;a=h;while(1){if((a|0)==(e|0)){v:{w:{a=x[d+484344>>2];b=z[d+1074446>>1];if(Bn(a,x[d+484348>>2],b)){a=Wb(a,b);b=x[a+16>>2];a=x[a+20>>2];if(tT(b,a)){break w}}x[d+1074408>>2]=x[d+480216>>2];a=x[d+480220>>2];break v}x[d+1074408>>2]=b}x[d+1074412>>2]=a;if(!y[s+30|0]){break l}a=x[d+1074416>>2];x[d+1074392>>2]=a;continue k}Jb(s+20|0,l,82);x:{if(!Gb(x[x[s+20>>2]>>2],x[s+24>>2])|y[a+805|0]!=1){break x}c=y[b+3|0];if((c|0)!=2&(c|0)!=3){break x}Ca=a,Da=zh(d,y[a+800|0],w[a+772>>1],x[a+704>>2]),x[Ca+700>>2]=Da}Jb(s+20|0,l,91);y:{if(!Gb(x[x[s+20>>2]>>2],x[s+24>>2])){break y}if(Tc(y[b|0])){break y}c=y[a+788|0];if(!Tc(c)|y[a+791|0]!=19){break y}f=y[a+793|0];if((f&240)!=208|A[d+1074416>>2]>(f&15)>>>0){break y}Ca=a,Da=zh(d,c,w[a+772>>1],0),x[Ca+700>>2]=Da}Jb(s+20|0,l,118);z:{if(!Gb(x[x[s+20>>2]>>2],x[s+24>>2])){break z}if(Tc(y[b|0])|!(y[a+89|0]&2)){break z}c=x[a+708>>2];if(!c){break z}if(!Tc(y[a+788|0])){break z}if(!Kl(y[a+790|0],y[a+791|0])){break z}x[a+700>>2]=c}c=s+20|0;Jb(c,l,92);A:{if(!Gb(x[x[s+20>>2]>>2],x[s+24>>2])){break A}Jb(s+12|0,l,5);if(Gb(x[x[s+12>>2]>>2],x[s+16>>2])|x[d+1074416>>2]!=1|y[a+791|0]!=17){break A}v[s+20|0]=1;Ca=d,Da=D(y[cf(c,a+793|0)|0],1e4),x[Ca+1074420>>2]=Da}c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+788|0]=c;v[a+789|0]=c>>>8;v[a+790|0]=c>>>16;v[a+791|0]=c>>>24;c=y[b+4|0]|y[b+5|0]<<8;v[a+792|0]=c;v[a+793|0]=c>>>8;c=x[a+676>>2];x[a+20>>2]=x[a+672>>2];x[a+24>>2]=c;x[a+88>>2]=x[a+88>>2]&-393217;Jb(s+20|0,l,21);if(!Gb(x[x[s+20>>2]>>2],x[s+24>>2])){v[a+831|0]=0}x[a+860>>2]=0;v[a+805|0]=0;b=b+6|0;a=a+872|0;continue}}break}c=x[d+1074416>>2];if(!c){x[d+1074416>>2]=1;c=1}a=x[d+480208>>2];e=x[d+1074392>>2];B:{C:{if(e){b=a&-4097;x[d+480208>>2]=b;f=x[d+480180>>2];if(f&1048580|!(a&2097152)&(f|0)==1){break B}if(Jl(q)>>>0<=e>>>0){break B}if(!((e>>>0)%(x[d+1074400>>2]+c>>>0)|0)){break C}break B}b=a&-528385}x[d+480208>>2]=b|4096}r=0;i=fb-16|0;fb=i;w[d+1074444>>1]=65535;x[d+1074436>>2]=-1;x[d+1074440>>2]=-1;X=d+1075809|0;P=d+480280|0;u=d+900380|0;J=d+484380|0;o=d+1074312|0;K=d+906300|0;R=d+1074992|0;G=d+1074376|0;M=d+480209|0;_=d+480210|0;while(1){if(z[d+480188>>1]<=r>>>0){D:{if(!(y[d+480209|0]&16)){break D}if(!lT(d,G,Xb(x[d+484360>>2],y[d+484376|0]),1)){break D}x[d+480208>>2]=x[d+480208>>2]|524288}fb=i+16|0}else{h=R+D(r,872)|0;a=y[h+789|0];c=y[h+793|0];q=y[h+792|0];b=x[d+1074400>>2];e=x[d+1074392>>2];f=x[d+1074416>>2];k=y[h+790|0];H=y[h+791|0];g=Kl(k,H);v[h+851|0]=x[d+480208>>2]>>>12&1|y[h+851|0]&254;f=(e>>>0)%(b+f>>>0)|0;b=y[h+788|0];E:{F:{G:{if((b|0)==252){j=Cj(k,q);l=Cj(H,c);b=252;e=a-1|0;if((e&255)>>>0>249){break G}e=x[$d(K,e)>>2];if(!e){break G}ib[x[x[e>>2]+44>>2]](e,j,E(E(l>>>0)/E(999)));b=y[h+788|0]}if((b&255)==251){break F}}if(B[h+860>>2]==E(0)|H){break E}}j=x[d+480208>>2]&4096;H:{if(!j){e=y[h+870|0];break H}e=y[h+789|0];v[h+870|0]=e}if((e-1&255)>>>0>249){break E}l=$d(K,(e&255)-1|0);e=x[l>>2];if(!e){break E}I:{if(!j){b=z[h+868>>1];break I}b=rB(y[h+790|0],y[h+792|0]);w[h+868>>1]=b;T=E(E(rB(y[h+791|0],y[h+793|0])>>>0)/E(999));B[h+864>>2]=T;Ca=h,Ea=E(E(T-E(ib[x[x[e>>2]+48>>2]](e,b)))/E(Jl(G)>>>0)),B[Ca+860>>2]=Ea;e=x[l>>2]}j=b;b=(x[d+1074392>>2]+1|0)==(Jl(G)|0);ib[x[x[e>>2]+(b?44:108)>>2]](e,j,B[h+(b?864:860)>>2]);b=y[h+788|0]}if(bT(b&255)){b=fb-16|0;fb=b;w[b+12>>1]=0;x[b+8>>2]=0;a=Ng(b+8|0);c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[h+788|0]=c;v[h+789|0]=c>>>8;v[h+790|0]=c>>>16;v[h+791|0]=c>>>24;a=y[a+4|0]|y[a+5|0]<<8;v[h+792|0]=a;v[h+793|0]=a>>>8;fb=b+16|0;H=0;q=0;k=0;c=0;g=0;a=0}J:{if(!(y[M|0]&16)){ES(d,h);break J}if(!a){break J}x[h+760>>2]=0}K:{L:{if((H|0)==33){Jb(i+8|0,o,30);b=c>>>4|0;dB(d,r&65535,b+(c&15)|0,Gb(x[x[i+8>>2]>>2],x[i+12>>2]));break L}b=0;if((H-19&255)>>>0>1){break L}M:{if(!(!(x[d+480180>>2]&16777250)|c)){c=y[h+833|0];break M}v[h+833|0]=c}e=c&240;if((e|0)==208){e=c&15;if(!e){e=x[d+480180>>2];if(e&16777248){b=1;break L}if((e|0)!=2){break L}break K}if(e>>>0>=x[d+1074400>>2]+x[d+1074416>>2]>>>0){Jb(i+8|0,o,14);b=e;if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break L}if(!a){break K}v[h+803|0]=a;break K}b=e;break L}if(!(x[d+480208>>2]&4096)|(e|0)!=224){break L}e=x[d+480180>>2];if(x[d+1074396>>2]?e&16777250:0){break L}j=c&15;if(!(e&2?j:1)){break L}x[d+1074396>>2]=j+1}j=x[d+480180>>2]==16&(H|0)==19&(c&240)==208;I=j?0:b;N:{if(!I|y[h+788|0]!=255|y[h+790|0]!=2){break N}Jb(i+8|0,o,74);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break N}v[h+790|0]=0}m=c&159;e=x[d+1074392>>2];Jb(i+8|0,o,72);O:{if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){l=0;if(I>>>0>=A[d+1074416>>2]){break O}}Jb(i+8|0,o,88);e=(e|0)==(I|0);l=e|(f|0)==(I|0);if(!(!I|!Gb(x[x[i+8>>2]>>2],x[i+12>>2]))){break O}l=e}c=j?m:c;b=i+8|0;Jb(b,o,44);e=y[h+851|0];Ca=h,Da=(Gb(x[x[i+8>>2]>>2],x[i+12>>2])?e&252|(f|0)==(I|0):e)&253,v[Ca+851|0]=Da;Jb(b,o,66);e=(!I|Gb(x[x[i+8>>2]>>2],x[i+12>>2])^1)&g;P:{Q:{R:{if(!(x[d+1074392>>2]|(!(y[_|0]&32)|!a))){x[h+660>>2]=0;if(l){g=y[h+788|0];break R}if(!Mi(x[h+8>>2],x[h+12>>2])){break P}v[h+803|0]=a;if(z[d+480190>>1]<a>>>0){break P}a=J+D(a,104)|0;x[h+688>>2]=z[a+30>>1];w[h+772>>1]=v[a+37|0];break P}if(!l){break P}g=y[h+788|0];if(!a){break Q}}v[h+803|0]=a}S:{T:{b=g&255;if(!Tc(b)){break T}Jb(i+8|0,o,67);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break T}f=w[h+770>>1];U:{if(!a|e){break U}j=rr(d,b,a);if(!j){break U}f=v[ni(d,j)+36|0]}g=(b+f|0)-132>>>0>=4294967176?g:0;break S}if(!(x[d+480180>>2]&25165856)){break S}f=z[d+480192>>1];if(!f){break S}if(b){b=Tc(b)}else{b=1}if(!b){break S}b=a;V:{if(!a){b=y[h+804|0];if(!b){break V}}if(x[u+(b<<2)>>2]?b>>>0<=f>>>0:0){break S}g=0}a=0}if(!((H|0)!=25|c)){Jb(i+8|0,o,55);b=Gb(x[x[i+8>>2]>>2],x[i+12>>2]);a=b?0:a;g=b?0:g}b=i+8|0;Jb(b,o,65);m=Gb(x[x[i+8>>2]>>2],x[i+12>>2]);L=1;if(!(x[d+480180>>2]&16777248)){Jb(b,o,107);L=Gb(x[x[i+8>>2]>>2],x[i+12>>2])}f=(a|0)!=0;b=g&255;V=!b;Jb(i+8|0,o,85);W:{if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break W}if(Mi(x[h+8>>2],x[h+12>>2])){break W}j=x[h+104>>2];if(j){if(le(x[j>>2],x[j+20>>2])){break W}}L=1}j=f&V;m=f&m;X:{Y:{Z:{_:{$:{aa:{if(!(x[d+480180>>2]&1048580)){break aa}ba:{if((b|0)!=255){break ba}if(!(!((k|0)==1|a)&(H|0)!=13)){Jb(i+8|0,o,55);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break ba}}f=x[h+656>>2];if(v[f+60|0]&1?f:0){break ba}x[h+688>>2]=0;x[h+88>>2]=x[h+88>>2]|2097152;ca:{if(!(x[d+480208>>2]&4096)){break ca}Jb(i+8|0,o,86);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break ca}x[h+88>>2]=x[h+88>>2]|4096}a=0;g=0;b=0;f=0;j=1;if(m){break Y}break X}Jb(i+8|0,o,59);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])|x[d+480208>>2]&4096){break aa}da:{if(!b){g=y[h+797|0]-y[h+770|0]|0;break da}if(b>>>0>250){L=0;m=1;g=0;break da}ea:{if(a){break ea}Jb(i+8|0,o,98);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break ea}a=0;break da}L=1;m=1}f=g;e=0;break $}f=0;if(!j){break _}}Jb(i+8|0,o,65);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Z}g=f;f=1}b=g;j=1;if(m){break Y}break X}g=f;f=1;j=m}fa:{ga:{if(!z[d+480192>>1]){if(z[d+480190>>1]<a>>>0){break fa}b=J+D(a,104)|0;break ga}b=x[h+104>>2];if(!b){break fa}}ha:{if(w[b+34>>1]<0){break ha}if(x[d+480180>>2]==2){if(!le(x[b>>2],x[b+20>>2])){break ha}}x[h+688>>2]=z[b+30>>1];x[h+88>>2]=x[h+88>>2]|2097152}if(!j){break fa}Sq(h,z[b+28>>1],d)}b=g}Jb(i+8|0,o,71);if(!(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])|!a)){v[h+839|0]=32}ia:{if(!z[d+480192>>1]){break ia}Jb(i+8|0,o,100);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])|!a){break ia}if(Tc(b&255)){break ia}g=x[d+480208>>2];ja:{if(e){if(g&8){break ja}break ia}if(!(g&4)){break ia}}Ym(h);x[h+696>>2]=65536;x[h+88>>2]=x[h+88>>2]|2097152}if(f){Jb(i+8|0,o,11);ka:{la:{ma:{if(!(Gb(x[x[i+8>>2]>>2],x[i+12>>2])|x[d+480180>>2]==268435456)){g=z[d+480192>>1];break ma}Jb(i+8|0,o,87);f=0;if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){f=Mi(x[h+8>>2],x[h+12>>2])^1}g=z[d+480192>>1];na:{if(g){if(a>>>0>g>>>0){break la}if(x[h+656>>2]!=x[u+(a<<2)>>2]|f){break na}break la}if((f^-1)&x[h+104>>2]==(J+D(a,104)|0)){break ka}}b=y[h+797|0]}if(!(g&65535)){break ka}}if(!(x[d+480180>>2]&1048588)){break ka}Ym(h);v[h+818|0]=0;x[h+756>>2]=0;x[h+696>>2]=65536;x[h+88>>2]=x[h+88>>2]&-2101249|2097152;Jb(i+8|0,o,86);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break ka}x[h+88>>2]=x[h+88>>2]&-2049}a=L?a:0}g=b&255;oa:{if(g>>>0<251){break oa}Jb(i+8|0,o,50);pa:{if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])|!a){break pa}f=rr(d,y[h+799|0],a);if(!f){break pa}f=J+D(f,104)|0;if(w[f+34>>1]<0){break pa}x[h+688>>2]=z[f+30>>1]}Jb(i+8|0,o,100);if(Ca=Gb(x[x[i+8>>2]>>2],x[i+12>>2]),Da=0,Fa=x[d+480208>>2]&4,Fa?Ca:Da){break oa}a=0}j=Tc(g);if(j){v[h+802|0]=b;v[h+799|0]=b;if(!e){FS(d,r&65535,a,g,0)}fV(h)}qa:{ra:{sa:{ta:{ua:{if(a){f=x[h+104>>2];Lo(d,h,a,e,1,1);va:{if(x[h+88>>2]&67109888){break va}b=x[h+104>>2];if(!b|!(y[b+35|0]&2)){break va}m=x[d+1298300>>2];if(!Ed(m)){break va}RB(m,r&65535,b+68|0)}wa:{xa:{if(x[d+480180>>2]==1){if(!e){break xa}Jb(i+8|0,o,85);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break xa}break wa}Jb(i+8|0,o,50);if((j|Gb(x[x[i+8>>2]>>2],x[i+12>>2])^1)!=1){break wa}}v[h+803|0]=0}Jb(i+8|0,o,42);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!j|(f|0)==x[h+104>>2]){break ta}break ua}if(x[d+480180>>2]&16777248){b=0;if(j&(f|0)!=x[h+104>>2]){break sa}}Jb(i+8|0,o,107);if(!(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])|(!(j^1|e)|(f|0)==x[h+104>>2])|A[h+76>>2]>=A[h+4>>2])){x[h+76>>2]=0;break ta}Jb(i+8|0,o,85);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break ta}if(!Mi(x[h+8>>2],x[h+12>>2])){break ua}break ta}if(!g){b=e;break qa}f=0;b=y[h+803|0];if(!(!b|j^1)){Lo(d,h,b,e,!(x[h+104>>2]?1:x[h+656>>2]),!(x[d+480180>>2]&1048580));v[h+803|0]=0;f=1}b=e;break ra}x[h>>2]=0;x[h+4>>2]=0}b=e}f=0;if(!g){break qa}}ya:{if(x[h+88>>2]&67109888){break ya}e=x[h+104>>2];if(!e|!(y[e+35|0]&2)){break ya}j=x[d+1298300>>2];if(!Ed(j)){break ya}if(!f){if(GS(j,r&65535)){break ya}}RB(j,r&65535,e+68|0)}e=r&65535;Su(d,h,g,b,!(x[d+480180>>2]&1048580),0,e);qT(x[d+480180>>2],z[d+480188>>1],G,e);if(!(!(x[d+480180>>2]&1048580)|(!b|!a))){x[h+88>>2]=x[h+88>>2]|2097152;Ym(h);v[h+818|0]=0;x[h+756>>2]=0}if(!(x[h+88>>2]&512)){break qa}if(!Ed(x[d+1298300>>2])){break qa}if(g>>>0<=253){if((g|0)!=253){break qa}Jb(i+8|0,o,99);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break qa}}Jb(i+8|0,o,110);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){SB(x[d+1298300>>2],e,0,1,0)}yk(x[d+1298300>>2],e)}za:{Aa:{switch(k-1|0){case 0:x[h+88>>2]=x[h+88>>2]|2097152;q=q>>>0>=64?64:q;x[h+688>>2]=q<<2;break za;case 1:break Aa;default:break za}}Zm(d,h,q,6)}if(z[d+480192>>1]){DS(d,r&65535)}e=b}b=i+8|0;Jb(b,o,77);if(Ca=Gb(x[x[i+8>>2]>>2],x[i+12>>2]),Da=0,Fa=x[P+(r<<5)>>2]&1024,Fa?Ca:Da){break K}a=x[d+1074392>>2];Jb(b,o,75);f=a>>>0>=I>>>0;Ba:{Ca:{Da:{Ea:{if(!I|!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ea}b=x[d+1074392>>2];if(!b){break Da}f=1;if((b|0)!=(I|0)){break Ea}f=!y[h+789|0]&(k|0)!=11}a=k;if(!f|a>>>0<3){break Da}if((a|0)==11){a=i+8|0;wB(a,d,y[h+791|0],y[h+792|0],I);a=y[_e(a)|0];bB(d,r&65535,z[i+8>>1]);if(a){break Ca}k=11;break Da}Jb(i+8|0,o,62);Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{if(!(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])|q)){q=0;k=0;Ma:{switch(a-8|0){case 0:break La;case 1:break Ma;default:break Da}}if(y[M|0]&16){break Da}x[h+692>>2]=0;break Da}Jb(i+8|0,o,41);Na:{if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Na}if(q){v[h+834|0]=q;break Na}q=y[h+834|0]}Oa:{switch(a-3|0){case 0:case 1:Pa:{Qa:{if(q){break Qa}Jb(i+8|0,o,41);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Qa}q=y[h+834|0];if(q){break Pa}q=0;break Da}v[h+834|0]=q}Jo(d,h,((a|0)==3?q<<4:q)&255);break Da;case 2:if((I|0)!=x[d+1074392>>2]){Jb(i+8|0,o,41);k=5;if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Da}}Jb(i+8|0,o,41);Io(d,h,q,Gb(x[x[i+8>>2]>>2],x[i+12>>2]));k=5;break Da;case 3:if((I|0)!=x[d+1074392>>2]){Jb(i+8|0,o,41);k=6;if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Da}}Jb(i+8|0,o,41);Ho(d,h,q,Gb(x[x[i+8>>2]>>2],x[i+12>>2]));k=6;break Da;case 11:break Fa;case 12:break Ga;case 10:break Ha;case 9:break Ia;case 7:break Ja;case 6:break Ka;case 5:break La;case 4:break Oa;default:break Da}}Jb(i+8|0,o,53);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){v[h+823|0]=q&15;k=7;break Da}Hl(h,q<<4);k=7;break Da}Hl(h,q);k=8;break Da}Jb(i+8|0,o,62);aB(d,h,q,Gb(x[x[i+8>>2]>>2],x[i+12>>2])^1);k=9;break Da}Jb(i+8|0,o,62);aB(d,h,q<<4&240,Gb(x[x[i+8>>2]>>2],x[i+12>>2])^1);k=10;break Da}k=12;Jb(i+8|0,o,12);CS(d,r&65535,q<<2&252,Gb(x[x[i+8>>2]>>2],x[i+12>>2]));break Da}Jb(i+8|0,o,12);BS(d,r&65535,q<<2&252,Gb(x[x[i+8>>2]>>2],x[i+12>>2]));k=13;break Da}k=15;if(!l){break Da}a=x[h+104>>2];if(!a|q>>>0>9){break Da}Ra:{if(!q){a=x[h+664>>2];break Ra}a=x[yb(a+68|0,q-1|0)>>2];x[h+664>>2]=a}Ko(d,h,a);break Da}k=14;if(q>>>0>1){break Da}v[h+851|0]=(y[h+851|0]&247|q<<3)^8}a=c;Sa:{Ta:{Ua:{switch(H-1|0){case 12:if(!(y[d+480209|0]&16)){break Ca}x[h+688>>2]=c>>>0>=64?256:c<<2;x[h+88>>2]=x[h+88>>2]|2097152;break Ca;case 45:if(!(y[d+480209|0]&16)){break Ca}x[h+688>>2]=c;x[h+88>>2]=x[h+88>>2]|2097152;break Ca;case 1:if(!c){a=0;if(v[d+480180|0]&1){break Ba}}CS(d,r&65535,c,0);break Ca;case 2:if(!c){a=0;if(v[d+480180|0]&1){break Ba}}BS(d,r&65535,c,0);break Ca;case 10:if(!c){a=0;if(x[d+480180>>2]==1){break Ba}}Jo(d,h,c);break Ca;case 3:bB(d,r&65535,c);break Ca;case 5:if(!(!c&x[d+480180>>2]==1)){Jo(d,h,c)}bB(d,r&65535,0);break Ca;case 4:Hl(h,c);break Ca;case 6:if(!(!c&x[d+480180>>2]==1)){Jo(d,h,c)}Hl(h,0);break Ca;case 15:if(!(y[d+480209|0]&16)){break Ca}break Sa;case 16:Jb(i+8|0,o,5);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!(y[d+480209|0]&16)){break Ca}if(c){break Sa}break Ca}a=Go(d,z[d+1074446>>1],x[d+1074424>>2],r&65535,0);Va:{if(!(x[d+480180>>2]&16777250)){break Va}if(a){v[h+835|0]=a;break Va}a=y[h+835|0]}x[i+8>>2]=D(a,1e4);xc(i+8|0,D(x[x[d+8>>2]+24>>2],1e4));b=fb-16|0;fb=b;e=x[i+8>>2];x[b+12>>2]=e;c=x[d+8>>2];Wa:{if(e>>>0>=(x[d+480180>>2]&16393?1e4:32e4)>>>0){e=x[d+480208>>2];f=b+4|0;Jb(f,d+1074312|0,92);if((Gb(x[x[b+4>>2]>>2],x[b+8>>2])|0)==((e&4096)>>>12|0)){break Wa}x[b+4>>2]=D(x[c+24>>2],1e4);Ca=d,Da=x[Hb(b+12|0,f)>>2],x[Ca+1074420>>2]=Da;break Wa}if(y[d+480209|0]&16){break Wa}e=(e>>>0)/1e4|0;f=D(e&15,1e4);x[d+1074420>>2]=x[d+1074420>>2]+((e&240)==16?f:0-f|0);e=x[c+20>>2];c=x[c+24>>2];Jb(b+4|0,d+1074312|0,8);Fp(d+1074420|0,D(e,1e4),Gb(x[x[b+4>>2]>>2],x[b+8>>2])?255e4:D(c,1e4))}fb=b+16|0;break Ba;case 9:if(!l|x[d+480180>>2]==4&e){break Ca}pT(d,h,r&65535,x[d+1074424>>2],z[d+1074446>>1]);break Ca;case 43:if(!l){break Ca}b=Aua(x[h+76>>2],0,c,0);a=hb;m=a>>>8|0;Ko(d,h,Bc((a&255)<<24|b>>>8,m));break Ca;case 0:if(x[d+1074392>>2]){break Ca}Xa:{if(y[h+797|0]?x[h+700>>2]:0){break Xa}a=x[h+656>>2];if(a){if(Jj(y[a+31|0])){break Xa}}Jb(i+8|0,o,13);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Xa}if(x[d+480180>>2]&16777248){break Ca}}if(!c){a=0;if(y[d+480180|0]&5){break Ba}v[h+805|0]=1;break Ba}v[h+806|0]=c;v[h+805|0]=1;break Ca;case 14:if(x[d+480180>>2]&1048580){c=c&240?c:y[h+807|0]&240|c;if(!(c&15)){c=y[h+807|0]&15|c}a=c|256}else{a=c}Jb(i+8|0,o,23);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){c=d;f=r&65535;if(a){v[h+807|0]=a;b=a}else{b=y[h+807|0]}$A(c,f,b&255,(k|0)==15?q+1|0:0);break Ba}Ya:{if(a){v[h+807|0]=a;break Ya}a=y[h+807|0]}$A(d,r&65535,a,(k|0)==15?q+1|0:0);break Ba;case 17:if(!(y[d+480209|0]&16)){break Ca}Jb(i+8|0,o,22);Za:{_a:{if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!c){c=0;break _a}if(y[d+480208|0]&4){break _a}a=c&240?c-16|0:c;c=a-((a&15)!=0)|0;v[h+840|0]=c;break _a}Jb(i+8|0,o,71);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Za}}v[h+839|0]=y[h+839|0]|128}v[h+805|0]=18;if(!c){a=0;break Ba}v[h+840|0]=c;break Ca;case 22:if(!(y[d+480209|0]&16)){break Ca}b=x[d+480180>>2];a=c<<!(b&59593760);if(a>>>0<=128){x[d+1074456>>2]=a<<1;break Ba}if(b&16777250){break Ba}x[d+1074456>>2]=256;break Ba;case 23:Jb(i+8|0,o,9);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){AS(d,c,h+817|0);break Ca}AS(d,c,X);break Ca;case 8:if(!(y[d+480209|0]&16)){break Ca}Zm(d,h,c,8);break Ca;case 28:aB(d,h,c,1);break Ca;case 7:hT(h,c);break Ca;case 25:iT(d,h,c);break Ca;case 18:e=fb-16|0;fb=e;g=d+1074992|0;f=r&65535;b=g+D(f,872)|0;a=c&15;$a:{ab:{switch(c>>>4|0){case 0:a=(c&1)<<14;f=z[d+480188>>1];b=0;while(1){if((b|0)==(f|0)){break $a}k=g+D(b,872)|0;x[k+88>>2]=(a|x[k+88>>2]&-16385)^16384;b=b+1|0;continue};case 1:if(!a){a=0;if(!(x[d+480180>>2]&1048580)){break $a}}nB(d,b,a);Jb(e+8|0,d+1074312|0,117);if(Gb(x[x[e+8>>2]>>2],x[e+12>>2])){break $a}Ao(d,f,c|240,1);break $a;case 2:if(!a){a=0;if(!(x[d+480180>>2]&1048580)){break $a}}mB(d,b,a);Jb(e+8|0,d+1074312|0,117);if(Gb(x[x[e+8>>2]>>2],x[e+12>>2])){break $a}Ao(d,f,0-(c|240)|0,1);break $a;case 3:x[b+88>>2]=x[b+88>>2]&-1048577|((a|0)!=0)<<20;break $a;case 4:v[b+822|0]=c&7;break $a;case 5:if(!(y[d+480209|0]&16)){break $a}g=x[d+480180>>2];if(g&69206025){a=a<<28>>24;w[b+772>>1]=a;if(!x[b+700>>2]){break $a}if(!Tc(y[b+788|0])){break $a}Ca=b,Da=zh(d,y[b+797|0],a,x[b+704>>2]),x[Ca+700>>2]=Da;break $a}f=Tc(y[b+788|0]);if((g|0)==16){if(!f){break $a}f=x[b+104>>2];if(!f){break $a}v[f+37|0]=a;w[b+772>>1]=a;if(!x[b+700>>2]){break $a}Ca=b,Da=zh(d,y[b+797|0],a,x[b+704>>2]),x[Ca+700>>2]=Da;break $a}if(!f){break $a}a=(c<<4^-128)<<24>>24;w[b+772>>1]=a;if(!x[b+700>>2]){break $a}Ca=b,Da=zh(d,y[b+797|0],a,x[b+704>>2]),x[Ca+700>>2]=Da;break $a;case 6:if(!(y[d+480209|0]&16)){break $a}vB(d,d+1074376|0,f,a);break $a;case 7:v[b+825|0]=c&7;break $a;case 8:if(!(y[d+480209|0]&16)){break $a}Zm(d,b,a,4);break $a;case 9:$A(d,f,a,0);break $a;case 10:if(a){Io(d,b,a,0);break $a}if(!(x[d+480180>>2]&1048580)){break $a}Io(d,b,0,0);break $a;case 11:if(a){Ho(d,b,a,0);break $a}if(!(x[d+480180>>2]&1048580)){break $a}Ho(d,b,0,0);break $a;case 12:dB(d,f,a,0);break $a;case 15:break ab;default:break $a}}if(x[d+480180>>2]==1){v[b+846|0]=a;if(!(y[d+480209|0]&16)){break $a}ES(d,b);break $a}v[b+844|0]=a}fb=e+16|0;break Ca;case 19:zS(d,r&65535,c);break Ca;case 24:Jb(i+8|0,o,55);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){if(x[d+1074392>>2]!=(c|0)){break Ca}a=x[h+656>>2];if(v[a+60|0]&1?a:0){break Ta}if(!(!(y[h+789|0]|y[h+790|0])|c)){x[h+88>>2]=x[h+88>>2]|4096;break Ta}x[h+688>>2]=0;x[h+88>>2]=x[h+88>>2]|2097152;break Ta}if(y[d+480209|0]&16){break Ta}break Ca;case 27:a=(c&240)-16>>>4|0;if(a>>>0>9){break Ca}if(!(1<<a&880)){if(a){if((a|0)!=1){break Ca}a=c&15;lB(d,h,a);Jb(i+8|0,o,117);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ca}Ao(d,r&65535,-224-a|0,1);break Ca}a=c&15;oB(d,h,a);Jb(i+8|0,o,117);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ca}Ao(d,r&65535,a|224,1);break Ca}Jb(i+8|0,o,58);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ca}zS(d,r&65535,c);break Ca;case 34:case 35:f=(H|0)==36;if(!(f|x[d+480208>>2]&4096)){break Ca}e=r&65535;g=G+D(e,872)|0;a=g+616|0;b=mT(d,z[d+1074446>>1],x[d+1074424>>2],e);bb:{if(!f){break bb}f=Jl(G)-x[G+16>>2]|0;if((f|0)<2){break bb}j=b;b=w[a+774>>1];b=gd(((j-b|0)/(f|0)|0)+b|0)}w[a+774>>1]=b;a=Eq(d,x[g+704>>2],x[a+656>>2]);if(a){ib[x[x[a>>2]+80>>2]](a,(b<<16>>16)+32768>>>2|0,e)}break Ca;case 20:if(!(y[d+480209|0]&16)|c>>>0>64){break Ca}x[h+748>>2]=c;x[h+88>>2]=x[h+88>>2]|2097152;break Ca;case 21:g=x[d+480180>>2];f=x[d+480208>>2];b=c;cb:{if(b){v[h+816|0]=b;break cb}b=y[h+816|0]}a=b&15;e=b&255;db:{eb:{if(!((a|0)!=15|e>>>0<16)){if(!(f&4096)){break db}a=e>>>4|0;break eb}f=f&4096;k=e&240;if(!(!a|(k|0)!=240)){if(!f){break db}a=0-a|0;break eb}if(f){break db}if(a){a=0-a|0;if(!k|!(g&25690144)){break eb}break db}if((b&255)>>>0<16){break db}a=e>>>4|0}Ca=h,Da=Yb(a+x[h+748>>2]|0,0,64),x[Ca+748>>2]=Da}break Ca;case 26:gT(h,c);break Ca;case 29:if(!(y[d+480209|0]&16)){break Ca}x[h+724>>2]=c;Jb(i+8|0,o,60);if(Ca=0,Da=Gb(x[x[i+8>>2]>>2],x[i+12>>2]),Fa=y[h+730|0]&4,Fa?Ca:Da){break Ca}x[h+740>>2]=c;x[h+732>>2]=c;break Ca;case 11:kT(d,G,r&65535);break Ca;case 13:a=jT(d,G,r&65535,c);if((a|0)==-1){break Ca}x[d+1074436>>2]=a;if(!(y[d+480208|0]&32)){break Ca}w[d+1074444>>1]=z[d+1074448>>1];break Ca;case 37:case 38:case 39:case 40:_S(d,h,c,(H|0)==38|(H|0)==40,(H&254)==40);break Ca;case 41:oT(h,c);break Ca;case 42:if(x[d+1074392>>2]|c>>>0>47){break Ca}b=c&15;if(b>>>0>1){break Ca}a=(c&240)==16;f=a?z[d+480188>>1]-1|0:r;a=a?0:r;b=((b|0)==1)<<25;while(1){e=a&65535;if(e>>>0>(f&65535)>>>0){break Ca}g=R+D(e,872)|0;k=x[g+88>>2];e=P+(e<<5)|0;x[e>>2]=b|x[e>>2]&-33554433;x[g+88>>2]=b|k&-33554433;a=a+1|0;continue};case 44:break Ua;default:break Ba}}nT(h,c);break Ca}Fo(d,h);break Ca}uT(d,G,c)}a=c}Jb(i+8|0,o,78);if(!(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])|!a)){dT(h,a&255)}a=y[h+789|0];if(!a){break K}v[h+804|0]=a}r=r+1|0;continue}break}a=1}fb=s+32|0;J=a&x[d+1074420>>2]!=0;fb:{if(!J){break fb}a=sT(d,d+1074376|0);x[d+1074380>>2]=a;x[d+1074404>>2]=a;b=Ld(z[d+480188>>1],1,31);gb:{if(Id(y[d+1074366|0])){a=x[d+24628>>2];if((a|0)>=129){a=((D(a-128|0,b+4|0)|0)/16|0)+128|0}o=((D(x[d+480228>>2],a)<<1&-128)>>>0)/y[(b>>>1|0)+30496|0]|0;break gb}o=x[d+480228>>2]}w[d+480212>>1]=0;j=d+1074478|0;P=d+480280|0;q=d+1074312|0;H=d+1074992|0;I=d+480210|0;G=d+480209|0;i=0;while(1){if((i|0)==256){a=x[d+24608>>2];b=z[d+480212>>1];if(a>>>0>b>>>0){break fb}k=fb-16|0;fb=k;x[k+12>>2]=d;c=j+(a<<1)|0;if((j|0)!=(c|0)){e=j+(b<<1)|0;h=k+12|0;hb:{a=c-j>>1;if((a|0)<2){break hb}b=a-2>>>1|0;while(1){if((b|0)<0){break hb}ER(j,x[h>>2],a,j+(b<<1)|0);b=b-1|0;continue}}a=c-j>>1;b=c;while(1){if((b|0)!=(e|0)){if(El(x[h>>2],z[b>>1],z[j>>1])){DR(b,j);ER(j,x[h>>2],a,j)}b=b+2|0;continue}break}a=c-j>>1;while(1){if((a|0)>1){g=z[j>>1];b=j;m=x[h>>2];f=0;e=a;i=a-2>>>1|0;while(1){l=f<<1;f=l|1;o=b+l|0;a=o+2|0;l=l+2|0;if((l|0)<(e|0)){q=l;l=o+4|0;o=El(m,z[a>>1],z[l>>1]);f=o?q:f;a=o?l:a}w[b>>1]=z[a>>1];b=a;if((f|0)<=(i|0)){continue}break}f=c-2|0;ib:{if((f|0)==(a|0)){w[a>>1]=g;break ib}w[b>>1]=z[f>>1];w[f>>1]=g;l=x[h>>2];b=b+2|0;a=b-j>>1;jb:{if((a|0)<2){break jb}f=a-2|0;a=j+(f&-2)|0;b=b-2|0;if(!El(l,z[a>>1],z[b>>1])){break jb}f=f>>>1|0;m=z[b>>1];while(1){kb:{g=b;b=a;w[g>>1]=z[a>>1];if(!f){break kb}a=f-1|0;f=a>>>1|0;a=j+(a&-2)|0;if(El(l,z[a>>1],m)){continue}}break}w[b>>1]=m}}a=e-1|0;c=c-2|0;continue}break}}fb=k+16|0}else{g=H+D(i,872)|0;lb:{if(!(x[g+88>>2]&4096)|(x[g+24>>2]|(x[g+20>>2]|x[g+696>>2]))){break lb}Jb(n+16|0,q,64);if(Gb(x[x[n+16>>2]>>2],x[n+20>>2])){break lb}x[g+76>>2]=0;x[g+92>>2]=0;x[g+96>>2]=0}c=z[d+480188>>1];b=x[g+88>>2];mb:{if(x[g+76>>2]|c>>>0>i>>>0?b&1024:1){if(c>>>0>i>>>0){JR(d,i&65535)}w[g+842>>1]=0;break mb}a=0;x[g+720>>2]=0;x[g+680>>2]=0;x[g+100>>2]=0;x[g+8>>2]=0;x[g+12>>2]=0;x[n+44>>2]=1065353216;w[n+42>>1]=0;s=x[g+656>>2];x[n+36>>2]=0;k=0;k=x[g+700>>2]?x[g+76>>2]!=0:k;nb:{ob:{pb:{if(c>>>0<=i>>>0){break pb}if(y[(P+(i<<5)|0)+8|0]){break ob}if(!s){break pb}a=y[s+34|0]!=0}if((a|k)!=1){break nb}}x[n+8>>2]=x[g+688>>2];x[n+32>>2]=x[g+752>>2];l=n+16|0;Jb(l,q,28);e=n+8|0;a=Gb(x[x[n+16>>2]>>2],x[n+20>>2])?n+32|0:e;b=d+1074312|0;qb:{if(Ob(b,28)){x[a>>2]=x[a>>2]+w[g+776>>1];Ge(a,0,64);break qb}c=Ob(b,1);b=w[g+776>>1];if(c){x[a>>2]=b+x[a>>2];Ge(a,0,256);break qb}x[g+688>>2]=b+x[g+688>>2];Ge(g+688|0,0,256);x[a>>2]=x[g+688>>2];w[g+776>>1]=0}rb:{sb:{a=d+1074312|0;if(!Ob(a,28)){if(!Ob(a,1)){break sb}}x[g+684>>2]=x[g+692>>2]+w[g+778>>1];Ge(g+684|0,0,256);break rb}x[g+692>>2]=x[g+692>>2]+w[g+778>>1];Ge(g+692|0,0,256);w[g+778>>1]=0;x[g+684>>2]=x[g+692>>2]}tb:{if(!(y[g+90|0]&4)|(x[d+480208>>2]&2101248)==2101248){break tb}ub:{if(x[e>>2]<=0){if(!Ob(d+1074312|0,21)){break ub}}c=5;if(!(y[d+480180|0]&5)){c=Ob(d+1074312|0,21)?5:6}a=KA(d,y[g+825|0],y[g+820|0]);vb:{if((y[g+825|0]&3)!=1){break vb}if(!Ob(d+1074312|0,89)){break vb}a=y[g+819|0];f=y[g+820|0];b=f<<2&124;a=(!(y[g+90|0]&2)|y[d+480209|0]&16?a:y[g+823|0]+a|0)&32?b^127:b;a=f&32?0-a|0:a}if(x[d+480180>>2]!=131072){a=x[e>>2]+((D(y[g+827|0],a)|0)/(1<<c)|0)|0}else{b=64-a|0;a=x[e>>2];a=((D(y[g+827|0],D(b,a))|0)/-8192|0)+a|0}x[e>>2]=a}a=x[d+480208>>2];if(!(x[d+480180>>2]&16777248)|a&4?a&4096:0){break tb}a=Ob(d+1074312|0,21);b=y[g+826|0];v[g+820|0]=y[g+820|0]+(a?b<<2:b)}f=fb-16|0;fb=f;a=d+1074312|0;Jb(f+8|0,a,71);h=i&65535;b=(D(h,872)+d|0)+1074992|0;wb:{if(Gb(x[x[f+8>>2]>>2],x[f+12>>2])){c=v[b+839|0];if((c|0)>=0){break wb}if(!(y[d+480209|0]&16|y[b+805|0]!=18)){xb:{yb:{if((c&-33)!=-64){a=c&223;if((a|0)!=128){break yb}c=y[b+840|0]>>>4|-64;break xb}c=y[b+840|0]&15|-128;break xb}c=a-1|0}v[b+839|0]=c;x[b+88>>2]=x[b+88>>2]|2097152}if((c&224)!=128){break wb}x[e>>2]=0;break wb}if(y[b+805|0]!=18){break wb}Jb(f+8|0,a,22);zb:{if(Gb(x[x[f+8>>2]>>2],x[f+12>>2])){a=y[b+839|0];c=a<<24>>24;if(!(!x[b+76>>2]|(c|0)>=0)){Ab:{Bb:{if((a|0)!=192){if((a|0)!=128){break Bb}c=y[b+840|0]>>>4|-64;break Ab}c=y[b+840|0]&15|-128;break Ab}c=c-1|0}v[b+839|0]=c}if((c&192)!=128){break zb}x[e>>2]=0;break zb}a=y[b+840|0];c=a>>>4|0;r=c+(a&15)|0;m=x[d+480180>>2];if(!(y[d+480208|0]&4?0:m&16777248)){r=r+2|0;c=c+1|0}a=y[b+839|0];if(!(m&4)){a=(a&255)>>>0<r>>>0?a:0;if((a&255)>>>0>=c>>>0){x[e>>2]=0}v[b+839|0]=a+1;break zb}Cb:{if(y[d+480209|0]&16){a=a&255;m=a-1|0;a=a>>>0>=m>>>0?m:0;break Cb}v[b+839|0]=a+1}if(((a&255)>>>0)%(r>>>0)>>>0<c>>>0){break zb}x[e>>2]=0}x[b+88>>2]=x[b+88>>2]|2097152}Db:{if(y[b+805|0]!=18){break Db}c=x[b+656>>2];if(!c){break Db}a=y[c+34|0];if(x[b+88>>2]&67109888|(!a|y[c+15|0]&2)){break Db}m=y[b+799|0];if(!Tc(m)){break Db}a=x[$d(d+906300|0,a-1|0)>>2];if(!a){break Db}m=ib[x[x[a>>2]+104>>2]](a,m,h)|0;r=x[e>>2];if(!(!m|r)){ib[x[x[a>>2]+96>>2]](a,c,y[b+799|0]|256,0,h);break Db}if(m|!r){break Db}ib[x[x[a>>2]+96>>2]](a,c,y[b+799|0],z[b+688>>1],h)}fb=f+16|0;Ge(e,0,256);x[n+8>>2]=x[n+8>>2]<<6;Eb:{if(s){Jb(l,q,31);if(Gb(x[x[n+16>>2]>>2],x[n+20>>2])){Nu(d,g)}a=n+8|0;Fb:{if(!HA(d,g,0)){break Fb}c=x[g+656>>2];e=d+1074312|0;f=Ob(e,31);b=x[g+724>>2];if(b?0:f){break Fb}l=b-Ob(e,31)|0;b=Rq(c+48|0,l,256,64);m=y[c+65|0];Gb:{if((m|0)==255){break Gb}f=w[g+728>>1];if((f|0)==-1){break Gb}m=yb(x[c+48>>2],m);r=y[m+2|0];c=r<<2;b=(l|0)==z[m>>1]?c:b;if(Ob(e,94)){b=f+(b-c<<1)|0;break Gb}if(!r){b=0;break Gb}b=(D(b,f)|0)/(c|0)|0}Ca=a,Da=(D(Yb(b,0,512),x[a>>2])|0)/256|0,x[Ca>>2]=Da}YS(g,a);Hb:{if(!HA(d,g,1)){break Hb}a=x[g+656>>2];b=d+1074312|0;f=Ob(b,31);c=x[g+732>>2];if(c?0:f){break Hb}b=Rq(a+68|0,c-Ob(b,31)|0,64,64)-32|0;a=x[g+684>>2];Ca=g,Da=Yb(((D(b,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),x[Ca+684>>2]=Da}Jb(n+16|0,q,115);if(Gb(x[x[n+16>>2]>>2],x[n+20>>2])){break Eb}b=y[g+797|0];if(!b){break Eb}a=x[g+656>>2];if(!a|!y[a+26|0]){break Eb}$S(g+684|0,b,y[a+26|0],y[a+27|0]);break Eb}if(!(y[g+89|0]&16)){break Eb}x[g+696>>2]=0;x[n+8>>2]=0}Ib:{if(y[g+851|0]&8){b=0;x[n+8>>2]=0;break Ib}b=x[n+8>>2];if(!b){b=0;break Ib}if(y[g+91|0]&4){x[g+680>>2]=0;break Ib}if(Id(y[d+1074365|0])){a=D(x[n+32>>2],x[g+748>>2]);c=a;f=a>>31;a=b<<8;Ca=g,Da=Gc(Bua(Aua(c,f,a,a>>31),hb,1048576,0),hb),x[Ca+680>>2]=Da;break Ib}a=D(x[n+32>>2],x[g+748>>2]);c=a;f=a>>31;a=D(x[d+1074456>>2],b);Ca=g,Da=Gc(Bua(Aua(c,f,a,a>>31),hb,1048576,0),hb),x[Ca+680>>2]=Da}r=g+700|0;x[g+720>>2]=b;Jb:{Kb:{b=x[g+700>>2];if(!(x[d+480180>>2]==2|(b|0)>=x[d+480260>>2])){if(!zj(d)){break Kb}b=x[r>>2]}if((b|0)<x[d+480264>>2]){break Jb}Jb(n+16|0,q,113);if(!Gb(x[x[n+16>>2]>>2],x[n+20>>2])){break Jb}if(zj(d)){break Jb}x[r>>2]=x[d+480264>>2];break Jb}x[r>>2]=x[d+480260>>2]}Jb(n+16|0,q,73);a=x[g+700>>2];x[n+36>>2]=a;Lb:{if((x[g+88>>2]&1572864)!=1572864){break Lb}b=x[d+480208>>2];if(b&2097152){if(!Kl(y[g+790|0],y[g+791|0])|b&4096){break Lb}}Mb:{if((a|0)==x[g+712>>2]){b=x[g+716>>2];break Mb}x[g+712>>2]=a;b=zh(d,Ku(d,a,w[g+772>>1],x[g+704>>2]),w[g+772>>1],x[g+704>>2]);x[g+716>>2]=b}x[n+36>>2]=b}l=fb-16|0;fb=l;a=D(h,872)+d|0;e=a+1074992|0;a=x[a+1075648>>2];Nb:{if(!a){break Nb}b=y[a+34|0];if(x[e+88>>2]&67109888|(!b|y[a+15|0]&2)){break Nb}if(!x[$d(d+906300|0,b-1|0)>>2]){break Nb}a=y[e+801|0];f=y[e+791|0];Ob:{Pb:{if((f|0)==1){b=a;Qb:{Rb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 0:b=a+(y[e+806|0]>>>4|0)|0;break Qb;case 1:break Rb;default:break Qb}}b=a+(y[e+806|0]&15)|0}if(y[e+800|0]==(b&255)){break Ob}if(!(v[e+851|0]&1)){break Pb}if(!Tc(y[e+788|0])){break Pb}if(Kl(y[e+790|0],1)){break Pb}break Ob}if(y[e+788|0]){b=a;if(!Kl(y[e+790|0],f)){break Ob}}b=a;if(!y[e+800|0]){break Ob}}Xm(d,h,b&255|512,z[e+688>>1])}c=y[e+800|0];Sb:{Tb:{if(c){if((f|0)!=1|(b&255)!=(c|0)){break Tb}break Sb}if(!(v[e+851|0]&1)|(f|0)!=1){break Sb}if(Tc(y[e+788|0])){break Sb}c=a;if(!Tc(a)){break Sb}}Xm(d,h,c&255|256,0)}v[e+800|0]=y[e+791|0]==1?b:0}Ub:{if(y[e+805|0]!=1){break Ub}if(Kj(x[e+656>>2])){b=0;Vb:{Wb:{switch((A[d+1074392>>2]%3|0)-1|0){case 0:b=y[e+806|0]>>>4|0;break Vb;case 1:break Wb;default:break Vb}}b=y[e+806|0]&15}w[n+42>>1]=b;v[e+851|0]=y[e+851|0]|96;break Ub}if(!(!(y[d+480209|0]&16)|x[d+480180>>2]!=1048576)){a=zh(d,y[e+797|0],w[e+772>>1],x[e+704>>2]);x[n+36>>2]=a;x[e+700>>2]=a}c=d+1074312|0;Jb(l+8|0,c,13);if(Gb(x[x[l+8>>2]>>2],x[l+12>>2])){b=y[e+806|0];if(!b){break Ub}a=65536;Xb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:b=b<<4;case 0:a=x[((b&240)<<2)+35504>>2];break;default:break Xb}}e=zj(d);b=x[n+36>>2];c=b>>31;if(e){a=Aua(b,c,a,a>>31);f=hb;a=a+32768|0;f=a>>>0<32768?f+1|0:f;a=Bua(a,f,65536,0);b=hb}else{e=(a|0)/2|0;f=e>>31;h=c<<16|b>>>16;c=b<<16;b=c+e|0;m=h+f|0;a=Bua(b,b>>>0<c>>>0?m+1|0:m,a,a>>31);b=hb}Ca=n,Da=Gc(a,b),x[Ca+36>>2]=Da;break Ub}Jb(l+8|0,c,51);if(Gb(x[x[l+8>>2]>>2],x[l+12>>2])){if(y[d+480209|0]&16){break Ub}Yb:{Zb:{a=x[d+1074416>>2];a=a-(A[d+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break Zb}if((a|0)==16){break Ub}b=0;_b:{switch((a|0)%3|0){case 0:break Ub;case 2:break Zb;case 1:break _b;default:break Yb}}b=y[e+806|0]>>>4|0;break Yb}b=y[e+806|0]&15}a=Ku(d,x[n+36>>2],w[e+772>>1],x[e+704>>2])+b|0;b=zh(d,a,w[e+772>>1],x[e+704>>2]);x[n+36>>2]=b;if(a>>>0<109){break Ub}x[l+8>>2]=b;Ca=l,Da=zh(d,109,0,x[e+704>>2]),x[Ca+4>>2]=Da;Ca=n,Da=x[bd(l+8|0,l+4|0)>>2],x[Ca+36>>2]=Da;break Ub}f=x[d+1074392>>2];a=x[d+480180>>2];$b:{if((a|0)!=1){b=y[e+797|0];break $b}b=Ku(d,x[n+36>>2],w[e+772>>1],x[e+704>>2]);a=x[d+480180>>2]}ac:{bc:{switch((((a&67633152?f+2|0:f)>>>0)%3|0)-1|0){case 0:b=(y[e+806|0]>>>4|0)+b|0;break ac;case 1:break bc;default:break ac}}b=(y[e+806|0]&15)+b|0}if(!(a&67633408|y[e+797|0]!=(b&255))){Jb(l+8|0,c,82);if(!Gb(x[x[l+8>>2]>>2],x[l+12>>2])){break Ub}}if(y[d+480210|0]&32){a=b&255;if((a|0)==85){x[n+36>>2]=2147483647;break Ub}b=a>>>0>85?b-37|0:b}a=zh(d,b&255,w[e+772>>1],x[e+704>>2]);x[n+36>>2]=a;if(x[d+480180>>2]&71860480){x[e+700>>2]=a;break Ub}Jb(l+8|0,c,82);if(!Gb(x[x[l+8>>2]>>2],x[l+12>>2])){break Ub}v[e+800|0]=b}fb=l+16|0;if(!(!(y[I|0]&33)|x[n+36>>2]==2147483647)){cc:{if(x[d+480180>>2]==2){b=452;a=3424;break cc}a=D(z[g+772>>1]>>>4&15,24);b=z[a+31238>>1]>>>1|0;b=b>>>0<=452?452:b;a=z[a+31216>>1]<<1}Ge(n+36|0,b,a);Ge(r,b,a)}eT(d,g);b=x[g+88>>2]}dc:{if(!(b&256)|y[G|0]&64){break dc}Jb(n+16|0,q,37);if(!Gb(x[x[n+16>>2]>>2],x[n+20>>2])){break dc}x[g+684>>2]=128}a=rT(d,g);ec:{if((a|0)<0|!(y[g+89|0]&2)){break ec}b=x[d+1298300>>2];if(!Ed(b)){break ec}Pq(b,i&65535,a&255,1)}l=i&65535;JR(d,l);fc:{if(!k){break fc}a=ZS(d,g,n+36|0);if((a|0)<0|!(y[g+89|0]&2)){break fc}b=x[d+1298300>>2];if(!Ed(b)){break fc}Pq(b,l,a>>>2&255,1)}gc:{if(y[g+790|0]!=8){break gc}hc:{ic:{a=y[g+791|0];switch(a-5|0){case 1:break gc;case 0:case 2:break hc;default:break ic}}if((a|0)!=26){break gc}}a=x[d+480180>>2];if((a|0)==4){if(y[G|0]&16){break gc}v[g+819|0]=y[g+819|0]+y[g+823|0];break gc}if(!(a&16777248)){break gc}Hl(g,y[g+792|0]);IR(d,l,n+36|0,n+44|0)}a=n+36|0;IR(d,l,a,n+44|0);jc:{if(!k){break jc}x[n+32>>2]=0;h=fb-16|0;fb=h;c=x[g+104>>2];kc:{if(!c|!y[c+40|0]){break kc}m=Kj(x[g+656>>2]);k=zj(d);b=k?36528:35504;e=k?35504:36528;if(!(m|!Ob(d+1074312|0,21)|x[d+480180>>2]==1048576)){r=y[c+41|0];if(!r){break kc}f=y[g+818|0];x[h+12>>2]=x[g+756>>2]+y[c+39|0];ui(h+12|0,y[c+40|0]<<8);m=x[h+12>>2];v[g+818|0]=f+r;x[g+756>>2]=m;m=(m|0)/256|0;lc:{mc:{switch(y[c+38|0]-1|0){case 3:f=GR(Eo(d))+-64|0;break lc;case 2:f=64-(f+1>>>1|0)|0;break lc;case 1:f=(f+1>>>1|0)+-64|0;break lc;case 0:f=(f^-1)>>>1&64;break lc;default:break mc}}f=v[f+31808|0]}ui(a,8388607);c=x[a>>2]<<8;x[a>>2]=c;u=D(f,m);m=(u|0)/64|0;f=m>>31;f=(f^m)-f|0;m=f&3;r=f>>>2|0;f=a;a=c>>31;L=a;nc:{oc:{if((u|0)<=-64){b=x[(r<<2)+b>>2];a=Gc(Bua(Aua(b,b>>31,c,a),hb,65536,0),hb)-c|0;if(!m){break nc}b=k?35440:35376;break oc}b=x[e+(r<<2)>>2];a=Gc(Bua(Aua(b,b>>31,c,a),hb,65536,0),hb)-c|0;if(!m){break nc}b=k?35376:35440}b=x[(m<<2)+b>>2];a=(Gc(Bua(Aua(c,L,b,b>>31),hb,65536,0),hb)+a|0)-c|0}x[f>>2]=(a+c|0)/256;x[n+32>>2]=a&255;break kc}k=x[d+480180>>2]&16777248;f=y[c+39|0];pc:{if(!(k|f)){x[g+756>>2]=y[c+40|0]<<8;break pc}qc:{if(k){x[g+756>>2]=x[g+756>>2]+(f<<1);k=y[c+40|0];break qc}k=y[c+40|0];if(y[g+89|0]&8){break qc}x[g+756>>2]=x[g+756>>2]+(((k<<8&65280)>>>0)/(f>>>0)|0)}ui(g+756|0,k<<8)}f=y[g+818|0]+y[c+41|0]|0;v[g+818|0]=f;f=f<<24>>24;rc:{sc:{switch(y[c+38|0]-1|0){case 3:v[g+818|0]=f+1;k=v[(f&63)+31744|0];break rc;case 2:k=(64-(f>>>1|0)&127)+-64|0;break rc;case 1:k=((f&254)>>>1^64)+-64|0;break rc;case 0:k=(f|0)>=0?-64:64;break rc;default:break sc}}k=0-v[(f&255)+31808|0]|0;if(x[d+480180>>2]!=1048576){break rc}k=(64-v[(f+-64&255)+31808|0]|0)/2<<16>>16}f=k;r=D(f,x[g+756>>2]);k=(r|0)/256|0;if(m){B[n+44>>2]=B[n+44>>2]+E(E(E(D(f,y[c+40|0])|0)*E(.05000000074505806))*E(.000244140625));v[g+851|0]=y[g+851|0]|64;break kc}if(x[d+480180>>2]!=4){tc:{if((r|0)<=-256){k=0-k|0;c=k>>>8|0;e=(c<<2)+b|0;break tc}b=e;c=k>>>8|0;e=b+(c<<2)|0}f=x[a>>2];c=x[((c<<2)+b|0)+4>>2];b=x[e>>2];b=((D(c-b|0,k>>>2&63)|0)/64|0)+b|0;b=Gc(Bua(Aua(f,f>>31,b,b>>31),hb,256,0),hb);x[a>>2]=b;x[n+32>>2]=b&255;x[a>>2]=x[a>>2]/256;break kc}x[a>>2]=x[a>>2]+((r|0)/16384|0)}fb=h+16|0;k=x[n+36>>2];if((k|0)<=x[d+480260>>2]){Jb(n+16|0,q,81);if(Gb(x[x[n+16>>2]>>2],x[n+20>>2])){x[g+76>>2]=0}k=x[d+480260>>2];x[n+36>>2]=k}uc:{if(!Kj(x[g+656>>2])){break uc}a=y[g+851|0];if(!(x[d+1074392>>2]|!(a&32)?a&64:1)){break uc}eV(g,B[n+44>>2],w[n+42>>1],d);a=y[g+851|0];v[g+851|0]=(a&64?-65:-97)&a}a=n+16|0;yB(a,d,g,k,x[n+32>>2]);c=Ab(a);a=Aua(x[n+16>>2],x[n+20>>2],x[d+480240>>2],0);m=hb;b=Bua(a,m,65536,0);e=hb;f=b;a=a+65535|0;b=!(a>>>0<65535?m+1|0:m)&a>>>0<131071;a=b?1:f;x[n+16>>2]=a;b=b?0:e;x[n+20>>2]=b;x[g+8>>2]=a;x[g+12>>2]=b;if((x[g+88>>2]&67110400)!=512){break jc}if(!Ed(x[d+1298300>>2])){break jc}Jb(n+8|0,q,99);a=x[g+88>>2];b=a&4096;vc:{wc:{if(Ca=Gb(x[x[n+8>>2]>>2],x[n+12>>2]),Da=1,Fa=b,Fa?Ca:Da){e=x[d+480180>>2];break wc}e=x[d+480180>>2];if((e|0)!=2){break vc}}f=(e|0)==2;e=a&2048;xc:{if(e?f:0){break xc}a=x[d+480240>>2];c=Aua(x[c>>2],0,261625,0);f=hb;c=c+66904|0;f=c>>>0<66904?f+1|0:f;a=Aua(a,0,Bc(Cua(c,f,133808,0),hb),0);m=hb;a=a+32768|0;m=a>>>0<32768?m+1|0:m;c=Bc((m&65535)<<16|a>>>16,m>>>16|0);a=1;yc:{if(e){break yc}a=0;if(!b){break yc}a=!x[g+696>>2]}b=n+8|0;Jb(b,q,110);if(Ca=Gb(x[x[n+8>>2]>>2],x[n+12>>2]),Da=0,Fa=a,Fa?Ca:Da){break xc}e=x[d+1298300>>2];Jb(b,q,95);SB(e,l,c,a,Gb(x[x[n+8>>2]>>2],x[n+12>>2]))}a=x[d+1298300>>2];b=Aua(D(x[g+752>>2],D(x[g+748>>2],x[g+720>>2])),0,63,0);h=hb;b=b+33554432|0;h=b>>>0<33554432?h+1|0:h;Pq(a,l,Bc((h&67108863)<<6|b>>>26,h>>>26|0)&255,0);b=x[g+684>>2];c=0;a=x[d+1298300>>2];e=Ql(a,l);zc:{if((e|0)==255){break zc}f=x[a>>2];if(Fj(f)){break zc}c=xb(Vd(a+318|0,e),10);h=x[a+4>>2];e=bv(e)|192;a=y[c|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;Ah(f,h,l,e,a&255);c=(a>>>5&1)+(a<<27>>31)|0}x[g+684>>2]=(c<<7)+128}Ac:{a=x[g+656>>2];if(!a|(y[a+60|0]&7)!=1){break Ac}b=x[a+48>>2];a=x[a+52>>2];if(mc(b,a)){break Ac}b=x[HR(g,0)>>2];a=xf(a);if(b>>>0<z[a>>1]|y[a+2|0]){break Ac}Ej(x[d+1298300>>2],l,1);Jb(n+8|0,q,109);a=x[x[n+8>>2]>>2];b=x[n+12>>2];x[g+696>>2]=0;c=x[g+88>>2];Ca=g,Da=(Gb(a,b)?c:c&-4609)|4096,x[Ca+88>>2]=Da;break jc}Jb(n+8|0,q,99);if(!Gb(x[x[n+8>>2]>>2],x[n+12>>2])|!(y[g+89|0]&16)|x[g+696>>2]){break jc}Ej(x[d+1298300>>2],l,1);x[g+88>>2]=x[g+88>>2]&-513}Bc:{if(!s){break Bc}Jb(n+16|0,q,31);if(Gb(x[x[n+16>>2]>>2],x[n+20>>2])){break Bc}Nu(d,g)}x[g+672>>2]=0;x[g+676>>2]=0;a=y[g+842|0];b=a-4|0;b=a>>>0>=b>>>0?b:0;v[g+842|0]=b;a=y[g+843|0];c=a-4|0;a=a>>>0>=c>>>0?c:0;v[g+843|0]=a;f=x[g+88>>2];h=x[g+680>>2];e=f&-65537|(h|(x[g+24>>2]|x[g+20>>2])?!(f&512)<<16:0);x[g+88>>2]=e;Cc:{Dc:{Ec:{Fc:{Gc:{Hc:{Ic:{Jc:{Kc:{c=x[g+104>>2];Lc:{if(!c){break Lc}k=x[c+20>>2];if(!le(x[c>>2],k)|!x[g+76>>2]){break Lc}if(Mi(x[g+8>>2],x[g+12>>2])){break Kc}}x[g+16>>2]=0;break Jc}x[g+16>>2]=k;if(k){break Ic}}if(!Bj(x[g+656>>2])){break Hc}k=0;if(f&6144){break Hc}}l=x[g+684>>2];c=(D(h,256-l|0)|0)/16384|0;c=c>>>0>=127?127:c;if(b<<24>>24<0){v[g+842|0]=c;m=c}else{m=b}b=c>>>1|0;if((m&255)>>>0<b>>>0){v[g+842|0]=b}b=(D(h,l)|0)/16384|0;b=b>>>0>=127?127:b;if(a<<24>>24<0){v[g+843|0]=b;a=b}b=b>>>1|0;if(b>>>0>(a&255)>>>0){break Gc}break Fc}if((b&255)>>>0>=129){v[g+842|0]=0}k=0;b=0;if((a&255)>>>0<129){break Ec}}v[g+843|0]=b}if(!k){break Ec}k=128;e=x[d+24624>>2];if(e>>>0>=2){k=Yb(x[g+684>>2],0,256)}x[n+16>>2]=k;b=D(h,o)>>>(Id(y[d+1074366|0])?7:8)|0;Mc:{Nc:{Oc:{switch(y[d+1074364|0]){case 0:if(!(y[d+24616|0]&16)){break Nc}case 1:if((k|0)<=127){a=b>>>1|0;c=(D(b,k)|0)/256|0;break Mc}a=(D(b,256-k|0)|0)/256|0;c=b>>>1|0;break Mc;case 3:break Oc;default:break Nc}}ui(n+16|0,255);c=x[n+16>>2];if((c|0)<=0){a=65536}else{a=z[(0-c<<1)+38064>>1]}a=D(a,b)>>>16|0;c=D(b,z[(c<<1)+37552>>1])>>>16|0;break Mc}a=(D(b,256-k|0)|0)/256|0;c=(D(b,k)|0)/256|0}b=x[g+656>>2];Pc:{if(b){k=y[b+14|0];if(up(k)){break Pc}}k=y[d+480268|0];if(up(k)){break Pc}b=y[d+24648|0];k=y[I|0]&128?x[d+24668>>2]?-1:b:b}v[g+794|0]=k;b=x[g+8>>2];h=x[g+12>>2];if(!(f&131072|((b|0)!=0|(h|0)!=1)|(x[g+756>>2]|(k&255)==255))){v[g+794|0]=0}k=a;a=1<<x[d+1074360>>2];x[g+672>>2]=(k|0)/(a|0);a=(c|0)/(a|0)|0;x[g+676>>2]=(f&256)>>>8|0?(e|0)==2?0-a|0:a:a;if(f&128){x[g+8>>2]=0-b;x[g+12>>2]=0-(((b|0)!=0)+h|0)}r=0;h=fb-16|0;fb=h;x[g+28>>2]=0;x[g+32>>2]=0;ui(g+672|0,524287);ui(g+676|0,524287);a=x[g+676>>2];b=x[g+672>>2];Qc:{Rc:{c=x[g+88>>2];if(!(c&65536)){break Rc}e=x[g+20>>2];f=x[g+24>>2];if((e|0)==(b|0)&(f|0)==(a|0)){break Rc}c=x[d+24620>>2];e=(b|0)<=(e|0)&(a|0)<=(f|0);Sc:{if(!e){a=fv(c,x[d+24636>>2]);break Sc}a=fv(c,x[d+24640>>2])}if(!(!Ob(d+1074312|0,4)|!(y[d+480180|0]&4))){a=x[d+24620>>2];a=Aua(a,a>>31,5,0);f=hb;a=a+500|0;f=a>>>0<500?f+1|0:f;a=Gc(Bua(a,f,1e3,0),hb)}b=a;c=x[g+656>>2];Tc:{if(e|!c){break Tc}c=z[c+12>>1];if(!c){break Tc}r=1;b=(D(c,x[d+24620>>2])>>>0)/1e5|0}c=b>>>0<=1?1:b;f=x[g+672>>2];l=x[g+20>>2];m=f-l<<12;L=g;e=x[g+676>>2];b=x[g+24>>2];k=e-b<<12;if(!(y[g+90|0]&32|(!(e|f)|(!(b|l)|r)))){x[h+12>>2]=x[d+1074380>>2];Ge(h+12|0,a,2048);c=x[h+12>>2]}k=(k|0)/(c|0)|0;x[L+32>>2]=k;l=(m|0)/(c|0)|0;x[g+28>>2]=l;a=e+((D(c,k)|0)/-4096|0)|0;x[g+24>>2]=a;b=f+((D(c,l)|0)/-4096|0)|0;x[g+20>>2]=b;if(k|l){x[g+100>>2]=c;c=x[g+88>>2];break Qc}x[g+24>>2]=e;x[g+20>>2]=f;a=e;b=f;c=x[g+88>>2]&-65537;break Qc}x[g+24>>2]=a;x[g+20>>2]=b;c=c&-65537}x[g+88>>2]=c&-2097153;x[g+40>>2]=a<<12;x[g+36>>2]=b<<12;fb=h+16|0;e=x[g+88>>2];if(!(e&512)){break Dc}break Cc}x[g+76>>2]=0;x[g+20>>2]=0;x[g+24>>2]=0;if(x[g+96>>2]){break Dc}if(!x[g+92>>2]){break Cc}}a=z[d+480212>>1];w[d+480212>>1]=a+1;w[j+(a<<1)>>1]=i}x[g+668>>2]=e;v[g+851|0]=y[g+851|0]&253}i=i+1|0;continue}break}}fb=n+48|0;if(J){b=x[d+480208>>2];break h}if(Id(y[d+1298424|0])){a=x[d+480208>>2]|512;break i}f=0;Uc:{a=x[d+24620>>2]/10|0;b=Gc(a,a>>31);if(!b){break Uc}c=b>>>0>=1048576?1048576:b;x[d+1074380>>2]=c;e=d+1074478|0;g=d+1074992|0;h=z[d+480212>>1];while(1){if((h|0)==(f|0)){break Uc}a=g+D(z[e+(f<<1)>>1],872)|0;x[a+672>>2]=0;x[a+676>>2]=0;x[a+100>>2]=c;k=x[a+24>>2]<<12;x[a+40>>2]=k;n=x[a+20>>2]<<12;x[a+36>>2]=n;x[a+88>>2]=x[a+88>>2]|65536;x[a+28>>2]=(0-n|0)/(c|0);x[a+32>>2]=(0-k|0)/(c|0);f=f+1|0;continue}}c=x[d+480208>>2];a=c|256;if(b){break i}a=c|512}b=a;x[d+480208>>2]=b}if(!(b&512)){break g}Ca=d,Da=Jl(va),x[Ca+1074392>>2]=Da}fb=C+96|0;break f}x[C+80>>2]=512;a=x[d+1074380>>2];x[C+88>>2]=ca;x[C+84>>2]=a;n=uE(C+80|0);if(x[d+24632>>2]){k=0;a=fb-48|0;fb=a;b=d+16396|0;c=n<<2;while(1){if((k|0)==4){Vc:{k=0;while(1){if((k|0)==4){break Vc}x[(a+32|0)+(k<<2)>>2]=b+(k<<11);k=k+1|0;continue}}}else{x[a+32>>2]=0;e=b+(k<<11)|0;Zz(e,c+e|0,a+32|0);k=k+1|0;continue}break}b=x[d+24632>>2];x[a+28>>2]=n;x[a+24>>2]=b;x[a+20>>2]=a+32;b=x[x[ba>>2]+8>>2];x[a+16>>2]=n;c=x[a+24>>2];x[a+8>>2]=x[a+20>>2];x[a+12>>2]=c;ib[b|0](ba,a+8|0);fb=a+48|0}if(Id(ta)){b=0;while(1){if((b|0)==4){a=x[d+24632>>2];x[C+76>>2]=n;x[C+72>>2]=a;x[C+68>>2]=C+80;a=x[x[ia>>2]+8>>2];x[C+40>>2]=n;b=x[C+72>>2];x[C+32>>2]=x[C+68>>2];x[C+36>>2]=b;ib[a|0](ia,C+32|0)}else{x[(C+80|0)+(b<<2)>>2]=(b<<11)+ua;b=b+1|0;continue}break}}M=0;l=fb-48|0;fb=l;if(n){G=d+12|0;J=d+24592|0;P=d+24588|0;Kn(G,n,J,P);if(A[d+24624>>2]>=3){Kn(d+8204|0,n,d+24600|0,d+24596|0)}w[l+42>>1]=0;da=d+484380|0;_=d+1074312|0;ea=d+24648|0;V=d+906300|0;fa=d+24596|0;wa=d+24600|0;xa=d+8204|0;q=d+397452|0;s=d+397448|0;I=d+393352|0;U=d+397456|0;ya=d+1074478|0;za=d+1074992|0;Aa=d+1074376|0;while(1){if(z[d+480212>>1]<=M>>>0){Ca=d,Da=z[qe(d+480214|0,l+42|0)>>1],w[Ca+480214>>1]=Da}else{f=ya+(M<<1)|0;u=z[f>>1];j=za+D(u,872)|0;Wc:{if(!(x[j+16>>2]|x[j+96>>2]|x[j+92>>2])){break Wc}a=y[j+794|0]+1&255;if(a>>>0<=5){h=x[(a<<2)+26144>>2]}else{h=0}g=x[j+88>>2];Xc:{if(!(y[d+24612|0]&32)|(g&16777216)>>>24){b=P;c=J;e=g;a=G;if(!(g&8388608)){break Xc}}if(!y[U+12|0]){Kn(I,n,s,q)}v[U+12|0]=1;u=z[f>>1];e=x[j+88>>2];b=q;c=s;a=I}f=b;b=e>>>8&A[d+24624>>2]>2;H=b?fa:f;K=b?wa:c;c=b?xa:a;$=om(d,Aa,u&65535,2,1)-1|0;na=($&255)>>>0>249;Yc:{if(na){break Yc}b=x[$d(V,$)>>2];if(!b){break Yc}a=x[b+24>>2];if(!a){break Yc}H=b+36|0;K=b+40|0;if(!(v[b+28|0]&1)){Kn(a,n,K,H);x[b+28>>2]=x[b+28>>2]|1}c=a}if(y[j+851|0]&8){XF(j,c,n);x[K>>2]=x[K>>2]+x[j+92>>2];x[H>>2]=x[H>>2]+x[j+96>>2];x[j+92>>2]=0;x[j+96>>2]=0;break Wc}L=0;a=l+20|0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;b=d+1074312|0;Ca=a,Da=Ob(b,33),v[Ca+16|0]=Da;Ca=a,Da=Ob(b,116)^1,v[Ca+17|0]=Da;if(x[j+16>>2]){WF(a,j);b=x[j+12>>2];f=b>>31;e=f;k=e^x[j+8>>2];b=(b^e)-((e>>>0>k>>>0)+e|0)|0;x[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Ba=g>>>12&8|(g>>>5&2|(h|g&1));R=j+76|0;r=a;b=n;while(1){Zc:{a=x[j+100>>2];X=a?a>>>0>b>>>0?b:a:b;x[l+12>>2]=X;_c:{$c:{if(!X){break $c}g=x[j+8>>2];a=x[j+12>>2];if(!(g|a)){break $c}h=x[R>>2];if(!h){break $c}e=x[r>>2];if(!e){break $c}u=x[j+88>>2];i=u&2;m=x[j+80>>2];x[j+16>>2]=e;e=x[j>>2];ad:{bd:{k=m&u<<30>>31;f=x[j+4>>2];if((k|0)>(f|0)){if((a|0)<0){e=hh(0,k<<1,e,f);x[j>>2]=e;f=hb;x[j+4>>2]=f;if(!(f>>>0<h+k>>>1>>>0&(f|0)>=(k|0))){e=0;x[j>>2]=e;f=k;x[j+4>>2]=f}cd:{if(u&4){a=0-(((g|0)!=0)+a|0)|0;g=0-g|0;x[j+8>>2]=g;x[j+12>>2]=a;u=u&-129;x[j+88>>2]=u;break cd}x[j>>2]=e;f=h-1|0;x[j+4>>2]=f}if(!i){break $c}if(h>>>0>f>>>0){break ad}break $c}if((f|0)>0|(f|0)>=0){break ad}f=0;break bd}if(h>>>0>f>>>0){break ad}if(!i){break $c}if(u&4){if(!!g&(a|0)>=0|(a|0)>0){a=0-(((g|0)!=0)+a|0)|0;g=0-g|0;x[j+8>>2]=g;x[j+12>>2]=a}u=u|128;x[j+88>>2]=u;if(y[l+37|0]){i=y[l+36|0];o=x[j+84>>2]-(i+m|0)|0;e=hh(e,f,0,h);f=hb;if(f>>>0<o>>>0){e=hh(0,h-i|0,e,f);f=hb;break bd}f=m;e=0;break bd}i=0-e|0;o=(h<<1)-((1-((e|0)!=0)|0)+f|0)|0;f=o;e=i;x[j>>2]=e;Y=0;f=Y|f;x[j+4>>2]=f;if(m>>>0<o>>>0&h>>>0>o>>>0){break ad}x[l+44>>2]=y[l+36|0]+1;f=Y|h-x[Hb(R,l+44|0)>>2];break bd}if((a|0)<0){a=0-(((g|0)!=0)+a|0)|0;g=0-g|0;x[j+8>>2]=g;x[j+12>>2]=a}Pb(j,0,m-h|0);u=x[j+88>>2]|8192;x[j+88>>2]=u;e=x[j>>2];f=x[j+4>>2];break ad}x[j>>2]=e;x[j+4>>2]=f}dd:{if((f|0)<(k|0)){if((a|f)<0){break $c}x[l+44>>2]=X;h=g;m=a;break dd}h=x[R>>2];if(h>>>0<f>>>0|(!!g&(a|0)>=0|(a|0)>0)&(h|0)==(f|0)){break $c}x[l+44>>2]=X;h=a>>31;i=h;o=h^g;h=o-h|0;m=(a^i)-((i>>>0>o>>>0)+i|0)|0}i=h;o=m;xc(l+12|0,x[l+32>>2]);oa=x[l+12>>2];fg(e,f,uf(g,a,oa-1|0),hb);m=hb;h=x[j+80>>2];pa=h>>>0>f>>>0|f>>>0>=h+16>>>0;if(pa){u=u&-8193;x[j+88>>2]=u}ed:{fd:{Y=x[l+24>>2];gd:{if(Y){h=x[l+28>>2];if(h>>>0<=f>>>0){hd:{if((a|0)<0){g=0;a=h;break hd}g=e;a=f;e=0;f=x[j+84>>2]}Ca=l,Da=Gp(hh(hh(e,f,g,a),hb,1,0),hb,i,o)+1|0,x[Ca+44>>2]=Da;x[j+16>>2]=Y;break ed}if(!(pa|!(u&8192))){Ca=l,Da=Gp(hh(hh(0,k+16|0,e,f),hb,1,0),hb,i,o)+1|0,x[Ca+44>>2]=Da;Ca=j,Da=Y+D(x[j+84>>2]-k|0,Zk(z[x[j+104>>2]+34>>1]))|0,x[Ca+16>>2]=Da;break ed}if(!g&(a|0)<=0|(a|0)<0){break gd}if(X>>>0<2|h>>>0>m>>>0){break fd}Ca=l,Da=Gp(hh(hh(0,h,e,f),hb,1,0),hb,i,o)+1|0,x[Ca+44>>2]=Da;break ed}if((a|0)>0|(a|0)>=0){break fd}}if((k|0)<=(m|0)){break ed}Ca=l,Da=Gp(hh(hh(e,f,0,k),hb,1,0),hb,i,o)+1|0,x[Ca+44>>2]=Da;break ed}h=x[R>>2];if((h|0)>(m|0)){break ed}Ca=l,Da=Gp(hh(hh(0,h,e,f),hb,1,0),hb,i,o)+1|0,x[Ca+44>>2]=Da}Fp(l+44|0,1,oa);f=x[l+44>>2];if((f|0)>0){break _c}}x[j+76>>2]=0;x[j+16>>2]=0;x[j+100>>2]=0;x[j>>2]=0;x[j+4>>2]=0;XF(j,c,b);x[K>>2]=x[K>>2]+x[j+92>>2];x[H>>2]=x[H>>2]+x[j+96>>2];x[j+92>>2]=0;x[j+96>>2]=0;x[j+88>>2]=x[j+88>>2]&-129;break Zc}id:{jd:{if(A[d+24608>>2]>z[l+42>>1]){a=4;if(x[j+100>>2]){break jd}a=0;if(x[j+24>>2]|x[j+20>>2]){break jd}}Pb(j,uf(x[j+8>>2],x[j+12>>2],f),hb);x[j+92>>2]=0;x[j+96>>2]=0;L=0;c=(f<<3)+c|0;break id}e=(f<<3)+c|0;g=e-8|0;x[j+92>>2]=0-x[g>>2];h=e-4|0;x[j+96>>2]=0-x[h>>2];ib[x[((a|Ba)<<2)+25760>>2]](j,ea,c,f);x[j+92>>2]=x[j+92>>2]+x[g>>2];x[j+96>>2]=x[j+96>>2]+x[h>>2];L=1;c=e}a=x[j+100>>2];kd:{if(!a){break kd}if(a>>>0<=f>>>0){x[j+100>>2]=0;x[j+28>>2]=0;x[j+32>>2]=0;a=x[j+676>>2];x[j+20>>2]=x[j+672>>2];x[j+24>>2]=a;if(x[j+696>>2]|!(y[j+89|0]&16)){break kd}x[j+16>>2]=0;x[j+76>>2]=0;break kd}x[j+100>>2]=a-f}i=0;u=0;a=x[j+4>>2];u=a>>>0>=A[j+84>>2]?(y[j+88|0]&2)>>>1|0:u;e=a;a=x[R>>2];i=x[j+88>>2]&2|(e>>>0<a>>>0|!a)?i:!z[j+786>>1];b=b-f|0;Jb(l+12|0,_,85);ld:{md:{nd:{if(!Gb(x[x[l+12>>2]>>2],x[l+16>>2])){break nd}a=y[j+803|0];if(!a){break nd}if(a>>>0<=z[d+480190>>1]){break md}}e=0;break ld}f=x[j+104>>2];a=da+D(a,104)|0;e=(f|0)!=(a|0);if((a|0)==(f|0)|(i|u)!=1){break ld}x[j+104>>2]=a;e=x[a+20>>2];x[j+16>>2]=e;f=z[a+34>>1];x[j+88>>2]=f|x[j+88>>2]&-768;g=f<<30>>31;f=x[a+8>>2];x[j+76>>2]=g&f;a=x[a+4>>2];x[j+84>>2]=f;x[j+80>>2]=a;x[j+4>>2]=a;WF(r,j);if(!e){break Zc}if((b|0)>0){continue}break Zc}od:{if(!u|e){break od}Jb(l+12|0,_,83);if(!Gb(x[x[l+12>>2]>>2],x[l+16>>2])|x[j+80>>2]){break od}x[j>>2]=x[j>>2];x[j+4>>2]=0;a=x[x[j+104>>2]+8>>2];x[j+84>>2]=a;x[j+76>>2]=a}if((b|0)>0){continue}}break}x[j+16>>2]=x[r>>2];w[l+42>>1]=z[l+42>>1]+L;if(na|!L){break Wc}a=x[$d(V,$)>>2];if(!a){break Wc}ib[x[x[a>>2]+152>>2]](a)}M=M+1|0;continue}break}}fb=l+48|0;r=x[d+1298300>>2];if(Ed(r)){b=W;a=n;c=(D(x[d+480232>>2],x[d+480236>>2])>>>0)/48|0;k=fb-16|0;fb=k;pd:{if(!y[r+534|0]){break pd}e=Aua(c,0,6169,0);c=hb;m=c>>>16|0;q=Bc((c&65535)<<16|e>>>16,m);while(1){if(!a){break pd}h=x[r>>2];e=x[h>>2];c=x[h+4>>2];while(1){if((c|0)>=(e|0)){x[h+8>>2]=x[h+12>>2];e=0;j=0;i=0;c=fb-16|0;fb=c;I=h+16|0;while(1){if((i|0)==18){e=(e|0)>=32767?32767:e;w[h+12>>1]=(e|0)<=-32768?-32768:e;e=(j|0)>=32767?32767:j;w[h+14>>1]=(e|0)<=-32768?-32768:e;w[h+3832>>1]=z[h+3832>>1]+1;e=(z[h+3834>>1]+1>>>0)%13440|0;w[h+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;w[h+3836>>1]=e>>>8;if(!y[h+3843|0]){w[h+3836>>1]=e>>>10}e=z[h+3838>>1]+1|0;w[h+3838>>1]=e;if((e&65535)>>>0>=1024){w[h+3838>>1]=0;w[h+3840>>1]=z[h+3840>>1]+1&7}fb=c+16|0}else{g=I+D(i,44)|0;qd:{if(!y[g+40|0]){w[c+12>>1]=0;w[c+14>>1]=0;break qd}l=x[g+16>>2];f=z[l+3840>>1];if(f&3){l=(z[g+20>>1]>>>7&7)>>>(y[l+3844|0]^1)>>>(f&1)<<z[g+22>>1];f=f&4?0-l|0:l}else{f=0}l=x[g+36>>2];rd:{if(l){G=z[l+32>>1];s=z[g+32>>1];f=f<<16>>16;l=Eg(x[g>>2],x[g+24>>2],f,0,w[g+30>>1]);m=x[g+24>>2];o=x[g+4>>2];if(!G){if(!s){l=Eg(o,m,f,l,0);l=Eg(x[g+8>>2],x[g+24>>2],f,l,0);f=Eg(x[g+12>>2],x[g+24>>2],f,l,0);break rd}m=Eg(o,m,f,0,0);m=Eg(x[g+8>>2],x[g+24>>2],f,m,0);f=Eg(x[g+12>>2],x[g+24>>2],f,m,0)+l|0;break rd}if(!s){l=Eg(o,m,f,l,0);m=Eg(x[g+8>>2],x[g+24>>2],f,0,0);f=Eg(x[g+12>>2],x[g+24>>2],f,m,0)+l|0;break rd}m=Eg(o,m,f,0,0);f=(Eg(x[g+8>>2],x[g+24>>2],f,m,0)+l|0)+Eg(x[g+12>>2],x[g+24>>2],f,0,0)|0;break rd}s=z[g+32>>1];f=f<<16>>16;l=Eg(x[g>>2],x[g+24>>2],f,0,w[g+30>>1]);m=x[g+24>>2];o=x[g+4>>2];if(!s){f=Eg(o,m,f,l,0);break rd}f=Eg(o,m,f,0,0)+l|0}w[c+14>>1]=y[g+41|0]?f:0;w[c+12>>1]=y[g+42|0]?f:0}i=i+1|0;j=w[c+12>>1]+j|0;e=w[c+14>>1]+e|0;continue}break}e=x[h>>2];c=x[h+4>>2]-e|0;x[h+4>>2]=c;continue}break}f=e-c|0;w[k+14>>1]=(D(w[h+12>>1],c)+D(f,w[h+8>>1])|0)/(e|0);w[k+12>>1]=(D(w[h+14>>1],c)+D(f,w[h+10>>1])|0)/(e|0);x[h+4>>2]=c+49716;x[b>>2]=x[b>>2]+D(q,w[k+14>>1]);x[b+4>>2]=x[b+4>>2]+D(q,w[k+12>>1]);b=b+8|0;a=a-1|0;continue}}fb=k+16|0}a=y[t+12|0];if(a|x[t+16>>2]){if(!a){Kn(Z,n,ma,la)}a=x[t>>2];b=x[t+80>>2];c=D(a,b)>>>4|0;c=c>>>0>=32767?32767:c;w[t+98>>1]=c;w[t+96>>1]=c;c=x[t+49948>>2];e=D(c,a)>>>4|0;e=e>>>0>=65536?65536:e;f=e+127>>>3|0;w[t+49946>>1]=f;e=e+255>>>4|0;w[t+49944>>1]=e;w[t+49942>>1]=e;w[t+49940>>1]=f;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0<=8?8:a)|0;a=16-(D((b|0)>=32768?32768:b,a>>>0<=16?a:0)>>15)|0;k=0;while(1){if((k|0)!=(n|0)){b=k<<3;c=b+W|0;x[c>>2]=x[c>>2]+D(a,x[b+Z>>2]>>4);b=b|4;c=b+W|0;x[c>>2]=x[c>>2]+D(a,x[b+Z>>2]>>4);k=k+1|0;continue}break}j=t+68|0;e=0;f=x[t+40>>2];g=x[t+36>>2];b=w[t+84>>1];while(1){if((e|0)==(n|0)){x[t+40>>2]=f;x[t+36>>2]=g;h=n}else{a=(e<<3)+Z|0;c=x[a>>2]>>12;g=(D(b,c-g|0)>>15)+c|0;x[a>>2]=g;c=a;a=x[a+4>>2]>>12;f=(D(b,a-f|0)>>15)+a|0;x[c+4>>2]=f;e=e+1|0;continue}break}if(h){a=Z;b=h;o=j+160|0;g=j+32928|0;e=x[j>>2]-1|0;c=z[j+22>>1];q=z[j+20>>1];k=w[j+26>>1];l=w[j+24>>1];r=w[j+18>>1];s=w[j+16>>1];f=x[j+4>>2];while(1){if(b){m=pd(x[a>>2]);i=pd(x[a+4>>2]);q=pd((q<<16>>16)-m|0);c=pd((c<<16>>16)-i|0);q=gd(pd((D(q,s)|0)/65536<<1)+m|0);c=gd(pd((D(c,r)|0)/65536<<1)+i|0);i=g+(f<<2)|0;I=w[i>>1];m=gd(((D(I,l)|0)/-65536|0)+q|0);f=f+1&127;G=g+(f<<2)|0;i=w[i+2>>1];J=gd(((D(i,k)|0)/-65536|0)+c|0);w[G+2>>1]=J;w[G>>1]=m;e=e+1&8191;G=o+(e<<2)|0;Ca=G,Da=gd(I+((D(l,m)|0)/65536|0)|0),w[Ca>>1]=Da;Ca=G,Da=gd(i+((D(k,J)|0)/65536|0)|0),w[Ca+2>>1]=Da;a=a+8|0;b=b-1|0;continue}break}w[j+22>>1]=c;w[j+20>>1]=q;x[j+4>>2]=f}k=t+49892|0;I=t+33508|0;a=h;b=Z;while(1){if(a){c=x[t+76>>2];e=c&4095;r=I+(e<<2)|0;f=b;e=4096-e|0;P=c-x[t+49892>>2]&4095;c=4096-P|0;c=c>>>0>e>>>0?e:c;c=a>>>0<c>>>0?a:c;g=c>>>0>=64?64:c;q=g;c=0;l=fb-32|0;fb=l;m=j+32|0;e=x[j>>2];while(1){if((c|0)==7){sd:{s=j+160|0;G=w[j+28>>1]/8<<16>>16;td:while(1){if(!q){break sd}q=q-1|0;c=0;i=0;e=0;while(1)if((c|0)==4){c=4;K=0;J=gd((e|0)/32768|0);H=gd((i|0)/32768|0);i=0;while(1)if((c|0)==7){c=gd(J+((i|0)/32768|0)|0);w[r>>1]=c;x[f>>2]=D(c,G);c=gd(H+((K|0)/32768|0)|0);w[r+2>>1]=c;x[f+4>>2]=D(c,G);f=f+8|0;r=r+4|0;continue td}else{e=l+(c<<2)|0;o=x[e>>2]+1&8191;x[e>>2]=o;o=s+(o<<2)|0;u=w[o>>1];e=m+(c<<4)|0;o=w[o+2>>1];K=(D(u,w[e+12>>1])+K|0)+D(o,w[e+14>>1])|0;i=(D(u,w[e+8>>1])+i|0)+D(o,w[e+10>>1])|0;c=c+1|0;continue}}else{o=l+(c<<2)|0;J=x[o>>2]+1&8191;x[o>>2]=J;L=i;i=s+(J<<2)|0;J=w[i>>1];o=m+(c<<4)|0;H=w[i+2>>1];i=(L+D(J,w[o+12>>1])|0)+D(H,w[o+14>>1])|0;e=(D(J,w[o+8>>1])+e|0)+D(H,w[o+10>>1])|0;c=c+1|0;continue}}}}else{x[l+(c<<2)>>2]=e+(x[m+(c<<4)>>2]^-1);c=c+1|0;continue}break}fb=l+32|0;H=I+(P<<2)|0;c=b;f=g;l=k+16448|0;X=k+8258|0;G=k+8256|0;_=k+66|0;J=k- -64|0;m=k+24640|0;e=x[k+4>>2];while(1){i=e&2047;if(f){P=w[G+((e+1206&2047)<<2)>>1];u=w[X+((e+754&2047)<<2)>>1];s=w[_+((e+1602&2047)<<2)>>1];L=w[J+((e+1750&2047)<<2)>>1];o=w[H>>1];r=w[H+2>>1];q=m+((e+502&2047)<<2)|0;K=w[q>>1];R=pd(w[k+32>>1]-K|0);q=w[q+2>>1];M=pd(w[k+34>>1]-q|0);V=w[k+26>>1];U=m+((e+22&2047)<<2)|0;$=w[U>>1];Y=pd(w[k+36>>1]-$|0);da=w[k+28>>1];U=w[U+2>>1];ea=pd(w[k+38>>1]-U|0);fa=w[k+30>>1];K=gd(pd((D(R,w[k+24>>1])|0)/65536<<1)+K|0);w[k+32>>1]=K;Ca=k,Da=gd(pd((D(M,V)|0)/65536<<1)+q|0),w[Ca+34>>1]=Da;Ca=k,Da=gd(pd((D(Y,da)|0)/65536<<1)+$|0),w[Ca+36>>1]=Da;q=gd(pd((D(ea,fa)|0)/65536<<1)+U|0);w[k+38>>1]=q;K=pd((D(K,w[k+16>>1])|0)/32768|0);q=pd((D(q,w[k+22>>1])|0)/32768|0);K=pd(((o|0)/4<<16>>16)+K|0);R=pd(q+((r|0)/4<<16>>16)|0);o=w[k+8>>1];M=pd(K+((D(o,L)|0)/-65536|0)|0);r=i<<2;V=r+J|0;q=w[k+10>>1];U=pd(R+((D(q,s)|0)/-65536|0)|0);w[V+2>>1]=U;w[V>>1]=M;L=pd(L+((D(o,M)|0)/65536|0)|0);M=l+r|0;s=pd(s+((D(q,U)|0)/65536|0)|0);w[M+2>>1]=s;w[M>>1]=L;L=pd(K+L|0);K=pd(s+R|0);s=l+((e+682&2047)<<2)|0;R=w[s+2>>1];M=w[s>>1];s=pd((D(R,w[k+42>>1])+D(M,w[k+40>>1])|0)/32768|0);e=l+((e+426&2047)<<2)|0;V=w[e+2>>1];U=w[e>>1];e=pd((D(V,w[k+46>>1])+D(U,w[k+44>>1])|0)/32768|0);M=pd(pd(L+M|0)-s|0);R=pd(pd(K+R|0)-e|0);L=pd(pd(L+U|0)-s|0);K=pd(pd(K+V|0)-e|0);s=pd(s+((D(o,P)|0)/-65536|0)|0);V=r+G|0;U=pd(e+((D(q,u)|0)/-65536|0)|0);w[V+2>>1]=U;w[V>>1]=s;o=(D(o,s)|0)/65536|0;e=pd(o+P|0);r=m+r|0;q=(D(q,U)|0)/65536|0;s=pd(q+u|0);w[r+2>>1]=s;w[r>>1]=e;Ca=c,Da=(x[c>>2]+D(pd(e+M|0),w[k+48>>1])|0)+D(pd(s+R|0),w[k+50>>1])|0,x[Ca>>2]=Da;Ca=c,Da=(x[c+4>>2]+D(pd(pd(o)+L|0),w[k+52>>1])|0)+D(pd(pd(q)+K|0),w[k+54>>1])|0,x[Ca+4>>2]=Da;c=c+8|0;e=i+1|0;H=H+4|0;f=f-1|0;continue}break}x[k+4>>2]=i;x[t+76>>2]=g+x[t+76>>2]&4095;x[t+68>>2]=g+x[t+68>>2]&8191;a=a-g|0;b=(g<<3)+b|0;continue}break}x[t+68>>2]=x[t+68>>2]&8191;e=Z;c=W;f=h;g=0;j=0;i=x[t+56>>2];k=x[t+52>>2];a=x[t+64>>2];b=x[t+60>>2];while(1){if(f){g=x[e>>2];j=x[e+4>>2];a=a-j|0;a=(((a|0)/1024|0)-a|0)+i|0;x[c+4>>2]=a+x[c+4>>2];b=b-g|0;b=(((b|0)/1024|0)-b|0)+k|0;x[c>>2]=b+x[c>>2];i=a+((a|0)/-512|0)|0;k=b+((b|0)/-512|0)|0;c=c+8|0;e=e+8|0;f=f-1|0;b=g;a=j;continue}break}x[t+64>>2]=j;x[t+60>>2]=g;x[t+56>>2]=i;x[t+52>>2]=k;a=x[t+20>>2];ud:{if(y[t+12|0]){break ud}a=x[t+16>>2];if(a>>>0>h>>>0){a=a-h|0;break ud}GP(t,ma,la);a=0}v[t+12|0]=0;x[t+16>>2]=a}if(x[d+946300>>2]){vd:{b=0;c=0;g=n<<2;o=d+906300|0;q=z[d+480214>>1]!=0;qa=B[d+1074336>>2];T=B[d+1074332>>2];while(1)if((b|0)==250){g=d+12|0;j=d+12300|0;l=d+14348|0;$w(g,j,l,n,T);G=y[d+1074476|0];v[d+1074476|0]=0;a=l;b=j;while(1){wd:{xd:{yd:{if((c|0)!=250){m=$d(o,c);h=x[m>>2];if(!h|!x[h+24>>2]){break wd}if(!ti(h+44|0)){break wd}i=h;zd:{if(Ep(y[m+24|0])){break zd}e=ib[x[x[h>>2]+148>>2]](h)|0;i=x[m>>2];if(e){break zd}e=0;if(y[i+28|0]&2){break zd}while(1){if((c|0)==(e|0)){break wd}f=$d(o,e);e=e+1|0;if((In(x[f+28>>2])|0)!=(c|0)){continue}break}}e=x[h+44>>2];r=Hc(e,0);I=Hc(e,1);s=(b|0)==(r|0);b=s?j:b;k=b;a=s?l:a;f=x[m+28>>2];e=a;Ad:{if(!f){break Ad}f=In(f);e=a;if(f>>>0<=c>>>0){break Ad}e=a;if(f>>>0>249){break Ad}f=x[$d(o,f)>>2];e=a;if(!f){break Ad}if(!(y[i+28|0]&4)){ib[x[x[f>>2]+152>>2]](f)}e=a;if(!ti(f+44|0)){break Ad}e=x[f+44>>2];k=Hc(e,0);e=Hc(e,1)}f=e;if(!Ep(y[m+24|0])){break xd}e=0;Bd:{if(s){break Bd}while(1){if((e|0)==(n|0)){break Bd}s=e<<2;J=s+r|0;P=b+s|0;B[J>>2]=B[P>>2]+B[J>>2];J=s+I|0;s=a+s|0;B[J>>2]=B[s>>2]+B[J>>2];x[P>>2]=0;x[s>>2]=0;e=e+1|0;continue}}a=f;b=k;if(!(q&1)){break xd}a=x[m>>2];if(a){ib[x[x[a>>2]+152>>2]](a)}e=In(x[m+28>>2]);b=c;while(1){a=e;e=a&255;if(e>>>0>249|e>>>0<=(b&255)>>>0){break yd}s=$d(o,e);e=In(x[s+28>>2]);b=a;a=x[s>>2];if(!a){continue}ib[x[x[a>>2]+152>>2]](a);continue}}k=0;while(1){if((k|0)!=(n|0)){T=E(B[b>>2]*qa);Cd:{if(E(F(T))<E(2147483648)){c=~~T;break Cd}c=-2147483648}x[g>>2]=c;T=E(B[a>>2]*qa);Dd:{if(E(F(T))<E(2147483648)){c=~~T;break Dd}c=-2147483648}x[g+4>>2]=c;k=k+1|0;g=g+8|0;a=a+4|0;b=b+4|0;continue}break}break vd}a=f;b=k}Ed:{Fd:{e=y[m+24|0];if(!TF(e)){if(!SF(e)|!(y[i+28|0]&4)){break Fd}}e=0;while(1){if((e|0)==(n|0)){break Ed}h=e<<2;m=h+k|0;B[m>>2]=B[h+r>>2]+B[m>>2];m=h+f|0;B[m>>2]=B[h+I>>2]+B[m>>2];e=e+1|0;continue}}if(G){ib[x[x[h>>2]+132>>2]](h)}ib[x[x[h>>2]+60>>2]](h,k,f,n);x[i+32>>2]=n+x[i+32>>2];if(!SF(y[m+24|0])){break Ed}if((ib[x[x[h>>2]+160>>2]](h)|0)<=0){break Ed}e=0;if(A[i+32>>2]<x[d+24620>>2]<<2>>>0){break Ed}Gd:{while(1){if((e|0)==(n|0)){break Gd}h=e<<2;T=B[h+k>>2];Hd:{if(T>=E(1.1920928955078125e-7)|T<=E(-1.1920928955078125e-7)){break Hd}T=B[h+f>>2];if(T>=E(1.1920928955078125e-7)){break Hd}e=e+1|0;if(!(T<=E(-1.1920928955078125e-7))){continue}}break}x[i+32>>2]=0;break Ed}x[i+28>>2]=x[i+28>>2]|4}x[i+28>>2]=x[i+28>>2]&-3}c=c+1|0;continue}}else{h=$d(o,b);a=x[h>>2];Id:{if(!a|!x[a+24>>2]){break Id}if(!ti(a+44|0)){break Id}if(!(ib[x[x[a>>2]+116>>2]](a)|0)){ib[x[x[a>>2]+112>>2]](a,1);ib[x[x[a>>2]+124>>2]](a)}f=x[a+44>>2];e=Hc(f,0);f=Hc(f,1);Jd:{if(v[a+28|0]&1){$w(x[a+24>>2],e,f,n,T);break Jd}if(x[a+40>>2]|x[a+36>>2]){Kn(x[a+24>>2],n,a+40|0,a+36|0);$w(x[a+24>>2],e,f,n,T);break Jd}Rb(e,0,g);Rb(f,0,g)}f=a;a=x[a+28>>2];x[f+28>>2]=a&-2;if(Ep(y[h+24|0])){break Id}q=!(a&4)|q}b=b+1|0;continue}}}if(x[d+24624>>2]==1){a=0;while(1){if((a|0)!=(n|0)){b=(a<<3)+W|0;x[(a<<2)+W>>2]=(x[b+4>>2]+x[b>>2]|0)/2;a=a+1|0;continue}break}}if(Id(y[d+1074365|0])){e=0;h=fb-16|0;fb=h;Kd:{if(!x[d+1074376>>2]){x[d+1074460>>2]=0;x[d+1074464>>2]=0;b=x[d+1074456>>2];x[d+1074468>>2]=b;g=d+1074460|0;break Kd}a=x[d+1074468>>2];b=x[d+1074456>>2];Ld:{if((a|0)==(b|0)){c=x[d+1074460>>2];break Ld}x[d+1074468>>2]=b;c=x[d+24620>>2];Md:{if((a|0)<(b|0)){c=fv(c,x[d+24636>>2]);break Md}c=fv(c,x[d+24640>>2])}x[d+1074460>>2]=c;x[d+1074464>>2]=c;a=b}g=d+1074460|0;if((c|0)<=0){break Kd}a=(a<<12)-x[d+1074472>>2]|0;e=(a|0)/(c|0)|0;if(y[d+1074368|0]!=2){break Kd}x[h+12>>2]=50;f=x[d+1074464>>2];x[h+8>>2]=1e4/(f+1|0);k=x[Ye(h+12|0,h+8|0)>>2];while(1){j=e>>31;if((k|0)>=((j^e)-j|0)){break Kd}c=c+f|0;x[g>>2]=c;e=(a|0)/(c|0)|0;continue}}Nd:{Od:{switch(x[d+24624>>2]-1|0){case 0:k=b<<12;c=d+12|0;j=b>>31;a=0;while(1){if((a|0)==(n|0)){break Nd}Pd:{if(x[g>>2]>0){f=x[d+1074472>>2]+e|0;x[d+1074472>>2]=f;l=x[c>>2];Ca=c,Da=Gc(Bua(Aua(l,l>>31,f,f>>31),hb,1048576,0),hb),x[Ca>>2]=Da;x[d+1074460>>2]=x[d+1074460>>2]-1;break Pd}f=x[c>>2];Ca=c,Da=Gc(Bua(Aua(f,f>>31,b,j),hb,256,0),hb),x[Ca>>2]=Da;x[d+1074472>>2]=k}a=a+1|0;c=c+4|0;continue};case 1:j=b<<12;c=d+12|0;f=b>>31;a=0;while(1){if((a|0)==(n|0)){break Nd}Qd:{if(x[g>>2]>0){k=x[d+1074472>>2]+e|0;x[d+1074472>>2]=k;l=x[c>>2];Ca=c,Da=Gc(Bua(Aua(l,l>>31,k,k>>31),hb,1048576,0),hb),x[Ca>>2]=Da;k=x[d+1074472>>2];i=k;m=k>>31;k=x[c+4>>2];Ca=c,Da=Gc(Bua(Aua(i,m,k,k>>31),hb,1048576,0),hb),x[Ca+4>>2]=Da;x[d+1074460>>2]=x[d+1074460>>2]-1;break Qd}k=x[c>>2];Ca=c,Da=Gc(Bua(Aua(k,k>>31,b,f),hb,256,0),hb),x[Ca>>2]=Da;k=x[c+4>>2];Ca=c,Da=Gc(Bua(Aua(k,k>>31,b,f),hb,256,0),hb),x[Ca+4>>2]=Da;x[d+1074472>>2]=j}a=a+1|0;c=c+8|0;continue};case 3:break Od;default:break Nd}}l=b<<12;c=d+8204|0;a=d+12|0;f=b;k=b>>31;b=0;while(1){if((b|0)==(n|0)){break Nd}Rd:{if(x[g>>2]>0){j=x[d+1074472>>2]+e|0;x[d+1074472>>2]=j;m=x[a>>2];Ca=a,Da=Gc(Bua(Aua(m,m>>31,j,j>>31),hb,1048576,0),hb),x[Ca>>2]=Da;j=x[d+1074472>>2];i=j;m=j>>31;j=x[a+4>>2];Ca=a,Da=Gc(Bua(Aua(i,m,j,j>>31),hb,1048576,0),hb),x[Ca+4>>2]=Da;j=x[d+1074472>>2];i=j;m=j>>31;j=x[c>>2];Ca=c,Da=Gc(Bua(Aua(i,m,j,j>>31),hb,1048576,0),hb),x[Ca>>2]=Da;j=x[d+1074472>>2];i=j;m=j>>31;j=x[c+4>>2];Ca=c,Da=Gc(Bua(Aua(i,m,j,j>>31),hb,1048576,0),hb),x[Ca+4>>2]=Da;x[d+1074460>>2]=x[d+1074460>>2]-1;break Rd}j=x[a>>2];Ca=a,Da=Gc(Bua(Aua(j,j>>31,f,k),hb,256,0),hb),x[Ca>>2]=Da;j=x[a+4>>2];Ca=a,Da=Gc(Bua(Aua(j,j>>31,f,k),hb,256,0),hb),x[Ca+4>>2]=Da;j=x[c>>2];Ca=c,Da=Gc(Bua(Aua(j,j>>31,f,k),hb,256,0),hb),x[Ca>>2]=Da;j=x[c+4>>2];Ca=c,Da=Gc(Bua(Aua(j,j>>31,f,k),hb,256,0),hb),x[Ca+4>>2]=Da;x[d+1074472>>2]=l}b=b+1|0;c=c+8|0;a=a+8|0;continue}}fb=h+16|0}if(x[ja>>2]!=128){b=d+12|0;c=d+8204|0;a=x[d+24604>>2];e=x[d+24624>>2];Sd:{if((a|0)==128|e>>>0<2){break Sd}CR(b,n,a);if(e>>>0<4){break Sd}CR(c,n,a)}}b=x[d+24624>>2];if((b|0)==4){b=n;while(1){b=b-1|0;if((b|0)>=0){a=(b<<4)+W|0;c=b<<3;e=c|4;x[a+12>>2]=x[e+ka>>2];x[a+8>>2]=x[c+ka>>2];x[a+4>>2]=x[e+W>>2];x[a>>2]=x[c+W>>2];continue}break}b=x[d+24624>>2]}if(Id(sa)){x[C- -64>>2]=n;x[C+60>>2]=b;x[C+56>>2]=W;a=x[x[ha>>2]+8>>2];x[C+24>>2]=n;b=x[C+60>>2];x[C+16>>2]=x[C+56>>2];x[C+20>>2]=b;ib[a|0](ha,C+16|0);b=x[d+24624>>2]}x[C+52>>2]=n;x[C+48>>2]=b;x[C+44>>2]=W;a=x[x[ga>>2]+8>>2];x[C+8>>2]=n;b=x[C+48>>2];x[C>>2]=x[C+44>>2];x[C+4>>2]=b;ib[a|0](ga,C);x[d+1074380>>2]=x[d+1074380>>2]-n;x[d+1074376>>2]=n+x[d+1074376>>2];ca=ca-n|0;ra=n+ra|0;continue}break}fb=aa+32|0;return ra}function dg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=E(0),o=0,q=0,s=0,t=0,u=E(0),G=0,H=0,I=0,J=E(0),K=0,L=0,M=0,O=0,V=0;s=fb-2240|0;fb=s;a:{b:{c:{d:{e:{f:{g:{if(bx(x[c>>2])){xc(b,268435456);L=x[c+8>>2];I=s+2220|0;e=I;x[e>>2]=0;x[e+4>>2]=0;Nb(e+8|0);h:{i:{j:{k:{l:{e=y[a+3|0];m:{n:{if((e-4&255)>>>0<=4){x[31609]=0;j=R(202,c|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break n}break b}if(e>>>0>17){break m}o:{d=1<<e;if(!(d&63503)){if(!(d&198144)){break m}break o}if(y[a|0]){break o}break n}e=0;f=AD(a,x[b>>2]);x[31609]=0;d=s+48|0;S(186,d|0,c|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break l}f=x[d+4>>2];x[I>>2]=x[d>>2];x[I+4>>2]=f;zn(I+8|0,d+8|0);Kc(d);f=Ze(I);if(!f){break h}j=x[I>>2]}e=y[a+3|0]}p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=y[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}h=8}d=!h;h=x[b>>2];if(!(d|h>>>0<262145)){d=e&255;x[s+48>>2]=((d|0)==10)<<4;x[s+28>>2]=j;k=j-x[Hb(s+48|0,s+28|0)>>2]|0;if(d>>>0>15){break k}r:{if(!(1<<d&63503)){if((d|0)==10){break r}break k}if(!(y[a|0]&7)){break k}}e=(k|0)<0?-1:k<<1;break j}e=e&255;if(e>>>0>8){break i}if(!(1<<e&432)){if((e|0)!=6){break i}e=0;if(j>>>0<10){break h}x[31609]=0;P(183,c|0,4)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}x[31609]=0;d=R(151,c|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){x[s+48>>2]=d;x[s+28>>2]=j;e=x[Hb(s+48|0,s+28|0)>>2];Ih(c,8);e=((e>>>0>50529027?-1:D(e,85))>>>0)/(y[a|0]>>>3>>>0)|0;break j}a=N()|0;break a}d=8/(jr(y[a+1|0])>>>0)|0;e=D(d,j);Aua(d,0,j,0);e=hb?-1:e;break j}a=N()|0;break a}h=0;e=jr(y[a+1|0]);s:{t:{switch(d|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=y[a|0];break s;case 9:h=16;break s;case 10:h=4;break s;case 16:case 17:break t;default:break s}}h=8}d=D(e,h)>>>3|0;e=(d+k|0)-1|0;e=((e>>>0<k>>>0?-1:e)>>>0)/(d>>>0)|0}xc(b,e);h=x[b>>2]}if(!h){e=0;break h}w[b+34>>1]=z[b+34>>1]&65470|y[a|0]>15|(y[a+1|0]!=1)<<6;if(!Gh(b)){e=0;x[b>>2]=0;break h}u:{e=s+48|0;if(oe(a,Zc(e,8,1,0,10))){x[31609]=0;d=P(203,c|0,e|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){e=0;if(!d){break u}a=x[b>>2];h=0;x[31609]=0;x[s+28>>2]=a+1>>>1;e=R(202,c|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}xc(s+28|0,e);a=f+16|0;b=x[b+20>>2];g=x[s+28>>2];e=g;while(1)if(e){d=s+48|0;f=y[d|y[a|0]&15]+h|0;v[b|0]=f;h=y[d|y[a|0]>>>4]+(f&255)|0;v[b+1|0]=h;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=g+16|0;break u}}a=N()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{h=y[a+3|0];switch(h-4|0){case 3:break B;case 4:break E;case 5:break F;case 2:break G;case 0:case 1:break H;default:break D}}x[31609]=0;b=ba(204,s+1132|0,c|0,b|0,(h|0)==5|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break g}ub(b);e=x[c+8>>2]-L|0;break u}if(y[a+1|0]!=1){break C}x[31609]=0;P(183,c|0,4)|0;a=x[31609];x[31609]=0;if((a|0)==1){break g}x[31609]=0;e=R(151,c|0)|0;a=x[31609];x[31609]=0;I:{J:{K:{if((a|0)!=1){x[31609]=0;x[s+28>>2]=e;f=R(197,c|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break K}x[31609]=0;d=s+48|0;S(205,d|0,c|0,e|0);a=x[31609];x[31609]=0;if((a|0)==1){break J}xc(s+28|0,x[s+48>>2]);e=x[s+28>>2];Mn(s+1124|0,d);cc(s+1116|0,x[b+20>>2],Qk(x[b>>2],z[b+34>>1]));x[31609]=0;aa(206,x[s+1124>>2],x[s+1128>>2],x[s+1116>>2],x[s+1120>>2],f<<24>>24);a=x[31609];x[31609]=0;if((a|0)==1){break I}e=e+9|0;Kc(d);break u}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;Kc(s+48|0);break a}if(y[a+1|0]!=1|y[a|0]!=16){break C}e=Xk(s+1114|0);a=x[b>>2];d=x[b+20>>2];e=z[e>>1];h=fb-16|0;fb=h;x[h+12>>2]=j>>>1;x[h+8>>2]=a;b=x[Hb(h+12|0,h+8|0)>>2];g=b;while(1){if(g){a=y[f|0]+e|0;e=a+y[f+1|0]|0;w[d>>1]=e<<8|a&255;d=d+2|0;f=f+2|0;g=g-1|0;continue}break}fb=h+16|0;e=b<<1;break u}if(y[a+1|0]!=1|y[a|0]>16){break C}d=x[c+8>>2];f=x[c>>2];e=0;x[31609]=0;d=U(150,f|0,d|0,8)|0;f=x[31609];x[31609]=0;if((f|0)==1){break g}if(!d){break u}x[31609]=0;d=R(151,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break g}if(d>>>0<4){break u}x[31609]=0;f=s+28|0;S(185,f|0,c|0,d|0);e=x[31609];x[31609]=0;if((e|0)==1){break d}o=ns(s+48|0,f);ub(f);e=x[o>>2];x[31609]=0;f=R(207,e|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break f}e=f+4|0;k=y[a|0];h=(k|0)!=16;f=0;while(1){if(A[b>>2]<=f>>>0){break w}L:{if(h){break L}x[31609]=0;i=P(158,o|0,8)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break L}a=T(28816)|0;break x}x[31609]=0;g=P(158,o|0,1)|0;a=x[31609];x[31609]=0;if((a|0)==1){break y}x[31609]=0;d=P(158,o|0,1)|0;a=x[31609];x[31609]=0;if((a|0)==1){break y}M:{N:{O:{if(!d){j=8;while(1){x[31609]=0;d=P(158,o|0,1)|0;a=x[31609];x[31609]=0;if((a|0)==1){break M}if(d){break O}j=j+16|0;continue}}x[31609]=0;a=P(158,o|0,3)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break N}break y}x[31609]=0;d=P(158,o|0,4)|0;a=x[31609];x[31609]=0;if((a|0)==1){break y}a=d+j|0}t=(t&255)+(((g?-1:0)^a)&255)|0;P:{if((k|0)!=16){v[x[b+20>>2]+f|0]=t;break P}w[x[b+20>>2]+(f<<1)>>1]=i&255|t<<8}f=f+1|0;continue}break}a=T(28816)|0;break x}Q:{if((h|0)==16){e=y[a|0];break Q}e=y[a|0];if((h|0)!=17){break z}}if((e&255)!=16){break z}d=y[a+1|0];if((d-1&255)>>>0>1){break z}M=s,O=D(x[b>>2],jr(d)),x[M+48>>2]=O;xc(s+48|0,j);a=x[b+20>>2];e=x[s+48>>2];if((h|0)==16){b=e;while(1){if(!b){break u}M=a,O=z[ac(28848,y[f|0])>>1],w[M>>1]=O;a=a+2|0;f=f+1|0;b=b-1|0;continue}}b=e;while(1){if(!b){break u}M=a,O=z[ac(29360,y[f|0])>>1],w[M>>1]=O;a=a+2|0;f=f+1|0;b=b-1|0;continue}}if((h|0)!=7){break A}}if(y[a+1|0]!=1|y[a|0]>16){break A}e=0;if(j>>>0<5){break u}f=x[b+20>>2];e=z[b+34>>1];a=x[b>>2];x[31609]=0;e=U(208,c|0,f|0,Qk(a,e)|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break u}break g}e=y[a|0]}d=(e&255)!=8;if(!(d|y[a+1|0]!=1)){R:{switch(h|0){case 0:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){v[e|0]=y[f|0];e=e+1|0;f=f+1|0;b=b-1|0;continue}break};fb=d+16|0;e=a;break u;case 1:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){v[e|0]=y[f|0]^128;e=e+1|0;f=f+1|0;b=b-1|0;continue}break};fb=d+16|0;e=a;break u;default:e=0;if((h|0)!=11){break u}break;case 2:break R}}e=vv(s+27|0);a=x[b>>2];g=x[b+20>>2];b=y[e|0];d=fb-16|0;fb=d;x[d+12>>2]=j;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){b=y[f|0]+b|0;v[g|0]=b;g=g+1|0;f=f+1|0;e=e-1|0;continue}break}fb=d+16|0;e=a;break u}if(!(y[a+1|0]!=3|d)){S:{switch(h|0){case 0:i=fb-16|0;fb=i;x[i+12>>2]=j;e=x[b>>2];x[i+8>>2]=e;a=i+8|0;g=x[Hb(a,i+12|0)>>2];x[i+8>>2]=e;x[i+4>>2]=j-g;e=x[Hb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=f;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+f|0;a=e;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};fb=i+16|0;e=e+g|0;break u;case 1:i=fb-16|0;fb=i;x[i+12>>2]=j;e=x[b>>2];x[i+8>>2]=e;a=i+8|0;g=x[Hb(a,i+12|0)>>2];x[i+8>>2]=e;x[i+4>>2]=j-g;e=x[Hb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=f;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+f|0;a=e;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};fb=i+16|0;e=e+g|0;break u;default:e=0;if((h|0)!=11){break u}break;case 2:break S}}g=y[vv(s+26|0)|0];k=fb-16|0;fb=k;x[k+12>>2]=j;d=x[b>>2];x[k+8>>2]=d;e=k+8|0;h=x[Hb(e,k+12|0)>>2];x[k+8>>2]=d;x[k+4>>2]=j-h;d=x[Hb(e,k+4|0)>>2];j=b;t=x[b+20>>2];e=g;b=h;i=f;while(1){if(b){e=y[i|0]+e|0;v[t|0]=e;t=t+2|0;i=i+1|0;b=b-1|0;continue}break}t=x[j+20>>2]+1|0;i=x[j>>2]+f|0;b=d;while(1){if(b){g=y[i|0]+g|0;v[t|0]=g;t=t+2|0;i=i+1|0;b=b-1|0;continue}break}fb=k+16|0;e=d+h|0;if(y[a+3|0]!=11){break u}a=x[j+20>>2];b=a+(x[j>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;continue}}d=e&255;if(!((d|0)!=8|y[a+1|0]!=2)){e=0;T:{switch(h|0){case 0:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){v[e|0]=y[f|0];v[e+1|0]=y[f+1|0];e=e+2|0;f=f+2|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<1;break u;case 1:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){v[e|0]=y[f|0]^128;v[e+1|0]=y[f+1|0]^128;e=e+2|0;f=f+2|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=vv(s+25|0);a=x[b>>2];d=x[b+20>>2];b=y[e|0];h=fb-16|0;fb=h;x[h+12>>2]=j>>>1;x[h+8>>2]=a;a=b;e=x[Hb(h+12|0,h+8|0)>>2];g=e;while(1){if(g){b=y[f|0]+b|0;v[d|0]=b;a=y[f+1|0]+a|0;v[d+1|0]=a;d=d+2|0;f=f+2|0;g=g-1|0;continue}break}fb=h+16|0;e=e<<1;break u}if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=1))){U:{switch(h|0){case 0:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){w[e>>1]=y[f|0]|y[f+1|0]<<8;e=e+2|0;f=f+2|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<1;break u;case 1:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){w[e>>1]=(y[f|0]|y[f+1|0]<<8)^32768;e=e+2|0;f=f+2|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<1;break u;default:e=0;if((h|0)!=11){break u}break;case 2:break U}}e=Xk(s+22|0);a=x[b>>2];g=x[b+20>>2];b=z[e>>1];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){b=(y[f|0]+b|0)+(y[f+1|0]<<8)|0;w[g>>1]=b;g=g+2|0;f=f+2|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<1;break u}d=e&255;if(!((d|0)!=16|y[a+1|0]!=1|y[a+2|0]!=1)){e=0;V:{switch(h|0){case 0:a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;b=x[Hb(d+12|0,d+8|0)>>2];e=b;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[g>>1]=a<<8|a>>>8;g=g+2|0;f=f+2|0;e=e-1|0;continue}break};fb=d+16|0;e=b<<1;break u;case 1:a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;b=x[Hb(d+12|0,d+8|0)>>2];e=b;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[g>>1]=(a<<8|a>>>8)^32768;g=g+2|0;f=f+2|0;e=e-1|0;continue}break};fb=d+16|0;e=b<<1;break u;case 2:break V;default:break u}}e=Xk(s+20|0);a=x[b>>2];g=x[b+20>>2];b=z[e>>1];d=fb-16|0;fb=d;x[d+12>>2]=j>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){b=(y[f+1|0]+b|0)+(y[f|0]<<8)|0;w[g>>1]=b;g=g+2|0;f=f+2|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<1;break u}if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=3))){W:{switch(h|0){case 0:k=fb-16|0;fb=k;x[k+12>>2]=j;i=x[b>>2]<<1;x[k+8>>2]=i;a=k+8|0;e=x[Hb(a,k+12|0)>>2];x[k+8>>2]=i;x[k+4>>2]=j-e;a=x[Hb(a,k+4|0)>>2];g=x[b+20>>2];e=e>>>1|0;h=e;d=f;while(1){if(h){w[g>>1]=y[d|0]|y[d+1|0]<<8;g=g+4|0;d=d+2|0;h=h-1|0;continue}break};g=f+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;h=a;while(1){if(h){w[d>>1]=y[g|0]|y[g+1|0]<<8;d=d+4|0;g=g+2|0;h=h-1|0;continue}break};fb=k+16|0;e=a+e<<1;break u;case 1:k=fb-16|0;fb=k;x[k+12>>2]=j;i=x[b>>2]<<1;x[k+8>>2]=i;a=k+8|0;e=x[Hb(a,k+12|0)>>2];x[k+8>>2]=i;x[k+4>>2]=j-e;a=x[Hb(a,k+4|0)>>2];g=x[b+20>>2];e=e>>>1|0;h=e;d=f;while(1){if(h){w[g>>1]=(y[d|0]|y[d+1|0]<<8)^32768;g=g+4|0;d=d+2|0;h=h-1|0;continue}break};g=f+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;h=a;while(1){if(h){w[d>>1]=(y[g|0]|y[g+1|0]<<8)^32768;d=d+4|0;g=g+2|0;h=h-1|0;continue}break};fb=k+16|0;e=a+e<<1;break u;default:e=0;if((h|0)!=11){break u}break;case 2:break W}}g=z[Xk(s+18|0)>>1];o=fb-16|0;fb=o;x[o+12>>2]=j;k=x[b>>2]<<1;x[o+8>>2]=k;e=o+8|0;d=x[Hb(e,o+12|0)>>2];x[o+8>>2]=k;x[o+4>>2]=j-d;h=x[Hb(e,o+4|0)>>2];t=x[b+20>>2];e=g;d=d>>>1|0;i=d;j=f;while(1){if(i){e=(y[j|0]+e|0)+(y[j+1|0]<<8)|0;w[t>>1]=e;t=t+4|0;j=j+2|0;i=i-1|0;continue}break}j=f+k|0;t=x[b+20>>2]+2|0;e=h>>>1|0;i=e;while(1){if(i){g=(y[j|0]+g|0)+(y[j+1|0]<<8)|0;w[t>>1]=g;t=t+4|0;j=j+2|0;i=i-1|0;continue}break}fb=o+16|0;e=d+e<<1;if(y[a+3|0]!=11){break u}a=x[b+20>>2];b=a+(x[b>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;continue}}d=e&255;if(!((d|0)!=16|y[a+1|0]!=3|y[a+2|0]!=1)){e=0;X:{switch(h|0){case 0:o=fb-16|0;fb=o;x[o+12>>2]=j;k=x[b>>2]<<1;x[o+8>>2]=k;a=o+8|0;e=x[Hb(a,o+12|0)>>2];x[o+8>>2]=k;x[o+4>>2]=j-e;d=x[Hb(a,o+4|0)>>2];i=x[b+20>>2];e=e>>>1|0;g=e;h=f;while(1){if(g){a=y[h|0]|y[h+1|0]<<8;w[i>>1]=a<<8|a>>>8;i=i+4|0;h=h+2|0;g=g-1|0;continue}break};i=f+k|0;h=x[b+20>>2]+2|0;b=d>>>1|0;g=b;while(1){if(g){a=y[i|0]|y[i+1|0]<<8;w[h>>1]=a<<8|a>>>8;h=h+4|0;i=i+2|0;g=g-1|0;continue}break};fb=o+16|0;e=b+e<<1;break u;case 1:o=fb-16|0;fb=o;x[o+12>>2]=j;k=x[b>>2]<<1;x[o+8>>2]=k;a=o+8|0;e=x[Hb(a,o+12|0)>>2];x[o+8>>2]=k;x[o+4>>2]=j-e;d=x[Hb(a,o+4|0)>>2];i=x[b+20>>2];e=e>>>1|0;g=e;h=f;while(1){if(g){a=y[h|0]|y[h+1|0]<<8;w[i>>1]=(a<<8|a>>>8)^32768;i=i+4|0;h=h+2|0;g=g-1|0;continue}break};i=f+k|0;h=x[b+20>>2]+2|0;b=d>>>1|0;g=b;while(1){if(g){a=y[i|0]|y[i+1|0]<<8;w[h>>1]=(a<<8|a>>>8)^32768;h=h+4|0;i=i+2|0;g=g-1|0;continue}break};fb=o+16|0;e=b+e<<1;break u;case 2:break X;default:break u}}e=z[Xk(s+16|0)>>1];o=fb-16|0;fb=o;x[o+12>>2]=j;k=x[b>>2]<<1;x[o+8>>2]=k;a=o+8|0;d=x[Hb(a,o+12|0)>>2];x[o+8>>2]=k;x[o+4>>2]=j-d;j=x[Hb(a,o+4|0)>>2];i=x[b+20>>2];a=e;h=d>>>1|0;g=h;d=f;while(1){if(g){a=(y[d+1|0]+a|0)+(y[d|0]<<8)|0;w[i>>1]=a;i=i+4|0;d=d+2|0;g=g-1|0;continue}break}d=f+k|0;i=x[b+20>>2]+2|0;a=j>>>1|0;g=a;while(1){if(g){e=(y[d+1|0]+e|0)+(y[d|0]<<8)|0;w[i>>1]=e;i=i+4|0;d=d+2|0;g=g-1|0;continue}break}fb=o+16|0;e=a+h<<1;break u}if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=2))){e=0;Y:{switch(h|0){case 0:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){w[e>>1]=y[f|0]|y[f+1|0]<<8;w[e+2>>1]=y[f+2|0]|y[f+3|0]<<8;e=e+4|0;f=f+4|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<2;break u;case 1:a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){w[e>>1]=(y[f|0]|y[f+1|0]<<8)^32768;w[e+2>>1]=(y[f+2|0]|y[f+3|0]<<8)^32768;e=e+4|0;f=f+4|0;b=b-1|0;continue}break};fb=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}e=Xk(s+14|0);a=x[b>>2];d=x[b+20>>2];b=z[e>>1];h=fb-16|0;fb=h;x[h+12>>2]=j>>>2;x[h+8>>2]=a;a=b;e=x[Hb(h+12|0,h+8|0)>>2];g=e;while(1){if(g){b=(y[f|0]+b|0)+(y[f+1|0]<<8)|0;w[d>>1]=b;a=(y[f+2|0]+a|0)+(y[f+3|0]<<8)|0;w[d+2>>1]=a;d=d+4|0;f=f+4|0;g=g-1|0;continue}break}fb=h+16|0;e=e<<2;break u}d=e&255;if(!((d|0)!=16|y[a+1|0]!=2|y[a+2|0]!=1)){e=0;Z:{switch(h|0){case 0:a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;b=x[Hb(d+12|0,d+8|0)>>2];e=b;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[g>>1]=a<<8|a>>>8;a=y[f+2|0]|y[f+3|0]<<8;w[g+2>>1]=a<<8|a>>>8;g=g+4|0;f=f+4|0;e=e-1|0;continue}break};fb=d+16|0;e=b<<2;break u;case 1:a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;b=x[Hb(d+12|0,d+8|0)>>2];e=b;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[g>>1]=(a<<8|a>>>8)^32768;a=y[f+2|0]|y[f+3|0]<<8;w[g+2>>1]=(a<<8|a>>>8)^32768;g=g+4|0;f=f+4|0;e=e-1|0;continue}break};fb=d+16|0;e=b<<2;break u;case 2:break Z;default:break u}}e=Xk(s+12|0);a=x[b>>2];d=x[b+20>>2];b=z[e>>1];h=fb-16|0;fb=h;x[h+12>>2]=j>>>2;x[h+8>>2]=a;a=b;e=x[Hb(h+12|0,h+8|0)>>2];g=e;while(1){if(g){b=(y[f+1|0]+b|0)+(y[f|0]<<8)|0;w[d>>1]=b;a=(y[f+3|0]+a|0)+(y[f+2|0]<<8)|0;w[d+2>>1]=a;d=d+4|0;f=f+4|0;g=g-1|0;continue}break}fb=h+16|0;e=e<<2;break u}if(!(h|y[a+1|0]!=1|(d|0)!=24)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=(j>>>0)/3;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=rd(y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24,16),w[M>>1]=O;e=e+2|0;f=f+3|0;b=b-1|0;continue}break}fb=d+16|0;e=D(a,3);break u}d=fb-16|0;fb=d;x[d+12>>2]=(j>>>0)/3;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=rd(y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24,16),w[M>>1]=O;e=e+2|0;f=f+3|0;b=b-1|0;continue}break}fb=d+16|0;e=D(a,3);break u}d=e&255;if(!(h|y[a+1|0]!=2|(d|0)!=24)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=(j>>>0)/6;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=rd(y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24,16),w[M>>1]=O;M=e,O=rd(y[f+4|0]<<16|y[f+3|0]<<8|y[f+5|0]<<24,16),w[M+2>>1]=O;e=e+4|0;f=f+6|0;b=b-1|0;continue}break}fb=d+16|0;e=D(a,6);break u}d=fb-16|0;fb=d;x[d+12>>2]=(j>>>0)/6;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=rd(y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24,16),w[M>>1]=O;M=e,O=rd(y[f+4|0]<<16|y[f+5|0]<<8|y[f+3|0]<<24,16),w[M+2>>1]=O;e=e+4|0;f=f+6|0;b=b-1|0;continue}break}fb=d+16|0;e=D(a,6);break u}if(!(h|y[a+1|0]!=1|(d|0)!=32)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=rd(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),16),w[M>>1]=O;e=e+2|0;f=f+4|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<2;break u}d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];g=a;while(1){if(g){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);M=e,O=rd(b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24),16),w[M>>1]=O;e=e+2|0;f=f+4|0;g=g-1|0;continue}break}fb=d+16|0;e=a<<2;break u}d=e&255;if(!(h|y[a+1|0]!=2|(d|0)!=32)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=rd(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),16),w[M>>1]=O;M=e,O=rd(y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),16),w[M+2>>1]=O;e=e+4|0;f=f+8|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<3;break u}d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];g=a;while(1){if(g){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);M=e,O=rd(b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24),16),w[M>>1]=O;b=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);M=e,O=rd(b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24),16),w[M+2>>1]=O;e=e+4|0;f=f+8|0;g=g-1|0;continue}break}fb=d+16|0;e=a<<3;break u}if(!(h|y[a+1|0]!=1|(d|0)!=64)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=Sc(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),48),w[M>>1]=O;e=e+2|0;f=f+8|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<3;break u}k=fb-16|0;fb=k;x[k+12>>2]=j>>>3;x[k+8>>2]=b;h=x[Hb(k+12|0,k+8|0)>>2];b=h;while(1){if(b){i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);M=e,O=Sc(o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)),g|(d|a>>>8),48),w[M>>1]=O;e=e+2|0;f=f+8|0;b=b-1|0;continue}break}fb=k+16|0;e=h<<3;break u}d=e&255;if(!(h|y[a+1|0]!=2|(d|0)!=64)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>4;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){M=e,O=Sc(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),48),w[M>>1]=O;M=e,O=Sc(y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24),y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24),48),w[M+2>>1]=O;e=e+4|0;f=f+16|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<4;break u}k=fb-16|0;fb=k;x[k+12>>2]=j>>>4;x[k+8>>2]=b;h=x[Hb(k+12|0,k+8|0)>>2];b=h;while(1){if(b){i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);M=e,O=Sc(o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)),g|(d|a>>>8),48),w[M>>1]=O;i=y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);M=e,O=Sc(o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)),g|(d|a>>>8),48),w[M+2>>1]=O;e=e+4|0;f=f+16|0;b=b-1|0;continue}break}fb=k+16|0;e=h<<4;break u}if(!(y[a+1|0]!=1|(h|0)!=3|(d|0)!=32)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){m=ag((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));m=li(E(Pd(Kg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));_:{if(E(F(m))<E(2147483648)){g=~~m;break _}g=-2147483648}M=e,O=gd(g),w[M>>1]=O;e=e+2|0;f=f+4|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<2;break u}d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];g=a;while(1){if(g){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);m=ag((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=li(E(Pd(Kg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));$:{if(E(F(m))<E(2147483648)){b=~~m;break $}b=-2147483648}M=e,O=gd(b),w[M>>1]=O;e=e+2|0;f=f+4|0;g=g-1|0;continue}break}fb=d+16|0;e=a<<2;break u}d=e&255;if(!(y[a+1|0]!=2|(h|0)!=3|(d|0)!=32)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){m=ag((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));m=li(E(Pd(Kg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));aa:{if(E(F(m))<E(2147483648)){g=~~m;break aa}g=-2147483648}M=e,O=gd(g),w[M>>1]=O;m=ag((l(2,y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24)),r()));m=li(E(Pd(Kg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));ba:{if(E(F(m))<E(2147483648)){g=~~m;break ba}g=-2147483648}M=e,O=gd(g),w[M+2>>1]=O;e=e+4|0;f=f+8|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<3;break u}d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=b;a=x[Hb(d+12|0,d+8|0)>>2];g=a;while(1){if(g){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);m=ag((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=li(E(Pd(Kg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));ca:{if(E(F(m))<E(2147483648)){b=~~m;break ca}b=-2147483648}M=e,O=gd(b),w[M>>1]=O;b=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);m=ag((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=li(E(Pd(Kg(m)?m>=E(0)?E(1):E(-1):m,E(-1))*E(32768)));da:{if(E(F(m))<E(2147483648)){b=~~m;break da}b=-2147483648}M=e,O=gd(b),w[M+2>>1]=O;e=e+4|0;f=f+8|0;g=g-1|0;continue}break}fb=d+16|0;e=a<<3;break u}if(!(y[a+1|0]!=1|(h|0)!=3|(d|0)!=64)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){g=fb-32|0;fb=g;x[g+24>>2]=j>>>3;x[g+16>>2]=b;d=x[Hb(g+24|0,g+16|0)>>2];b=d;while(1){if(b){a=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,a|0);q=Jg(+n());M=g,V=Af(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=Fe(C[Yg(g+24|0,g+16|0,g+8|0)>>3]*32768);ea:{if(F(q)<2147483648){a=~~q;break ea}a=-2147483648}M=e,O=gd(a),w[M>>1]=O;e=e+2|0;f=f+8|0;b=b-1|0;continue}break}fb=g+32|0;e=d<<3;break u}k=fb-32|0;fb=k;x[k+24>>2]=j>>>3;x[k+16>>2]=b;h=x[Hb(k+24|0,k+16|0)>>2];b=h;while(1){if(b){i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)));l(1,g|(d|a>>>8));q=Jg(+n());M=k,V=Af(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[k+16>>2]=0;x[k+20>>2]=-1074790400;x[k+8>>2]=0;x[k+12>>2]=1072693248;q=Fe(C[Yg(k+24|0,k+16|0,k+8|0)>>3]*32768);fa:{if(F(q)<2147483648){a=~~q;break fa}a=-2147483648}M=e,O=gd(a),w[M>>1]=O;e=e+2|0;f=f+8|0;b=b-1|0;continue}break}fb=k+32|0;e=h<<3;break u}d=e&255;if(!(y[a+1|0]!=2|(h|0)!=3|(d|0)!=64)){e=x[b+20>>2];b=x[b>>2];if(!y[a+2|0]){g=fb-32|0;fb=g;x[g+24>>2]=j>>>4;x[g+16>>2]=b;d=x[Hb(g+24|0,g+16|0)>>2];b=d;while(1){if(b){a=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,a|0);q=Jg(+n());M=g,V=Af(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=Fe(C[Yg(g+24|0,g+16|0,g+8|0)>>3]*32768);ga:{if(F(q)<2147483648){a=~~q;break ga}a=-2147483648}M=e,O=gd(a),w[M>>1]=O;a=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);l(0,y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24));l(1,a|0);q=Jg(+n());M=g,V=Af(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=Fe(C[Yg(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(F(q)<2147483648){a=~~q;break ha}a=-2147483648}M=e,O=gd(a),w[M+2>>1]=O;e=e+4|0;f=f+16|0;b=b-1|0;continue}break}fb=g+32|0;e=d<<4;break u}k=fb-32|0;fb=k;x[k+24>>2]=j>>>4;x[k+16>>2]=b;h=x[Hb(k+24|0,k+16|0)>>2];b=h;while(1){if(b){i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)));l(1,g|(d|a>>>8));q=Jg(+n());M=k,V=Af(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[k+16>>2]=0;x[k+20>>2]=-1074790400;x[k+8>>2]=0;x[k+12>>2]=1072693248;q=Fe(C[Yg(k+24|0,k+16|0,k+8|0)>>3]*32768);ia:{if(F(q)<2147483648){a=~~q;break ia}a=-2147483648}M=e,O=gd(a),w[M>>1]=O;i=y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24);g=i<<24|(i&65280)<<8;a=i&-16777216;d=a>>>24|0;o=a<<8;a=i&16711680;j=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);l(0,o|a<<24|(((j&255)<<24|i>>>8)&-16777216|((j&16777215)<<8|i>>>24)&16711680|(j>>>8&65280|j>>>24)));l(1,g|(d|a>>>8));q=Jg(+n());M=k,V=Af(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[k+16>>2]=0;x[k+20>>2]=-1074790400;x[k+8>>2]=0;x[k+12>>2]=1072693248;q=Fe(C[Yg(k+24|0,k+16|0,k+8|0)>>3]*32768);ja:{if(F(q)<2147483648){a=~~q;break ja}a=-2147483648}M=e,O=gd(a),w[M+2>>1]=O;e=e+4|0;f=f+16|0;b=b-1|0;continue}break}fb=k+32|0;e=h<<4;break u}ka:{if((d|0)==24){if((h|0)!=15|(y[a+1|0]-1&255)>>>0>1){break ka}x[s+48>>2]=-2147483648;la:{if(!y[a+2|0]){o=s+48|0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;xc(t+12|0,(j>>>0)/3|0);e=f;h=x[t+12>>2];d=h;while(1){if(d){i=y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24;ma:{if((i|0)<0){a=-2147483648;if((i|0)==-2147483648){break ma}i=0-i|0}a=g>>>0<i>>>0?i:g}g=a;d=d-1|0;e=e+3|0;continue}else{na:{if(!g){break na}k=g-1|0;j=g>>>1|0;i=x[b+20>>2];e=h;while(1){if(!e){break na}a=y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24;d=a&-2147483648|a>>>1;a=j|a<<31;oa:{if((d|0)>0|(d|0)>=0){a=Cua(a,d,g,0);d=hb;break oa}d=Cua(k-a|0,0-((a>>>0>k>>>0)+d|0)|0,g,0);a=0-d|0;d=0-(hb+((d|0)!=0)|0)|0}M=i,O=rd(Gc(a,d),16),w[M>>1]=O;e=e-1|0;f=f+3|0;i=i+2|0;continue}}}break}if(o){x[o>>2]=g}fb=t+16|0;e=D(h,3);break la}o=s+48|0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;xc(t+12|0,(j>>>0)/3|0);e=f;h=x[t+12>>2];d=h;while(1){if(d){i=y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24;pa:{if((i|0)<0){a=-2147483648;if((i|0)==-2147483648){break pa}i=0-i|0}a=g>>>0<i>>>0?i:g}g=a;d=d-1|0;e=e+3|0;continue}else{qa:{if(!g){break qa}k=g-1|0;j=g>>>1|0;i=x[b+20>>2];e=h;while(1){if(!e){break qa}a=y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24;d=a&-2147483648|a>>>1;a=j|a<<31;ra:{if((d|0)>0|(d|0)>=0){a=Cua(a,d,g,0);d=hb;break ra}d=Cua(k-a|0,0-((a>>>0>k>>>0)+d|0)|0,g,0);a=0-d|0;d=0-(hb+((d|0)!=0)|0)|0}M=i,O=rd(Gc(a,d),16),w[M>>1]=O;e=e-1|0;f=f+3|0;i=i+2|0;continue}}}break}if(o){x[o>>2]=g}fb=t+16|0;e=D(h,3)}if(!e){break u}a=x[s+48>>2];if((a|0)==-2147483648){break u}f=Aua(z[b+32>>1],0,a,0);a=hb;f=f+1073741824|0;a=f>>>0<1073741824?a+1|0:a;M=b,O=Ld(Bc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break u}d=e&255;if((d|0)==32){if(!((h|0)!=15|(y[a+1|0]-1&255)>>>0>1)){x[s+48>>2]=-2147483648;sa:{if(!y[a+2|0]){o=s+48|0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;xc(t+12|0,j>>>2|0);d=f;h=x[t+12>>2];g=h;while(1){if(g){e=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);ta:{if((e|0)<0){a=-2147483648;if((e|0)==-2147483648){break ta}e=0-e|0}a=e>>>0>i>>>0?e:i}i=a;g=g-1|0;d=d+4|0;continue}else{ua:{if(!i){break ua}k=i-1|0;j=i>>>1|0;g=x[b+20>>2];e=h;while(1){if(!e){break ua}a=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);d=a&-2147483648|a>>>1;a=j|a<<31;va:{if((d|0)>0|(d|0)>=0){a=Cua(a,d,i,0);d=hb;break va}d=Cua(k-a|0,0-((a>>>0>k>>>0)+d|0)|0,i,0);a=0-d|0;d=0-(hb+((d|0)!=0)|0)|0}M=g,O=rd(Gc(a,d),16),w[M>>1]=O;e=e-1|0;f=f+4|0;g=g+2|0;continue}}}break}if(o){x[o>>2]=i}fb=t+16|0;e=h<<2;break sa}o=s+48|0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;xc(t+12|0,j>>>2|0);g=f;h=x[t+12>>2];e=h;while(1){if(e){a=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);d=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);wa:{if((d|0)<0){a=-2147483648;if((d|0)==-2147483648){break wa}d=0-d|0}a=d>>>0>i>>>0?d:i}i=a;e=e-1|0;g=g+4|0;continue}else{xa:{if(!i){break xa}k=i-1|0;j=i>>>1|0;g=x[b+20>>2];e=h;while(1){if(!e){break xa}a=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);d=a&-2147483648|a>>>1;a=j|a<<31;ya:{if((d|0)>0|(d|0)>=0){a=Cua(a,d,i,0);d=hb;break ya}d=Cua(k-a|0,0-((a>>>0>k>>>0)+d|0)|0,i,0);a=0-d|0;d=0-(hb+((d|0)!=0)|0)|0}M=g,O=rd(Gc(a,d),16),w[M>>1]=O;e=e-1|0;f=f+4|0;g=g+2|0;continue}}}break}if(o){x[o>>2]=i}fb=t+16|0;e=h<<2}if(!e){break u}a=x[s+48>>2];if((a|0)==-2147483648){break u}f=Aua(z[b+32>>1],0,a,0);a=hb;f=f+1073741824|0;a=f>>>0<1073741824?a+1|0:a;M=b,O=Ld(Bc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break u}if((h|0)!=14|(y[a+1|0]-1&255)>>>0>1){break ka}x[s+48>>2]=1065353216;za:{if(!y[a+2|0]){d=s+48|0;g=fb-16|0;fb=g;M=g,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;xc(g+12|0,j>>>2|0);h=f;a=x[g+12>>2];e=a;while(1){if(e){m=ag((l(2,y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24)),r()));m=E(F(Kg(m)?m>=E(0)?E(1):E(-1):m));u=m>u?m:u;e=e-1|0;h=h+4|0;continue}else{Aa:{if(u==E(0)){break Aa}J=E(E(1)/u);h=x[b+20>>2];e=a;while(1){if(!e){break Aa}m=ag((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));m=li(E(Pd(E(J*(Kg(m)?m>=E(0)?E(1):E(-1):m)),E(-1))*E(32768)));Ba:{if(E(F(m))<E(2147483648)){i=~~m;break Ba}i=-2147483648}M=h,O=gd(i),w[M>>1]=O;e=e-1|0;f=f+4|0;h=h+2|0;continue}}if(d){B[d>>2]=u}fb=g+16|0;e=a<<2}break}break za}d=s+48|0;i=fb-16|0;fb=i;M=i,O=D(x[b>>2],_d(z[b+34>>1])),x[M+12>>2]=O;xc(i+12|0,j>>>2|0);g=f;a=x[i+12>>2];e=a;while(1){if(e){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);m=ag((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));m=E(F(Kg(m)?m>=E(0)?E(1):E(-1):m));u=m>u?m:u;e=e-1|0;g=g+4|0;continue}else{Ca:{if(u==E(0)){break Ca}J=E(E(1)/u);g=x[b+20>>2];e=a;while(1){if(!e){break Ca}h=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);m=ag((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));m=li(E(Pd(E(J*(Kg(m)?m>=E(0)?E(1):E(-1):m)),E(-1))*E(32768)));Da:{if(E(F(m))<E(2147483648)){h=~~m;break Da}h=-2147483648}M=g,O=gd(h),w[M>>1]=O;e=e-1|0;f=f+4|0;g=g+2|0;continue}}if(d){B[d>>2]=u}fb=i+16|0;e=a<<2}break}}if(!e){break u}m=B[s+48>>2];if(m==E(1)){break u}m=li(CB(E(m*E(z[b+32>>1])),E(1),E(64)));a=65535;Ea:{if(m>=E(65535)){break Ea}a=0;if(m<=E(0)){break Ea}a=~~m>>>0;if(m<E(4294967296)&m>=E(0)){break Ea}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break u}if((h|0)!=14|(y[a+1|0]-1&255)>>>0>1|(d|0)!=64){break ka}x[s+48>>2]=0;x[s+52>>2]=1072693248;Fa:{if(!y[a+2|0]){h=s+48|0;i=fb-32|0;fb=i;M=i,O=D(x[b>>2],_d(z[b+34>>1])),x[M+4>>2]=O;xc(i+4|0,j>>>3|0);d=f;a=x[i+4>>2];e=a;while(1){if(e){g=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));l(1,g|0);q=Jg(+n());q=F(Af(q)?q>=0?1:-1:q);H=q>H?q:H;e=e-1|0;d=d+8|0;continue}else{Ga:{if(H==0){break Ga}K=1/H;d=x[b+20>>2];e=a;while(1){if(!e){break Ga}g=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,g|0);q=Jg(+n());M=i,V=K*(Af(q)?q>=0?1:-1:q),C[M+24>>3]=V;x[i+16>>2]=0;x[i+20>>2]=-1074790400;x[i+8>>2]=0;x[i+12>>2]=1072693248;q=Fe(C[Yg(i+24|0,i+16|0,i+8|0)>>3]*32768);Ha:{if(F(q)<2147483648){g=~~q;break Ha}g=-2147483648}M=d,O=gd(g),w[M>>1]=O;e=e-1|0;f=f+8|0;d=d+2|0;continue}}if(h){C[h>>3]=H}fb=i+32|0;e=a<<3}break}break Fa}o=s+48|0;G=fb-32|0;fb=G;M=G,O=D(x[b>>2],_d(z[b+34>>1])),x[M+4>>2]=O;xc(G+4|0,j>>>3|0);d=f;a=x[G+4>>2];e=a;while(1){if(e){k=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);j=k<<24|(k&65280)<<8;g=k&-16777216;h=g>>>24|0;t=g<<8;g=k&16711680;i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,t|g<<24|(((i&255)<<24|k>>>8)&-16777216|((i&16777215)<<8|k>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,j|(h|g>>>8));q=Jg(+n());q=F(Af(q)?q>=0?1:-1:q);H=q>H?q:H;e=e-1|0;d=d+8|0;continue}else{Ia:{if(H==0){break Ia}K=1/H;d=x[b+20>>2];e=a;while(1){if(!e){break Ia}t=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);k=t<<24|(t&65280)<<8;i=t&16711680;j=i>>>8|0;h=t&-16777216;g=h>>>24|0;i=h<<8|i<<24;h=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,i|(((h&255)<<24|t>>>8)&-16777216|((h&16777215)<<8|t>>>24)&16711680|(h>>>8&65280|h>>>24)));l(1,k|(g|j));q=Jg(+n());M=G,V=K*(Af(q)?q>=0?1:-1:q),C[M+24>>3]=V;x[G+16>>2]=0;x[G+20>>2]=-1074790400;x[G+8>>2]=0;x[G+12>>2]=1072693248;q=Fe(C[Yg(G+24|0,G+16|0,G+8|0)>>3]*32768);Ja:{if(F(q)<2147483648){g=~~q;break Ja}g=-2147483648}M=d,O=gd(g),w[M>>1]=O;e=e-1|0;f=f+8|0;d=d+2|0;continue}}if(o){C[o>>3]=H}fb=G+32|0;e=a<<3}break}}if(!e){break u}q=C[s+48>>3];if(q==1){break u}M=b,O=LD(Zv(q*+z[b+32>>1],1,64)),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break u}Ka:{La:{Ma:{Na:{d=(e&255)!=32;Oa:{if(!(d|(y[a+1|0]!=1|(h|0)!=12))){u=E(30517578125e-15);if(!y[a+2|0]){break Oa}break Ka}if(!(y[a+1|0]!=2|(h|0)!=12|d)){u=E(30517578125e-15);if(!y[a+2|0]){break Ma}break La}d=(e&255)!=32;if(d|(y[a+1|0]!=1|(h|0)!=13)){break Na}u=E(1.1920928955078125e-7);if(y[a+2|0]){break Ka}}a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){m=ag((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));m=li(E(Pd(E((Kg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Pa:{if(E(F(m))<E(2147483648)){g=~~m;break Pa}g=-2147483648}M=e,O=gd(g),w[M>>1]=O;e=e+2|0;f=f+4|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<2;break u}e=0;if(y[a+1|0]!=2|(h|0)!=13|d){break u}u=E(1.1920928955078125e-7);if(y[a+2|0]){break La}}a=x[b>>2];e=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];b=a;while(1){if(b){m=ag((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));m=li(E(Pd(E((Kg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Qa:{if(E(F(m))<E(2147483648)){g=~~m;break Qa}g=-2147483648}M=e,O=gd(g),w[M>>1]=O;m=ag((l(2,y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24)),r()));m=li(E(Pd(E((Kg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Ra:{if(E(F(m))<E(2147483648)){g=~~m;break Ra}g=-2147483648}M=e,O=gd(g),w[M+2>>1]=O;e=e+4|0;f=f+8|0;b=b-1|0;continue}break}fb=d+16|0;e=a<<3;break u}a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>3;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);m=ag((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=li(E(Pd(E((Kg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Sa:{if(E(F(m))<E(2147483648)){b=~~m;break Sa}b=-2147483648}M=g,O=gd(b),w[M>>1]=O;b=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);m=ag((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=li(E(Pd(E((Kg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Ta:{if(E(F(m))<E(2147483648)){b=~~m;break Ta}b=-2147483648}M=g,O=gd(b),w[M+2>>1]=O;g=g+4|0;f=f+8|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<3;break u}a=x[b>>2];g=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=j>>>2;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);m=ag((l(2,b<<24|(b&65280)<<8|(b>>>8&65280|b>>>24)),r()));m=li(E(Pd(E((Kg(m)?m>=E(0)?E(1):E(-1):m)*u),E(-1))*E(32768)));Ua:{if(E(F(m))<E(2147483648)){b=~~m;break Ua}b=-2147483648}M=g,O=gd(b),w[M>>1]=O;g=g+2|0;f=f+4|0;e=e-1|0;continue}break}fb=d+16|0;e=a<<2;break u}a=T(28816)|0}if((gb|0)!=($(28816)|0)){break e}Y(a|0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break v}}ub(o);break u}a=N()|0;break e}x[31609]=0;P(149,c|0,e+L|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break g}}Kc(I)}fb=s+2240|0;return e|0}a=N()|0;break a}a=N()|0}ub(o);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}Kc(I);Q(a|0);p()}function $ra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0;e=fb-608|0;fb=e;yc(b);d=fb-16|0;fb=d;g=e+416|0;sw(d+8|0,g);j=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(j|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(j|0);if(!d){GZ(g)}a:{b:{c:{if(!d){break c}if(!IZ(g)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(HZ(g),hb))){break c}f=1;if((c|0)==64){break c}Dd(a,32);v[e+415|0]=0;j=Fb(e+400|0);d:{e:{f:{g:{h:{i:{if((y[e+416|0]|y[e+417|0]<<8|(y[e+418|0]<<16|y[e+419|0]<<24))==778924148){x[31609]=0;O(417,a|0,16777216);d=x[31609];x[31609]=0;if((d|0)==1){break b}d=x[b>>2];x[31609]=0;d=R(154,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}x[31609]=0;P(149,b|0,d-4|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}x[31609]=0;B=R(151,b|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break i}break b}j:{k:{l:{m:{n:{o:{if(((y[e+456|0]|y[e+457|0]<<8)-2185&65535)>>>0>1910){break o}d=x[b>>2];x[31609]=0;d=R(154,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}x[31609]=0;P(149,b|0,d-4|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}x[31609]=0;B=R(151,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}if(B>>>0<256){break o}d=x[b>>2];x[31609]=0;d=R(154,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}if(d>>>0<=B>>>0){break o}x[31609]=0;d=P(149,b|0,B|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}if(!d){break o}x[31609]=0;d=R(418,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}if(!d){break o}x[31609]=0;O(417,a|0,16777216);d=x[31609];x[31609]=0;if((d|0)==1){break b}d=y[e+456|0]|y[e+457|0]<<8;if(d>>>0>=4096){x[31609]=0;c=P(1,e+160|0,16553)|0;b=x[31609];x[31609]=0;if((b|0)==1){break h}a=x[a+1298472>>2];x[31609]=0;S(385,a|0,1,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(c);f=0;break d}b=N()|0;tb(c);break a}if(d>>>0<2194){break o}x[31609]=0;d=P(1,e+388|0,16082)|0;f=x[31609];x[31609]=0;if((f|0)==1){break n}f=x[a+1298472>>2];x[31609]=0;S(385,f|0,4,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break m}tb(d)}if(x[a+480180>>2]!=32){break i}d=y[e+456|0]|y[e+457|0]<<8;if((d&61440)!=20480){break j}d=d&4095;f=d<<16;if((y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))!=1414548815){break l}v[e+415|0]=1;break k}b=N()|0;break a}b=N()|0;tb(d);break a}if(d>>>0<297){break k}f=y[e+476|0]|y[e+477|0]<<8|f}x[a+1074308>>2]=f;break i}f=y[e+458|0]|y[e+459|0]<<8;if(!((f|0)!=2184&(d|0)!=2184)){v[e+415|0]=1;x[a+1074308>>2]=18284544;break i}if((d|0)!=768){if((d|0)!=532|(f|0)!=514|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))){break i}x[a+1074308>>2]=17367040;x[31609]=0;d=P(1,e+376|0,14750)|0;f=x[31609];x[31609]=0;if((f|0)!=1){zb(j,d);tb(d);v[e+415|0]=1;break i}b=N()|0;break a}if(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)|(f|0)!=768|((y[e+448|0]|y[e+449|0]<<8)!=256|y[e+468|0]!=128)){break i}if(y[e+469|0]){break i}x[a+1074308>>2]=18285088;v[e+415|0]=1}d=y[e+460|0]|y[e+461|0]<<8;f=d>>>2|0;x[a+480208>>2]=d<<3&32768|(f&8|(f&4|(x[a+480208>>2]&-32797|d<<1&16)));f=e+280|0;n=e+420|0;Yr(f,n);x[31609]=0;d=e+160|0;O(218,d|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break g}zb(a+1298308|0,d);tb(d);if(!(!(y[e+462|0]&4)|x[a+1074308>>2]-18285314>>>0>4276681982)){x[a+480216>>2]=y[e+446|0];x[a+480220>>2]=y[e+447|0]}d=y[e+464|0];x[a+480200>>2]=d>>>0>128?256:d<<1;d=y[e+466|0];if(d){x[a+480196>>2]=d}v[e+160|0]=31;v[e+280|0]=y[e+467|0];d=e+160|0;f=e+280|0;M=a,T=D(y[cf(d,f)|0],1e4),x[M+480204>>2]=T;v[e+160|0]=y[e+465|0];v[e+280|0]=128;M=a,T=y[Qb(d,f)|0],x[M+480228>>2]=T;h=a+480280|0;i=e+480|0;m=e+544|0;f=0;while(1){if((f|0)==64){p:{x[31609]=0;P(149,b|0,192)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}if(x[a+480180>>2]==16777216){if(((y[e+456|0]|y[e+457|0]<<8)-2187&65535)>>>0<=2){break p}}d=y[a+484376|0];f=x[a+484360>>2];x[31609]=0;aa(348,Xb(f,d)|0,b|0,y[e+448|0]|y[e+449|0]<<8,255,254);d=x[31609];x[31609]=0;if((d|0)==1){break b}break e}}else{g=f+i|0;q:{if(y[g|0]==255){break q}d=h+(f<<5)|0;Ve(d);M=d,T=Ld(y[f+m|0],0,64),w[M+6>>1]=T;g=v[g|0];if((g|0)<0){x[d>>2]=x[d>>2]|1024}g=g&127;if(g>>>0<=64){w[d+4>>1]=g<<2;break q}if((g|0)!=100){break q}x[d>>2]=x[d>>2]|256}f=f+1|0;continue}break}f=0;x[31609]=0;d=R(189,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break f}if(d){break d}x[31609]=0;d=R(151,b|0)|0;g=x[31609];x[31609]=0;r:{if((g|0)==1){break r}if(d>>>0>4e3){break d}g=y[a+484376|0];m=x[a+484360>>2];x[31609]=0;d=U(419,Xb(m,g)|0,b|0,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break r}if(!d){break d}break e}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}s=Nb(e+364|0);o=Nb(e+352|0);f=0;m=Nb(e+340|0);x[31609]=0;d=U(420,b|0,s|0,y[e+450|0]|y[e+451|0]<<8)|0;g=x[31609];x[31609]=0;s:{t:{u:{if((g|0)==1){break u}if(!d){break s}x[31609]=0;d=U(420,b|0,o|0,y[e+452|0]|y[e+453|0]<<8)|0;g=x[31609];x[31609]=0;if((g|0)==1){break u}if(!d){break s}x[31609]=0;d=U(420,b|0,m|0,y[e+454|0]|y[e+455|0]<<8)|0;g=x[31609];x[31609]=0;if((g|0)==1){break u}if(!d){break s}x[e+336>>2]=-1;M=e,T=wb(x[s>>2]),x[M+160>>2]=T;g=wb(x[s+4>>2]);d=x[e+336>>2];while(1){f=x[e+160>>2];if(Ib(f,g)){f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!(!f|d>>>0<=f>>>0)){x[e+336>>2]=f;d=f}Xe(e+160|0);continue}else{M=e,T=wb(x[o>>2]),x[M+160>>2]=T;g=wb(x[o+4>>2]);d=x[e+336>>2];while(1){f=x[e+160>>2];if(Ib(f,g)){f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!(!f|d>>>0<=f>>>0)){x[e+336>>2]=f;d=f}Xe(e+160|0);continue}else{M=e,T=wb(x[m>>2]),x[M+160>>2]=T;g=wb(x[m+4>>2]);d=x[e+336>>2];v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{while(1){f=x[e+160>>2];if(Ib(f,g)){f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!(!f|d>>>0<=f>>>0)){x[e+336>>2]=f;d=f}Xe(e+160|0);continue}else{if(v[e+462|0]&1){x[e+160>>2]=y[e+472|0]|y[e+473|0]<<8|(y[e+474|0]<<16|y[e+475|0]<<24);d=x[Hb(e+336|0,e+160|0)>>2];x[e+336>>2]=d}g=0;if((y[e+458|0]|y[e+459|0]<<8)!=532){break D}f=y[e+456|0]|y[e+457|0]<<8;if(y[e+447|0]|(f?(f|0)!=532:0)|(y[e+446|0]|y[e+469|0])){break D}if(y[e+460|0]&192|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))){break D}if(y[e+450|0]|y[e+451|0]<<8){break E}g=y[e+452|0]|y[e+453|0]<<8;if(!g){break E}if((x[b+8>>2]+(oc(x[o>>2],x[o+4>>2])<<2)|0)+2>>>0>d>>>0){break E}}break}f=0;while(1){d=f&65535;if(d>>>0<(g&65535)>>>0){x[31609]=0;g=R(151,b|0)|0;l=x[31609];x[31609]=0;F:{if((l|0)!=1){if(!g){break F}Ih(b,(d<<2)+4|0);break E}b=N()|0;break t}f=f+1|0;g=y[e+452|0]|y[e+453|0]<<8;continue}break}x[31609]=0;d=P(1,e+324|0,15065)|0;f=x[31609];x[31609]=0;if((f|0)==1){break C}zb(j,d);tb(d)}g=1;if(y[e+456|0]|y[e+457|0]<<8){break D}x[31609]=0;d=P(1,e+312|0,15518)|0;f=x[31609];x[31609]=0;if((f|0)==1){break B}zb(j,d);tb(d)}d=y[e+462|0]|y[e+463|0]<<8;G:{if(d&2){x[31609]=0;f=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break w}d=x[b+8>>2];l=x[b>>2];x[31609]=0;k=d;d=f<<3;l=U(150,l|0,k|0,d|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break w}if(!(!l|A[e+336>>2]<d+x[b+8>>2]>>>0)){x[31609]=0;O(421,a+1298412|0,f|0);d=x[31609];x[31609]=0;if((d|0)==1){break w}M=e,T=wb(x[a+1298412>>2]),x[M+280>>2]=T;l=wb(x[a+1298416>>2]);H:{I:{while(1){d=x[e+280>>2];if(!Ib(d,l)){if(!(!f&g)){break G}if(!(y[e+462|0]&4)){break H}x[31609]=0;d=P(1,e+300|0,15551)|0;f=x[31609];x[31609]=0;if((f|0)==1){break I}zb(j,d);tb(d);break G}x[31609]=0;O(422,b|0,e+160|0);k=x[31609];x[31609]=0;if((k|0)!=1){x[d>>2]=0;x[d+4>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+8>>2]=0;x[d+12>>2]=0;x[d+16>>2]=0;k=y[e+160|0]|y[e+161|0]<<8;if(k|(y[e+162|0]|y[e+163|0]<<8)){x[d>>2]=((k&65024)>>>9|0)+1980;M=d,T=Yb((y[e+160|0]|y[e+161|0]<<8)>>>5&15,1,12),x[M+4>>2]=T;M=d,T=Yb((y[e+160|0]|y[e+161|0]<<8)&31,1,31),x[M+8>>2]=T;M=d,T=Yb((y[e+162|0]|y[e+163|0]<<8)>>>11|0,0,23),x[M+12>>2]=T;M=d,T=Yb((y[e+162|0]|y[e+163|0]<<8)>>>5&63,0,59),x[M+16>>2]=T;k=Yb((y[e+162|0]|y[e+163|0]<<8)<<1&62,0,59);x[d+24>>2]=k;x[d+28>>2]=k>>31}x[d+32>>2]=y[e+164|0]|y[e+165|0]<<8|(y[e+166|0]<<16|y[e+167|0]<<24);x[e+280>>2]=x[e+280>>2]+40;continue}break}b=N()|0;break t}b=N()|0;break t}x[31609]=0;d=P(1,e+300|0,15087)|0;f=x[31609];x[31609]=0;if((f|0)!=1){zb(j,d);tb(d);break G}b=N()|0;break t}Ih(b,2);break G}if(g^1|d>>>0>1){break G}x[31609]=0;d=R(189,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break v}if(!d){x[31609]=0;d=P(1,e+300|0,15065)|0;f=x[31609];x[31609]=0;if((f|0)!=1){zb(j,d);tb(d);break G}b=N()|0;break t}Ih(b,2)}J:{if(!(y[e+460|0]&128|y[e+462|0]&8)){break J}x[31609]=0;d=a+901404|0;f=P(423,b|0,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break A}if(!f){break J}DD(d)}if((y[e+458|0]|y[e+459|0]<<8)>>>0<=531){lr(a+901404|0)}x[31609]=0;C=R(168,e+280|0)|0;d=x[31609];x[31609]=0;K:{L:{M:{if((d|0)!=1){x[31609]=0;f=P(412,b|0,13951)|0;d=x[31609];x[31609]=0;if((d|0)==1){break M}if(f){x[31609]=0;g=R(151,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break L}x[31609]=0;d=e+260|0;S(185,d|0,b|0,g|0);g=x[31609];x[31609]=0;if((g|0)==1){break L}g=hc(e+160|0,d);kd(C,g);ub(g);ub(d)}w[a+480188>>1]=1;x[31609]=0;d=P(412,b|0,13956)|0;g=x[31609];x[31609]=0;if((g|0)==1){break M}if(!d){break y}x[31609]=0;d=R(151,b|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){x[31609]=0;S(185,e+260|0,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){break K}}b=N()|0;break x}b=N()|0;break t}b=N()|0;break x}b=N()|0;break x}f=e+260|0;d=hc(e+160|0,f);ub(f);g=x[d>>2];x[31609]=0;g=R(154,g|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break z}w[e+260>>1]=(g>>>0)/20;g=z[Oc(25044,f)>>1];w[a+480188>>1]=g;f=0;while(1){if((f|0)==(g|0)){ub(d);f=1;break y}x[31609]=0;S(424,d|0,(h+(f<<5)|0)+9|0,20);l=x[31609];x[31609]=0;if((l|0)!=1){f=f+1|0;continue}break}break z}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;ub(d);break x}N:{O:{P:{Q:{R:{S:{T:{U:{V:{d=x[e+336>>2];g=x[b+8>>2];W:{if(d>>>0>=g>>>0){d=d-g|0;break W}x[31609]=0;d=R(202,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break V}}x[31609]=0;g=e+160|0;S(185,g|0,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break V}G=hc(e+260|0,g);ub(g);x[31609]=0;d=e+258|0;S(425,d|0,a|0,G|0);g=x[31609];x[31609]=0;if((g|0)==1){break U}H=Jc(d);I=y[e+258|0]!=0|f;if((y[e+456|0]|y[e+457|0]<<8)!=535|(y[e+458|0]|y[e+459|0]<<8)!=512|(y[H|0]|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)))){break Q}X:{if(I){break X}f=Xb(x[a+484360>>2],y[a+484376|0]);d=x[f+4>>2];if(!mc(x[f>>2],d)){if(z[Gn(d)>>1]==65535){break X}}if(!rq(i,255,64)){break S}}x[a+1074308>>2]=18219008;x[31609]=0;d=P(1,e+244|0,14922)|0;f=x[31609];x[31609]=0;if((f|0)==1){break T}break R}b=N()|0;break x}b=N()|0;break N}b=N()|0;break N}x[a+1074308>>2]=18284544;x[31609]=0;d=P(1,e+244|0,16904)|0;f=x[31609];x[31609]=0;if((f|0)==1){break P}}zb(j,d);tb(d);v[e+415|0]=1}Y:{if(!(v[e+462|0]&1)|!(y[e+470|0]|y[e+471|0]<<8)){break Y}x[31609]=0;d=P(149,b|0,y[e+472|0]|y[e+473|0]<<8|(y[e+474|0]<<16|y[e+475|0]<<24))|0;f=x[31609];x[31609]=0;if((f|0)==1){break O}if(!d){break Y}x[31609]=0;V(336,a+1298332|0,b|0,y[e+470|0]|y[e+471|0]<<8,4);d=x[31609];x[31609]=0;if((d|0)==1){break O}}w[a+480192>>1]=0;d=0;if(y[e+460|0]&4){w[e+160>>1]=y[e+450|0]|y[e+451|0]<<8;w[e+100>>1]=255;d=z[Oc(e+160|0,e+100|0)>>1];w[a+480192>>1]=d}f=0;Z:{while(1){if((d&65535)>>>0<=f>>>0){x[e+240>>2]=0;f=y[e+452|0]|y[e+453|0]<<8;if(f){d=yb(x[o>>2],f-1|0);x[e+240>>2]=(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+80}w[e+160>>1]=f;w[e+100>>1]=3999;d=z[Oc(e+160|0,e+100|0)>>1];w[a+480190>>1]=d;l=c&2;t=a+946304|0;q=a+484380|0;E=e+180|0;f=0;k=0;while(1){_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{if((d&65535)>>>0>f>>>0){d=yb(x[o>>2],f);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);if(!d){break $}x[31609]=0;d=P(149,b|0,d|0)|0;g=x[31609];x[31609]=0;ha:{ia:{ja:{ka:{la:{if((g|0)==1){break la}if(!d){break $}x[31609]=0;d=e+160|0;g=P(426,b|0,d|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break la}if(!g){break $}x[31609]=0;g=f+1|0;i=q+D(g,104)|0;h=P(427,d|0,i|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ka}r=e+148|0;Yr(r,E);x[31609]=0;d=e+100|0;O(218,d|0,r|0);r=x[31609];x[31609]=0;if((r|0)==1){break ja}Ac(t+(g<<5)|0,d);tb(d);x[31609]=0;h=P(149,b|0,h|0)|0;r=x[31609];x[31609]=0;if((r|0)==1){break ka}if(!h){break $}h=z[i+34>>1];if(!(h&512)){break ia}x[31609]=0;d=P(428,b|0,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break ga}if(!d){break ha}x[e+16>>2]=y[e+108|0]|y[e+109|0]<<8|(y[e+110|0]<<16|y[e+111|0]<<24);d=y[e+104|0]|y[e+105|0]<<8|(y[e+106|0]<<16|y[e+107|0]<<24);x[e+8>>2]=y[e+100|0]|y[e+101|0]<<8|(y[e+102|0]<<16|y[e+103|0]<<24);x[e+12>>2]=d;Sk(i,1,e+8|0);break ha}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}if(!(h&16384)){r=y[e+456|0]|y[e+457|0]<<8;F=e+100|0;h=y[e+178|0];k=h&2;d=y[e+206|0];g=Zc(F,k?16:8,1,0,(d^-1)&1);if(!(!(h&4)|r>>>0<532)){wp(g,3)}ma:{na:{if(h&8){h=d&4?5:4;break na}if(!k){h=10;if((d|0)==255){break na}}if(d&2){v[g+2|0]=1}if(d&4){wg(g,2)}if(!(d&8)){break ma}h=9;if(!k){break ma}}wg(g,h)}if(l){d=0;x[31609]=0;U(215,F|0,i|0,b|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){break ca}break _}d=1;g=y[e+103|0];if(g>>>0>17){break ba}h=1<<g;if(!(h&63503)){if(!(h&198144)){break ba}break da}if(y[e+100|0]){break da}break ca}x[31609]=0;O(429,b|0,e+88|0);d=x[31609];x[31609]=0;if((d|0)==1){break ea}h=x[e+88>>2];if(!(!l|!h)){d=Fb(e+100|0);x[31609]=0;S(270,b|0,d|0,h|0);h=x[31609];x[31609]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((h|0)!=1){x[31609]=0;h=e+136|0;O(383,h|0,16475);i=x[31609];x[31609]=0;if((i|0)==1){break ua}x[e+76>>2]=g;x[31609]=0;g=e+124|0;S(258,g|0,0,d|0);i=x[31609];x[31609]=0;if((i|0)==1){break ta}x[31609]=0;i=e+148|0;V(430,i|0,h|0,e+76|0,g|0);k=x[31609];x[31609]=0;if((k|0)==1){break sa}k=x[a+1298472>>2];x[31609]=0;S(385,k|0,2,i|0);k=x[31609];x[31609]=0;if((k|0)==1){break ra}tb(i);tb(g);Eb(h);tb(d);break ha}b=N()|0;break oa}b=N()|0;break oa}b=N()|0;break pa}b=N()|0;break qa}b=N()|0;tb(e+148|0)}tb(e+124|0)}Eb(e+136|0)}tb(d);break N}x[31609]=0;P(183,b|0,h|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ea}}d=0;break aa}w[e+160>>1]=1;w[e+100>>1]=d;M=a,T=z[qe(e+160|0,e+100|0)>>1],w[M+480190>>1]=T;if(!((y[e+456|0]|y[e+457|0]<<8)==516&u)|(y[e+458|0]|y[e+459|0]<<8)!=512|(y[e+462|0]|y[e+463|0]<<8|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)))){break fa}if(((y[e+460|0]|y[e+461|0]<<8)&65527)!=21|y[e+464|0]!=128|(y[e+465|0]!=48|y[e+468|0]!=128)){break fa}if(y[e+469|0]|(y[e+470|0]|y[e+471|0]<<8)){break fa}f=1;g=64;while(1){d=128;if((g|0)==128){while(1)if((d|0)==192){d=20;while(1){if((d|0)==26){va:{if(!(f&1)){break fa}x[31609]=0;d=P(1,e+148|0,9895)|0;f=x[31609];x[31609]=0;if((f|0)==1){break va}zb(j,d);tb(d);break fa}}else{f=!y[d+n|0]&f;d=d+1|0;continue}break}b=N()|0;break N}else{f=y[(e+416|0)+d|0]==64&f;d=d+1|0;continue}}else{f=(y[(e+416|0)+g|0]&127)==32&f;g=g+1|0;continue}}}b=N()|0;break N}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;f=oc(x[m>>2],x[m+4>>2]);w[e+160>>1]=f;d=e+160|0;t=z[Oc(d,x[a+8>>2]+10|0)>>1];w[e+122>>1]=t;wa:{xa:{ya:{za:{if((f|0)!=(t|0)){x[31609]=0;f=e+100|0;W(431,f|0);g=x[31609];x[31609]=0;if((g|0)==1){break wa}g=x[m+4>>2];h=x[m>>2];x[31609]=0;M=e,T=oc(h,g),x[M+136>>2]=T;V(432,d|0,f|0,e+136|0,e+122|0);g=x[31609];x[31609]=0;if((g|0)==1){break ya}g=x[a+1298472>>2];x[31609]=0;S(385,g|0,2,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break za}tb(d);Eb(f)}if(!(c&1)){w[e+122>>1]=0;t=0}h=0;Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{while(1){Ra:{if((h|0)==(t|0)){c=x[e+240>>2];if(!c){break Oa}x[31609]=0;P(149,b|0,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Qa}if(!k){break Oa}while(1){Sa:{c=x[b+8>>2];d=x[b>>2];x[31609]=0;c=U(150,d|0,c|0,4)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Sa}if(!c){break Oa}x[31609]=0;c=P(412,b|0,13930)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Sa}Ta:{if(!c){x[31609]=0;c=P(412,b|0,13935)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Sa}if(!c){break Ta}}x[31609]=0;c=R(151,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Pa}Ih(b,8);if(c&-2139062144){break Ta}if(c&1616928864){break Oa}}x[31609]=0;c=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Sa}x[31609]=0;P(183,b|0,c|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){continue}}break}b=N()|0;break N}Ua:{c=yb(x[m>>2],h);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);Va:{if(!c){break Va}x[31609]=0;c=P(149,b|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Na}if(!c){break Va}x[31609]=0;c=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Aa}x[31609]=0;n=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Ba}if((n-1025&65535)>>>0<64512){break Va}x[31609]=0;d=P(183,b|0,4)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Ba}if(!d){break Va}x[31609]=0;d=e+100|0;S(185,d|0,b|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break Ca}c=hc(e+160|0,d);ub(d);d=z[a+480188>>1];l=0;x[31609]=0;d=P(433,e+136|0,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Ea}Wa:{Xa:while(1){u=l>>>0>=n>>>0;while(1){if(u){break Wa}f=x[c>>2];x[31609]=0;f=U(150,f|0,x[e+168>>2],1)|0;g=x[31609];x[31609]=0;if((g|0)==1){break Ua}if(!f){break Wa}x[31609]=0;f=R(197,c|0)|0;g=x[31609];x[31609]=0;Ya:{if((g|0)!=1){f=f<<24>>24;if(f){break Ya}l=l+1|0;continue Xa}break Ra}Za:{g=f&127;q=g?g+65535|0:0;i=q&65535;if(Xc(x[d>>2],x[e+140>>2])>>>0>i>>>0){break Za}x[31609]=0;v[e+100|0]=0;S(434,d|0,i+1|0,e+100|0);g=x[31609];x[31609]=0;if((g|0)!=1){break Za}break Ra}_a:{if((f|0)<0){x[31609]=0;f=R(197,c|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break _a}M=xb(x[d>>2],i),T=f,v[M|0]=T}f=xb(x[d>>2],i);g=y[f|0];if(!(!(g&15)|i>>>0<z[a+480188>>1])){w[a+480188>>1]=q+1;g=y[f|0]}if(g&1){x[31609]=0;P(183,c|0,1)|0;f=x[31609];x[31609]=0;if((f|0)==1){break _a}f=xb(x[d>>2],i)}if(y[f|0]&2){x[31609]=0;P(183,c|0,1)|0;f=x[31609];x[31609]=0;if((f|0)==1){break _a}f=xb(x[d>>2],i)}if(y[f|0]&4){x[31609]=0;P(183,c|0,1)|0;f=x[31609];x[31609]=0;if((f|0)==1){break _a}f=xb(x[d>>2],i)}if(!(y[f|0]&8)){continue}x[31609]=0;P(183,c|0,2)|0;f=x[31609];x[31609]=0;if((f|0)!=1){continue}}break}break}break Ra}x[e+100>>2]=x[b+8>>2];M=e,T=x[bd(e+240|0,e+100|0)>>2],x[M+240>>2]=T;fc(d);ub(c)}h=h+1|0;continue}}break}b=N()|0;fc(d);break Da}b=N()|0;break N}b=N()|0;break N}x[31609]=0;E=P(435,a|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){c=E|y[e+415|0];v[e+415|0]=c;if(!(y[H|0]|!(c&255))){Uv(a+1074312|0);v[a+1074368|0]=0}x[31609]=0;r=ba(436,a|0,b|0,0,e+415|0)|0;c=x[31609];x[31609]=0;$a:{if((c|0)==1){break $a}x[31609]=0;q=a+484344|0;O(223,q|0,t|0);c=x[31609];x[31609]=0;if((c|0)==1){break $a}L=a+480183|0;h=0;while(1){ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{if((h|0)!=(t|0)){c=yb(x[m>>2],h);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);if(c){x[31609]=0;c=P(149,b|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ob}if(c){break nb}}x[31609]=0;c=U(196,q|0,h&65535,64)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ob}if(c){break pb}w[e+64>>1]=h;x[31609]=0;c=e+100|0;W(437,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break tb}x[31609]=0;d=e+160|0;S(438,d|0,c|0,e- -64|0);f=x[31609];x[31609]=0;if((f|0)==1){break sb}f=x[a+1298472>>2];x[31609]=0;S(385,f|0,2,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break rb}tb(d);Eb(c)}if(!x[a+1074308>>2]){f=y[e+456|0]|y[e+457|0]<<8;if((f|0)!=2184){break lb}x[a+1074308>>2]=18284544}if(!Ad(x[j+4>>2],y[j+11|0])){break mb}x[31609]=0;c=P(1,e+100|0,18262)|0;d=x[31609];x[31609]=0;if((d|0)==1){break cb}f=x[a+1074308>>2];x[31609]=0;d=e+76|0;O(134,d|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break eb}x[31609]=0;f=e+160|0;S(2,f|0,c|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break fb}g=zb(j,f);tb(f);tb(d);tb(c);f=x[a+1074308>>2];if((y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))==1414548815){break kb}if((f|0)!=18284544){break jb}f=18284544;if(!(E|(r|I))){break ib}break hb}b=N()|0;break N}b=N()|0;break qb}b=N()|0;tb(e+160|0)}Eb(e+100|0);break N}c=x[q>>2];x[31609]=0;O(439,Wb(c,h)|0,C|0);c=x[31609];x[31609]=0;if((c|0)!=1){break ab}}b=N()|0;break N}x[31609]=0;d=R(189,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Fa}x[31609]=0;F=R(189,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Ga}x[31609]=0;c=P(183,b|0,4)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Ga}if(!c){break ab}x[31609]=0;c=U(196,q|0,h&65535,F|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Ga}if(!c){break ab}x[31609]=0;c=e+100|0;S(185,c|0,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break Ha}k=hc(e+160|0,c);ub(c);d=x[q>>2];x[31609]=0;O(439,Wb(d,h)|0,C|0);d=x[31609];x[31609]=0;if((d|0)==1){break Ja}d=z[a+480188>>1];x[31609]=0;n=P(433,e+124|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Ka}d=z[a+480188>>1];w[e+104>>1]=0;x[31609]=0;x[e+100>>2]=0;l=U(440,e+88|0,d|0,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Ma}M=e,T=wb(x[Wb(x[q>>2],h)>>2]),x[M+76>>2]=T;u=0;while(1){ub:{vb:{wb:{xb:{if(u>>>0>=F>>>0){break xb}c=x[k>>2];x[31609]=0;c=U(150,c|0,x[e+168>>2],1)|0;d=x[31609];x[31609]=0;if((d|0)==1){break bb}if(!c){break xb}x[31609]=0;c=R(197,k|0)|0;d=x[31609];x[31609]=0;yb:{if((d|0)!=1){c=c<<24>>24;if(c){break yb}s_(e+76|0,z[a+480188>>1]);u=u+1|0;continue}break bb}zb:{d=c&127;i=d?d-1&65535:0;if(Xc(x[n>>2],x[e+128>>2])>>>0>i>>>0){break zb}x[31609]=0;v[e+100|0]=0;d=i+1|0;f=e+100|0;S(434,n|0,d|0,f|0);g=x[31609];x[31609]=0;if((g|0)==1){break bb}w[e+104>>1]=0;x[31609]=0;x[e+100>>2]=0;S(441,l|0,d|0,f|0);d=x[31609];x[31609]=0;if((d|0)!=1){break zb}break bb}if((c|0)<0){x[31609]=0;c=R(197,k|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break bb}M=xb(x[n>>2],i),T=c,v[M|0]=T}w[e+104>>1]=0;x[e+100>>2]=0;d=e+100|0;if(i>>>0<z[a+480188>>1]){d=Yc(x[e+76>>2],i)}g=xb(x[n>>2],i);f=y[g|0];if(f&16){M=d,T=y[Yc(x[l>>2],i)|0],v[M|0]=T;f=y[g|0]}if(f&32){M=d,T=y[Yc(x[l>>2],i)+1|0],v[M+1|0]=T;f=y[g|0]}if(f&64){c=Yc(x[l>>2],i);v[d+2|0]=y[c+2|0];v[d+4|0]=y[c+4|0];f=y[g|0]}if(f<<24>>24<0){c=Yc(x[l>>2],i);v[d+3|0]=y[c+3|0];v[d+5|0]=y[c+5|0];f=y[g|0]}if(f&1){x[31609]=0;c=R(197,k|0)|0;f=x[31609];x[31609]=0;Ab:{Bb:{if((f|0)!=1){c=c<<24>>24;c=(((c^-1)&128)>>>7|0)+c|0;if(!(v[L|0]&1)){break Bb}f=c;break Ab}break bb}f=253;if((c-121&255)>>>0<132){break Ab}f=(c&255)!=253?c:0}v[d|0]=f;M=Yc(x[l>>2],i),T=f,v[M|0]=T;g=xb(x[n>>2],i)}if(y[g|0]&2){x[31609]=0;c=R(197,k|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break bb}v[d+1|0]=c;M=Yc(x[l>>2],i),T=c,v[M+1|0]=T;g=xb(x[n>>2],i)}if(!(y[g|0]&4)){break ub}x[31609]=0;g=R(197,k|0)|0;c=x[31609];x[31609]=0;Cb:{Db:{if((c|0)!=1){if(g>>>0>64){break Db}v[d+4|0]=g;f=1;break Cb}break bb}if(g<<24>>24<=-64){f=2;v[d+2|0]=2;g=g&127;v[d+4|0]=g;break vb}if(g>>>0<=74){f=5;v[d+2|0]=5;g=g-65|0;v[d+4|0]=g;break vb}if(g>>>0<=84){f=6;v[d+2|0]=6;g=g-75|0;v[d+4|0]=g;break vb}if(g>>>0<=94){f=3;v[d+2|0]=3;g=g-85|0;v[d+4|0]=g;break vb}if(g>>>0<=104){f=4;v[d+2|0]=4;g=g-95|0;v[d+4|0]=g;break vb}if(g>>>0<=114){f=13;v[d+2|0]=13;g=g-105|0;v[d+4|0]=g;break vb}if(g>>>0<=124){f=12;v[d+2|0]=12;g=g-115|0;v[d+4|0]=g;break vb}c=g+63|0;if((c&255)>>>0<=9){v[d+4|0]=c;f=11;v[d+2|0]=11;g=c;break vb}c=g+53|0;J=c&255;if(J>>>0<=9){v[d+4|0]=c;f=8;v[d+2|0]=8;if(!J){g=0;break vb}if(x[a+1074308>>2]-1>>>0>18285139){break wb}f=7;v[d+2|0]=7;break wb}g=g+33|0;if((g&255)>>>0>=10){g=y[d+4|0];f=y[d+2|0];break vb}v[d+4|0]=g;f=15}v[d+2|0]=f;break vb}Mk(l);fc(n);ub(k);break ab}g=c}c=Yc(x[l>>2],i);v[c+4|0]=g;v[c+2|0]=f;g=xb(x[n>>2],i)}if(!(y[g|0]&8)){continue}x[31609]=0;c=e+52|0;O(198,c|0,k|0);f=x[31609];x[31609]=0;if((f|0)!=1){BD(d,y[e+52|0],y[Jc(c)|0],1);c=Yc(x[l>>2],i);v[c+3|0]=y[d+3|0];v[c+5|0]=y[d+5|0];continue}break}break bb}f=y[e+456|0]|y[e+457|0]<<8}Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{c=f&65535;switch(c>>>12|0){case 13:break Jb;case 7:break Kb;case 6:break Lb;case 4:break Mb;case 1:break Ob;case 0:break Pb;default:break gb}}if(y[H|0]){x[31609]=0;c=P(1,e+160|0,8340)|0;d=x[31609];x[31609]=0;if((d|0)!=1){zb(j,c);tb(c);break gb}b=N()|0;break N}Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{c=f&65535;if((c|0)!=532){break Yb}d=y[e+458|0]|y[e+459|0]<<8;if((d|0)!=512){break Xb}if(y[e+462|0]|y[e+463|0]<<8|(y[e+460|0]|y[e+461|0]<<8)!=9|(y[e+447|0]|y[e+446|0])){break Yb}if(y[e+450|0]|y[e+451|0]<<8|((y[e+454|0]|y[e+455|0]<<8)+1|0)!=(y[e+448|0]|y[e+449|0]<<8)|(y[e+464|0]!=128|y[e+465|0]!=100)){break Yb}if(y[e+466|0]!=1|y[e+468|0]!=128|(y[e+469|0]|(y[e+470|0]|y[e+471|0]<<8))){break Yb}if(y[e+472|0]|y[e+473|0]<<8|(y[e+474|0]<<16|y[e+475|0]<<24)|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))){break Yb}x[31609]=0;c=P(1,e+160|0,9876)|0;d=x[31609];x[31609]=0;if((d|0)!=1){zb(j,c);tb(c);break gb}b=N()|0;break N}Zb:{if((c|0)!=514|(y[e+458|0]|y[e+459|0]<<8)!=512|(y[e+447|0]|y[e+446|0])){break Zb}if(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)){break Zb}c=x[m>>2];if(mc(c,x[m+4>>2])){break Vb}d=x[o>>2];if(mc(d,x[o+4>>2])){break Vb}c=yb(c,0);g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);if(!g){break Vb}c=yb(d,0);if(g>>>0>=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))>>>0){break Vb}x[a+1074308>>2]=16777376;x[31609]=0;c=P(1,e+160|0,13487)|0;d=x[31609];x[31609]=0;if((d|0)!=1){zb(j,c);tb(c);v[e+415|0]=1;break gb}b=N()|0;break N}if((f&65535)!=532){break Wb}d=y[e+458|0]|y[e+459|0]<<8;if((d|0)!=512){break Xb}f=532;if(y[e+447|0]|y[e+446|0]){break Fb}d=512;if(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)){break Eb}_b:{if(y[e+462|0]&6){$b:{d=x[s>>2];if(oc(d,x[s+4>>2])>>>0<2){break $b}c=yb(d,1);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);c=yb(d,0);if((f-(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))|0)!=557){break $b}x[a+1074308>>2]=16777394;x[31609]=0;c=P(1,e+160|0,15298)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break _b}b=N()|0;break N}x[a+1074308>>2]=16777393;x[31609]=0;c=P(1,e+160|0,13377)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break _b}b=N()|0;break N}x[a+1074308>>2]=16777381;x[31609]=0;c=P(1,e+160|0,15003)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Ib}}zb(j,c);tb(c);v[e+415|0]=1;break gb}f=532;if((d|0)!=532){break Ub}if((y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24))==1229080643){x[31609]=0;c=P(1,e+160|0,8378)|0;d=x[31609];x[31609]=0;if((d|0)!=1){zb(j,c);tb(c);f=a+1074312|0;d=38;break Nb}b=N()|0;break N}if(y[e+469|0]|(y[e+462|0]|y[e+463|0]<<8)>>>0>1|(y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24)|((y[e+460|0]|y[e+461|0]<<8)&4294)!=4)){break Vb}if(!z[a+480190>>1]){break Vb}x[31609]=0;f=P(36,e+100|0,13620)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Sb}c=fb-32|0;fb=c;d=fb-16|0;fb=d;Tw(d+8|0,a+484527|0);lZ(c+24|0,x[d+8>>2],x[d+12>>2]);fb=d+16|0;fe(c+16|0,f);d=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=d;d=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;tb(f);if(d){break Tb}f=y[e+456|0]|y[e+457|0]<<8}if(f&65535){break Vb}if(Ad(x[j+4>>2],y[j+11|0])){break Qb}}d=y[e+458|0]|y[e+459|0]<<8}if((d&65535)>>>0>767){break gb}break Eb}x[31609]=0;c=P(1,e+160|0,8404)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Rb}zb(j,c);tb(c);break gb}b=N()|0;break N}b=N()|0;break N}x[31609]=0;c=P(1,e+160|0,9766)|0;d=x[31609];x[31609]=0;if((d|0)!=1){zb(j,c);tb(c);break gb}b=N()|0;break N}f=y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24);x[31609]=0;d=e+160|0;S(442,d|0,c|0,y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24));g=x[31609];x[31609]=0;ac:{bc:{cc:{dc:{ec:{fc:{gc:{hc:{ic:{jc:{kc:{lc:{mc:{nc:{if((g|0)!=1){zb(j,d);tb(d);c=(c|0)==8191?f:c-4176|0;if((c|0)>1915){break nc}d=x[a+480208>>2];if(!(d&16)){break mc}x[31609]=0;P(267,a+1074312|0,7)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break lc}break Gb}b=N()|0;break N}if(c>>>0>4200){break jc}d=x[a+480208>>2]}if(!(d&16)){x[31609]=0;P(267,a+1074312|0,7)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Gb}}if((c|0)>2385){break kc}}x[31609]=0;P(267,a+1074312|0,38)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Gb}}x[31609]=0;c=P(267,a+1074312|0,102)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Gb}x[31609]=0;P(267,c|0,48)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Gb}break ic}if(c>>>0>4383){break hc}}x[31609]=0;c=U(266,a+1074312|0,116,1)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Gb}x[31609]=0;P(267,c|0,115)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Gb}break gc}if(c>>>0>4563){break fc}}x[31609]=0;c=P(267,a+1074312|0,43)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Gb}x[31609]=0;c=P(267,c|0,42)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Gb}x[31609]=0;P(267,c|0,87)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Gb}break ec}if(c>>>0>4876){break dc}}x[31609]=0;P(267,a+1074312|0,120)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Gb}break cc}if(c>>>0>5100){break bc}}x[31609]=0;c=P(267,a+1074312|0,47)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Gb}x[31609]=0;P(267,c|0,39)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Gb}break ac}if(c>>>0>5103){break gb}}x[31609]=0;f=P(267,a+1074312|0,44)|0;c=x[31609];x[31609]=0;d=87;if((c|0)==1){break Gb}}x[31609]=0;P(267,f|0,d|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Gb}break gb}x[31609]=0;c=e+100|0;W(443,c|0);d=x[31609];x[31609]=0;oc:{pc:{qc:{if((d|0)!=1){d=y[e+456|0]|y[e+457|0]<<8;x[e+64>>2]=d>>>8&15;x[31609]=0;x[e+52>>2]=d&255;d=e+76|0;O(444,d|0,e+52|0);f=x[31609];x[31609]=0;if((f|0)==1){break qc}x[31609]=0;f=e+160|0;V(430,f|0,c|0,e- -64|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break pc}zb(j,f);tb(f);tb(d);Eb(c);break gb}b=N()|0;break N}b=N()|0;break oc}b=N()|0;tb(e+76|0)}Eb(e+100|0);break N}x[31609]=0;c=P(1,e+160|0,8340)|0;d=x[31609];x[31609]=0;if((d|0)!=1){zb(j,c);tb(c);break gb}b=N()|0;break N}if(!((c|0)!=32767|(y[e+458|0]|y[e+459|0]<<8)!=533)){x[31609]=0;c=P(1,e+160|0,5042)|0;d=x[31609];x[31609]=0;if((d|0)!=1){zb(j,c);tb(c);break gb}b=N()|0;break N}x[31609]=0;c=e+100|0;O(131,c|0,4150);d=x[31609];x[31609]=0;rc:{if((d|0)!=1){d=y[e+456|0]|y[e+457|0]<<8;x[e+76>>2]=d>>>8&15;x[e+64>>2]=d>>>4&15;x[31609]=0;x[e+52>>2]=d&15;d=e+160|0;aa(132,d|0,c|0,e+76|0,e- -64|0,e+52|0);f=x[31609];x[31609]=0;if((f|0)==1){break rc}zb(j,d);tb(d);Eb(c);break gb}b=N()|0;break N}b=N()|0;Eb(e+100|0);break N}x[31609]=0;c=P(1,e+160|0,6123)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Hb}zb(j,c);tb(c);break gb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}d=512}if(!Ad(x[j+4>>2],y[j+11|0])){break gb}sc:{tc:{uc:{vc:{wc:{if((d&65535)>>>0>=533){x[31609]=0;c=P(1,e+76|0,15035)|0;d=x[31609];x[31609]=0;if((d|0)!=1){zb(j,c);tb(c);break wc}b=N()|0;break N}if((f&65535)>>>0>=533){x[31609]=0;c=e+76|0;O(445,c|0,4015);d=x[31609];x[31609]=0;xc:{if((d|0)!=1){x[31609]=0;x[e+64>>2]=(y[e+456|0]|y[e+457|0]<<8)-532;d=e+160|0;S(446,d|0,c|0,e- -64|0);f=x[31609];x[31609]=0;if((f|0)==1){break xc}zb(j,d);tb(d);Eb(c);break wc}b=N()|0;break N}b=N()|0;Eb(e+76|0);break N}x[31609]=0;c=e+76|0;O(268,c|0,4314);d=x[31609];x[31609]=0;if((d|0)==1){break vc}d=y[e+456|0]|y[e+457|0]<<8;x[e+52>>2]=d>>>8&15;x[31609]=0;x[e+40>>2]=d&255;d=e- -64|0;O(444,d|0,e+40|0);f=x[31609];x[31609]=0;if((f|0)==1){break uc}x[31609]=0;f=e+160|0;V(430,f|0,c|0,e+52|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break tc}zb(j,f);tb(f);tb(d);Eb(c)}if(!mc(x[a+1298412>>2],x[a+1298416>>2])){break gb}c=y[e+476|0]|y[e+477|0]<<8|(y[e+478|0]<<16|y[e+479|0]<<24);if(!c){break gb}c=GF(y[e+456|0]|y[e+457|0]<<8,c);d=kp(e+160|0);x[d+32>>2]=c;x[31609]=0;O(447,a+1298412|0,d|0);c=x[31609];x[31609]=0;if((c|0)!=1){break gb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break sc}b=N()|0;tb(e- -64|0)}Eb(e+76|0);break N}if(!(E|(r|(f|0)!=18284544|I))){break ib}break hb}if(((y[e+456|0]|y[e+457|0]<<8)&61440)!=20480){break hb}}x[31609]=0;c=P(1,e+160|0,16916)|0;d=x[31609];x[31609]=0;yc:{if((d|0)!=1){x[31609]=0;P(74,g|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break yc}tb(c);break gb}b=N()|0;break N}b=N()|0;tb(c);break N}if(!SG(f)){break gb}x[31609]=0;c=P(1,e+160|0,17152)|0;d=x[31609];x[31609]=0;zc:{if((d|0)!=1){x[31609]=0;P(74,g|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break zc}tb(c);break gb}b=N()|0;break N}b=N()|0;tb(c);break N}Ac:{Bc:{Cc:{Dc:{Ec:{Fc:{Gc:{Hc:{Ic:{if(K&1){x[31609]=0;c=P(1,e- -64|0,17166)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Ic}x[31609]=0;P(74,j|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Hc}tb(c)}f=x[a+480180>>2];if(!((f|0)!=16777216|(y[e+456|0]|y[e+457|0]<<8)>>>0<2186)){x[31609]=0;c=P(149,b|0,B|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break $a}if(c){x[31609]=0;S(448,a|0,b|0,y[e+456|0]|y[e+457|0]<<8);b=x[31609];x[31609]=0;if((b|0)==1){break $a}}f=x[a+480180>>2]}if((f|0)!=16777216){break Gc}x[31609]=0;P(1,e+52|0,13913)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break Fc}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(c);break N}x[31609]=0;b=e+40|0;O(268,b|0,4314);c=x[31609];x[31609]=0;if((c|0)==1){break Ec}c=y[e+458|0]|y[e+459|0]<<8;x[e+36>>2]=c>>>8;x[31609]=0;x[e+20>>2]=c&255;c=e+24|0;O(444,c|0,e+20|0);d=x[31609];x[31609]=0;if((d|0)==1){break Dc}x[31609]=0;V(430,e+52|0,b|0,e+36|0,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break Cc}}b=e+52|0;zb(a+1298344|0,b);tb(b);if((f|0)!=16777216){tb(e+24|0);Eb(e+40|0)}b=x[a+480180>>2];x[31609]=0;b=P(1,e+52|0,((b|0)==16777216?10140:6127)|0)|0;c=x[31609];x[31609]=0;f=1;if((c|0)==1){break Ac}zb(a+1298356|0,b);tb(b);zb(a+1298368|0,j);M=a,T=x[Fc(e+36|0,x[a+1074308>>2]?22:4)>>2],x[M+1298404>>2]=T;x[a+1298408>>2]=0;ub(G);ub(C);break s}b=N()|0;break N}b=N()|0;break Bc}b=N()|0;tb(e+24|0)}Eb(e+40|0);break N}b=N()|0;break N}b=N()|0;tb(e+76|0);break db}b=N()|0}tb(c);break N}b=N()|0;break N}b=N()|0;Mk(l);break La}h=h+1|0;continue}}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}fc(n);break Ia}b=N()|0;break Ia}b=N()|0}ub(k);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(c);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(e+160|0);break xa}b=N()|0}Eb(e+100|0);break N}b=N()|0;break N}b=N()|0;break N}d=0;g=AD(e+100|0,x[i>>2]);x[31609]=0;P(183,b|0,g|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break _}}g=y[e+103|0];if(!x[i>>2]|(g|0)!=1){break ba}u=1;break aa}K=(g|0)==10|K}x[e+100>>2]=x[b+8>>2];M=e,T=x[bd(e+240|0,e+100|0)>>2],x[M+240>>2]=T;k=(d|0)!=0}f=f+1|0;d=z[a+480190>>1];continue}break}b=N()|0;break N}Jc:{d=yb(x[s>>2],f);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);Kc:{if(!d){break Kc}x[31609]=0;d=P(149,b|0,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break Jc}if(!d){break Kc}d=x[b+8>>2];g=x[b>>2];x[31609]=0;d=U(150,g|0,d|0,554)|0;g=x[31609];x[31609]=0;if((g|0)==1){break Jc}if(!d){break Kc}x[31609]=0;d=U(251,a|0,f+1&65535,0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break Z}if(!d){break Kc}x[31609]=0;V(449,a|0,b|0,d|0,y[e+458|0]|y[e+459|0]<<8);g=x[31609];x[31609]=0;if((g|0)==1){break Z}v[d+33|0]=y[e+469|0]}f=f+1|0;d=z[a+480192>>1];continue}break}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(G)}ub(C);break t}b=N()|0;break t}b=N()|0;break t}}}}}b=N()|0}wc(m);wc(o);wc(s);break a}wc(m);wc(o);wc(s)}tb(j)}fb=e+608|0;return f|0}b=N()|0}tb(j);Q(b|0);p()}function Dqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0,Y=0;e=fb-1712|0;fb=e;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{d=e+1704|0;i:{if(!vi(b,d)){break i}if(!oY(d)){break i}f=1;if((c|0)==64){break i}k=y[e+1707|0];v[e+1703|0]=k;x[e+1696>>2]=-1;x[e+1692>>2]=1048576;if(k>>>0>=5){d=Rg(b);x[e+1696>>2]=d;f=0;if(!Mb(x[b>>2],x[b+8>>2],d)){break i}x[e+288>>2]=134217727;X=e,Y=x[Hb(e+288|0,e+1696|0)>>2]<<5,x[X+1692>>2]=Y}C=Nb(e+1680|0);x[e+288>>2]=y[e+1708|0]|y[e+1709|0]<<8|(y[e+1710|0]<<16|y[e+1711|0]<<24);d=x[Hb(e+1692|0,e+288|0)>>2];x[31609]=0;O(553,C|0,d|0);d=x[31609];x[31609]=0;j:{k:{l:{m:{if((d|0)!=1){x[31609]=0;d=U(554,b|0,C|0,y[e+1708|0]|y[e+1709|0]<<8|(y[e+1710|0]<<16|y[e+1711|0]<<24))|0;h=x[31609];x[31609]=0;n:{if((h|0)==1){break n}f=0;if(!d){break j}if(k>>>0>=5){x[31609]=0;P(149,b|0,x[e+1696>>2]+12|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break n}}x[31609]=0;O(246,a|0,0);d=x[31609];x[31609]=0;if((d|0)==1){break n}eg(a);se(e+1648|0,x[C>>2],x[C+4>>2]);d=Md(e+1640|0);x[31609]=0;h=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=h;m=hg(555,e+1660|0,x[e+1648>>2],x[e+1652>>2],e+88|0);d=x[31609];x[31609]=0;o:{p:{q:{if((d|0)!=1){x[31609]=0;S(358,m|0,a+1298308|0,-1);d=x[31609];x[31609]=0;if((d|0)==1){break q}x[31609]=0;S(358,m|0,a+1298332|0,-1);d=x[31609];x[31609]=0;if((d|0)==1){break q}x[31609]=0;d=P(556,m|0,e+1218|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break m}if(!d){break k}d=v[e+1218|0];if((d|0)<=0|(y[e+1227|0]|y[e+1228|0]<<8)>>>0>255|(y[e+1229|0]|y[e+1230|0]<<8)>>>0>3999){break k}w[a+480188>>1]=d&255;$e(Xb(x[a+484360>>2],y[a+484376|0]),y[e+1221|0]|y[e+1222|0]<<8);w[a+480192>>1]=y[e+1227|0]|y[e+1228|0]<<8;w[a+480190>>1]=y[e+1229|0]|y[e+1230|0]<<8;d=y[e+1231|0];x[a+480196>>2]=d?d:6;d=y[e+1232|0];x[a+480204>>2]=D(d?d:125,1e4);h=y[e+1233|0]|y[e+1234|0]<<8|(y[e+1235|0]<<16|y[e+1236|0]<<24);d=32;r:{if(h&256){break r}d=2;if(h&2){break r}d=1;if(h&128){break r}d=h&8?16:4}x[31609]=0;O(417,a|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break m}d=x[a+480208>>2];g=d|16777216;x[a+480208>>2]=g;h=y[e+1233|0]|y[e+1234|0]<<8|(y[e+1235|0]<<16|y[e+1236|0]<<24);if(h&1){g=d|16777232;x[a+480208>>2]=g}d=x[a+480180>>2];i=(d|0)==32;f=i&!(h&1024);j=(d|0)==2;o=j&h>>>4;s=h&2097152;j=j&h>>>2;i=i&!(h&2048);if(f|(s|j|(i|o))){g=o?g|65536:g;g=j?g|2:g;g=i?g|4:g;x[a+480208>>2]=s>>>6|(f?g|8:g)}if(h&524288){x[31609]=0;U(266,a+1074312|0,5,1)|0;d=x[31609];x[31609]=0;if((d|0)==1){break m}d=x[a+480180>>2]}if((d|0)==2){break p}if((d|0)!=32){break o}v[e+288|0]=y[e+1237|0];v[e+220|0]=128;X=a,Y=y[Qb(e+288|0,e+220|0)|0]<<1,x[X+480200>>2]=Y;break o}d=N()|0;break a}d=N()|0;break b}v[e+288|0]=y[e+1237|0];v[e+220|0]=64;X=a,Y=y[Qb(e+288|0,e+220|0)|0]<<2,x[X+480200>>2]=Y}F=a+480188|0;h=v[e+1239|0];s:{if((h|0)<0){h=h+52<<24>>24;break s}H=Qt(+(h|0)*3.1/20);t:{if(H<4294967296&H>=0){h=~~H>>>0;break t}h=0}h=h+51|0}x[a+480228>>2]=h;w[e+288>>1]=64;s=a+480280|0;g=z[Oc(F,e+288|0)>>1];o=e+1304|0;i=e+1240|0;f=0;j=(d|0)!=32;r=(d|0)==4;while(1){if((f|0)==(g|0)){f=0;g=0;h=e+1368|0}else{u:{v:{if(!j){v[e+288|0]=y[f+i|0];v[e+220|0]=64;X=s+(f<<5)|0,Y=y[Qb(e+288|0,e+220|0)|0],w[X+6>>1]=Y;break v}if(r){break u}}w:{h=y[f+o|0];if((h|0)!=255){if((h|0)!=127){break w}x[s+(f<<5)>>2]=256;break u}w[(s+(f<<5)|0)+4>>1]=256;break u}w[(s+(f<<5)|0)+4>>1]=h}f=f+1|0;continue}break}while(1){if((f|0)!=16){g=y[f+h|0]!=0|g;f=f+1|0;continue}break}o=e+1384|0;f=0;while(1)if((f|0)==128){if(!(g&1)){break l}d=a+901692|0;f=0;while(1){if((f|0)==16){d=a+902204|0;f=0;while(1){if((f|0)!=128){h=o+(f<<1)|0;x:{if(y[h+1|0]){x[31609]=0;g=e+220|0;W(557,g|0);i=x[31609];x[31609]=0;y:{z:{A:{B:{C:{if((i|0)!=1){i=y[h+1|0];x[31609]=0;x[e+244>>2]=i-1;i=e+1164|0;O(558,i|0,e+244|0);j=x[31609];x[31609]=0;if((j|0)==1){break C}h=y[h|0];x[31609]=0;v[e+192|0]=h;h=e+1144|0;O(559,h|0,e+192|0);j=x[31609];x[31609]=0;if((j|0)==1){break B}x[31609]=0;j=e+288|0;V(560,j|0,g|0,i|0,h|0);r=x[31609];x[31609]=0;if((r|0)==1){break A}fe(e+1192|0,j);qf(Pe(d,f),x[e+1192>>2],x[e+1196>>2]);tb(j);tb(h);tb(i);Eb(g);break x}d=N()|0;break b}d=N()|0;break y}d=N()|0;break z}d=N()|0;tb(e+1144|0)}tb(e+1164|0)}Eb(e+220|0);break b}h=pc(e+1184|0,22292);qf(Pe(d,f),x[h>>2],x[e+1188>>2])}f=f+1|0;continue}break}d=x[a+480180>>2];break l}i=f+h|0;D:{if(y[i|0]){x[31609]=0;g=e+220|0;W(561,g|0);j=x[31609];x[31609]=0;E:{F:{G:{if((j|0)!=1){i=y[i|0];x[31609]=0;x[e+1144>>2]=i-1;i=e+1164|0;O(558,i|0,e+1144|0);j=x[31609];x[31609]=0;if((j|0)==1){break G}x[31609]=0;j=e+288|0;S(290,j|0,g|0,i|0);r=x[31609];x[31609]=0;if((r|0)==1){break F}fe(e+1208|0,j);qf(Pe(d,f),x[e+1208>>2],x[e+1212>>2]);tb(j);tb(i);Eb(g);break D}d=N()|0;break b}d=N()|0;break E}d=N()|0;tb(e+1164|0)}Eb(e+220|0);break b}g=pc(e+1200|0,22292);qf(Pe(d,f),x[g>>2],x[e+1204>>2])}f=f+1|0;continue}}else{g=y[(o+(f<<1)|0)+1|0]!=0|g;f=f+1|0;continue}}d=N()|0;break a}d=N()|0;break a}d=N()|0;break b}h=y[a+484376|0];g=x[a+484360>>2];x[31609]=0;d=d&5;aa(348,Xb(g,h)|0,m|0,y[e+1219|0]|y[e+1220|0]<<8,(d?65535:255)|0,(d?65535:254)|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}x[31609]=0;d=e+288|0;S(185,d|0,m|0,D(y[e+1218|0],y[e+1223|0]|y[e+1224|0]<<8)<<1);h=x[31609];x[31609]=0;if((h|0)==1){break d}I=hc(e+1164|0,d);ub(d);x[31609]=0;S(185,d|0,m|0,(y[e+1223|0]|y[e+1224|0]<<8)<<1);h=x[31609];x[31609]=0;if((h|0)==1){break f}J=hc(e+1144|0,d);ub(d);x[31609]=0;r=P(214,e+1132|0,y[e+1225|0]|y[e+1226|0]<<8)|0;d=x[31609];x[31609]=0;if((d|0)==1){break h}X=e,Y=wb(x[r>>2]),x[X+244>>2]=Y;h=wb(x[r+4>>2]);H:{I:{J:{while(1){g=x[e+244>>2];if(!Ib(g,h)){d=x[a+480180>>2];E=c&1;if(!E){break I}x[31609]=0;O(223,a+484344|0,y[e+1223|0]|y[e+1224|0]<<8);h=x[31609];x[31609]=0;if((h|0)!=1){break I}d=N()|0;break H}x[31609]=0;f=R(151,m|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){x[31609]=0;d=e+220|0;S(185,d|0,m|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break J}o=g;g=hc(e+288|0,d);kd(o,g);ub(g);ub(d);Qf(e+244|0);continue}break}d=N()|0;break H}d=N()|0;break H}q=(d|0)==16?14:(d|0)==32?1:13;K=a+484344|0;j=1;while(1){K:{L:{M:{N:{O:{P:{if((y[e+1223|0]|y[e+1224|0]<<8)>>>0<=l>>>0){switch(x[a+480180>>2]-1|0){case 0:break N;case 3:break P;default:break M}}x[31609]=0;d=R(189,J|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break O}x[e+220>>2]=d;if(!E){break K}x[31609]=0;d=U(196,K|0,l&65535,d|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break O}h=0;if(!d){break K}while(1){f=h&65535;if(f>>>0>=y[e+1218|0]){break K}x[31609]=0;d=R(189,I|0)|0;g=x[31609];x[31609]=0;Q:{if((g|0)!=1){g=x[r>>2];if(Sf(g,x[r+4>>2])>>>0<=d>>>0){break Q}u=ch(g,d);yc(u);g=0;d=Wb(x[K>>2],l);f=md(x[d>>2],x[x[d+48>>2]+12>>2],0,f);R:while(1){if(A[e+220>>2]<=g>>>0){break Q}x[31609]=0;d=R(197,u|0)|0;o=x[31609];x[31609]=0;if((o|0)!=1){if(!d){break Q}t=d>>>4|0;B=d&15;i=0;o=Ng(e+288|0);while(1){S:{T:{U:{if(B>>>0>(i&255)>>>0){x[31609]=0;d=e+244|0;O(198,d|0,u|0);n=x[31609];x[31609]=0;if((n|0)==1){break U}V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{d=y[xb(d,0)|0];switch(d-1|0){case 5:break ia;case 1:break ja;case 0:break ka;case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break V;case 33:break Z;case 30:case 31:break _;case 29:break $;case 28:break aa;case 26:break ba;case 19:case 20:break ca;case 17:break da;case 15:break ea;case 14:break fa;case 10:break ga;case 6:break ha;default:break la}}switch(d-48|0){case 4:break W;case 1:case 2:break X;case 0:break Y;default:break V}}d=y[xb(e+244|0,1)|0];ma:{if(d>>>0<=119){d=d+q|0;break ma}na:{switch(d-254|0){case 1:d=255;break ma;case 0:d=254;break ma;default:break na}}d=253}v[o|0]=d;j=OD(d)&j;break S}X=e,Y=y[xb(e+244|0,1)|0]+1|0,v[X+289|0]=Y;break S}oa:{if(y[e+290|0]){break oa}d=x[a+480180>>2];if((d|0)!=32){if((d|0)!=4){break oa}d=y[xb(e+244|0,1)|0];if(d&15){break oa}v[e+290|0]=11;v[e+292|0]=d>>>4;break S}d=0;n=y[xb(e+244|0,1)|0];while(1){if((d|0)==10){break oa}if((n|0)==y[d+42144|0]){v[e+292|0]=d;v[e+290|0]=11;break S}else{d=d+1|0;continue}}}X=e,Y=y[xb(e+244|0,1)|0],v[X+293|0]=Y;v[e+291|0]=4;break S}d=xb(e+244|0,1);pa:{if(y[e+290|0]){break pa}n=y[d|0];if(x[a+480180>>2]!=32|n>>>0>9){break pa}v[e+292|0]=n;v[e+290|0]=8;break S}v[e+293|0]=y[d|0];v[e+291|0]=5;break S}qa:{if(y[e+290|0]){break qa}ra:{d=x[a+480180>>2];if((d|0)!=4){if((d|0)!=32){break qa}d=xb(e+244|0,1);n=y[d|0];if((n|0)!=255){break ra}v[e+292|0]=64;v[e+290|0]=2;break S}d=xb(e+244|0,1);if(y[d|0]&15){break qa}break T}if(!(n&3)){break T}}X=e,Y=y[xb(e+244|0,1)|0],v[X+293|0]=Y;v[e+291|0]=9;break S}n=y[e+290|0];d=xb(e+244|0,1);sa:{if(n|x[a+480180>>2]==1){break sa}n=y[d|0];if(n>>>0>64){break sa}v[e+292|0]=n;v[e+290|0]=1;break S}v[e+293|0]=y[d|0];v[e+291|0]=13;break S}d=y[xb(e+244|0,1)|0];v[e+293|0]=d;v[e+291|0]=14;if(x[a+480180>>2]==32){break S}v[e+293|0]=D((d&240)>>>4|0,10)+(d&15);break S}d=y[xb(e+244|0,1)|0];v[e+293|0]=d;v[e+291|0]=d>>>0<32?16:17;break S}n=y[xb(e+244|0,1)|0];if(n>>>0>=16){v[e+292|0]=n>>>4;v[e+290|0]=(d|0)==20?3:5;break S}v[e+292|0]=n;v[e+290|0]=(d|0)==20?4:6;break S}d=y[xb(e+244|0,1)|0];if(d>>>0>=16){v[e+290|0]=10;v[e+292|0]=d>>>4;break S}v[e+292|0]=d;v[e+290|0]=9;break S}d=y[xb(e+244|0,1)|0];v[e+291|0]=28;v[e+293|0]=d|16;break S}d=y[xb(e+244|0,1)|0];v[e+291|0]=28;v[e+293|0]=d|32;break S}X=e,Y=y[xb(e+244|0,1)|0],v[X+292|0]=Y;v[e+290|0]=(d|0)==31?7:8;break S}d=y[e+291|0];v[e+291|0]=(d|0)==4?6:(d|0)==5?7:11;X=e,Y=y[xb(e+244|0,1)|0],v[X+293|0]=Y;break S}d=xb(e+244|0,1);v[e+292|0]=y[d|0]%10;d=y[d|0];if(d>>>0<=9){v[e+290|0]=5;break S}if(d>>>0<=19){v[e+290|0]=6;break S}if(d>>>0<=29){v[e+290|0]=3;break S}if(d>>>0>39){break S}v[e+290|0]=4;break S}X=e,Y=y[xb(e+244|0,1)|0],v[X+292|0]=Y;v[e+290|0]=(d|0)==49?13:12;break S}d=y[xb(e+244|0,1)|0]+33|0;if((d&255)>>>0>9){break S}v[e+290|0]=15;v[e+292|0]=d;break S}if(d>>>0>57){break S}X=e,Y=y[xb(e+244|0,1)|0],v[X+293|0]=Y;v[e+291|0]=y[d+25216|0];break S}x[e+244>>2]=g+t;d=x[Hb(e+244|0,e+220|0)>>2];d=d>>>0<g>>>0?g:d;while(1){if((d|0)!=(g|0)){i=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[f|0]=i;v[f+1|0]=i>>>8;v[f+2|0]=i>>>16;v[f+3|0]=i>>>24;i=y[o+4|0]|y[o+5|0]<<8;v[f+4|0]=i;v[f+5|0]=i>>>8;g=g+1|0;f=D(y[e+1218|0],6)+f|0;continue}break}g=d;continue R}d=N()|0;break H}d=y[d|0];v[e+290|0]=2;v[e+292|0]=d>>>2}i=i+1|0;continue}}break}d=N()|0;break H}d=N()|0;break H}h=h+1|0;continue}}f=z[a+480192>>1];d=0;break L}d=N()|0;break H}if(!(z[F>>1]==4&j)){break M}x[a+480208>>2]=x[a+480208>>2]|8454144}f=0;d=!((y[e+1233|0]|y[e+1234|0]<<8|(y[e+1235|0]<<16|y[e+1236|0]<<24))&512)}x[31609]=0;u=P(562,e+1120|0,f|0)|0;h=x[31609];x[31609]=0;ta:{ua:{va:{wa:{xa:{if((h|0)!=1){o=k>>>0<5;i=1;ya:{while(1){f=i&65535;if(f>>>0>z[a+480192>>1]){break ya}za:{Aa:{Ba:{Ca:{if(!d){x[31609]=0;g=U(251,a|0,f|0,0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break Ca}if(g){break Ba}}while(1){x[31609]=0;h=R(197,m|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break ua}if(h){continue}break}if(!o){while(1){x[31609]=0;h=R(197,m|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){d=N()|0;break ta}if(h){continue}break}}x[31609]=0;P(183,m|0,826)|0;h=x[31609];x[31609]=0;if((h|0)!=1){break Aa}}d=N()|0;break ta}h=Fb(e+220|0);x[31609]=0;S(358,m|0,h|0,-1);j=x[31609];x[31609]=0;if((j|0)==1){break za}Ac(g+492|0,h);if(!o){x[31609]=0;S(358,m|0,h|0,-1);j=x[31609];x[31609]=0;if((j|0)==1){break za}Ac(g+524|0,h)}x[31609]=0;j=e+288|0;l=P(563,m|0,j|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break va}if(!l){break xa}l=x[a+480180>>2];x[31609]=0;S(564,j|0,g|0,l|0);g=x[31609];x[31609]=0;if((g|0)==1){break va}if(x[a+480180>>2]==4){g=yb(x[u>>2],f-1|0);f=y[e+1090|0]|y[e+1091|0]<<8|(y[e+1092|0]<<16|y[e+1093|0]<<24);v[g|0]=f;v[g+1|0]=f>>>8;v[g+2|0]=f>>>16;v[g+3|0]=f>>>24}tb(h)}i=i+1|0;continue}break}break va}if(!d){break wa}w[a+480192>>1]=0;break wa}d=N()|0;break H}tb(h)}d=z[a+480190>>1];x[31609]=0;o=P(565,e+276|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){B=y[e+1703|0];M=!(v[e+1233|0]&1)|B>>>0>4;n=c&2;T=a+946304|0;E=a+484380|0;i=1;d=0;while(1){h=d;Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{j=i&65535;if(j>>>0<=z[a+480190>>1]){f=Fb(e+264|0);x[31609]=0;S(358,m|0,f|0,-1);c=x[31609];x[31609]=0;Ya:{Za:{if((c|0)!=1){Ac((j<<5)+T|0,f);d=B>>>0<5;if(d){break Za}x[31609]=0;S(358,m|0,f|0,-1);c=x[31609];x[31609]=0;if((c|0)!=1){break Ya}}d=N()|0;break Ga}sf(f)}x[31609]=0;c=e+288|0;g=P(566,m|0,c|0)|0;l=x[31609];x[31609]=0;_a:{$a:{if((l|0)==1){break $a}if(!g){break _a}g=x[a+480180>>2];x[31609]=0;k=c;c=E+D(j,104)|0;V(567,k|0,c|0,g|0,M|0);g=x[31609];x[31609]=0;if((g|0)==1){break $a}Be(c+43|0,f);q=0;ab:{if(((y[e+308|0]|y[e+309|0]<<8)&61440)!=28672|d){break ab}x[31609]=0;q=R(568,m|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break ab}d=N()|0;break Ga}if(!n){break Ea}g=y[e+323|0]|y[e+324|0]<<8|(y[e+325|0]<<16|y[e+326|0]<<24);d=y[e+308|0]|y[e+309|0]<<8;l=d&61440;if(!(g|l)){d=Zc(e+220|0,d&1?16:8,d&1024?3:1,0,0);x[31609]=0;U(215,d|0,c|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break Ea}d=N()|0;break Ga}if((g|0)<0){d=g+j|0;if((d|0)<=0){break Ea}nY(c,E+D(d,104)|0);break Ea}if((g|0)<=0){break Ea}if(d&1){w[c+34>>1]=z[c+34>>1]|1}if(d&1024){w[c+34>>1]=z[c+34>>1]|64}x[31609]=0;k=e+220|0;S(185,k|0,b|0,g|0);g=x[31609];x[31609]=0;bb:{cb:{db:{eb:{fb:{gb:{if((g|0)!=1){g=hc(e+244|0,k);ub(k);k=_d(z[c+34>>1]);L=(l|0)==16384;if(!L&(l|0)!=8192){break eb}t=x[g>>2];x[31609]=0;t=R(154,t|0)|0;G=x[31609];x[31609]=0;if((G|0)==1){break bb}G=4/(k>>>0)|0;Aua(G,0,t,0);xc(c,hb?-1:D(t,G));if((l|0)==8192){break gb}if(!L){break eb}if(!Gh(c)){break db}d=x[c>>2];c=x[c+20>>2];if(!(v[e+308|0]&1)){break fb}x[31609]=0;V(569,g|0,c|0,d|0,k|0);c=x[31609];x[31609]=0;d=h;if((c|0)==1){break Ia}break cb}d=N()|0;break Ga}if(!Gh(c)){break db}d=x[c>>2];c=x[c+20>>2];if(v[e+308|0]&1){x[31609]=0;V(570,g|0,c|0,d|0,k|0);c=x[31609];x[31609]=0;d=h;if((c|0)!=1){break cb}break Ia}x[31609]=0;V(571,g|0,c|0,d|0,k|0);c=x[31609];x[31609]=0;d=h;if((c|0)==1){break Ia}break cb}x[31609]=0;V(572,g|0,c|0,d|0,k|0);c=x[31609];x[31609]=0;d=h;if((c|0)==1){break Ia}break cb}if((d&45056)==12288){c=mY(e+220|0,g,y[e+327|0]|y[e+328|0]<<8,q);X=kd(wf(x[o>>2],j-1|0),c),Y=x[c+20>>2],x[X+20>>2]=Y;ub(c);break db}if((l|0)!=32768){d=1;if((l|0)!=4096){break cb}l=He(e+220|0,g);x[31609]=0;d=P(573,e+214|0,g|0)|0;k=x[31609];x[31609]=0;if((k|0)!=1){hb:{ib:{if(!y[e+219|0]){break ib}q=y[e+327|0]|y[e+328|0]<<8;k=z[e+216>>1]<<1;if(q>>>0<(k&65535)>>>0){break ib}k=q-k|0;v[e+327|0]=k;v[e+328|0]=k>>>8;d=z[d>>1];x[31609]=0;P(149,g|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break hb}x[31609]=0;k=R(202,g|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break hb}x[31609]=0;d=e+172|0;S(185,d|0,g|0,k|0);k=x[31609];x[31609]=0;if((k|0)==1){break hb}k=hc(e+192|0,d);kd(l,k);ub(k);ub(d)}x[31609]=0;j=U(574,a|0,j|0,l|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break hb}d=1;if(j){d=y[e+327|0]|y[e+328|0]<<8;jb:{if(!d){break jb}j=z[c+34>>1];k=Qk(x[c>>2],j);if(k>>>0<=d>>>0){break jb}j=Zk(j);q=x[c+20>>2];hl(q,d+q|0,k-d|0);x[c>>2]=x[c>>2]-((d>>>0)/(j>>>0)|0)}xc(c,y[e+296|0]|y[e+297|0]<<8|(y[e+298|0]<<16|y[e+299|0]<<24));d=h}ub(l);break cb}}d=N()|0;ub(l);break Ha}x[31609]=0;d=P(428,g|0,e+220|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break Xa}if(!d){break db}x[e+80>>2]=y[e+228|0]|y[e+229|0]<<8|(y[e+230|0]<<16|y[e+231|0]<<24);d=y[e+224|0]|y[e+225|0]<<8|(y[e+226|0]<<16|y[e+227|0]<<24);x[e+72>>2]=y[e+220|0]|y[e+221|0]<<8|(y[e+222|0]<<16|y[e+223|0]<<24);x[e+76>>2]=d;Sk(c,1,e+72|0)}d=h}ub(g);break Da}d=N()|0;break Ha}d=N()|0;break Ga}tb(f)}kb:{if(!n){break kb}k=1;while(1){d=k&65535;if(d>>>0>z[a+480190>>1]){break kb}b=wf(x[o>>2],d-1|0);c=x[b>>2];x[31609]=0;c=R(172,c|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break Wa}lb:{mb:{if(!c){break mb}c=d+w[b+22>>1]|0;c=((c|0)>0?c:k)&65535;i=z[b+20>>1];f=(c|0)!=(d|0)&(c|0)!=0&c>>>0<=z[a+480190>>1]&(i|0)!=0;nb:{if(f){g=wf(x[o>>2],c-1|0);break nb}c=x[b>>2];x[31609]=0;i=R(154,c|0)|0;c=x[31609];x[31609]=0;g=b;if((c|0)==1){break Va}}yc(g);ob:{if(f){c=x[g+8>>2];j=x[g>>2];l=z[b+20>>1];x[31609]=0;c=U(150,j|0,c|0,l|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break Va}if(!c){break mb}x[e+220>>2]=0;x[e+244>>2]=0;x[31609]=0;j=e+288|0;S(186,j|0,g|0,i|0);c=x[31609];x[31609]=0;pb:{if((c|0)!=1){c=bD(Ze(j),uh(x[e+288>>2]),e+220|0,e+244|0);x[31609]=0;P(183,g|0,x[e+220>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break pb}Kc(j);break ob}d=N()|0;break Fa}d=N()|0;Kc(e+288|0);break Fa}c=0;x[e+220>>2]=0;x[e+244>>2]=0}x[31609]=0;g=e+288|0;O(575,g|0,b|0);i=x[31609];x[31609]=0;qb:{rb:{if((i|0)!=1){j=Ze(g);i=x[e+288>>2];if(!f){c=bD(j,uh(i),e+220|0,e+244|0);x[31609]=0;g=x[e+220>>2];P(183,b|0,g|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break lb}j=g+j|0;i=i-g|0}if(c){break rb}h=1;break qb}d=N()|0;break Fa}l=E+D(d,104)|0;Gh(l);g=0;f=x[e+244>>2];while(1){sb:{if(!i|(f|0)!=1?f:0){break sb}d=x[l>>2];if(d>>>0<=g>>>0){break sb}if(!le(d,x[l+20>>2])){break sb}x[e+192>>2]=0;x[e+172>>2]=0;d=e+172|0;n=lY(c,j,uh(i),e+192|0,e+264|0,d);x[31609]=0;x[e+220>>2]=n;P(183,b|0,n|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Ja}ui(d,uh(x[l>>2]-g|0));d=x[e+172>>2];tb:{if((d|0)<=0){break tb}f=x[e+192>>2];B=z[l+34>>1];if((_d(B)|0)!=(f|0)){break tb}q=D(f,g);t=x[l+20>>2];if(B&1){x[e+168>>2]=d;x[e+156>>2]=d;x[e- -64>>2]=d;x[e+48>>2]=d;x[e+152>>2]=f;x[e+148>>2]=x[e+264>>2];x[e+164>>2]=f;x[e+160>>2]=t+(q<<1);x[31609]=0;f=x[e+152>>2];x[e+40>>2]=x[e+148>>2];x[e+44>>2]=f;f=x[e+164>>2];x[e+56>>2]=x[e+160>>2];x[e+60>>2]=f;O(576,e+56|0,e+40|0);f=x[31609];x[31609]=0;if((f|0)!=1){break tb}break Ja}x[e+144>>2]=d;x[e+132>>2]=d;x[e+32>>2]=d;x[e+16>>2]=d;x[e+128>>2]=f;x[e+124>>2]=x[e+264>>2];x[e+140>>2]=f;x[e+136>>2]=q+t;x[31609]=0;f=x[e+128>>2];x[e+8>>2]=x[e+124>>2];x[e+12>>2]=f;f=x[e+140>>2];x[e+24>>2]=x[e+136>>2];x[e+28>>2]=f;O(577,e+24|0,e+8|0);f=x[31609];x[31609]=0;if((f|0)==1){break Ja}}i=i-n|0;j=j+n|0;f=kY(c);x[e+244>>2]=f;g=d+g|0;continue}break}jY(c)}Kc(e+288|0)}k=k+1|0;continue}break}break Ja}ub:{if(x[a+480180>>2]!=4){break ub}f=0;while(1){if(z[a+480192>>1]<=f>>>0){break ub}b=yb(x[u>>2],f);c=y[b+3|0];d=y[b+2|0];g=y[b+1|0];b=y[b|0];x[31609]=0;f=f+1|0;ja(400,a|0,f&65535,b|0,g|0,d|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){continue}break}d=N()|0;break Fa}if(!(y[e+1235|0]&16)){break Ra}b=x[m+8>>2];c=x[m>>2];x[31609]=0;b=U(150,c|0,b|0,1)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Ta}if(!b){break Ra}f=0;x[31609]=0;b=R(197,m|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Ua}if(!(b&1)){break Sa}while(1){if(z[F>>1]<=f>>>0){break Sa}x[31609]=0;b=R(151,m|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){v[(s+(f<<5)|0)+8|0]=b;f=f+1|0;continue}break}d=N()|0;break Fa}d=N()|0;break Ha}d=N()|0;break Fa}d=N()|0;break Fa}d=N()|0;break Fa}d=N()|0;break Fa}g=a+906300|0;while(1){b=x[m+8>>2];c=x[m>>2];x[31609]=0;b=U(150,c|0,b|0,1)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Ka}if(!b){break Ra}x[31609]=0;b=R(197,m|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Pa}if(!b){break Ra}x[31609]=0;c=R(151,m|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Qa}x[31609]=0;d=e+220|0;S(185,d|0,m|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break Qa}c=hc(e+288|0,d);ub(d);vb:{if(b>>>0<=250){x[31609]=0;O(450,c|0,$d(g,b-1|0)|0);b=x[31609];x[31609]=0;if((b|0)==1){break vb}}ub(c);continue}break}d=N()|0;ub(c);break Fa}l=a+901404|0;g=Fb(e+192|0);c=0;j=0;while(1){b=x[m+8>>2];d=x[m>>2];x[31609]=0;b=U(150,d|0,b|0,8)|0;d=x[31609];x[31609]=0;wb:{xb:{yb:{zb:{Ab:{if((d|0)!=1){if(b){x[31609]=0;d=R(151,m|0)|0;b=x[31609];x[31609]=0;Bb:{Cb:{Db:{Eb:{Fb:{Gb:{Hb:{Ib:{if((b|0)!=1){x[31609]=0;b=R(151,m|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Ib}x[31609]=0;f=e+288|0;S(185,f|0,m|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break Hb}b=hc(e+220|0,f);ub(f);if((d|0)==1229211981){break Eb}if((d|0)==1229476432){break Fb}if((d|0)==1397900630){break Gb}if((d|0)!=1414548815){break wb}x[31609]=0;d=P(412,b|0,13951)|0;i=x[31609];x[31609]=0;if((i|0)==1){break Oa}if(!d){break xb}x[31609]=0;d=R(151,b|0)|0;i=x[31609];x[31609]=0;if((i|0)!=1){x[31609]=0;S(185,f|0,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){break Db}}d=N()|0;break Na}d=N()|0;break La}d=N()|0;break La}d=N()|0;break La}Jb:{Kb:{Lb:{d=x[a+480180>>2];switch(d-2|0){case 1:break wb;case 0:break Cb;case 2:break Kb;default:break Lb}}if((d|0)==16){break Jb}if((d|0)!=32){break wb}x[31609]=0;c=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Oa}x[31609]=0;j=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break wb}break Oa}d=Fc(e+120|0,4);x[e+288>>2]=32;f=x[b>>2];x[31609]=0;f=R(154,f|0)|0;i=x[31609];x[31609]=0;if((i|0)!=1){x[e+244>>2]=f;d=x[d>>2];f=x[Hb(e+288|0,e+244|0)>>2];x[31609]=0;V(578,b|0,g|0,d|0,f|0);d=x[31609];x[31609]=0;if((d|0)!=1){break wb}}d=N()|0;break Na}x[31609]=0;d=R(197,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Bb}x[31609]=0;f=e+244|0;O(579,f|0,4211);i=x[31609];x[31609]=0;Mb:{if((i|0)!=1){x[e+264>>2]=d>>>4;x[31609]=0;x[e+104>>2]=d&15;d=e+288|0;V(307,d|0,f|0,e+264|0,e+104|0);i=x[31609];x[31609]=0;if((i|0)==1){break Mb}zb(g,d);tb(d);Eb(f);break wb}d=N()|0;break Na}d=N()|0;Eb(e+244|0);break Na}x[31609]=0;d=R(197,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Oa}x[a+480216>>2]=d;x[31609]=0;d=R(197,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Oa}x[a+480220>>2]=d;break wb}x[31609]=0;P(423,b|0,l|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Oa}DD(l);break wb}d=e+288|0;i=hc(e+244|0,d);ub(d);f=x[i>>2];x[31609]=0;f=R(154,f|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break yb}w[e+288>>1]=f>>>5;X=e,Y=Xj(x[a+484344>>2],x[a+484348>>2]),w[X+264>>1]=Y;d=z[Oc(d,e+264|0)>>1];f=0;while(1){if((d|0)==(f|0)){ub(i);break xb}x[31609]=0;k=e+288|0;O(580,i|0,k|0);n=x[31609];x[31609]=0;Nb:{if((n|0)==1){break Nb}n=x[K>>2];x[31609]=0;O(581,Wb(n,f)|0,k|0);k=x[31609];x[31609]=0;if((k|0)==1){break Nb}f=f+1|0;continue}break}break yb}x[31609]=0;c=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Oa}break wb}d=N()|0;break Na}b=x[a+480180>>2];Ob:{Pb:{Qb:{if((b|0)!=32){break Qb}d=c&65535;if(d>>>0<256){break Qb}if(d>>>0<532){break Pb}}b=(b|0)!=2;Rb:{if(b){break Rb}d=c&65535;if(d>>>0<12544){break Rb}if(d>>>0<12820){break Pb}}if(b){break Ob}b=c&65535;if(b>>>0<4864|b>>>0>4895){break Ob}}lr(l)}Sb:{if(!(v[e+1235|0]&1)){break Sb}f=x[a+1074308>>2];if(!f){c=a+900380|0;f=1;while(1){b=f&65535;if(b>>>0<=z[a+480192>>1]){b=x[c+(b<<2)>>2];if(b){d=x[a+480180>>2];x[31609]=0;O(582,Wh(b,2)|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break Ab}v[b+19|0]=y[b+19|0]+3>>>2}f=f+1|0;continue}break}f=x[a+1074308>>2]}if(f>>>0<=18350079){x[31609]=0;b=P(267,a+1074312|0,27)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Ma}x[31609]=0;P(267,b|0,57)|0;b=x[31609];x[31609]=0;if((b|0)==1){break Ma}f=x[a+1074308>>2]}if(f>>>0<=19070975){x[31609]=0;P(267,a+1074312|0,73)|0;b=x[31609];x[31609]=0;if((b|0)==1){break Ma}f=x[a+1074308>>2]}if(f>>>0>19267583){break Sb}x[31609]=0;P(267,a+1074312|0,50)|0;b=x[31609];x[31609]=0;if((b|0)==1){break Ma}}Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{$b:{ac:{bc:{cc:{dc:{ec:{if(Ad(x[g+4>>2],y[g+11|0])){x[31609]=0;c=e+220|0;W(583,c|0);b=x[31609];x[31609]=0;fc:{if((b|0)!=1){x[31609]=0;d=e+288|0;S(551,d|0,c|0,e+1703|0);b=x[31609];x[31609]=0;if((b|0)==1){break fc}break ec}d=N()|0;break La}d=N()|0;Eb(e+220|0);break La}x[31609]=0;c=e+220|0;W(584,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break dc}x[31609]=0;d=e+288|0;V(585,d|0,c|0,e+1703|0,g|0);b=x[31609];x[31609]=0;if((b|0)==1){break cc}}zb(g,d);tb(d);Eb(c);x[31609]=0;c=e+220|0;O(550,c|0,3977);b=x[31609];x[31609]=0;if((b|0)==1){break ac}x[31609]=0;b=e+288|0;S(551,b|0,c|0,e+1703|0);d=x[31609];x[31609]=0;if((d|0)==1){break $b}zb(a+1298344|0,b);tb(b);Eb(c);x[31609]=0;b=P(1,b|0,15083)|0;c=x[31609];x[31609]=0;if((c|0)==1){break _b}zb(a+1298356|0,b);tb(b);b=x[a+480180>>2];switch(b-1|0){case 2:break zb;case 1:break Wb;case 3:break Xb;case 0:break Yb;default:break bc}}d=N()|0;break La}d=N()|0;Eb(e+220|0);break La}if((b|0)==16){break Zb}if((b|0)==32){break Vb}if((b|0)!=16777216){break zb}x[31609]=0;b=P(1,e+220|0,10140)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Ub}zb(a+1298392|0,b);tb(b);x[31609]=0;b=P(1,e+244|0,13913)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Tb}zb(a+1298380|0,b);tb(b);break zb}d=N()|0;break La}d=N()|0;Eb(e+220|0);break La}d=N()|0;break La}x[31609]=0;b=P(1,e+220|0,10145)|0;c=x[31609];x[31609]=0;gc:{if((c|0)!=1){zb(a+1298392|0,b);tb(b);x[31609]=0;b=P(1,e+244|0,8365)|0;c=x[31609];x[31609]=0;if((c|0)==1){break gc}zb(a+1298380|0,b);tb(b);break zb}d=N()|0;break La}d=N()|0;break La}x[31609]=0;b=P(1,e+220|0,12402)|0;c=x[31609];x[31609]=0;hc:{if((c|0)!=1){zb(a+1298392|0,b);tb(b);x[31609]=0;b=P(1,e+244|0,14309)|0;c=x[31609];x[31609]=0;if((c|0)==1){break hc}zb(a+1298380|0,b);tb(b);break zb}d=N()|0;break La}d=N()|0;break La}x[31609]=0;b=P(1,e+220|0,10118)|0;c=x[31609];x[31609]=0;ic:{if((c|0)!=1){zb(a+1298392|0,b);tb(b);x[31609]=0;b=P(1,e+244|0,15384)|0;c=x[31609];x[31609]=0;if((c|0)==1){break ic}zb(a+1298380|0,b);tb(b);break zb}d=N()|0;break La}d=N()|0;break La}x[31609]=0;b=P(1,e+220|0,10490)|0;c=x[31609];x[31609]=0;jc:{if((c|0)!=1){zb(a+1298392|0,b);tb(b);x[31609]=0;b=P(1,e+244|0,15125)|0;c=x[31609];x[31609]=0;if((c|0)==1){break jc}zb(a+1298380|0,b);tb(b);break zb}d=N()|0;break La}d=N()|0;break La}x[31609]=0;b=P(1,e+220|0,6127)|0;c=x[31609];x[31609]=0;kc:{lc:{mc:{nc:{oc:{if((c|0)!=1){zb(a+1298392|0,b);tb(b);if(!(j&65535)){break kc}x[31609]=0;b=e+264|0;O(268,b|0,4314);c=x[31609];x[31609]=0;if((c|0)==1){break oc}x[e+116>>2]=(j&65280)>>>8;x[31609]=0;x[e+100>>2]=j&255;c=e+104|0;O(444,c|0,e+100|0);d=x[31609];x[31609]=0;if((d|0)==1){break nc}x[31609]=0;d=e+244|0;V(430,d|0,b|0,e+116|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break mc}zb(a+1298380|0,d);tb(d);tb(c);Eb(b);break zb}d=N()|0;break La}d=N()|0;break La}d=N()|0;break lc}d=N()|0;tb(e+104|0)}Eb(e+264|0);break La}x[31609]=0;b=P(1,e+244|0,8573)|0;c=x[31609];x[31609]=0;if((c|0)!=1){zb(a+1298380|0,b);tb(b);break zb}d=N()|0;break La}d=N()|0;break La}d=N()|0;break La}d=N()|0;break La}d=N()|0;break La}zb(a+1298368|0,g);pc:{if(x[a+1074308>>2]){X=a,Y=x[Fc(e+264|0,22)>>2],x[X+1298404>>2]=Y;break pc}if(x[a+480180>>2]==1){X=a,Y=x[Fc(e+264|0,28)>>2],x[X+1298404>>2]=Y;break pc}X=a,Y=x[Fc(e+264|0,4)>>2],x[X+1298404>>2]=Y}f=1;qc:{rc:{if(h&1){x[31609]=0;b=P(1,e+264|0,16687)|0;c=x[31609];x[31609]=0;if((c|0)==1){break rc}a=x[a+1298472>>2];x[31609]=0;S(385,a|0,2,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break qc}tb(b)}tb(g);iY(o);wc(u);Rc(r);ub(J);ub(I);break k}d=N()|0;break La}d=N()|0;tb(b);break La}d=N()|0;ub(i);break Na}x[31609]=0;d=P(412,b|0,13956)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Oa}sc:{if(!d){break sc}x[31609]=0;d=R(151,b|0)|0;f=x[31609];x[31609]=0;tc:{if((f|0)!=1){x[31609]=0;S(185,e+244|0,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){break tc}}d=N()|0;break Na}d=e+244|0;i=hc(e+288|0,d);ub(d);f=x[i>>2];x[31609]=0;f=R(154,f|0)|0;k=x[31609];x[31609]=0;if((k|0)!=1){w[e+244>>1]=(f>>>0)/20;w[e+264>>1]=z[F>>1];d=z[Oc(d,e+264|0)>>1];f=0;while(1){if((d|0)==(f|0)){ub(i);break sc}x[31609]=0;S(424,i|0,(s+(f<<5)|0)+9|0,20);k=x[31609];x[31609]=0;if((k|0)!=1){f=f+1|0;continue}break}}d=N()|0;ub(i);break Na}x[31609]=0;P(435,a|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Oa}x[31609]=0;ba(436,a|0,b|0,1,0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Oa}if((c-2186&65535)>>>0<=117){x[a+480180>>2]=16777216;x[31609]=0;S(448,a|0,b|0,c&65535);d=x[31609];x[31609]=0;if((d|0)==1){break Oa}}if(!x[a+1074308>>2]){break wb}x[31609]=0;f=P(1,e+172|0,18262)|0;d=x[31609];x[31609]=0;uc:{vc:{wc:{if((d|0)!=1){i=x[a+1074308>>2];x[31609]=0;d=e+244|0;O(134,d|0,i|0);i=x[31609];x[31609]=0;if((i|0)==1){break wc}x[31609]=0;i=e+288|0;S(2,i|0,f|0,d|0);k=x[31609];x[31609]=0;if((k|0)==1){break vc}zb(g,i);tb(i);tb(d);tb(f);break wb}d=N()|0;break Na}d=N()|0;break uc}d=N()|0;tb(e+244|0)}tb(f);break Na}ub(b);continue}}d=N()|0;break Fa}d=N()|0;break Fa}d=N()|0}ub(b);break La}d=N()|0}tb(g);break Fa}d=N()|0;break Fa}d=N()|0;Kc(e+288|0);break Fa}d=N()|0}ub(g)}tb(f)}iY(o);break ta}d=h}tb(f);i=i+1|0;continue}}d=N()|0;break ta}d=N()|0;tb(h);break ta}d=N()|0}wc(u);break H}l=l+1|0;continue}}Rc(r);break g}ub(m)}fc(C)}fb=e+1712|0;return f|0}d=N()|0}ub(J);break e}d=N()|0}ub(I);break b}d=N()|0;break b}d=N()|0}ub(m)}fc(C);Q(d|0);p()}function Pqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0;f=fb-944|0;fb=f;yc(b);d=f+892|0;a:{if(!CY(b,d)){break a}if(!GY(d)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(FY(d),hb))){break a}e=1;if((c|0)==64){break a}Dd(a,8);eg(a);h=y[f+895|0]-48|0;v[f+891|0]=h;dd(b,$b(y[f+900|0]|y[f+901|0]<<8|(y[f+902|0]<<16|y[f+903|0]<<24)));d=f+584|0;he(d,b,504);T=hc(f+868|0,d);ub(d);e=0;x[31609]=0;O(524,b|0,d|0);d=x[31609];x[31609]=0;b:{c:{d:{e:{f:{g:{if((d|0)!=1){if(y[f+867|0]>63){break b}if(Bb(z[f+584>>1])<<16>>16<0){break b}d=f+504|0;Rb(d,0,80);h:{e=$b(y[f+924|0]|y[f+925|0]<<8|(y[f+926|0]<<16|y[f+927|0]<<24));if(!e){break h}x[31609]=0;e=P(149,b|0,e|0)|0;k=x[31609];x[31609]=0;if((k|0)!=1){if(!e){break h}x[31609]=0;O(525,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){break h}}g=N()|0;break e}x[31609]=0;d=f+500|0;S(526,d|0,b|0,h&255);e=x[31609];x[31609]=0;if((e|0)!=1){Z=_e(d);e=0;d=z[f+500>>1];if((d-128&65535)>>>0<65409){break b}w[a+480188>>1]=d;I=Nb(f+488|0);d=$b(y[f+916|0]|y[f+917|0]<<8|(y[f+918|0]<<16|y[f+919|0]<<24));i:{if(d){x[31609]=0;P(149,b|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break g}x[31609]=0;S(527,b|0,I|0,y[f+867|0]);d=x[31609];x[31609]=0;if((d|0)==1){break g}d=y[f+867|0];break i}d=y[f+867|0];if(d){break c}}G=a+480188|0;d=d&255;w[a+480192>>1]=d;w[a+480190>>1]=d;_=(h&255)>>>0<2|v[f+848|0]>=0;s=!_;B=c&2;n=a+484380|0;J=a+900380|0;m=1;l=1;while(1){j:{k:{l:{m:{n:{o:{h=d&65535;d=l&65535;if(h>>>0>=d>>>0){x[31609]=0;u=m&65535;h=U(251,a|0,d|0,u|0)|0;e=x[31609];x[31609]=0;p:{if((e|0)!=1){if(h){break p}break d}g=N()|0;break f}h=x[(d<<2)+J>>2];w[f+92>>1]=0;x[f+88>>2]=0;x[31609]=0;o=R(168,f+468|0)|0;e=x[31609];x[31609]=0;q:{if((e|0)!=1){d=yb(x[I>>2],d-1|0);d=$b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r:{if(!d){break r}x[31609]=0;d=P(149,b|0,d|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break k}if(!d){break r}x[31609]=0;O(528,b|0,f+88|0);d=x[31609];x[31609]=0;if((d|0)==1){break k}e=x[f+88>>2];k=w[f+92>>1];x[31609]=0;d=f+128|0;g=$b(e);e=ze(k);S(185,d|0,b|0,g<<((e|0)>0&(e&65504)>>>5));e=x[31609];x[31609]=0;if((e|0)==1){break k}e=hc(f+188|0,d);kd(o,e);ub(e);ub(d)}g=ze(w[f+92>>1]);d=g&15;if((g|0)>=0){break q}Nv(h,0);ba=1;break o}g=N()|0;break f}if(d>>>0>6){break o}j=y[d+25094|0];if(!d){break m}w[a+480190>>1]=(z[a+480190>>1]+j|0)-1;i=h+108|0;t=h+236|0;k=4;q=j-2<<3;s:while(1){d=1;if((k|0)==10){break n}d=D(k,12);e=k+q|0;r=y[e+25100|0]+m|0;C=y[e+25148|0];e=0;while(1)if((e|0)==12){k=k+1|0;continue s}else{A=d+e|0;la=ac(t,A),ma=r,w[la>>1]=ma;A=xb(i,A);v[A|0]=C+y[A|0];e=e+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=$b(x[f+508>>2]);if(!d){break D}if(!Bb(z[f+512>>1])){break D}x[31609]=0;d=P(149,b|0,d|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break C}if(!d){break D}la=f,ma=Bb(z[f+512>>1]),w[la+188>>1]=ma;w[f+128>>1]=y[f+867|0];i=z[Oc(f+188|0,f+128|0)>>1];h=f+136|0;m=f+132|0;k=Bb(z[f+514>>1]);l=k>>>0<5;o=k>>>0<19;u=k>>>0<21;q=k>>>0<15;s=k>>>0<6;d=0;while(1){if((d|0)==(i|0)){break D}x[31609]=0;S(529,b|0,f+188|0,k|0);e=x[31609];x[31609]=0;E:{F:{G:{if((e|0)!=1){d=d+1|0;e=x[(d<<2)+J>>2];g=y[f+188|0];if(g){t=Yl(f+128|0,0,64);Yl(m,g-1&65535,64);j=y[f+189|0];if(j){j=64/(j>>>0)|0}else{j=0}Yl(h,j+g|0,0);x[31609]=0;g=e+48|0;S(530,g|0,t|0,3);j=x[31609];x[31609]=0;if((j|0)==1){break G}if(y[f+188|0]==1){j=x[vb(f+464|0,wb(x[g>>2]))>>2];t=wb(x[g>>2]);j=x[g>>2]+(Lv(j,t)<<2)|0;Jd(g,Kv(j+4|0,x[g+4>>2],j));wb(j)}g=y[f+189|0];x[e>>2]=g?g<<9:32767;v[e+60|0]=y[e+60|0]|1;t=1}H:{if(l){break H}g=y[f+192|0];if(g){la=xb(e+108|0,24),ma=g+24|0,v[la|0]=ma;t=1}if(o){break H}x[e+4>>2]=y[f+206|0]+1>>>1;if(u){break H}w[e+28>>1]=y[f+208|0]|y[f+209|0]<<8}e=n+D(z[ac(e+236|0,61)>>1],104)|0;v[e+37|0]=y[f+191|0]<<4;if(q){break F}g=$b(y[f+198|0]|y[f+199|0]<<8|(y[f+200|0]<<16|y[f+201|0]<<24));x[e+4>>2]=g;la=e,ma=$b(y[f+202|0]|y[f+203|0]<<8|(y[f+204|0]<<16|y[f+205|0]<<24))+g|0,x[la+8>>2]=ma;break E}g=N()|0;break f}g=N()|0;break f}if(s){continue}}g=y[f+193|0];w[e+34>>1]=z[e+34>>1]&65529|g<<1&2|g>>>1&4;if(!(g&4)){continue}w[e+32>>1]=0;continue}}I:{d=$b(x[f+524>>2]);if(!d){break I}if(!Bb(z[f+528>>1])){break I}x[31609]=0;d=P(149,b|0,d|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break C}if(!d){break I}la=f,ma=Bb(z[f+528>>1]),w[la+188>>1]=ma;w[f+128>>1]=y[f+867|0];g=a+946304|0;j=z[Oc(f+188|0,f+128|0)>>1];i=Bb(z[f+530>>1]);k=0;J:while(1){if((j|0)==(k|0)){break I}x[31609]=0;d=f+188|0;S(531,b|0,d|0,i|0);h=x[31609];x[31609]=0;if((h|0)==1){break t}h=f+88|0;A_(h,d);x[31609]=0;d=f+128|0;O(218,d|0,h|0);h=x[31609];x[31609]=0;if((h|0)==1){break u}k=k+1|0;e=(k<<2)+J|0;Ac(x[e>>2]+492|0,d);tb(d);h=x[e>>2];x[31609]=0;O(389,d|0,h|0);h=x[31609];x[31609]=0;if((h|0)==1){break v}la=f,ma=Ti(x[f+128>>2]),x[la+88>>2]=ma;m=Pf(d);while(1){d=x[f+88>>2];if(Ib(d,m)){h=g+(z[dp(d)>>1]<<5)|0;d=x[e>>2];l=x[d+496>>2];x[h>>2]=x[d+492>>2];x[h+4>>2]=l;l=x[d+520>>2];x[h+24>>2]=x[d+516>>2];x[h+28>>2]=l;l=x[d+512>>2];x[h+16>>2]=x[d+508>>2];x[h+20>>2]=l;l=x[d+504>>2];x[h+8>>2]=x[d+500>>2];x[h+12>>2]=l;ah(f+88|0);continue}else{Yv(f+128|0);continue J}}}}lr(a+901404|0);d=pc(f+456|0,4940);qf(Pe(a+901692|0,0),x[d>>2],x[d+4>>2]);yc(b);ca=c&1;u=a+484344|0;q=a+1298332|0;$=a+1298308|0;C=a+480280|0;W=a+484360|0;da=f+850|0;k=0;m=0;while(1){K:{c=k&255;if(c>>>0>=y[Z|0]){break K}x[31609]=0;V(532,b|0,f+892|0,f+504|0,f+584|0);d=x[31609];x[31609]=0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((d|0)==1){break X}Y:{if(!c){e=0;break Y}x[31609]=0;c=R(274,W|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break X}e=k;if((c|0)==255){break d}}j=Mj(x[W>>2],e&255);o=og(f+444|0);Nc(j);if(y[f+891|0]<=1){c=Bb(z[f+586>>1]);if(c>>>0>256){break Q}d=f+188|0;zY(d,f+584|0);x[31609]=0;S(533,j|0,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break W}la=f,ma=wb(x[j>>2]),x[la+188>>2]=ma;d=wb(x[j+4>>2]);while(1){c=x[f+188>>2];if(Ib(c,d)){w[c>>1]=z[c>>1]+m;ge(f+188|0);continue}break}Uh(a,1);w[f+188>>1]=16;c=z[Oc(G,f+188|0)>>1];e=0;while(1)if((c|0)==(e|0)){c=32;break M}else{v[f+188|0]=y[e+da|0];v[f+128|0]=64;la=(e<<5)+C|0,ma=y[Qb(f+188|0,f+128|0)|0],w[la+6>>1]=ma;e=e+1|0;continue}}zY(f+188|0,f+584|0);c=Bb(z[f+200>>1]);if(!c|c>>>0>64|z[G>>1]>64){break Q}l=$b(x[f+208>>2]);c=Bb(z[f+212>>1]);if(c){w[f+128>>1]=c;w[f+88>>1]=800;c=Bc(((z[Oc(f+128|0,f+88|0)>>1]<<5)+50>>>0)/100|0,0)}else{c=32}d=x[f+196>>2];x[31609]=0;d=P(149,b|0,$b(d)|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break V}e=0;Z:{if(!d){break Z}while(1){if(z[G>>1]<=e>>>0){break Z}x[31609]=0;d=R(197,b|0)|0;h=x[31609];x[31609]=0;if((h|0)!=1){v[f+128|0]=d;v[f+88|0]=64;la=(e<<5)+C|0,ma=y[Qb(f+128|0,f+88|0)|0],w[la+6>>1]=ma;e=e+1|0;continue}break}g=N()|0;break w}_:{$:{d=$b(x[f+204>>2]);if(!d){break $}x[31609]=0;d=P(149,b|0,d|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break V}e=0;if(!d){break $}while(1){if(z[G>>1]<=e>>>0){break _}x[31609]=0;d=R(534,b|0)|0;h=x[31609];x[31609]=0;if((h|0)!=1){la=(e<<5)+C|0,ma=(Yb(d,-16,16)<<3)+128|0,w[la+4>>1]=ma;e=e+1|0;continue}break}g=N()|0;break w}Uh(a,1)}h=Nb(f+176|0);d=x[f+192>>2];x[31609]=0;g=P(149,b|0,$b(d)|0)|0;d=x[31609];x[31609]=0;aa:{if((d|0)==1){break aa}d=33;e=0;if(!g){break N}g=z[f+586>>1];i=x[b+8>>2];n=x[b>>2];x[31609]=0;g=U(150,n|0,i|0,Bb(g)<<1)|0;i=x[31609];x[31609]=0;if((i|0)==1){break aa}if(!g){break N}g=z[f+586>>1];x[31609]=0;g=U(535,b|0,h|0,Bb(g)|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break aa}if(!g){break N}la=f,ma=wb(x[h>>2]),x[la+172>>2]=ma;n=wb(x[f+180>>2]);s=x[f+188>>2];B=z[f+202>>1];while(1){d=x[f+172>>2];if(!Ib(d,n)){d=0;e=1;break N}d=Bb(y[d|0]|y[d+1|0]<<8);ba:{if(Bb(B)>>>0<d>>>0){break ba}x[31609]=0;P(149,b|0,$b(s)+(d<<2)|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break U}x[31609]=0;d=R(281,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break U}x[31609]=0;d=P(149,b|0,d|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break U}if(!d){break ba}d=x[b+8>>2];e=x[b>>2];x[31609]=0;d=U(150,e|0,d|0,42)|0;e=x[31609];x[31609]=0;if((e|0)==1){break U}if(!d){break ba}x[31609]=0;O(536,b|0,f+128|0);d=x[31609];x[31609]=0;ca:{if((d|0)!=1){if(mc(x[j>>2],x[j+4>>2])){break ca}x[31609]=0;O(537,j|0,65534);d=x[31609];x[31609]=0;if((d|0)!=1){break ca}}g=N()|0;break O}d=Bb(y[f+168|0]|y[f+169|0]<<8);x[f+124>>2]=d;e=x[b+8>>2];g=x[b>>2];x[31609]=0;d=U(150,g|0,e|0,d|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break T}if(!d){x[31609]=0;d=R(202,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break T}xc(f+124|0,d)}xc(f+124|0,65534);d=x[j+4>>2];g=x[j>>2];e=0;x[31609]=0;i=x[f+124>>2];r=$c(g,d);O(538,j|0,i+r|0);d=x[31609];x[31609]=0;if((d|0)==1){break P}while(1){da:{if((e|0)==(i|0)){if(y[f+128|0]){En(f+88|0,f+128|0);x[31609]=0;d=f+112|0;S(539,d|0,x[f+88>>2],x[f+92>>2]);e=x[31609];x[31609]=0;if((e|0)==1){break S}pp(j,d);tb(d)}d=$b(y[f+160|0]|y[f+161|0]<<8|(y[f+162|0]<<16|y[f+163|0]<<24));if(!d){break ba}x[31609]=0;d=P(149,b|0,d|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break da}break P}x[31609]=0;d=R(273,b|0)|0;g=x[31609];x[31609]=0;ea:{if((g|0)!=1){d=d<<16>>16;if((d|0)<0){break ea}x[31609]=0;O(537,j|0,d+m&65535);d=x[31609];x[31609]=0;if((d|0)!=1){break ea}}g=N()|0;break O}e=e+1|0;continue}break}if(!d){break ba}while(1){fa:{x[31609]=0;d=P(540,b|0,f+108|0)|0;e=x[31609];x[31609]=0;ga:{ha:{ia:{ja:{if((e|0)!=1){if(!d){break ba}x[31609]=0;e=f+68|0;S(185,e|0,b|0,y[f+111|0]);d=x[31609];x[31609]=0;if((d|0)==1){break ja}d=hc(f+88|0,e);ub(e);g=Bb(z[f+108>>1]);e=bm(g+r|0);w[f+68>>1]=e;if((g|0)==65535){break fa}g=x[j>>2];if($c(g,x[j+4>>2])>>>0<=e>>>0){break fa}i=65535;switch(y[f+110|0]-1|0){case 0:break ha;case 1:break ia;default:break ga}}g=N()|0;break O}g=N()|0;break O}x[31609]=0;e=R(273,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break R}x[31609]=0;g=P(541,o|0,f+68|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break R}w[g>>1]=e;g=x[j>>2];i=65534;e=z[f+68>>1]}la=ac(g,e),ma=i,w[la>>1]=ma}ub(d);continue}break}ub(d)}ge(f+172|0);continue}}g=N()|0;break O}g=N()|0;break f}g=N()|0;break w}g=N()|0;break w}g=N()|0;break O}g=N()|0;break O}g=N()|0;break O}g=N()|0;ub(d);break O}iD(o);break d}g=N()|0}od(h);break w}od(h);if(!e){break L}c=c>>>(l>>>1&1)|0}e=Bb(z[f+844>>1]);h=y[f+847|0];aa=h&64;d=y[f+848|0];X=d&32;K=(d&31)+1|0;la=a,ma=wY(e,aa>>>6|0,X>>>5|0,K),x[la+480204>>2]=ma;la=a,ma=Ld(y[f+849|0],1,32),x[la+480196>>2]=ma;if(X){x[a+480216>>2]=K;x[a+480220>>2]=K<<2}d=y[f+866|0];if(d){v[f+188|0]=d;v[f+128|0]=64;la=a,ma=y[Qb(f+188|0,f+128|0)|0]<<2,x[la+480200>>2]=ma}x[a+480228>>2]=c;x[a+480232>>2]=c;x[a+480208>>2]=x[a+480208>>2]&-3|(h^-1)>>>4&2;ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{c=$b(x[f+548>>2]);ua:{if(!c){break ua}x[31609]=0;c=P(149,b|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ta}if(!c){break ua}c=x[f+552>>2];x[31609]=0;S(270,b|0,$|0,$b(c)|0);c=x[31609];x[31609]=0;if((c|0)==1){break ta}if(y[Z|0]<2){break ua}x[31609]=0;c=f+56|0;S(258,c|0,28,$|0);d=x[31609];x[31609]=0;if((d|0)==1){break ta}pp(j,c);tb(c)}va:{if($b(x[f+520>>2])>>>0<2){break va}c=x[f+516>>2];x[31609]=0;c=P(149,b|0,$b(c)|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ta}if(!c){break va}c=x[f+520>>2];x[31609]=0;V(336,q|0,b|0,$b(c)-1|0,4);c=x[31609];x[31609]=0;if((c|0)==1){break ta}}c=$b(x[f+560>>2]);if(!c){break ka}x[31609]=0;c=P(149,b|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ta}if(!c){break ka}c=x[b+8>>2];d=x[b>>2];x[31609]=0;c=U(150,d|0,c|0,12)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ta}if(!c){break ka}x[31609]=0;P(183,b|0,6)|0;c=x[31609];x[31609]=0;if((c|0)==1){break ta}x[31609]=0;c=R(273,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ta}if((c|0)!=1){break ka}x[31609]=0;c=R(281,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ra}if(!c){break ka}d=x[b+8>>2];e=x[b>>2];x[31609]=0;d=U(150,e|0,d|0,c|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break ra}if(d){break sa}break ka}g=N()|0;break w}d=UG(f+188|0,q);x[31609]=0;V(336,q|0,b|0,c|0,4);c=x[31609];x[31609]=0;if((c|0)==1){break ma}if(!Ad(x[f+192>>2],y[f+199|0])){x[31609]=0;c=U(542,f+32|0,2,13)|0;e=x[31609];x[31609]=0;if((e|0)==1){break qa}x[31609]=0;e=f+128|0;S(543,e|0,d|0,c|0);g=x[31609];x[31609]=0;if((g|0)==1){break pa}x[31609]=0;g=f+44|0;S(544,g|0,e|0,q|0);i=x[31609];x[31609]=0;if((i|0)==1){break oa}zb(q,g);tb(g);tb(e);tb(c)}tb(d);break ka}g=N()|0;break w}g=N()|0;break la}g=N()|0;break na}g=N()|0;tb(f+128|0)}tb(c);break la}g=N()|0}tb(d);break w}wa:{L=y[f+891|0];if(L>>>0<2){break wa}g=0;if(!$b(x[f+572>>2])){break wa}while(1){if(z[G>>1]<=g>>>0){break wa}c=x[f+572>>2];x[31609]=0;c=P(149,b|0,$b(c)+(g<<2)|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break x}xa:{if(!c){break xa}x[31609]=0;c=R(281,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break x}x[31609]=0;c=P(149,b|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break x}i=0;d=0;if(!c){break xa}while(1){ya:{c=x[b+8>>2];e=x[b>>2];x[31609]=0;c=U(150,e|0,c|0,8)|0;e=x[31609];x[31609]=0;za:{Aa:{Ba:{if((e|0)!=1){if(!c){break ya}x[31609]=0;O(545,b|0,f+188|0);c=x[31609];x[31609]=0;if((c|0)==1){break Ba}c=$b(x[f+188>>2]);if(!c){break ya}switch((c&536870911)-1|0){case 1:break za;case 0:break Aa;default:continue}}g=N()|0;break w}g=N()|0;break w}i=$b(x[f+192>>2]);continue}d=$b(x[f+192>>2]);continue}break}if(!i|!d){break xa}x[31609]=0;c=P(149,b|0,i|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break y}if(!c){break xa}x[31609]=0;S(424,b|0,((g<<5)+C|0)+9|0,d|0);c=x[31609];x[31609]=0;if((c|0)==1){break y}}g=g+1|0;continue}}la=f,ma=Bb(z[f+584>>1]),w[la+172>>1]=ma;Hf(f+172|0,(m^-1)&65535);x[31609]=0;s=z[f+172>>1];O(223,u|0,s+m&65535);c=x[31609];x[31609]=0;Ca:{if((c|0)==1){break Ca}ea=m&65535;B=0;fa=(h&16)!=0;Da:{Ea:{while(1){if((s|0)==(B|0)){la=f,ma=Ti(x[o>>2]),x[la+128>>2]=ma;h=Pf(o);while(1){Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{c=x[f+128>>2];if(!Zg(c,h)){c=$b(x[f+504>>2]);if(c){break Ka}d=31;break Ja}c=dp(c);d=_e(c);e=z[c>>1];if(!e){e=0;break Ia}g=e-1&65535;if(!Wi(j,g)){break Ia}x[31609]=0;e=P(368,j|0,g|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Fa}break Ha}x[31609]=0;c=P(149,b|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Ca}d=c?0:31}m=m+s|0;break L}if(z[d>>1]==(e+1|0)){break Ga}x[31609]=0;e=P(367,u|0,1)|0;g=x[31609];x[31609]=0;if((g|0)==1){break Fa}if((e|0)==65535){break Ga}la=ac(x[j>>2],z[c>>1]),ma=e,w[la>>1]=ma}c=Wb(x[u>>2],e);Ae(c,An(We(Oe(f+188|0,12,ew(z[d>>1])),x[c+12>>2]-1|0)));s=(s&65535)>>>0>e>>>0?s:e+1|0}ah(f+128|0);continue}break}g=N()|0;break w}La:{Ma:{if(!ca){break Ma}c=y[f+908|0]|y[f+909|0]<<8|(y[f+910|0]<<16|y[f+911|0]<<24);x[31609]=0;c=P(149,b|0,$b(c)+(B<<2)|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Ea}if(!c){break Ma}x[31609]=0;c=R(281,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Ea}x[31609]=0;c=P(149,b|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Ea}if(!c){break Ma}A=Fb(f+68|0);x[31609]=0;c=v[f+846|0];M=R(168,f+12|0)|0;d=x[31609];x[31609]=0;Na:{Oa:{if((d|0)!=1){l=c+48|0;if(L){break Oa}x[31609]=0;O(546,b|0,f+188|0);c=x[31609];x[31609]=0;if((c|0)==1){break La}w[f+124>>1]=y[f+188|0];r=y[f+189|0]+1|0;break Na}g=N()|0;break z}x[31609]=0;O(547,b|0,f+176|0);d=x[31609];x[31609]=0;Pa:{Qa:{if((d|0)!=1){h=Bb(z[f+176>>1]);w[f+124>>1]=h;r=Bb(z[f+178>>1])+1|0;d=$b(z[f+180>>1]|z[f+182>>1]<<16);if(!d){break Pa}e=x[b+8>>2];x[31609]=0;P(149,b|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break A}x[31609]=0;O(548,b|0,f+188|0);d=x[31609];x[31609]=0;if((d|0)==1){break A}d=y[f+192|0]|y[f+193|0]<<8|(y[f+194|0]<<16|y[f+195|0]<<24);x[31609]=0;d=P(149,b|0,$b(d)|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break A}if(!d){break Qa}d=y[f+196|0]|y[f+197|0]<<8|(y[f+198|0]<<16|y[f+199|0]<<24);x[31609]=0;S(270,b|0,A|0,$b(d)|0);d=x[31609];x[31609]=0;if((d|0)!=1){break Qa}break A}break A}d=$b(y[f+204|0]|y[f+205|0]<<8|(y[f+206|0]<<16|y[f+207|0]<<24));Ra:{if(!d){break Ra}x[31609]=0;d=P(149,b|0,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break A}if(!d){break Ra}x[31609]=0;d=R(281,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break A}x[31609]=0;d=P(149,b|0,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break A}if(!d){break Ra}x[31609]=0;d=f+88|0;S(185,d|0,b|0,D(h,r)|0);h=x[31609];x[31609]=0;if((h|0)==1){break A}h=hc(f+128|0,d);kd(M,h);ub(h);ub(d)}x[31609]=0;P(149,b|0,e|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break A}}l=L>>>0>2?c+24|0:l}x[31609]=0;c=B+ea|0;d=U(196,u|0,c&65535,r|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break A}Sa:{if(!d){break Sa}d=x[u>>2];x[31609]=0;n=Wb(d,c);O(283,n|0,A|0);c=x[31609];x[31609]=0;if((c|0)==1){break Da}Hf(f+124|0,z[G>>1]);ga=r-1|0;c=0;ha=z[f+124>>1];Ta:while(1){if((c|0)==(r|0)){break Sa}h=c+1|0;ia=c-1|0;g=0;e=md(x[n>>2],x[x[n+48>>2]+12>>2],c,0);ja=c>>>0>=ga>>>0;while(1){H=g&65535;if(ha>>>0<=H>>>0){c=h;continue Ta}zD(f+128|0,y[e+3|0],e+5|0);Ua:{if(!L){x[31609]=0;d=f+188|0;O(549,d|0,b|0);i=x[31609];x[31609]=0;if((i|0)!=1){i=y[f+188|0];E=Jc(d);v[e+1|0]=i>>>3&16|y[E|0]>>>4|i>>>1&32;E=y[E|0];la=e,ma=y[_e(d)|0],v[la+5|0]=ma;d=i&63;d=d?d+l|0:0;i=E&15;break Ua}break A}x[31609]=0;d=f+188|0;O(357,d|0,b|0);i=x[31609];x[31609]=0;Va:{Wa:{if((i|0)!=1){i=Jc(d);E=_e(d);Y=Yi(d);x[31609]=0;d=R(197,M|0)|0;F=x[31609];x[31609]=0;if((F|0)==1){break A}v[e+4|0]=d;F=y[f+188|0];d=F&127;if(!d){break Wa}d=d+l|0;break Va}break A}d=0;if((F|0)!=128){break Va}v[e|0]=254}v[e+1|0]=y[i|0]&63;i=y[E|0];v[e+5|0]=y[Y|0]}if(d-1>>>0<=119){v[e|0]=d}Y=(d|0)>84;E=f+188|0;F=(aa|0)!=0;ka=(X|0)!=0;d=fb-16|0;fb=d;v[e+3|0]=0;Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{i=i&255;switch(i-4|0){case 4:case 10:break Ya;case 42:break _a;case 37:break $a;case 28:break ab;case 27:break bb;case 26:break cb;case 25:break db;case 24:break eb;case 23:break fb;case 22:break gb;case 21:break hb;case 20:break ib;case 18:break jb;case 17:break kb;case 16:break lb;case 14:break mb;case 13:break nb;case 12:break ob;case 11:break pb;case 9:break qb;case 8:break rb;case 5:break sb;case 0:break tb;default:break Za}}v[e+3|0]=5;i=y[e+5|0];v[d+15|0]=i>>>3;v[d+14|0]=15;F=y[Qb(d+15|0,d+14|0)|0];v[d+13|0]=i<<1&30;v[d+12|0]=15;la=e,ma=y[Qb(d+13|0,d+12|0)|0]|F<<4,v[la+5|0]=ma;break Ya}if((y[e+5|0]-1&255)>>>0>19){break Ya}v[e+3|0]=16;break Ya}v[e+3|0]=13;i=y[e+5|0];ub:{if(!fa){if(i>>>0>152){break ub}v[e+5|0]=D((i&240)>>>4|0,10)+(i&15);break Ya}v[e+5|0]=(i&127)+1>>>1;break Ya}v[e+3|0]=0;break Ya}v[e+3|0]=11;break Ya}i=y[e+5|0];if(!i){v[e+3|0]=14;break Ya}if(i>>>0>240){break Ya}v[e+3|0]=17;if(i>>>0<=2){v[e+5|0]=112;break Ya}i=LD(+(wY(i,F,ka,K)>>>0)/1e4);if(i>>>0<=255){v[e+5|0]=i;break Ya}v[e+5|0]=i>>>8;v[d+11|0]=i;ee(E,34,d+11|0);break Xa}v[e+3|0]=31;v[e+5|0]=y[e+5|0]|128;break Ya}v[e+3|0]=19;v[d+10|0]=15;la=e,ma=y[Qb(e+5|0,d+10|0)|0]|16,v[la+5|0]=ma;break Ya}v[e+3|0]=19;v[d+9|0]=15;la=e,ma=y[Qb(e+5|0,d+9|0)|0]|32,v[la+5|0]=ma;break Ya}v[e+3|0]=5;i=y[e+5|0];v[d+8|0]=(i>>>4|0)+1;v[d+7|0]=15;la=e,ma=i&15|y[Qb(d+8|0,d+7|0)|0]<<4,v[la+5|0]=ma;break Ya}v[e+3|0]=19;v[e+5|0]=y[e+5|0]&15|80;break Ya}v[e+3|0]=19;v[d+6|0]=15;la=e,ma=y[Qb(e+5|0,d+6|0)|0]|96,v[la+5|0]=ma;break Ya}v[e+3|0]=19;v[d+5|0]=15;la=e,ma=y[Qb(e+5|0,d+5|0)|0]|192,v[la+5|0]=ma;break Ya}v[e+3|0]=10;break Ya}v[e+3|0]=19;v[d+4|0]=15;la=e,ma=y[Qb(e+5|0,d+4|0)|0]|160,v[la+5|0]=ma;break Ya}v[e+3|0]=19;v[d+3|0]=15;la=e,ma=y[Qb(e+5|0,d+3|0)|0]|176,v[la+5|0]=ma;break Ya}i=y[e+5|0]-1<<24>>24;if((i|0)<0){break Ya}v[e+5|0]=i;v[e+3|0]=31;break Ya}v[e+3|0]=14;break Ya}v[e+3|0]=19;v[d+2|0]=15;la=e,ma=y[Qb(e+5|0,d+2|0)|0]|224,v[la+5|0]=ma;break Ya}i=y[e+5|0];if(i>>>0>=16){v[e+3|0]=19;v[e+5|0]=i>>>4|208;break Ya}if(!i){break Ya}v[e+3|0]=19;v[e+5|0]=i|144;break Ya}if(y[e+5|0]|y[e+4|0]){break Ya}if(!Tc(y[e|0])){break Ya}v[e+5|0]=159;v[e+3|0]=20;break Ya}i=y[e+4|0];if(!i){break Ya}v[e+3|0]=44;la=e,ma=si(Bc(((y[e+5|0]<<8&65280)>>>0)/(i>>>0)|0,0)),v[la+5|0]=ma;break Ya}i=y[e+5|0];if((i+16&255)>>>0>32){break Ya}v[e+3|0]=9;la=e,ma=Eh(((i^128)<<3)-896|0),v[la+5|0]=ma;break Ya}if(i>>>0>15){break Ya}Cf(e,i,y[e+5|0])}v[d+1|0]=0;zD(E,0,d+1|0)}fb=d+16|0;vb:{if(y[f+128|0]!=34){break vb}if(!y[e+3|0]){d=z[f+128>>1];v[e+3|0]=d;v[e+5|0]=d>>>8;break vb}if(!c){break vb}la=md(x[n>>2],x[x[n+48>>2]+12>>2],ia,H),ma=255,v[la+5|0]=ma}d=Y&_;wb:{if(!y[f+188|0]){break wb}if(!ja){i=md(x[n>>2],x[x[n+48>>2]+12>>2],h,H);H=z[f+188>>1];v[i+3|0]=H;v[i+5|0]=H>>>8;break wb}v[e+5|0]=255}t=d|t;e=e+6|0;g=g+1|0;continue}}}ub(M);tb(A)}B=B+1|0;continue}break}break A}g=N()|0;break w}break A}g=N()|0;break w}iD(o);e=0;xb:{switch(d-31|0){default:if(d){break c}break;case 2:break xb;case 1:break c;case 0:break K}}k=k+1|0;continue}break}Vj(W,0);e=1;if(t&1){break B}while(1){b=e&65535;if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=0;break B}b=(b<<2)+J|0;c=x[b>>2];if(c){Db(Mv(c))}x[b>>2]=0;e=e+1|0;continue}}g=N()|0;break f}yb:{if(!ba){break yb}x[31609]=0;b=P(1,f+188|0,16428)|0;c=x[31609];x[31609]=0;zb:{if((c|0)!=1){c=x[a+1298472>>2];x[31609]=0;S(385,c|0,2,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break zb}tb(b);break yb}g=N()|0;break f}g=N()|0;tb(b);break f}d=22292;Ab:{Bb:{switch(y[f+891|0]){case 0:d=z[G>>1]>4?17316:17302;break Ab;case 1:d=17284;break Ab;case 2:d=17266;break Ab;case 3:break Bb;default:break Ab}}d=17239}x[31609]=0;b=f+88|0;O(550,b|0,16838);c=x[31609];x[31609]=0;Cb:{Db:{Eb:{if((c|0)!=1){x[31609]=0;c=f+128|0;S(551,c|0,b|0,f+891|0);h=x[31609];x[31609]=0;if((h|0)==1){break Eb}zb(a+1298344|0,c);tb(c);Eb(b);x[31609]=0;c=P(1,c|0,12722)|0;h=x[31609];x[31609]=0;if((h|0)==1){break Db}zb(a+1298356|0,c);tb(c);x[31609]=0;O(130,a+1298368|0,d|0);c=x[31609];x[31609]=0;if((c|0)==1){break Cb}la=a,ma=x[Fc(b,28)>>2],x[la+1298404>>2]=ma;e=1;break c}g=N()|0;break f}g=N()|0;Eb(f+88|0);break f}g=N()|0;break f}g=N()|0;break f}g=N()|0;ub(M)}tb(A);break w}g=N()|0;break w}g=N()|0}iD(o);break f}g=N()|0;break f}g=N()|0;break f}g=N()|0;break f}j=1;if((d|0)!=7){break m}e=h+108|0;d=PC(e);while(1){if((d|0)!=(e|0)){la=e,ma=iw(y[e|0]-24|0),v[la|0]=ma;e=e+1|0;continue}break}d=0}t=1;break l}d=0;Fb:{if(s|(g|0)<0){break Fb}i=h+108|0;k=7;Gb:while(1){if((k|0)==10){break Fb}q=D(k,12);r=D(k,-12)+72|0;e=0;while(1)if((e|0)==12){k=k+1|0;continue Gb}else{C=xb(i,e+q|0);v[C|0]=r+y[C|0];e=e+1|0;continue}}}}x[31609]=0;O(552,T|0,f+188|0);e=x[31609];x[31609]=0;if((e|0)!=1){Hb:{e=y[f+192|0];if((e-1&255)>>>0<=15){v[h+31|0]=e;t=1}e=y[f+193|0];if(e-1<<24>>24>=0){v[h+30|0]=e}e=0;Ib:{while(1){if((e|0)==(j|0)){if(!B){break j}if((g|0)>=0){break Ib}break j}x[31609]=0;h=n+D(e+u|0,104)|0;O(279,h|0,8);k=x[31609];x[31609]=0;if((k|0)!=1){v[f+128|0]=y[f+194|0];v[f+68|0]=64;la=h,ma=y[Qb(f+128|0,f+68|0)|0]<<2,w[la+30>>1]=ma;v[h+36|0]=y[f+195|0];e=e+1|0;continue}break}break k}k=Zc(f+128|0,8,1,1,0);q=Bb(z[f+190>>1]);i=Bb(z[f+188>>1]);h=x[o>>2];x[31609]=0;g=R(154,h|0)|0;h=x[31609];x[31609]=0;if((h|0)!=1){h=ze(w[f+92>>1]);if(h&16){hd(k,16);g=g>>>1|0}if(h&32){wp(k,3);g=g>>>1|0}if(h&64){wg(k,2)}if(d){g=(g>>>0)/((-1<<j^-1)>>>0)|0}d=i+q|0;e=0;while(1){if((e|0)==(j|0)){break j}h=n+D(e+u|0,104)|0;x[h>>2]=g;x[31609]=0;U(215,k|0,h|0,o|0)|0;r=x[31609];x[31609]=0;if((r|0)==1){break Hb}i=i<<1;d=d<<1;if(q>>>0>=2){x[h+8>>2]=d;x[h+4>>2]=i;w[h+34>>1]=z[h+34>>1]|2}e=e+1|0;g=g<<1;continue}}}}}g=N()|0;ub(o);break f}ub(o);l=l+1|0;m=j+m|0;d=z[a+480192>>1];continue}}g=N()|0;break e}g=N()|0;break e}g=N()|0}wc(I)}ub(T);Q(g|0);p()}e=0}wc(I)}ub(T)}fb=f+944|0;return e|0}function soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,F=E(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=E(0),fa=0,ga=0,ia=0,ja=0,ka=0;f=fb-608|0;fb=f;yc(b);a:{b:{c:{e=f+600|0;if(!vi(b,e)){break c}if(!jW(e)){break c}if((op(b)|0)>=0){break c}d=1;if((c|0)==64){break c}Dd(a,16777216);x[a+480208>>2]=x[a+480208>>2]|1681e4;sr(f+256|0,32);e=x[f+268>>2];d=a+1074320|0;x[d>>2]=x[f+264>>2];x[d+4>>2]=e;d=x[f+260>>2];x[a+1074312>>2]=x[f+256>>2];x[a+1074316>>2]=d;bg(a+1074312|0,38);r=Nb(f+588|0);s=Nb(f+576|0);C=Nb(f+564|0);k=Nb(f+552|0);Ih(b,4);o=a+484380|0;m=a+480190|0;K=c&1;G=a+1298332|0;q=2500;H=!(c&2);d:{e:{f:{while(1){c=x[b+8>>2];d=x[b>>2];x[31609]=0;c=U(150,d|0,c|0,4)|0;d=x[31609];x[31609]=0;g:{h:{i:{j:{k:{l:{m:{n:{if((d|0)!=1){o:{if(c){x[31609]=0;c=R(711,b|0)|0;d=x[31609];x[31609]=0;p:{if((d|0)==1){break p}n=4;d=0;q:{r:{s:{switch(c+21|0){case 20:x[31609]=0;c=R(281,b|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){d=c&65535;if(z[a+480188>>1]|d-1>>>0>126){continue}w[a+480188>>1]=c;ja=a,ka=Yb(512/(d>>>0)|0,16,128),x[ja+480228>>2]=ka;continue}c=N()|0;break a;case 19:x[31609]=0;M=R(281,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break p}if(M>>>0<=1024){continue}break n;case 16:x[31609]=0;c=R(281,b|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){if((c&65535)==4){continue}break n}c=N()|0;break a;case 15:x[31609]=0;c=R(281,b|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){x[f+256>>2]=c;x[f+152>>2]=800;ja=a,ka=Te(+A[Hb(f+256|0,f+152|0)>>2]*1.24*1e4),x[ja+480204>>2]=ka;continue}c=N()|0;break a;case 31:x[31609]=0;c=R(281,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break p}Z=1;q=Ld(c,0,1e4);continue;case 32:case 33:x[31609]=0;c=R(281,b|0)|0;d=x[31609];x[31609]=0;t:{u:{if((d|0)!=1){Z=1;if(!c){continue}x[31609]=0;d=P(1,f+540|0,12631)|0;c=x[31609];x[31609]=0;if((c|0)==1){break u}c=x[a+1298472>>2];x[31609]=0;S(385,c|0,2,d|0);c=x[31609];x[31609]=0;if((c|0)==1){break t}tb(d);continue}c=N()|0;break a}c=N()|0;break a}c=N()|0;tb(d);break a;case 14:x[31609]=0;P(183,b|0,4)|0;c=x[31609];x[31609]=0;if((c|0)==1){break p}h=!z[m>>1]|h;continue;case 11:if(!K){break r}if(!mc(x[r>>2],x[r+4>>2])){break r}x[31609]=0;c=f+256|0;O(712,c|0,b|0);d=x[31609];x[31609]=0;if((d|0)!=1){if(x[r>>2]){Nc(r);d=x[r>>2];Zo(r);Db(d);ja=Ab(r),ka=0,x[ja>>2]=ka;x[r>>2]=0;x[r+4>>2]=0}x[r>>2]=x[c>>2];x[r+4>>2]=x[c+4>>2];d=Ab(c);ja=Ab(r),ka=x[d>>2],x[ja>>2]=ka;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Qi(c);continue}c=N()|0;break a;case 3:case 4:case 10:e=Rh(x[k>>2],x[k+4>>2]);d=z[m>>1];if(e>>>0<=d>>>0){continue}if((h|H)&1){break r}if(!oi(d)){break r}d=d+1|0;w[m>>1]=d;u=Nb(f+528|0);x[31609]=0;n=R(168,f+508|0)|0;e=x[31609];x[31609]=0;v:{w:{x:{if((e|0)!=1){if((c|0)==-17){break x}if((c|0)!=-11){break w}x[31609]=0;e=R(281,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break v}x[31609]=0;c=f+152|0;S(185,c|0,b|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break v}e=hc(f+256|0,c);kd(n,e);ub(e);break g}c=N()|0;break d}x[31609]=0;c=f+256|0;O(713,c|0,b|0);e=x[31609];x[31609]=0;y:{if((e|0)!=1){e=zn(u,c);fc(c);se(f+480|0,x[e>>2],x[f+532>>2]);c=Md(f+472|0);x[31609]=0;e=x[c+4>>2];x[f+16>>2]=x[c>>2];x[f+20>>2]=e;c=hg(327,f+488|0,x[f+480>>2],x[f+484>>2],f+16|0);e=x[31609];x[31609]=0;if((e|0)==1){break y}kd(n,c);break g}c=N()|0;break e}c=N()|0;break e}x[31609]=0;c=f+256|0;O(714,c|0,b|0);e=x[31609];x[31609]=0;z:{if((e|0)!=1){e=zn(u,c);fc(c);se(f+440|0,x[e>>2],x[f+532>>2]);c=Md(f+432|0);x[31609]=0;e=x[c+4>>2];x[f+8>>2]=x[c>>2];x[f+12>>2]=e;c=hg(327,f+452|0,x[f+440>>2],x[f+444>>2],f+8|0);e=x[31609];x[31609]=0;if((e|0)==1){break z}kd(n,c);break g}c=N()|0;break e}c=N()|0;break e}c=N()|0;break e;case 9:c=z[m>>1];if(!oi(c)){continue}w[m>>1]=c+1;continue;case 8:if(!K){break r}if(!mc(x[C>>2],x[C+4>>2])){break r}x[31609]=0;c=f+256|0;O(715,c|0,b|0);d=x[31609];x[31609]=0;if((d|0)!=1){iW(C,c);wc(c);continue}c=N()|0;break a;case 7:if(!mc(x[k>>2],x[k+4>>2])){break r}x[31609]=0;c=f+256|0;O(716,c|0,b|0);d=x[31609];x[31609]=0;if((d|0)!=1){if(x[k>>2]){Nc(k);d=x[k>>2];oC(k);Db(d);ja=Ab(k),ka=0,x[ja>>2]=ka;x[k>>2]=0;x[k+4>>2]=0}x[k>>2]=x[c>>2];x[k+4>>2]=x[c+4>>2];d=Ab(c);ja=Ab(k),ka=x[d>>2],x[ja>>2]=ka;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;tv(c);continue}c=N()|0;break a;case 6:if(!K){break r}if(!mc(x[s>>2],x[s+4>>2])){break r}x[31609]=0;c=f+256|0;O(717,c|0,b|0);d=x[31609];x[31609]=0;if((d|0)!=1){if(x[s>>2]){Nc(s);d=x[s>>2];kv(s);Db(d);ja=Ab(s),ka=0,x[ja>>2]=ka;x[s>>2]=0;x[s+4>>2]=0}x[s>>2]=x[c>>2];x[s+4>>2]=x[c+4>>2];d=Ab(c);ja=Ab(s),ka=x[d>>2],x[ja>>2]=ka;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;kn(c);continue}c=N()|0;break a;case 17:case 18:break q;case 0:case 1:case 2:break r;case 5:break s;default:break n}}x[31609]=0;d=f+256|0;O(718,d|0,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break o}A:{c=x[f+256>>2];e=x[f+260>>2];if(mc(c,e)){break A}x[31609]=0;V(343,G|0,c|0,Xc(c,e)|0,1);c=x[31609];x[31609]=0;if((c|0)!=1){break A}c=N()|0;fc(d);break a}fc(f+256|0);continue}x[31609]=0;n=R(281,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break p}}x[31609]=0;P(183,b|0,n|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){continue}}c=N()|0;break a}d=0;if(!z[a+480188>>1]|!M){break n}b=x[k>>2];c=x[k+4>>2];if(mc(b,c)){break n}if(K){if(mc(x[r>>2],x[r+4>>2])){break n}if(mc(x[C>>2],x[C+4>>2])){break n}if(mc(x[s>>2],x[s+4>>2])){break n}}b=Rh(b,c);if(b>>>0>=256){x[31609]=0;O(719,k|0,255);b=x[31609];x[31609]=0;if((b|0)==1){break b}b=Rh(x[k>>2],x[k+4>>2])}w[a+480192>>1]=b;n=a+480192|0;ja=a,ka=z[qe(m,n)>>1],w[ja+480190>>1]=ka;if(h&1){x[31609]=0;b=P(1,f+528|0,16517)|0;c=x[31609];x[31609]=0;if((c|0)==1){break h}c=x[a+1298472>>2];x[31609]=0;S(385,c|0,2,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break i}tb(b)}i=a+946304|0;h=0;B:while(1){if((h|0)!=2){d=1;while(1){g=d&65535;if(g>>>0>z[n>>1]){h=h+1|0;continue B}C:{e=hn(x[k>>2],g-1|0);if(!y[e|0]|v[e+128|0]<0){break C}if((qv(e)|0)==((h|0)!=1|0)){break C}D:{E:{F:{c=0;G:{if(!qv(e)){break G}if(Bb(y[e+6|0]|y[e+7|0]<<8)){break G}if(Bb(y[e+14|0]|y[e+15|0]<<8)>>>0>20){break G}c=(Bb(y[e+18|0]|y[e+19|0]<<8)|0)==4}H:{I:{if(c){c=y[e+23|0];b=y[e+140|0];x[31609]=0;b=ha(720,e|0,a|0,(b&2)>>>1|0,o+D(g,104)|0,q&65535)|0;l=x[31609];x[31609]=0;J:{K:{if((l|0)!=1){if(!b){break J}x[31609]=0;b=P(36,f+384|0,10771)|0;l=x[31609];x[31609]=0;if((l|0)==1){break K}Ac(i+(g<<5)|0,b);tb(b);l=x[k>>2];b=d;if(Rh(l,x[k+4>>2])>>>0<=c>>>0){break H}ja=e,ka=y[e+143|0]+y[hn(l,c)+143|0]|0,v[ja+143|0]=ka;break I}c=N()|0;break a}c=N()|0;break a}b=c+1|0;break H}c=0;L:{if(!qv(e)){break L}if((Bb(y[e+6|0]|y[e+7|0]<<8)|0)!=1){break L}if((Bb(y[e+14|0]|y[e+15|0]<<8)|0)!=2){break L}c=(Bb(y[e+18|0]|y[e+19|0]<<8)|0)==10}b=d;if(!c){break H}c=f+256|0;aW(c,e);b=Bb(y[f+276|0]|y[f+277|0]<<8);if(b>>>0>=z[m>>1]){break I}x[31609]=0;l=R(709,f+152|0)|0;t=x[31609];x[31609]=0;if((t|0)==1){break F}t=y[f+292|0]|y[f+293|0]<<8;u=z[m>>1];x[31609]=0;G=(o+D(b,104)|0)+104|0;b=Bb(t);b=ba(721,c|0,G|0,(b>>>0<u>>>0?(o+D(b,104)|0)+104|0:l)|0,o+D(g,104)|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break E}if(!b){break I}x[31609]=0;b=P(36,f+140|0,11269)|0;c=x[31609];x[31609]=0;if((c|0)==1){break D}Ac(i+(g<<5)|0,b);tb(b);v[e+139|0]=y[e+139|0]+12}b=d}x[31609]=0;b=b&65535;c=U(251,a|0,g|0,b|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){if(!c|b>>>0>z[m>>1]){break C}x[31609]=0;V(722,e|0,c|0,o+D(b,104)|0,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break C}}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}d=d+1|0;continue}}break}H=og(f+128|0);t=og(f+116|0);b=oc(x[C>>2],x[C+4>>2]);_=D(z[a+480188>>1],M);$=bm((b>>>0)/(_>>>0)|0);x[31609]=0;X=a+484344|0;O(223,X|0,$|0);b=x[31609];x[31609]=0;if((b|0)==1){break k}Nc(Xb(x[a+484360>>2],y[a+484376|0]));b=z[a+480188>>1];x[31609]=0;u=P(723,f+104|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break l}ja=f,ka=wb(x[s>>2]),x[ja+52>>2]=ka;fa=a+902204|0;ga=wb(x[s+4>>2]);while(1){M:{N:{m=x[f+52>>2];if(!Ib(m,ga)){break N}b=ze((y[m+6|0]|y[m+7|0]<<8)<<16>>16);if((b|0)==1){break M}if((b&65535)==65535){break N}e=Bb(y[m|0]|y[m+1|0]<<8);b=x[r>>2];g=x[r+4>>2];c=Mg(b,g);if(e>>>0>=c>>>0){break M}d=Bb(y[m+2|0]|y[m+3|0]<<8);if(d>>>0>c>>>0|!d|e>>>0>c-d>>>0){break M}c=b+(Mg(b,g)<<5)|0;x[f+256>>2]=b;x[f+260>>2]=c-b>>5;b=x[f+256>>2];Zb(f+76|0,b+(Bb(y[m|0]|y[m+1|0]<<8)<<5)|0,Bb(y[m+2|0]|y[m+3|0]<<8));O:{I=Xb(x[a+484360>>2],y[a+484376|0]);if(mc(x[I>>2],x[I+4>>2])){break O}x[31609]=0;O(537,I|0,65534);b=x[31609];x[31609]=0;if((b|0)!=1){break O}break m}ja=f,ka=wb(x[f+76>>2]),x[ja+40>>2]=ka;b=fb-16|0;fb=b;ia=x[vb(b+12|0,x[f+76>>2]+(x[f+80>>2]<<5)|0)>>2];fb=b+16|0;while(1){i=x[f+40>>2];if(!Ib(i,ia)){break M}b=ze(ze((y[m+8|0]|y[m+9|0]<<8)<<16>>16)+ze((y[i+16|0]|y[i+17|0]<<8)<<16>>16)<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8;b=de(H);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!mv(i,d)){c=1;if(!mv(d,i)){break P}b=b+4|0}b=x[b>>2];continue}break}Q:{R:{S:{if(c){x[31609]=0;b=P(724,H|0,i|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break m}G=z[b>>1];break S}G=0;if(!K){break S}b=y[i+12|0]|y[i+13|0]<<8;x[31609]=0;G=P(367,X|0,Bb(b)|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break m}if((G|0)==65535){break M}x[31609]=0;b=P(724,H|0,i|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break m}w[b>>1]=G;if(Bb(y[i+8|0]|y[i+9|0]<<8)>>>0>=$>>>0){break R}if(Bb(y[i+10|0]|y[i+11|0]<<8)>>>0>=M>>>0){break R}q=Bb(y[i+14|0]|y[i+15|0]<<8);c=Ek(wb(x[C>>2]),D(Bb(y[i+8|0]|y[i+9|0]<<8),_));b=z[a+480188>>1];ja=f,ka=Ek(c,D(b,Bb(y[i+10|0]|y[i+11|0]<<8))),x[ja+28>>2]=ka;T=0;x[f+100>>2]=0;o=Ng(f- -64|0);T:while(1){U:{d=Bb(y[i+12|0]|y[i+13|0]<<8);c=Wb(x[X>>2],G);if(d>>>0<=T>>>0){break U}n=0;Y=md(x[c>>2],x[x[c+48>>2]+12>>2],T,0);c=0;while(1){if((b&65535)>>>0<=n>>>0){T=T+1|0;continue T}b=wb(x[C+4>>2]);d=x[f+28>>2];g=Ib(d,b)?d:f+100|0;b=wb(x[C+4>>2]);if(Ib(x[f+28>>2],b)){gW(f+28|0)}d=Y+D(n,6)|0;e=y[g+1|0];b=(e>>>0>=85?-1:e+25|0)<<24>>24;l=0;h=x[k>>2];L=Rh(h,x[k+4>>2]);J=y[g+3|0];V:{if(L>>>0<=J>>>0){break V}l=J+1|0;if(v[hn(h,J)+142|0]&1|(b|0)<0){break V}b=ze((y[i+16|0]|y[i+17|0]<<8)<<16>>16)+b<<24>>24;aa=b&255;b=(b|0)<=0?1:aa>>>0>=120?120:aa}W:{if(!y[d|0]|!(y[g|0]|(e|0)!=255|J|y[g+2|0])){break W}e=y[d+1|0];if(!e|e>>>0>L>>>0){break W}if(y[hn(h,e-1|0)+132|0]!=2){break W}Wo(d)}e=sv(x[u>>2],n);X:{Y:{if(!(c&1)){h=y[g|0];break Y}c=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;c=y[o+4|0]|y[o+5|0]<<8;v[d+4|0]=c;v[d+5|0]=c>>>8;Z:{if(y[d+3|0]){break Z}h=y[e+21|0];c=y[sv(x[u>>2],n-1|0)+21|0];if((h|0)==(c|0)){break Z}v[d+3|0]=21;v[e+21|0]=c;v[d+5|0]=c}c=0;h=y[g|0];if(!(h-24>>>0<2|(h|0)==9|!h&(y[g+2|0]+7&255)>>>0<2)){break X}}_:{$:{aa:{ba:{switch(h|0){case 5:c=y[e+17|0];break aa;case 0:ca:{da:{c=y[g+2|0];if(c>>>0>=201){h=0;ea:{switch(c-242|0){case 11:v[d+4|0]=1;v[d+2|0]=14;v[e+16|0]=0;break ca;case 9:if(!y[d|0]){v[d|0]=y[e+17|0]}v[d+4|0]=1;v[d+2|0]=15;break ca;case 8:if((q&255)>>>0<2){break ca}v[d+3|0]=16;q=q-1|0;v[d+5|0]=q;break ca;case 7:if((q&255)==255){q=255;break ca}v[d+3|0]=16;q=q+1|0;v[d+5|0]=q;break ca;case 6:v[e+17|0]=b;if(y[e+18|0]!=(l&255)){break ca}v[d+5|0]=255;v[d+3|0]=4;v[d|0]=b;w[e+32>>1]=0;x[e+8>>2]=0;break ca;case 5:v[d+5|0]=242;v[d+3|0]=2;break ca;case 4:v[d+5|0]=242;v[d+3|0]=3;break ca;case 3:v[d+5|0]=244;v[d+3|0]=2;break ca;case 2:v[d+5|0]=244;v[d+3|0]=3;break ca;case 1:v[d+5|0]=248;v[d+3|0]=2;break ca;case 12:break da;case 0:break ea;default:break ca}}v[d+5|0]=248;v[d+3|0]=3;break ca}h=0;L=v[g+1|0];if((L|0)<0&c>>>0>99){break ca}if((L|0)>=0){v[e+17|0]=b;v[d|0]=b;v[e+18|0]=l;v[d+1|0]=l;w[e+32>>1]=0;x[e+8>>2]=0;c=y[g+2|0]}b=c&255;if(!b){break ca}ja=e,ka=Zl(+(b>>>0)*.64),v[ja+19|0]=ka;j=B[e>>2];x[e>>2]=0;h=j!=E(0);break ca}v[d+4|0]=0;v[d+2|0]=14;v[e+16|0]=1}b=Bc(((D(y[e+20|0],y[e+19|0])+50&65535)>>>0)/100|0,0);if(!(!h&y[e+21|0]==(b&255))){v[e+21|0]=b;v[d+5|0]=b;v[d+3|0]=21}if(n&1|v[g+1|0]<=0|(z[a+480188>>1]-1|0)<=(n|0)){break _}b=x[k>>2];if(Rh(b,x[k+4>>2])>>>0<=J>>>0){break _}if(y[hn(b,J)+132|0]!=1){break _}g=n|1;b=Y+D(g,6)|0;c=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[d+4|0]|y[d+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;v[b+1|0]=y[b+1|0]+1;b=sv(x[u>>2],g);v[b+19|0]=y[e+19|0];B[b>>2]=B[e>>2];B[b+4>>2]=B[e+4>>2];B[b+8>>2]=B[e+8>>2];B[b+12>>2]=B[e+12>>2];w[b+30>>1]=z[e+30>>1];break _;case 1:x[e+4>>2]=0;B[e>>2]=E(y[g+2|0])*E(.0333000011742115);break _;case 2:x[e+4>>2]=0;B[e>>2]=E(y[g+2|0])*E(-.0333000011742115);break _;case 12:v[f+256|0]=15;v[f+96|0]=y[g+3|0]>>>3;b=y[Qb(f+256|0,f+96|0)|0];v[f+256|0]=15;v[f+96|0]=y[g+2|0]>>>3;ja=e,ka=y[Qb(f+256|0,f+96|0)|0]|b<<4,v[ja+24|0]=ka;break _;case 3:x[e+12>>2]=0;b=y[g+2|0];w[e+32>>1]=0;B[e+8>>2]=E(b>>>0)*E(.0333000011742115);break _;case 4:x[e+12>>2]=0;b=y[g+2|0];w[e+32>>1]=0;B[e+8>>2]=E(b>>>0)*E(-.0333000011742115);break _;case 15:if(!y[g+2|0]|(b|0)<0){break _}h=b-y[e+17|0]<<5;c=h>>31;c=(c^h)-c|0;x[f+256>>2]=c;v[e+17|0]=b;x[e+8>>2]=0;v[d+3|0]=4;v[d|0]=b;b=Eh((c>>>0)/(y[g+2|0]<<1>>>0)|0);v[d+5|0]=b;v[e+27|0]=b;x[f+96>>2]=D(b,(q&255)-1|0);ja=e,ka=c-x[Cd(f+256|0,f+96|0)>>2]|0,w[ja+32>>1]=ka;break _;case 13:v[f+256|0]=15;v[f+96|0]=y[g+3|0]>>>3;b=y[Qb(f+256|0,f+96|0)|0];v[f+256|0]=15;v[f+96|0]=y[g+2|0];ja=e,ka=y[Qb(f+256|0,f+96|0)|0]|b<<4,v[ja+23|0]=ka;break _;case 18:b=y[g+2|0]+y[e+17|0]&255;b=b?b>>>0>=120?120:b:1;v[e+17|0]=b;v[d+5|0]=255;v[d+3|0]=4;v[d|0]=b;break $;case 23:case 24:case 25:b=de(t);while(1){fa:{c=0;if(!b){break fa}h=b+13|0;if(!ov(g,h)){c=1;if(!ov(h,g)){break fa}b=b+4|0}b=x[b>>2];continue}break};if(c){v[d+3|0]=31;x[31609]=0;b=P(725,t|0,g|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break m}v[d+5|0]=y[b|0];break _}b=x[Ab(t)>>2];if(b>>>0>127){break _}x[f+92>>2]=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);c=x[a+480208>>2];x[31609]=0;x[f+24>>2]=x[f+92>>2];c=U(726,f+24|0,Pe(fa,b)|0,c|0)|0;h=x[31609];x[31609]=0;ga:{if((h|0)==1){break ga}if(!c){break _}v[d+3|0]=31;x[31609]=0;c=P(725,t|0,g|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break ga}b=b|-128;v[c|0]=b;v[d+5|0]=b;ca=(y[g|0]&254)==24|ca;break _}break m;case 16:if(!y[g+2|0]){break _}v[d+3|0]=15;x[f+256>>2]=15;x[f+96>>2]=y[g+3|0]+1;ja=d,ka=x[Cd(f+256|0,f+96|0)>>2],v[ja+5|0]=ka;w[e+30>>1]=D(y[g+2|0],y[g+3|0]+1|0);break _;case 9:v[d+3|0]=16;b=y[g+2|0];q=b?b:4;v[d+5|0]=q;break _;case 19:ha:{b=y[g+1|0];switch(b|0){case 0:case 4:break ha;default:break _}}h=128;h=(b|0)==4?y[g+3|0]:h;v[f+91|0]=h;v[f+256|0]=y[g+2|0];v[f+96|0]=100;b=f+256|0;l=f+96|0;c=y[Qb(b,l)|0];x[f+256>>2]=128;x[f+96>>2]=256-(h&255);h=x[Cd(b,l)>>2];v[f+256|0]=128;b=y[Qb(b,f+91|0)|0];h=(D(c,h)|0)/128|0;l=h&255;if((l|0)!=y[e+20|0]){v[e+20|0]=h;v[d+3|0]=21;h=Bc(((D(l,y[e+19|0])+50&65535)>>>0)/100|0,0);v[e+21|0]=h;v[d+5|0]=h}if(y[g+1|0]!=4|(z[a+480188>>1]-1|0)<=(n|0)){break _}g=n+1|0;h=sv(x[u>>2],g);b=D(b,c)>>>7|0;if(y[h+20|0]==(b&255)){break _}v[h+20|0]=b;b=Y+D(g,6)|0;v[b+3|0]=21;c=Bc(((D(y[e+20|0],y[e+19|0])+50&65535)>>>0)/100|0,0);v[e+21|0]=c;v[b+5|0]=c;break _;case 10:case 11:case 17:case 20:v[d+3|0]=0;break _;case 7:b=y[g+2|0];v[e+25|0]=0;v[e+26|0]=0;v[e+22|0]=b;break _;case 8:v[e+22|0]=y[e+22|0]+y[g+2|0];break _;case 14:v[e+25|0]=y[g+3|0];v[e+26|0]=y[g+2|0];break _;case 6:break ba;default:break _}}v[e+18|0]=l;v[e+17|0]=b;v[d+1|0]=l;c=b}v[d|0]=c;if((b|0)>=0){v[e+18|0]=l;v[d+1|0]=l}if(y[g|0]==5){v[d+4|0]=1;v[d+2|0]=11}b=y[e+26|0];c=y[e+22|0];if(!(b|(c|y[g+2|0]))){break $}if(b){da=(Pi(+z[e+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{da=0}v[d+3|0]=44;ja=d,ka=Zl(da+ +(c+y[g+2|0]|0)),v[ja+5|0]=ka}w[e+32>>1]=0}ia:{if(y[d|0]){v[e+16|0]=0;break ia}c=0;if(y[e+16|0]){break X}}ja:{if(!z[e+30>>1]){break ja}b=q&255;w[f+256>>1]=b;c=e+30|0;ja=c,ka=z[qe(c,f+256|0)>>1]-b|0,w[ja>>1]=ka;if(y[d+3|0]){break ja}v[d+5|0]=0;v[d+3|0]=15}j=B[e>>2];ka:{if(j==E(0)){break ka}b=q&255;j=E(E(j*E(b>>>0))+B[e+4>>2]);B[e+4>>2]=j;if(y[d+3|0]){break ka}la:{ma:{na:{oa:{if(b>>>0>=2){g=b-1|0;F=E(g|0);if(!(F<=j)){break oa}v[f+256|0]=15;ja=f,ka=Bh(E(j/F)),v[ja+96|0]=ka;b=y[Qb(f+256|0,f+96|0)|0];B[e+4>>2]=j-E(D(b,g)|0);v[d+3|0]=22;c=b<<4;break la}if(!(j>=E(1))){break na}break ma}if(j>=E(1)){break ma}if(!(j<=E(1-b|0))){break na}v[f+256|0]=15;ja=f,ka=Bh(E(E(-j)/F)),v[ja+96|0]=ka;c=y[Qb(f+256|0,f+96|0)|0];B[e+4>>2]=j+E(D(g,c)|0);v[d+3|0]=22;break la}if(!(j<=E(-1))){break ka}v[f+256|0]=14;ja=f,ka=Bh(E(-j)),v[ja+96|0]=ka;b=y[Qb(f+256|0,f+96|0)|0];B[e+4>>2]=j+E(b>>>0);v[d+3|0]=22;c=b|-16;break la}v[f+256|0]=15;ja=f,ka=Bh(j),v[ja+96|0]=ka;b=y[Qb(f+256|0,f+96|0)|0];B[e+4>>2]=j-E(b>>>0);v[d+3|0]=22;c=b<<4|15}v[d+5|0]=c}j=B[e+8>>2];pa:{if(j==E(0)){break pa}b=q&255;j=E(E(j*E(b>>>0))+B[e+12>>2]);B[e+12>>2]=j;qa:{ra:{if(!y[d+3|0]){sa:{ta:{if(b>>>0>=2){g=b-1|0;F=E(g|0);if(!(F<=j)){break ta}v[f+256|0]=223;ja=f,ka=Bh(E(j/F)),v[ja+96|0]=ka;c=y[Qb(f+256|0,f+96|0)|0];B[e+12>>2]=j-E(D(g,c)|0);v[d+3|0]=2;b=5;break qa}if(!(j>=E(1))){break sa}break ra}if(j>=E(1)){break ra}if(!(E(1-b|0)>=j)){break sa}v[f+256|0]=223;ja=f,ka=Bh(E(E(-j)/F)),v[ja+96|0]=ka;c=y[Qb(f+256|0,f+96|0)|0];B[e+12>>2]=j+E(D(g,c)|0);v[d+3|0]=3;b=5;break qa}if(!(j<=E(-1))){break pa}v[f+256|0]=14;ja=f,ka=Bh(E(-j)),v[ja+96|0]=ka;b=y[Qb(f+256|0,f+96|0)|0];B[e+12>>2]=j+E(b>>>0);v[d+3|0]=3;c=b|-16;b=5;break qa}if(y[d+2|0]|b>>>0<2){break pa}ea=E(j*E(.25));g=b-1|0;F=E(g|0);ua:{if(ea>=F){v[f+256|0]=9;ja=f,ka=Bh(E(j/F))>>>2|0,v[ja+96|0]=ka;c=y[Qb(f+256|0,f+96|0)|0];B[e+12>>2]=j-E(D(g,c)<<2);v[d+2|0]=12;break ua}if(!(ea<=E(1-b|0))){break pa}v[f+256|0]=9;ja=f,ka=Bh(E(E(-j)/F))>>>2|0,v[ja+96|0]=ka;c=y[Qb(f+256|0,f+96|0)|0];B[e+12>>2]=j+E(D(g,c)<<2);v[d+2|0]=13}b=4;break qa}v[f+256|0]=15;ja=f,ka=Bh(j),v[ja+96|0]=ka;b=y[Qb(f+256|0,f+96|0)|0];B[e+12>>2]=j-E(b>>>0);v[d+3|0]=2;c=b|-16;b=5}v[b+d|0]=c}va:{wa:{xa:{ya:{za:{Aa:{Ba:{b=y[d+3|0];switch(b|0){case 4:break va;case 0:break Ba;default:break Aa}}Ca:{b=y[e+23|0];if(!b){b=y[e+24|0];if(b){break Ca}if(!z[e+32>>1]){break va}h=e+32|0;break za}v[d+5|0]=b;v[d+3|0]=5;if(!z[e+32>>1]){break va}break ya}v[d+5|0]=b;v[d+3|0]=8;if(z[e+32>>1]){break ya}break va}if(!z[e+32>>1]){break va}h=e+32|0;if(b){break xa}}v[d+3|0]=4;break wa}h=e+32|0}v[d+2|0]=11}w[f+256>>1]=D(y[e+27|0],(q&255)-1|0);ja=e,ka=z[e+32>>1]-z[Oc(h,f+256|0)>>1]|0,w[ja+32>>1]=ka}w[e+28>>1]=z[e+28>>1]+D(y[e+25|0],q&255)&1023;c=0;if(n&1){break X}b=y[e+18|0];if(!b){break X}e=x[k>>2];if(Rh(e,x[k+4>>2])>>>0<b>>>0){break X}e=hn(e,b-1|0);if(!(y[e+142|0]&4)){break X}b=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[o|0]=b;v[o+1|0]=b>>>8;v[o+2|0]=b>>>16;v[o+3|0]=b>>>24;b=y[d+4|0]|y[d+5|0]<<8;v[o+4|0]=b;v[o+5|0]=b>>>8;c=1;b=y[f+65|0];if(!b|y[e+132|0]!=1){break X}v[f+65|0]=b+1}n=n+1|0;b=z[a+480188>>1];continue}}break}Ae(c,Vh(We(Oe(f+256|0,16,Bb(y[i+14|0]|y[i+15|0]<<8)&255),0)))}b=cm(x[I>>2],x[I+4>>2]);ja=f,ka=Bb(y[i+4|0]|y[i+5|0]<<8),w[ja+256>>1]=ka;w[f+64>>1]=1;c=z[qe(f+256|0,f- -64|0)>>1];x[31609]=0;V(727,I|0,b|0,c|0,G&65535);b=x[31609];x[31609]=0;if((b|0)==1){break Q}b=ze((y[m+8|0]|y[m+9|0]<<8)<<16>>16);b=ze(ze((y[i+16|0]|y[i+17|0]<<8)<<16>>16)-b<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8}Zq(f+40|0);continue}break}break m}d=ca&1;if(d){x[31609]=0;e=a+906300|0;b=$d(e,0);W(286,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break m}x[b+24>>2]=655376;x[b+28>>2]=0;x[b+16>>2]=1299020115;x[b+20>>2]=1869112133;x[f+256>>2]=0;g=b+48|0;c=f+256|0;c0(b+32|0,g,c);x[31609]=0;c=P(36,c|0,9587)|0;h=x[31609];x[31609]=0;if((h|0)==1){break m}wE(g,c);tb(c);x[31609]=0;c=P(36,f+76|0,9580)|0;g=x[31609];x[31609]=0;if((g|0)==1){break m}rw(b+80|0,c);tb(c);x[31609]=0;b=P(36,f- -64|0,9572)|0;c=x[31609];x[31609]=0;if((c|0)==1){break m}wE($d(e,1)+48|0,b);tb(b)}c=a+480280|0;b=0;while(1){if(z[a+480188>>1]>b>>>0){bE(a,b&65535);e=c+(b<<5)|0;v[e+8|0]=d;w[e+4>>1]=b<<8&256;b=b+1|0;continue}break}x[31609]=0;b=P(1,f+52|0,12181)|0;c=x[31609];x[31609]=0;Da:{Ea:{Fa:{if((c|0)!=1){zb(a+1298344|0,b);tb(b);x[31609]=0;b=P(1,f+40|0,12399)|0;c=x[31609];x[31609]=0;if((c|0)==1){break m}zb(a+1298356|0,b);tb(b);if(Z){break Fa}x[31609]=0;b=P(1,f+28|0,12181)|0;c=x[31609];x[31609]=0;if((c|0)==1){break m}break Ea}break m}if(Rh(x[k>>2],x[k+4>>2])>>>0<=128){x[31609]=0;b=P(1,f+28|0,9314)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break Ea}break m}x[31609]=0;b=P(1,f+28|0,14894)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Da}}zb(a+1298368|0,b);tb(b);ja=a,ka=x[Fc(f+100|0,28)>>2],x[ja+1298404>>2]=ka;fW(u);WV(t);VV(H);d=1;break n}break m}Vo(f+52|0);continue}}c=N()|0;break a}c=N()|0;break a}tv(k);wc(C);kn(s);Qi(r);break c}c=N()|0;fW(u);break j}c=N()|0;break j}c=N()|0}WV(t);VV(H);break a}c=N()|0;tb(b);break a}c=N()|0;break a}ub(c);x[31609]=0;c=d&65535;d=U(728,a|0,c|0,n|0)|0;e=x[31609];x[31609]=0;Ga:{Ha:{Ia:{Ja:{if((e|0)==1){break Ja}if(d){break Ga}x[31609]=0;d=U(729,a|0,c|0,n|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break Ja}if(d){break Ga}x[31609]=0;d=U(730,a|0,c|0,n|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break Ja}if(d){break Ga}x[31609]=0;d=P(731,o+D(c,104)|0,n|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break Ja}if(d){break Ga}x[31609]=0;d=P(1,f+420|0,16228)|0;e=x[31609];x[31609]=0;if((e|0)==1){break Ia}e=x[a+1298472>>2];x[31609]=0;S(385,e|0,2,d|0);e=x[31609];x[31609]=0;if((e|0)==1){break Ha}tb(d);break Ga}c=N()|0;break e}c=N()|0;break e}c=N()|0;tb(d);break e}Ka:{La:{Ma:{i=o+D(c,104)|0;if(y[i+34|0]&64){d=z[m>>1];if(oi(d)){break Ma}}d=x[k>>2];if(Rh(d,x[k+4>>2])>>>0<=c>>>0){break La}if(y[hn(d,c)+132|0]!=2){break La}c=z[m>>1];if(!oi(c)){break La}w[m>>1]=c+1;break La}c=d+1|0;w[a+480190>>1]=c;t=o+D(c&65535,104)|0;e=x[i>>2];c=x[i+20>>2];Na:{if(!le(e,c)){break Na}d=(i|0)==(t|0);g=z[i+34>>1];if(d|(_d(g)|0)!=2){break Na}if(!(le(x[t>>2],x[t+20>>2])?d:1)){break Na}le(x[i>>2],x[i+20>>2]);if(!d){c=pv(e,Jn(g))}g=x[i+20>>2];if(!(g?c:0)){if(!d){cC(c)}break Na}Oa:{Pa:{switch(Jn(z[i+34>>1])-1|0){case 1:d=c;e=g;h=x[i+20>>2];l=x[i>>2];while(1){if(l){w[d>>1]=z[h>>1];w[e>>1]=z[h+2>>1];h=h+4|0;e=e+2|0;d=d+2|0;l=l-1|0;continue}break};break Oa;case 0:break Pa;default:break Oa}}d=c;e=g;h=x[i+20>>2];l=x[i>>2];while(1){if(l){v[d|0]=y[h|0];v[e|0]=y[h+1|0];h=h+2|0;e=e+1|0;d=d+1|0;l=l-1|0;continue}break}}d=Xo(t,i);w[d+34>>1]=z[d+34>>1]&65471;x[t+20>>2]=c;c=Xo(i,i);w[c+34>>1]=z[c+34>>1]&65471;x[i+20>>2]=g;h=1074992;while(1){if((h|0)!=1298224){e=a+h|0;g=x[e+104>>2];if(!((g|0)!=(d|0)&(c|0)!=(g|0))){x[e+88>>2]=x[e+88>>2]&-65}h=h+872|0;continue}break}Ij(d,a);Ij(c,a)}x[31609]=0;c=P(36,f+408|0,6320)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Ka}Be(t+43|0,c);tb(c);x[31609]=0;c=P(36,f+396|0,6223)|0;d=x[31609];x[31609]=0;if((d|0)==1){break f}Be(i+43|0,c);tb(c)}ub(n);fc(u);h=0;continue}break}c=N()|0;break e}c=N()|0}ub(n)}fc(u);break a}fb=f+608|0;return d|0}c=N()|0}tv(k);wc(C);kn(s);Qi(r);Q(c|0);p()}function Fv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,R=0,T=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ia=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=E(0),ua=0,va=0,xa=0,ya=E(0);k=fb-192|0;fb=k;X=Nb(a);r=k+160|0;v[r+26|0]=0;w[r+24>>1]=0;x[r+16>>2]=0;x[r+20>>2]=-1;x[r+8>>2]=-1;x[r+12>>2]=-1;x[r>>2]=0;x[r+4>>2]=0;ca=x[d+16>>2];a=y[d+6|0];n=x[b+484360>>2];fa=(ua=a,va=y[b+484376|0],xa=Gj(n,x[b+484364>>2])>>>0>a>>>0,xa?ua:va);a=fa&255;H=Mj(n,a);x[31609]=0;s=P(603,k+128|0,b|0)|0;n=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{if((n|0)!=1){m=x[s+4>>2];x[31609]=0;G=U(604,k+92|0,b|0,a|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break g}na=b+484360|0;_=c&7;f=x[d>>2];a=z[d+4>>1];n=$c(x[H>>2],x[H+4>>2]);while(1){q=a&65535;if(q>>>0>=n>>>0){break f}if(Wi(H,q)){break f}a=a+1|0;f=0;continue}}a=N()|0;break d}a=N()|0;break e}x[d>>2]=f;w[d+4>>1]=a;x[m+52>>2]=f;x[m+48>>2]=f;x[r+16>>2]=f;w[m+74>>1]=a;w[m+72>>1]=a;w[r+24>>1]=a;ia=Md(k+84|0);h:{if((_|0)!=7){break h}a=fb-16|0;fb=a;n=a+8|0;Jb(n,ia,1);bp(n);fb=a+16|0;if((ca|0)!=2){break h}a=x[H>>2];e=$c(a,x[H+4>>2]);n=z[d+12>>1];if(e>>>0<=n>>>0){break h}q=x[b+484344>>2];e=x[b+484348>>2];a=z[ac(a,n)>>1];if(!Je(q,e,a)){break h}n=Wb(q,a);q=x[d+8>>2];if(A[n+12>>2]<=q>>>0){break h}a=0;l=md(x[n>>2],x[x[n+48>>2]+12>>2],q,0);n=x[s+8>>2];q=z[b+480188>>1];e=z[b+480192>>1];while(1){if((a|0)==(q|0)){break h}i:{j:{k:{l:{i=y[l|0];switch(i-253|0){case 1:case 2:break j;case 0:break l;default:break k}}if(e){break j}}if(!Tc(i)|!y[l+1|0]){break i}if(Kl(y[l+2|0],y[l+3|0])){break i}}ua=Se(n,a),va=-1,x[ua>>2]=va}l=l+6|0;a=a+1|0;continue}}Y=c&1;if(Y){yT(m+223860|0)}K=m+74|0;J=m+48|0;oa=m+223872|0;L=m+80|0;pa=b+901692|0;qa=b+902204|0;$=m+44|0;ra=b+484380|0;ka=b+900380|0;da=m+223860|0;Z=m+20|0;sa=b+480280|0;F=b+1074312|0;T=m+616|0;ba=32768;la=(_|0)!=7;a=0;n=0;m:{n:{o:{p:{q:{r:{s:{t:{u:while(1){ea=a&1;v:while(1){ma=C[d+8>>3];o(+ma);q=j(1)|0;e=j(0)|0;i=x[d+16>>2];M=(i|0)!=3;w:{x:{y:{z:{while(1){xT(k+24|0,x[b+480180>>2],z[b+480188>>1],m,ea);t=y[k+24|0];if(!M&C[s+24>>3]>=ma){break z}a=65535;g=x[H>>2];f=$c(g,x[H+4>>2]);l=z[m+72>>1];if(f>>>0>l>>>0){a=z[ac(g,l)>>1]}w[m+70>>1]=a;g=x[b+484344>>2];h=x[b+484348>>2];f=a&65535;if(!(Je(g,h,f)|(i|0)!=2|(f|0)==65535)&(l|0)==(q&65535)){break z}A:{while(1){R=Xj(g,h);u=x[H>>2];while(1){l=a&65535;if(l>>>0<R>>>0){break A}a=z[m+72>>1];B:{C:{if((l|0)!=65535){f=$c(u,x[H+4>>2]);if(a>>>0<f>>>0){break C}}l=z[H+28>>1];if((a|0)==(l|0)){break A}f=$c(u,x[H+4>>2]);break B}l=a+1|0}w[m+72>>1]=l;a=65535;I=f;f=l&65535;if(I>>>0>f>>>0){a=z[ac(u,f)>>1]}w[m+74>>1]=l;w[m+70>>1]=a;if(Je(g,h,a&65535)){continue}break}a=Jq(k+24|0,T);x[31609]=0;a=ha(605,G|0,l&65535,0,a|0,(t|0)!=0|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break q}if(!a){h=x[b+484348>>2];g=x[b+484344>>2];a=z[m+70>>1];continue}break}if(ca>>>0<=1){a=z[m+72>>1];x[r+8>>2]=0;w[r+20>>1]=a}if(!i){break A}if(!Wu(G,K,J)){break A}C[r>>3]=C[s+24>>3];x[31609]=0;O(606,X|0,r|0);a=x[31609];x[31609]=0;if((a|0)==1){break r}x[r+16>>2]=x[J>>2];w[r+24>>1]=z[K>>1];x[31609]=0;W(607,s|0);a=x[31609];x[31609]=0;if((a|0)==1){break r}a=z[m+74>>1];w[m+72>>1]=a;ua=m,va=z[ac(x[H>>2],a)>>1],w[ua+70>>1]=va;x[m+52>>2]=x[m+48>>2]}if(z[K>>1]==65535){break n}a=x[b+484344>>2];g=z[m+70>>1];if(!Je(a,x[b+484348>>2],g)){a=z[m+72>>1];if((a|0)==z[H+28>>1]){if(!i){break o}if(!Wu(G,K,J)){break p}C[r>>3]=C[s+24>>3];x[31609]=0;O(606,X|0,r|0);a=x[31609];x[31609]=0;if((a|0)==1){break r}x[r+16>>2]=x[J>>2];w[r+24>>1]=z[K>>1];x[31609]=0;W(607,s|0);a=x[31609];x[31609]=0;if((a|0)==1){break r}x[m+52>>2]=x[m+48>>2];continue}w[K>>1]=a+1;continue}break}f=x[J>>2];if(f>>>0>=A[Wb(a,g)+12>>2]){x[J>>2]=0;f=0}if((i|0)!=2){break y}if(z[m+72>>1]!=(q&65535)|(f|0)!=(e|0)){break x}}i=1;v[r+26|0]=1;break n}a=0;if((i|0)==3){break w}}a=0;if(A[G+28>>2]<ba>>>0){break w}x[s+24>>2]=0;x[s+28>>2]=2146435072;x[G+28>>2]=0;ba=ba>>>(ba>>>0>256)|0;f=x[J>>2];a=1}q=z[m+72>>1];e=Jq(k+24|0,T);x[31609]=0;q=ha(605,G|0,q|0,f|0,e|0,(t|0)!=0|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break t}if((a|q)==1){if(ca>>>0<=1){w[r+20>>1]=z[m+72>>1];x[r+8>>2]=x[m+48>>2]}if(!i){break o}if(!Wu(G,K,J)){break p}C[r>>3]=C[s+24>>3];x[31609]=0;O(606,X|0,r|0);a=x[31609];x[31609]=0;if((a|0)==1){break s}x[r+16>>2]=x[J>>2];w[r+24>>1]=z[K>>1];x[31609]=0;W(607,s|0);a=x[31609];x[31609]=0;if((a|0)==1){break s}x[m+52>>2]=x[m+48>>2];continue}w[r+22>>1]=z[m+72>>1];x[r+12>>2]=x[m+48>>2];wT(b,m,0);l=x[m+48>>2];q=Wb(x[b+484344>>2],z[m+70>>1]);if(l>>>0>=A[q+12>>2]){x[J>>2]=0;l=0}if(t){continue}a=0;l=md(x[q>>2],x[x[q+48>>2]+12>>2],l,0);Jb(k+24|0,F,77);g=Gb(x[x[k+24>>2]>>2],x[k+28>>2]);D:{while(1){if(z[b+480188>>1]>a>>>0){q=D(a,872)+T|0;E:{F:{if(!zB(l)){if(!g|!(y[((a<<5)+sa|0)+1|0]&4)){break F}}Wo(q+788|0);break E}if(Wg(y[l|0])){G:{if(!Id(y[m+223884|0])){break G}e=y[l+1|0];if(e-251>>>0<5|!e){break G}h=y[l+5|0];f=y[l+3|0];t=Cj(y[l+2|0],y[l+4|0]);i=k+24|0;v[i|0]=e-1;x[i+4>>2]=t&65535;x[31609]=0;e=P(608,oa|0,i|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break D}ua=e,ya=E(E(Cj(f,h)>>>0)/E(999)),B[ua>>2]=ya}Wo(q+788|0);break E}e=y[l|0]|y[l+1|0]<<8|(y[l+2|0]<<16|y[l+3|0]<<24);v[q+788|0]=e;v[q+789|0]=e>>>8;v[q+790|0]=e>>>16;v[q+791|0]=e>>>24;e=y[l+4|0]|y[l+5|0]<<8;v[q+792|0]=e;v[q+793|0]=e>>>8;H:{I:{J:{K:{switch(y[l+3|0]-16|0){case 0:f=y[l+5|0];break J;case 3:break H;case 4:break I;case 1:break K;default:break E}}Jb(k+24|0,F,5);if(!Gb(x[x[k+24>>2]>>2],x[k+28>>2])){break E}f=y[l+5|0];if(!f){break E}}uT(b,m,f&255);break E}e=y[q+793|0];L:{if(!(e|!(x[b+480180>>2]&16777250))){v[q+793|0]=y[q+833|0];break L}v[q+833|0]=e}q=y[l+5|0];e=q&240;if((e|0)!=224){if((e|0)!=96){break E}x[m+24>>2]=x[m+24>>2]+(q&15);break E}if(x[Z>>2]){break E}q=q&15;if(q?0:y[b+480180|0]&2){break E}x[Z>>2]=q+1;break E}q=y[l+5|0];if((q&240)!=224){break E}x[Z>>2]=(q&15)+1}l=l+6|0;a=a+1|0;continue}break}q=Jl(m);x[k+24>>2]=1;a=x[bd(Z,k+24|0)>>2];w[m+68>>1]=65535;x[m+60>>2]=-1;x[m+64>>2]=-1;u=q-1|0;e=q-a|0;M=D(e,1e4);l=0;while(1){M:{N:{O:{P:{Q:{if(z[b+480188>>1]<=l>>>0){if(x[b+480180>>2]!=4|x[m+40>>2]!=65535){break Q}x[m+52>>2]=x[m+48>>2];w[m+74>>1]=z[m+72>>1];continue v}h=D(l,872)+T|0;if(zB(h+788|0)){break M}t=y[h+791|0];f=y[h+793|0];if(!Y){break O}a=y[h+788|0];i=y[h+789|0];if(i){v[h+799|0]=0;v[h+803|0]=i;ua=Se(x[s+8>>2],l),va=255,v[ua+5|0]=va;i=y[h+788|0]}else{i=a}R:{if(!Tc(i)){break R}v[h+799|0]=a;fV(h);if(!la){if(x[Se(x[s+8>>2],l)>>2]!=-1){break R}}g=h+656|0;i=y[h+803|0];i=x[(i?i>>>0>z[b+480192>>1]?g:(i<<2)+ka|0:g)>>2];if(!i){break R}g=y[i+21|0];if(vd(g)){ua=h,va=Hh(g),v[ua+837|0]=va}i=y[i+22|0];if(!vd(i)){break R}ua=h,va=Hh(i),v[ua+838|0]=va}S:{if(!(Tc(y[h+788|0])|y[h+789|0])){break S}g=y[h+803|0];T:{if(!g){g=0;break T}if(z[b+480192>>1]<g>>>0){break T}i=x[(g<<2)+ka>>2];if(!i|!(v[i+15|0]&1)){break T}Sq(h,x[i+8>>2],b);g=y[h+803|0]}a=rr(b,a,g&255);if(!a){break S}a=D(a,104)+ra|0;if(!(y[a+34|0]&32)){break S}Sq(h,z[a+28>>1],b)}U:{V:{W:{a=y[h+790|0];switch(a-1|0){case 1:break O;case 2:case 3:break V;case 0:break W;default:break U}}ua=Se(x[s+8>>2],l),va=y[h+792|0],v[ua+5|0]=va;break O}a=y[h+792|0];if(!a){break O}v[h+834|0]=a;break O}if((a|0)==11){break P}break O}x[m+32>>2]=x[b+480216>>2];a=Wb(x[b+484344>>2],z[m+70>>1]);e=x[a+16>>2];if(tT(e,x[a+20>>2])){x[m+32>>2]=e}i=sT(b,m);a=D(i,q);C[s+24>>3]=C[s+24>>3]+ +(a>>>0)/+A[b+24620>>2];x[m>>2]=a+x[m>>2];X:{Y:{Z:{if(la){break Z}f=0;ea=(n|0)!=0&(i|0)!=(n|0);while(1){if(z[b+480188>>1]<=f>>>0){break Z}u=Se(x[s+8>>2],f);_:{if(x[u>>2]==-1){break _}a=D(f,872)+T|0;t=a+788|0;M=x[a+700>>2];if(!M){if(zB(t)){break _}}l=y[a+793|0];g=Kl(y[a+790|0],y[a+791|0]);if(y[a+789|0]){x[a+660>>2]=0}e=l&15;h=0;$:{if(!Tc(y[t|0])){break $}if(g&y[u+4|0]!=0){yB(k+24|0,b,a,M,0);h=x[k+28>>2];x[a+8>>2]=x[k+24>>2];x[a+12>>2]=h}v[a+802|0]=y[a+799|0];M=x[a+692>>2];h=y[a+803|0];if(h){Lo(b,a,h,g,1,1)}h=y[a+788|0];x[31609]=0;ga(609,b|0,a|0,h|0,g|0,1,0,65535);h=x[31609];x[31609]=0;if((h|0)==1){break Y}l=l>>>4|0;rT(b,a);qT(x[b+480180>>2],z[b+480188>>1],m,f&65535);R=Se(x[s+8>>2],f);v[R+4|0]=1;u=y[a+791|0];aa:{if(!((y[a+793|0]&240)!=208|(u-19&255)>>>0>1)){h=e;if(h>>>0<q>>>0){break aa}}h=(u|0)==33?l>>>0<q>>>0?l:0:0}I=x[Z>>2];if(!(!(x[b+480180>>2]&16777250)|(!h|I>>>0<2))){h=D(I-1|0,x[m+24>>2]+x[m+40>>2]|0)+h|0}if(!g){x[R>>2]=0}ba:{if((u|0)==9){break ba}ca:{if((u|0)!=19){if((u|0)!=20|(l|0)!=8){break ca}break ba}if((l|0)==8){break ba}}if(y[a+790|0]!=2){break $}}x[a+692>>2]=M}da:{if(!Tc(y[t|0])){Jb(k+24|0,F,114);if(!Gb(x[x[k+24>>2]>>2],x[k+28>>2])){break da}}ea:{fa:{ga:{ha:{g=y[a+791|0];switch(g-42|0){case 1:break ea;case 0:break fa;case 2:break ga;default:break ha}}if((g|0)!=10){break ea}g=z[m+70>>1];l=x[m+48>>2];x[31609]=0;aa(610,b|0,a|0,f&65535,l|0,g|0);g=x[31609];x[31609]=0;if((g|0)!=1){break da}break X}l=Aua(y[a+793|0],0,x[a+76>>2],0);g=hb;u=g>>>8|0;Ko(b,a,Bc((g&255)<<24|l>>>8,u));break da}if(!x[a+104>>2]){break ea}x[31609]=0;V(611,s|0,f&65535,n|0,-1);g=x[31609];x[31609]=0;if((g|0)==1){break X}oT(a,y[a+793|0]);h=x[m+40>>2]-1|0;break da}if(y[a+790|0]!=15){break da}l=x[a+104>>2];if(!l){break da}g=y[a+792|0];if(g>>>0>9){break da}ia:{if(!g){g=x[a+664>>2];break ia}g=x[yb(l+68|0,g-1|0)>>2];x[a+664>>2]=g}Ko(b,a,g)}ja:{ka:{la:{switch(y[t|0]-253|0){case 0:if(z[b+480192>>1]){break ka}break;case 1:case 2:break ka;default:break la}}g=y[a+791|0];if(!((y[a+793|0]&240)!=192|(g-19&255)>>>0>1)&e>>>0<q>>>0){break ka}u=g&255;if((u|0)==25){break ka}l=0;if(!((u|0)==33&(e|0)!=0&q>>>0>h+e>>>0)){break ja}}g=y[a+791|0];l=1}ma:{na:{oa:{e=g&255;if((e|0)!=46){if((e|0)!=13){break oa}I=y[a+793|0]<<2;break na}I=y[a+793|0];break na}if(y[a+790|0]!=1){break ma}I=y[a+792|0]<<2}x[a+688>>2]=I}pa:{qa:{ra:{if(l|(!x[a+104>>2]|e>>>0>46)){break ra}Jb(k+24|0,ia,e);if(Gb(x[x[k+24>>2]>>2],x[k+28>>2])){break qa}g=y[a+791|0];if((g|0)!=19){break ra}e=y[a+793|0]&240;if((e|0)==16){break qa}g=19;if((e|0)==32){break qa}}if(!l){break pa}}gV(a);ua=Se(x[s+8>>2],f),va=0,x[ua>>2]=va;break _}if(ea){x[31609]=0;V(611,s|0,f&65535,n|0,-1);e=x[31609];x[31609]=0;if((e|0)==1){break X}g=y[a+791|0]}sa:{ta:{ua:{va:{wa:{e=g&255;if(e-6>>>0>=2){xa:{switch(e-19|0){case 1:break va;case 0:break wa;default:break xa}}if(e-35>>>0<2){break ta}if((e|0)==45){break ua}if((e|0)!=11){break sa}}if(!y[a+793|0]&x[b+480180>>2]==1){break sa}l=0;while(1){if((l|0)==(q|0)){break sa}v[a+851|0]=!l|y[a+851|0]&254;Jo(b,a,y[a+793|0]);l=l+1|0;continue}}g=y[a+793|0];e=g&15;if(!(e|x[b+480180>>2]&1048580)){break sa}v[a+851|0]=y[a+851|0]|1;g=g&240;if((g|0)!=176){if((g|0)!=160){break sa}Io(b,a,e,0);break sa}Ho(b,a,e,0);break sa}ya:{za:{Aa:{e=y[a+793|0];switch(e-158|0){case 1:break za;case 0:break Aa;default:break ya}}x[31609]=0;V(611,s|0,f&65535,n|0,-1);e=x[31609];x[31609]=0;if((e|0)==1){break X}x[a+88>>2]=x[a+88>>2]&-129;break sa}x[31609]=0;V(611,s|0,f&65535,n|0,-1);e=x[31609];x[31609]=0;if((e|0)==1){break X}e=x[a+88>>2];x[a+88>>2]=e|128;if(x[a+4>>2]){break sa}g=x[a+76>>2];if(!g){break sa}if(!(ua=Tc(y[t|0]),va=1,xa=e&2,xa?ua:va)){break sa}x[a>>2]=-1;x[a+4>>2]=g-1;break sa}if((e&240)!=112|e>>>0<115){break sa}dV(a,e,x[b+480180>>2]);break sa}nT(a,y[a+793|0]);break sa}x[31609]=0;e=f&65535;V(611,s|0,e|0,n|0,-1);g=x[31609];x[31609]=0;if((g|0)==1){break X}ua=a,va=mT(b,z[m+70>>1],x[m+48>>2],e),w[ua+774>>1]=va}e=y[a+851|0]|1;v[a+851|0]=e;Ba:{Ca:{switch(y[a+790|0]-3|0){case 2:e=y[a+792|0];Jb(k+24|0,F,41);Io(b,a,e,Gb(x[x[k+24>>2]>>2],x[k+28>>2]));break Ba;case 3:e=y[a+792|0];Jb(k+24|0,F,41);Ho(b,a,e,Gb(x[x[k+24>>2]>>2],x[k+28>>2]));break Ba;case 0:case 1:g=y[a+792|0];Da:{if(g){break Da}Jb(k+24|0,F,41);g=0;if(!Gb(x[x[k+24>>2]>>2],x[k+28>>2])){break Da}g=y[a+834|0];if(!g){break Ba}}l=0;e=(y[a+790|0]==3?g<<4:g)&255;while(1){if((l|0)==(q|0)){break Ba}v[a+851|0]=!l|y[a+851|0]&254;Jo(b,a,e);l=l+1|0;continue};case 11:break Ca;default:break Ba}}g=y[a+792|0];if(g>>>0>1){break Ba}v[a+851|0]=(e&247|g<<3)^8}if(y[a+851|0]&8){break _}l=1;Ea:{Fa:{Ga:{a=y[t+3|0];if(a>>>0>28){break Ga}e=1<<a;if(e&92){break Ea}if(!(e&268959744)){break Ga}if((y[t+5|0]-16&255)>>>0<32){break Ea}break Fa}if(a-38>>>0<4){break Ea}}l=(y[t+2|0]-11&255)>>>0<3}if(l){e=Se(x[s+8>>2],f);a=x[e>>2];x[e>>2]=a+q;x[31609]=0;V(611,s|0,f&65535,i|0,a+h|0);a=x[31609];x[31609]=0;if((a|0)!=1){break _}a=N()|0;break m}a=Se(x[s+8>>2],f);x[a>>2]=x[a>>2]+(q-h|0)}f=f+1|0;continue}}a=lT(b,m,H,0);n=i;continue u}a=N()|0;break m}a=N()|0;break m}a=y[h+792|0];if(!a){break O}i=k+24|0;wB(i,b,y[h+791|0],a,0);w[h+768>>1]=z[k+24>>1];if(y[_e(i)|0]){break N}}Ha:{Ia:{Ja:{Ka:{La:{switch(t-12|0){case 0:kT(b,m,l&65535);break Ha;case 2:a=jT(b,m,l&65535,f);if((a|0)==-1){break Ha}x[m+60>>2]=a;break Ha;case 5:Jb(k+24|0,F,5);if(Gb(x[x[k+24>>2]>>2],x[k+28>>2])){break Ha}g=D(Go(b,z[m+70>>1],x[m+48>>2],l&65535,0),1e4);x[k+56>>2]=g;Ma:{if(!Y|!(x[b+480180>>2]&16777250)){break Ma}if(g>>>0>=1e4){v[h+835|0]=(g>>>0)/1e4;break Ma}g=D(y[h+835|0],1e4);x[k+56>>2]=g}a=x[b+8>>2];if(g>>>0>=32e4){x[k+24>>2]=D(x[a+24>>2],1e4);ua=$,va=x[Hb(k+56|0,k+24|0)>>2],x[ua>>2]=va;break Ha}i=x[$>>2];R=(g>>>0)/1e4|0;I=D(M,R&15);g=i-I|0;x[$>>2]=(R&48)==16?i+I|0:g>>>0<=i>>>0?g:0;i=x[a+20>>2];a=x[a+24>>2];Jb(k+24|0,F,8);Fp($,D(i,1e4),Gb(x[x[k+24>>2]>>2],x[k+28>>2])?255e4:D(a,1e4));break Ha;case 8:Na:{switch(f-144>>>4|0){case 0:if(f>>>0>145){break Ha}x[h+88>>2]=x[h+88>>2]&-257|((f|0)==145)<<8;break Ha;case 1:v[h+836|0]=f&15;break Ha;case 2:break Ka;case 6:break Na;default:break Ha}}v[h+844|0]=f&15;break Ha;case 1:case 3:case 4:case 6:break Ha;case 7:break La;default:break Ia}}a=f&240;if((a|0)==240){break Ja}if((a|0)!=96){break Ha}}vB(b,m,l&65535,f&15);break Ha}v[h+844|0]=f&15;break Ha}if((t|0)!=28|(f&240)!=160){break Ha}Jb(k+24|0,F,58);if(Gb(x[x[k+24>>2]>>2],x[k+28>>2])){break Ha}v[h+836|0]=f&15}if(!Y){break M}Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{switch(t-2|0){case 0:if(!f){break Oa}Jb(k+24|0,F,90);if(!Gb(x[x[k+24>>2]>>2],x[k+28>>2])){v[h+812|0]=f}v[h+811|0]=f;break N;case 1:if(!f){break Oa}Jb(k+24|0,F,90);if(!Gb(x[x[k+24>>2]>>2],x[k+28>>2])){v[h+811|0]=f}v[h+812|0]=f;break N;case 2:if(!f){break Oa}w[h+768>>1]=f;break N;case 8:if(!f){break Oa}x[h+664>>2]=f<<8;break N;case 4:case 9:if(!f){break Oa}v[h+809|0]=f;break N;case 11:ua=Se(x[s+8>>2],l),va=f,v[ua+5|0]=va;break N;case 44:ua=Se(x[s+8>>2],l),va=f+3>>>2|0,v[ua+5|0]=va;break N;case 21:a=x[b+480180>>2];f=f<<(!(a&59593760)&f<<24>>24>=0);i=f&255;if(i>>>0<=128){x[L>>2]=i<<1;break N}if(a&16777250){break N}x[L>>2]=256;break N;case 22:Jb(k+24|0,F,9);Xa:{if(Gb(x[x[k+24>>2]>>2],x[k+28>>2])){if(f){v[h+817|0]=f;break Xa}f=y[h+817|0];break Xa}if(f){v[m+1433|0]=f;break Xa}f=y[m+1433|0]}a=f&15;i=f&255;Ya:{if(!((a|0)!=15|i>>>0<16)){f=(f&240)>>>4<<!(x[b+480180>>2]&59593760);a=x[L>>2]+(f<<1)|0;break Ya}i=i&240;if(!(!a|(i|0)!=240)){f=a<<(x[b+480180>>2]&59593760?1:2);a=x[L>>2]-f|0;break Ya}if(i){f=(f>>>3&30)<<!(x[b+480180>>2]&59593760);a=x[L>>2]+D(e,f)|0;break Ya}f=f<<(x[b+480180>>2]&59593760?1:2);a=x[L>>2]-D(e,f&255)|0}x[L>>2]=a;Ge(L,0,256);break N;case 19:if(f>>>0>64){break N}x[h+748>>2]=f;break N;case 20:Za:{if(f){v[h+816|0]=f;break Za}f=y[h+816|0]}a=x[h+748>>2];i=f&15;g=f&255;_a:{if(!((i|0)!=15|g>>>0<16)){x[k+24>>2]=a+(g>>>4|0);break _a}if(!(!i|(g&240)!=240)){x[k+24>>2]=a-i;break _a}if(i){x[k+24>>2]=a-D(e,i);break _a}x[k+24>>2]=a+D(e,g>>>4|0)}Ge(k+24|0,0,64);x[h+748>>2]=x[k+24>>2];break N;case 7:Zm(b,h,f,8);break N;case 29:case 30:break Pa;case 25:break Qa;case 6:break Ra;case 24:break Sa;case 3:break Ta;case 5:break Ua;case 18:break Va;case 17:break Wa;default:break N}}if(f>>>0>15){break Va}i=(f&1)<<14;g=z[b+480188>>1];a=0;while(1){if((a|0)==(g|0)){break Va}t=D(a,872)+T|0;x[t+88>>2]=(i|x[t+88>>2]&-16385)^16384;a=a+1|0;continue}}if((f&240)!=128){break N}Zm(b,h,f&15,4);break N}if(f){v[h+809|0]=f}f=0}Hl(h,f);break N}iT(b,h,f);break N}hT(h,f);break N}gT(h,f);break N}$a:{if(f<<24>>24>=0){a=Pe(pa,y[h+844|0]);break $a}a=Pe(qa,f&127)}i=y[h+793|0];x[31609]=0;ja(612,b|0,m|0,l&65535,0,a|0,i|0);a=x[31609];x[31609]=0;if((a|0)!=1){break N}a=N()|0;break m}f=0}ab:{bb:{switch(y[h+790|0]-2|0){case 0:Zm(b,h,y[h+792|0],6);break ab;case 5:Jb(k+24|0,F,53);a=y[h+792|0];if(Gb(x[x[k+24>>2]>>2],x[k+28>>2])){v[h+823|0]=a&15;break ab}Hl(h,a<<4);break ab;case 6:break bb;default:break ab}}Hl(h,y[h+792|0])}cb:{db:{eb:{fb:{gb:{a=y[h+791|0];switch(a-5|0){case 1:break cb;case 3:break eb;case 0:case 2:break fb;default:break gb}}switch(a-26|0){case 1:break db;case 0:break fb;default:break cb}}hb:{if(x[b+480180>>2]&16777248){a=q;if(!(y[b+480208|0]&4)){break hb}}a=e}i=y[h+823|0];Jb(k+24|0,F,21);a=D(a,i);ua=h,va=y[h+819|0]+(Gb(x[x[k+24>>2]>>2],x[k+28>>2])?a<<2:a)|0,v[ua+819|0]=va;break cb}ib:{if(x[b+480180>>2]&16777248){a=q;if(!(y[b+480208|0]&4)){break ib}}a=e}i=y[h+826|0];Jb(k+24|0,F,21);a=D(a,i);ua=h,va=y[h+820|0]+(Gb(x[x[k+24>>2]>>2],x[k+28>>2])?a<<2:a)|0,v[ua+820|0]=va;break cb}v[h+821|0]=y[h+821|0]+D(u,y[h+829|0]);eT(b,h)}Jb(k+24|0,F,78);if(!Gb(x[x[k+24>>2]>>2],x[k+28>>2])){break M}a=f&255;if(!a){break M}dT(h,a)}l=l+1|0;continue}}break}break}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}i=1;break n}i=0}jb:{if((_|0)!=7){break jb}a=0;while(1){if(z[b+480188>>1]<=a>>>0){break jb}kb:{if(x[Se(x[s+8>>2],a)>>2]==-1){break kb}x[31609]=0;V(611,s|0,a&65535,n|0,-1);d=x[31609];x[31609]=0;if((d|0)!=1){break kb}a=N()|0;break m}a=a+1|0;continue}}if(y[r+26|0]){w[r+20>>1]=z[m+72>>1];x[r+8>>2]=x[m+48>>2]}C[r>>3]=C[s+24>>3];x[31609]=0;O(606,X|0,r|0);a=x[31609];x[31609]=0;if((a|0)!=1){if(!Y){break a}if(!(i?y[r+26|0]:1)){break c}q=iB(k+56|0);if(Id(y[da+24|0])){TS(q,da)}tB(da);n=m+616|0;d=zc(b+1074376|0,m,614);e=d+616|0;a=0;while(1){if((a|0)==256){zn(d+223848|0,m+223848|0);a=d+223860|0;e=y[a+24|0];n=m+223860|0;lb:{if((Id(y[n+24|0])|0)==(e|0)){if(!e){break lb}e=gc(a);Mu(a,x[e>>2]);x[a>>2]=x[n>>2];x[a+4>>2]=x[n+4>>2];x[a+8>>2]=x[n+8>>2];mb:{if(!x[Ab(a)>>2]){x[a>>2]=e;break mb}x[x[e>>2]+8>>2]=e;e=gc(n);x[n>>2]=e;x[e>>2]=0;ua=Ab(n),va=0,x[ua>>2]=va}a=a+12|0;e=gc(a);Lu(a,x[e>>2]);n=n+12|0;x[a>>2]=x[n>>2];x[a+4>>2]=x[n+4>>2];x[a+8>>2]=x[n+8>>2];nb:{if(!x[Ab(a)>>2]){x[a>>2]=e;break nb}x[x[e>>2]+8>>2]=e;a=gc(n);x[n>>2]=a;x[a>>2]=0;ua=Ab(n),va=0,x[ua>>2]=va}break lb}if(e){tB(a);break lb}TS(a,n)}}else{i=D(a,872);Gq(i+e|0,i+n|0);a=a+1|0;continue}break}sB(d);x[b+1074400>>2]=0;v[b+1074476|0]=1;x[b+1074392>>2]=-2;x[b+1074396>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];ob:{pb:{a=x[b+1298300>>2];if(Fj(a)){break pb}x[31609]=0;W(613,a|0);a=x[31609];x[31609]=0;if((a|0)!=1){break pb}break ob}e=b+1074992|0;i=(_|0)==7;a=0;while(1){if(z[b+480188>>1]<=a>>>0){d=IC(k+24|0);a=Ti(x[q+12>>2]);x[k+20>>2]=a;e=b+906300|0;g=Pf(q+12|0);while(1){if(!Zg(a,g)){qb:{a=250;n=d;rb:{while(1){if(a>>>0>=32){if(x[n>>2]){a=1;break rb}else{a=a-32|0;n=n+4|0;continue}}break}a=(x[d+28>>2]&67108863)!=0}if(!a){break qb}a=0;while(1){if((a|0)==250){break qb}Jb(k+12|0,d,a);sb:{if(!Gb(x[x[k+12>>2]>>2],x[k+16>>2])){break sb}n=x[$d(e,a)>>2];i=x[x[n>>2]+180>>2];x[31609]=0;W(i|0,n|0);n=x[31609];x[31609]=0;if((n|0)!=1){break sb}break ob}a=a+1|0;continue}}a=Ti(x[q>>2]);x[k+12>>2]=a;d=Pf(q);while(1)if(Zg(a,d)){a=ud(a);n=gc(a);ua=$d(e,y[a|0]),ya=B[n>>2],B[ua+144>>2]=ya;a=x[ah(k+12|0)>>2];continue}else{Hq(q);break b}}n=ud(a);h=Ab(n);tb:{i=y[n|0];a=x[$d(e,i)>>2];if(a){Jb(k+12|0,d,i);if(!Gb(x[x[k+12>>2]>>2],x[k+16>>2])){x[31609]=0;P(614,d|0,i|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break tb}i=x[x[a>>2]+176>>2];x[31609]=0;O(i|0,a|0,-1);i=x[31609];x[31609]=0;if((i|0)==1){break tb}}ta=B[h>>2];n=x[n+4>>2];i=x[x[a>>2]+44>>2];x[31609]=0;wa(i|0,a|0,n|0,E(ta));a=x[31609];x[31609]=0;if((a|0)==1){break tb}}a=x[ah(k+20|0)>>2];continue}break}break ob}d=e+D(a,872)|0;n=y[d+799|0];if(n){v[d+802|0]=n}n=Se(x[s+8>>2],a);if(!(y[n+5|0]==255|i)){v[k+24|0]=64;ua=d,va=y[Qb(n+5|0,k+24|0)|0]<<2,x[ua+688>>2]=va}ub:{if(x[d+88>>2]&67109888){break ub}n=x[d+104>>2];if(!n|!(y[n+35|0]&2)){break ub}g=x[b+1298300>>2];if(!Ed(g)){break ub}x[31609]=0;f=g;g=a&65535;S(615,f|0,g|0,n+68|0);n=x[31609];x[31609]=0;if((n|0)!=1){n=x[b+1298300>>2];x[31609]=0;S(616,n|0,g|0,1);n=x[31609];x[31609]=0;if((n|0)!=1){break ub}}break ob}x[d+16>>2]=0;a=a+1|0;continue}}a=N()|0;Hq(q);break m}a=N()|0}Ru(G)}cT(s)}Qi(X);Q(a|0);p()}if((c|0)==3){break b}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074456>>2]=x[b+480200>>2]}a=fa&255;if((a|0)==y[b+484376|0]){break a}Vj(na,a)}if(c&9){a=b+1298264|0;if(x[a>>2]){ZT(a);b=x[a>>2];cl(a);Db(b);ua=Ab(a),va=0,x[ua>>2]=va;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[G>>2];x[a+4>>2]=x[G+4>>2];b=Ab(G);ua=Ab(a),va=x[b>>2],x[ua>>2]=va;x[b>>2]=0;x[G>>2]=0;x[G+4>>2]=0;a=a+12|0;c=gc(a);Mq(a,x[c>>2]);b=G+12|0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];vb:{if(!x[Ab(a)>>2]){x[a>>2]=c;break vb}x[x[c>>2]+8>>2]=c;a=gc(b);x[b>>2]=a;x[a>>2]=0;ua=Ab(b),va=0,x[ua>>2]=va}}Ru(G);cT(s);fb=k+192|0}function lY(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,q=0,r=0,s=E(0),t=0,u=E(0),C=0,F=0,G=E(0),H=E(0),I=0,J=E(0),K=E(0),L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=E(0),Z=E(0),$=0,aa=0,ba=0,ca=0,da=E(0),ea=E(0),fa=0,ga=E(0),ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;ba=fb-16|0;fb=ba;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;d=b;e=0;h=x[a+1420>>2];b=(h|0)>0?h:0;q=a+1424|0;while(1){if((b|0)!=(e|0)){x[(q+D(e,20)|0)+12>>2]=0;e=e+1|0;continue}break}b:{c:{d:{if((h|0)>3){break d}e=0;if((c|0)<4){break c}c=c-3|0;b=0;while(1){if((b|0)==(c|0)){break d}e:{f:{k=b+d|0;if(y[k|0]!=79|(y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))!=(y[125468]|y[125469]<<8|(y[125470]<<16|y[125471]<<24))){break f}j=b+26|0;if((j|0)>=(c|0)){break e}e=b+27|0;i=d+j|0;f=y[i|0];if((e+f|0)>=(c|0)){break e}l=d+e|0;g=f+27|0;e=0;while(1)if((e|0)==(f|0)){e=0;f=0;while(1){o=22;if((e|0)!=22){f=gz(f,y[e+k|0]);e=e+1|0;continue}break}while(1){if((o|0)!=26){o=o+1|0;f=gz(f,0);continue}break}x[a+1420>>2]=h+1;e=q+D(h,20)|0;x[e+8>>2]=f;x[e+4>>2]=g-26;x[e>>2]=y[k+22|0]|y[k+23|0]<<8|(y[k+24|0]<<16|y[k+25|0]<<24);f=-1;if(y[(l+y[i|0]|0)-1|0]!=255){f=y[k+6|0]|y[k+7|0]<<8|(y[k+8|0]<<16|y[k+9|0]<<24)}x[e+12>>2]=j;x[e+16>>2]=f;h=x[a+1420>>2];if((h|0)!=4){break f}h=4;break d}else{g=y[e+l|0]+g|0;e=e+1|0;continue}}b=b+1|0;continue}break}c=b}g=0;g:while(1){m=(g|0)>(h|0)?g:h;while(1){if((g|0)==(m|0)){break b}e=0;b=q+D(g,20)|0;k=x[b+4>>2];l=x[b+12>>2];i=c-l|0;j=(i|0)>(k|0)?k:i;C=(j|0)>0?j:0;U=d+l|0;f=x[b+8>>2];while(1){if((e|0)!=(C|0)){f=gz(f,y[e+U|0]);e=e+1|0;continue}break}x[b+8>>2]=f;x[b+4>>2]=k-j;if((i|0)>=(k|0)){if(x[b>>2]==(f|0)){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[b+16>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;e=j+l|0;break c}e=h-1|0;x[a+1420>>2]=e;e=q+D(e,20)|0;f=x[e+4>>2];x[b>>2]=x[e>>2];x[b+4>>2]=f;x[b+16>>2]=x[e+16>>2];f=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=f;h=x[a+1420>>2];continue g}else{g=g+1|0;continue}}}}c=e}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!NL(a)){x[f>>2]=0;c=0;break a}ca=fb-16|0;fb=ca;la=ba+4|0;x[a+1504>>2]=0;x[a+1508>>2]=0;h:{if(x[a+96>>2]){break h}i:{j:{k:{if(x[a+1380>>2]!=-1){break k}c=ff(a);if(x[a+96>>2]){break i}if((c|0)!=79){break j}if((ff(a)|0)!=103){break j}if((ff(a)|0)!=103){break j}if((ff(a)|0)!=83){break j}if(!ML(a)){break i}if(!(v[a+1375|0]&1)){break k}v[a+1376|0]=0;x[a+1384>>2]=0;bc(a,32);break i}g=dz(a);break i}bc(a,30)}if(!g){break h}if(rc(a,1)){bc(a,35);break h}l:{m:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=rc(a,Jm(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break h}x[ca+12>>2]=c;q=D(c,6)+a|0;if(!y[q+412|0]){h=x[a+112>>2];g=h>>1;break m}h=x[a+116>>2];g=h>>1;c=rc(a,1);k=(rc(a,1)|0)!=0;if(c|!y[q+412|0]){break m}x[la>>2]=h-x[a+112>>2]>>2;c=x[a+112>>2]+h>>2;break l}_(6325,13274,3152,10779);p()}x[la>>2]=0;c=g}x[ca+8>>2]=c;n:{if(!(!y[q+412|0]|k)){c=D(h,3);x[ba+8>>2]=c-x[a+112>>2]>>2;h=c+x[a+112>>2]>>2;break n}x[ba+8>>2]=g}x[ca+4>>2]=h;h=1}if(h){U=x[la>>2];ha=x[ba+8>>2];ma=x[ca+4>>2];h=0;N=fb-2368|0;fb=N;O=a+996|0;t=a+132|0;oa=D(x[ca+12>>2],6)+a|0;P=x[a+404>>2]+D(y[oa+413|0],40)|0;r=P+9|0;V=x[((y[oa+412|0]<<2)+a|0)+104>>2];ia=V>>1;ra=0-ia|0;o:{while(1){c=x[a+4>>2];if((c|0)>(h|0)){c=y[(x[P+4>>2]+D(h,3)|0)+2|0];g=h<<2;L=g+(N+1344|0)|0;x[L>>2]=0;k=y[c+r|0];if(z[t+(k<<1)>>1]){q=x[a+260>>2];p:{q:{if(!rc(a,1)){break q}c=2;l=x[g+O>>2];q=q+D(k,1596)|0;C=x[(y[q+1588|0]<<2)+88876>>2];g=Jm(C)-1|0;sa=l,ta=rc(a,g),w[sa>>1]=ta;sa=l,ta=rc(a,g),w[sa+2>>1]=ta;fa=q+82|0;Q=q+65|0;T=q+49|0;$=q+33|0;R=q+1|0;j=0;while(1){if(y[q|0]>j>>>0){i=y[j+R|0];o=y[i+T|0];m=-1<<o;S=y[i+$|0];r:{if(!o){k=0;break r}g=x[a+124>>2]+D(y[i+Q|0],2096)|0;if(x[a+1396>>2]<=9){vl(a)}k=x[a+1392>>2];W=w[(g+((k&1023)<<1)|0)+36>>1];s:{if((W|0)>=0){F=k;W=W&65535;k=y[W+x[g+8>>2]|0];x[a+1392>>2]=F>>>k;k=x[a+1396>>2]-k|0;x[a+1396>>2]=(k|0)>0?k:0;k=(k|0)<0?-1:W;break s}k=Im(a,g)}if(!y[g+23|0]){break r}k=x[x[g+2088>>2]+(k<<2)>>2]}W=m^-1;g=c+S|0;S=fa+(i<<4)|0;while(1){if((c|0)!=(g|0)){m=0;i=w[S+((k&W)<<1)>>1];t:{if((i|0)<0){break t}i=x[a+124>>2]+D(i&65535,2096)|0;if(x[a+1396>>2]<=9){vl(a)}m=x[a+1392>>2];M=w[(i+((m&1023)<<1)|0)+36>>1];u:{if((M|0)>=0){F=m;M=M&65535;m=y[M+x[i+8>>2]|0];x[a+1392>>2]=F>>>m;m=x[a+1396>>2]-m|0;x[a+1396>>2]=(m|0)>0?m:0;m=(m|0)<0?-1:M;break u}m=Im(a,i)}if(!y[i+23|0]){break t}m=x[x[i+2088>>2]+(m<<2)>>2]}k=k>>o;w[l+(c<<1)>>1]=m;c=c+1|0;continue}break}j=j+1|0;c=g;continue}break}if(x[a+1396>>2]==-1){break q}w[N+320>>1]=257;g=q+338|0;o=q+1088|0;c=2;while(1){m=x[q+1592>>2];if((m|0)<=(c|0)){c=0;while(1){if((c|0)>=(m|0)){break p}if(!y[(N+320|0)+c|0]){w[l+(c<<1)>>1]=65535;m=x[q+1592>>2]}c=c+1|0;continue}}else{k=c<<1;i=k+o|0;L=y[i|0];m=L<<1;j=z[m+g>>1];fa=y[i+1|0];Q=fa<<1;T=w[l+m>>1];i=w[Q+l>>1]-T|0;m=i>>31;j=(D((i^m)-m|0,z[g+k>>1]-j|0)|0)/(z[g+Q>>1]-j|0)|0;m=T+((i|0)<0?0-j|0:j)|0;Q=k+l|0;j=z[Q>>1];v:{w:{if(j){k=N+320|0;v[k+fa|0]=1;v[k+L|0]=1;v[c+k|0]=1;k=j<<16>>16;i=C-m|0;if((k|0)>=((i|0)<(m|0)?i:m)<<1){if((i|0)>(m|0)){break v}m=C+(j^-1)|0;break w}if(k&1){m=m-(k+1>>>1|0)|0;break w}m=(k>>1)+m|0;break w}v[(N+320|0)+c|0]=0}w[Q>>1]=m}c=c+1|0;continue}}}x[L>>2]=1}h=h+1|0;continue}else{bc(a,21);c=0;break o}}break}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){zc(N+320|0,N+1344|0,c<<2);h=z[P>>1];c=0;while(1){if((c|0)==(h|0)){pa=P+24|0;fa=a+800|0}else{g=x[P+4>>2]+D(c,3)|0;k=(N+1344|0)+(y[g|0]<<2)|0;x:{y:{if(!x[k>>2]){m=y[g+1|0];break y}m=y[g+1|0];if(x[(N+1344|0)+(m<<2)>>2]){break x}}x[(N+1344|0)+(m<<2)>>2]=0;x[k>>2]=0}c=c+1|0;continue}break}k=0;while(1){z:{if(y[P+8|0]>k>>>0){m=0;c=x[a+4>>2];q=(c|0)>0?c:0;c=0;while(1){if((c|0)==(q|0)){break z}if(y[(x[P+4>>2]+D(c,3)|0)+2|0]==(k|0)){g=c<<2;A:{if(x[g+(N+1344|0)>>2]){h=1;g=0;break A}h=0;g=x[g+fa>>2]}v[m+N|0]=h;x[(N+256|0)+(m<<2)>>2]=g;m=m+1|0}c=c+1|0;continue}}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){g=(ia|0)>0?ia:0;m=z[P>>1];B:while(1){if((m|0)<=0){Q=ia<<2;m=0;c=0;while(1){k=x[a+4>>2];if((k|0)<=(c|0)){while(1){if((k|0)>(m|0)){Q=y[oa+412|0];L=V>>1;g=L<<2;W=x[a+92>>2];o=V>>3;$=V>>2;k=x[(m<<2)+fa>>2];c=L<<2;P=k+c|0;C:{if(x[a+80>>2]){q=oo(a,g);break C}q=Gd(g)}c=(q+c|0)-8|0;C=x[((Q<<2)+a|0)+1068>>2];i=C;g=k;while(1){if((g|0)!=(P|0)){B[c+4>>2]=E(B[g>>2]*B[i>>2])-E(B[i+4>>2]*B[g+8>>2]);B[c>>2]=E(B[g>>2]*B[i+4>>2])+E(B[g+8>>2]*B[i>>2]);g=g+16|0;i=i+8|0;c=c-8|0;continue}break}g=P-12|0;while(1){if(c>>>0>=q>>>0){B[c+4>>2]=E(B[g>>2]*B[i+4>>2])-E(B[g+8>>2]*B[i>>2]);B[c>>2]=E(E(-B[g+8>>2])*B[i+4>>2])-E(B[i>>2]*B[g>>2]);g=g-16|0;i=i+8|0;c=c-8|0;continue}break}c=$<<2;g=c+k|0;i=c+q|0;h=C+(L<<2)|0;c=q;j=k;while(1){l=h-32|0;if(l>>>0>=C>>>0){n=B[c>>2];s=B[i>>2];u=B[i+4>>2];G=B[c+4>>2];B[g+4>>2]=u+G;B[g>>2]=B[i>>2]+B[c>>2];u=E(u-G);t=h-16|0;r=h-12|0;n=E(s-n);B[j+4>>2]=E(u*B[t>>2])-E(B[r>>2]*n);B[j>>2]=E(n*B[t>>2])+E(u*B[r>>2]);n=B[c+8>>2];s=B[i+8>>2];u=B[i+12>>2];G=B[c+12>>2];B[g+12>>2]=u+G;B[g+8>>2]=B[i+8>>2]+B[c+8>>2];u=E(u-G);h=h-28|0;n=E(s-n);B[j+12>>2]=E(u*B[l>>2])-E(B[h>>2]*n);B[j+8>>2]=E(n*B[l>>2])+E(u*B[h>>2]);c=c+16|0;i=i+16|0;j=j+16|0;g=g+16|0;h=l;continue}break}g=Jm(V);c=V>>4;h=L-1|0;j=0-o|0;JL(c,k,h,j,C);JL(c,k,h-$|0,j,C);T=V>>5;c=0-c|0;hq(T,k,h,c,C,16);hq(T,k,h-o|0,c,C,16);hq(T,k,h-(o<<1)|0,c,C,16);hq(T,k,h+D(o,-3)|0,c,C,16);c=g-4>>1;o=(c|0)<=2?2:c;c=2;while(1){D:{E:{F:{if((c|0)==(o|0)){M=g-7|0;break F}i=0;j=2<<c;j=(j|0)>0?j:0;l=8<<c;t=V>>c+4;r=V>>c+2;R=0-(r>>1)|0;while(1){if((i|0)==(j|0)){break E}hq(t,k,h-D(i,r)|0,R,C,l);i=i+1|0;continue}}while(1){G:{if((o|0)<(M|0)){l=2<<o;R=8<<o;i=V>>o+6;aa=V>>o+2;X=0-(aa>>1)|0;pa=32<<o<<2;c=h;g=C;while(1){if((i|0)<=0){break G}j=l;t=(c<<2)+k|0;r=t+(X<<2)|0;S=D(R,12)+g|0;n=B[S>>2];O=(R<<3)+g|0;s=B[O>>2];F=(R<<2)+g|0;u=B[F>>2];G=B[S+4>>2];J=B[O+4>>2];Y=B[F+4>>2];Z=B[g+4>>2];ga=B[g>>2];S=0-aa<<2;while(1){if((j|0)>0){O=r-4|0;K=B[O>>2];da=B[t>>2];ea=B[r>>2];B[t>>2]=da+ea;F=t-4|0;H=B[F>>2];B[F>>2]=H+B[O>>2];H=E(H-K);K=E(da-ea);B[O>>2]=E(H*ga)+E(Z*K);B[r>>2]=E(K*ga)-E(Z*H);O=r-12|0;da=B[O>>2];F=t-8|0;H=B[F>>2];I=F;F=r-8|0;ea=B[F>>2];B[I>>2]=H+ea;I=t-12|0;K=B[I>>2];B[I>>2]=K+B[O>>2];K=E(K-da);H=E(H-ea);B[O>>2]=E(K*u)+E(Y*H);B[F>>2]=E(H*u)-E(Y*K);O=r-20|0;da=B[O>>2];F=t-16|0;H=B[F>>2];I=F;F=r-16|0;ea=B[F>>2];B[I>>2]=H+ea;I=t-20|0;K=B[I>>2];B[I>>2]=K+B[O>>2];K=E(K-da);H=E(H-ea);B[O>>2]=E(K*s)+E(J*H);B[F>>2]=E(H*s)-E(J*K);O=r-28|0;da=B[O>>2];F=t-24|0;H=B[F>>2];I=F;F=r-24|0;ea=B[F>>2];B[I>>2]=H+ea;I=t-28|0;K=B[I>>2];B[I>>2]=K+B[O>>2];K=E(K-da);H=E(H-ea);B[O>>2]=E(K*n)+E(G*H);B[F>>2]=E(H*n)-E(G*K);j=j-1|0;r=r+S|0;t=t+S|0;continue}break}i=i-1|0;c=c-8|0;g=g+pa|0;continue}}l=(h<<2)+k|0;g=l-(T<<6)|0;n=B[C+(V>>3<<2)>>2];ga=E(-n);while(1){if(g>>>0<l>>>0){J=B[l>>2];c=l-32|0;Y=B[c>>2];B[l>>2]=J+Y;h=l-4|0;s=B[h>>2];j=h;h=l-36|0;Z=B[h>>2];B[j>>2]=s+Z;j=l-8|0;u=B[j>>2];F=j;j=l-40|0;H=B[j>>2];B[F>>2]=u+H;i=l-12|0;G=B[i>>2];F=i;i=l-44|0;K=B[i>>2];B[F>>2]=G+K;B[c>>2]=J-Y;B[h>>2]=s-Z;h=l-16|0;s=B[h>>2];F=h;h=l-48|0;da=B[h>>2];B[F>>2]=s+da;u=E(u-H);G=E(G-K);B[j>>2]=n*E(u+G);B[i>>2]=n*E(G-u);j=l-28|0;u=B[j>>2];i=l-60|0;G=B[i>>2];C=l-24|0;J=B[C>>2];o=l-56|0;Y=B[o>>2];t=l-20|0;Z=B[t>>2];F=t;t=l-52|0;H=B[t>>2];B[F>>2]=Z+H;B[C>>2]=J+Y;B[j>>2]=u+G;B[h>>2]=Z-H;B[t>>2]=-E(s-da);s=E(u-G);u=E(J-Y);B[o>>2]=n*E(s-u);B[i>>2]=E(u+s)*ga;IL(l);IL(c);l=l+-64|0;continue}break}l=L-4|0;c=q+(l<<2)|0;i=(q+($<<2)|0)-16|0;g=x[((Q<<2)+a|0)+1100>>2];while(1){if(i>>>0>=q>>>0){h=(z[g>>1]<<2)+k|0;B[c+12>>2]=B[h>>2];B[c+8>>2]=B[h+4>>2];B[i+12>>2]=B[h+8>>2];B[i+8>>2]=B[h+12>>2];h=(z[g+2>>1]<<2)+k|0;B[c+4>>2]=B[h>>2];B[c>>2]=B[h+4>>2];B[i+4>>2]=B[h+8>>2];B[i>>2]=B[h+12>>2];g=g+4|0;c=c-16|0;i=i-16|0;continue}break}g=x[((Q<<2)+a|0)+1084>>2];i=q;c=i+(L<<2)|0;h=c;while(1){j=h-16|0;if(j>>>0>i>>>0){n=B[i+4>>2];C=h-4|0;s=B[C>>2];u=E(n-s);G=B[g+4>>2];n=E(n+s);s=B[i>>2];o=h-8|0;J=B[o>>2];Y=E(s-J);Z=B[g>>2];ga=E(E(G*n)-E(Y*Z));B[i+4>>2]=u+ga;s=E(s+J);n=E(E(G*Y)+E(n*Z));B[i>>2]=s+n;B[C>>2]=ga-u;B[o>>2]=s-n;n=B[i+8>>2];s=B[j>>2];u=E(n+s);G=B[g+12>>2];n=E(n-s);s=B[i+12>>2];h=h-12|0;J=B[h>>2];Y=E(s+J);Z=B[g+8>>2];ga=E(E(G*n)+E(Y*Z));B[i+8>>2]=u+ga;s=E(s-J);n=E(E(G*Y)-E(n*Z));B[i+12>>2]=s+n;B[j>>2]=u-ga;B[h>>2]=n-s;i=i+16|0;g=g+16|0;h=j;continue}break}i=x[((Q<<2)+a|0)+1076>>2]+(L<<2)|0;h=(V<<2)+k|0;g=(l<<2)+k|0;while(1){j=c-32|0;if(j>>>0>=q>>>0){n=B[c-8>>2];s=B[i-4>>2];u=B[i-8>>2];G=B[c-4>>2];J=E(E(n*s)-E(u*G));B[k>>2]=J;B[g+12>>2]=-J;n=E(E(u*E(-n))-E(s*G));B[P>>2]=n;B[h-4>>2]=n;n=B[c-16>>2];s=B[i-12>>2];u=B[i-16>>2];G=B[c-12>>2];J=E(E(n*s)-E(u*G));B[k+4>>2]=J;B[g+8>>2]=-J;n=E(E(u*E(-n))-E(s*G));B[P+4>>2]=n;B[h-8>>2]=n;n=B[c-24>>2];s=B[i-20>>2];u=B[i-24>>2];G=B[c-20>>2];J=E(E(n*s)-E(u*G));B[k+8>>2]=J;B[g+4>>2]=-J;n=E(E(u*E(-n))-E(s*G));B[P+8>>2]=n;B[h-12>>2]=n;n=B[j>>2];s=B[i-28>>2];i=i-32|0;u=B[i>>2];G=B[c-28>>2];J=E(E(n*s)-E(u*G));B[k+12>>2]=J;B[g>>2]=-J;n=E(E(u*E(-n))-E(s*G));B[P+12>>2]=n;h=h-16|0;B[h>>2]=n;g=g-16|0;P=P+16|0;k=k+16|0;c=j;continue}break}if(!x[a+80>>2]){Db(q)}x[a+92>>2]=W;break D}o=o+1|0;continue}}c=c+1|0;continue}break}m=m+1|0;k=x[a+4>>2];continue}break}}else{g=c<<2;i=x[g+fa>>2];H:{if(x[g+(N+320|0)>>2]){Rb(i,0,Q);break H}L=x[g+O>>2];I:{g=y[(y[(x[P+4>>2]+D(c,3)|0)+2|0]+P|0)+9|0];if(!z[((g<<1)+a|0)+132>>1]){bc(a,21);break I}C=V>>1;o=x[a+260>>2]+D(g,1596)|0;T=o+338|0;$=o+838|0;g=D(y[o+1588|0],w[L>>1]);j=1;h=0;while(1){if(x[o+1592>>2]>(j|0)){k=y[j+$|0]<<1;q=w[k+L>>1];if((q|0)>=0){q=D(y[o+1588|0],q&65535);k=z[k+T>>1];if((k|0)!=(h|0)){l=q-g|0;t=k-h|0;r=(l|0)/(t|0)|0;J:{R=(k|0)<(C|0)?k:C;if((R|0)<=(h|0)){break J}F=l;l=l>>31;S=r>>31;S=((F^l)-l|0)-D(t,(S^r)-S|0)|0;W=l|1;l=i+(h<<2)|0;B[l>>2]=B[((g&255)<<2)+88896>>2]*B[l>>2];R=R-1|0;l=0;while(1){if((h|0)==(R|0)){break J}h=h+1|0;M=i+(h<<2)|0;l=l+S|0;aa=(l|0)<(t|0);g=(g+r|0)+(aa?0:W)|0;B[M>>2]=B[((g&255)<<2)+88896>>2]*B[M>>2];l=l-(aa?0:t)|0;continue}}h=k}g=q}j=j+1|0;continue}break}if((h|0)>=(C|0)){break I}g=(g<<2)+88896|0;while(1){if((h|0)==(C|0)){break I}k=i+(h<<2)|0;B[k>>2]=B[g>>2]*B[k>>2];h=h+1|0;continue}}}c=c+1|0;continue}break}LL(a);K:{if(y[a+1377|0]){x[a+1060>>2]=ra;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=V-ma;break K}c=x[a+1412>>2];if(!c){break K}g=ha-U|0;if((g|0)<=(c|0)){x[a+1412>>2]=c-g;x[la>>2]=ha;U=ha;break K}U=c+U|0;x[la>>2]=U;x[a+1412>>2]=0}c=x[a+1064>>2];L:{M:{N:{O:{if(x[a+1388>>2]==x[a+1404>>2]){P:{if(!c|!(y[a+1375|0]&4)){break P}c=x[a+1408>>2];g=x[a+1060>>2];if(c>>>0>=g+(ma-U|0)>>>0){break P}g=c-g|0;c=(c>>>0>=g>>>0?g:0)+U|0;c=(c|0)<(ma|0)?c:ma;x[ba+12>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break M}x[a+1064>>2]=1;c=x[a+1408>>2]+(U-ia|0)|0;break O}if(!c){break N}c=x[a+1060>>2]}x[a+1060>>2]=c+(ha-U|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break L}x[ba+12>>2]=ma}c=1;break o}_(6325,13274,3451,5634);p()}m=m-1|0;c=x[P+4>>2]+D(m,3)|0;h=x[(y[c+1|0]<<2)+fa>>2];k=x[(y[c|0]<<2)+fa>>2];c=0;while(1){if((c|0)==(g|0)){continue B}q=c<<2;j=q+h|0;u=B[j>>2];q=k+q|0;n=B[q>>2];Q:{if(n>E(0)){if(u>E(0)){s=E(n-u);break Q}s=n;n=E(n+u);break Q}if(u>E(0)){s=E(n+u);break Q}s=n;n=E(n-u)}B[q>>2]=n;B[j>>2]=s;c=c+1|0;continue}}}_(6325,13274,3335,5634);p()}T=N+256|0;C=fb-16|0;fb=C;g=x[a+4>>2];c=y[k+pa|0];i=x[a+396>>2]+D(c,24)|0;h=x[i+4>>2];W=z[((c<<1)+a|0)+268>>1];c=ia<<((W|0)==2);j=c>>>0>h>>>0?h:c;h=x[i>>2];L=(j-(c>>>0>h>>>0?h:c)>>>0)/A[i+8>>2]|0;q=L<<2;c=D(g,q+4|0);S=x[x[a+124>>2]+D(y[i+13|0],2096)>>2];F=x[a+92>>2];R:{if(x[a+80>>2]){h=oo(a,c);g=x[a+4>>2];break R}h=Gd(c)}j=(m|0)>0?m:0;o=ia<<2;l=0;c=(g|0)>0?g:0;g=h+(g<<2)|0;while(1){if((c|0)!=(l|0)){x[h+(l<<2)>>2]=g;l=l+1|0;g=g+q|0;continue}break}q=h;c=0;while(1){if((c|0)!=(j|0)){if(!y[c+N|0]){Rb(x[T+(c<<2)>>2],0,o)}c=c+1|0;continue}break}S:{if(!((m|0)==1|(W|0)!=2)){c=0;while(1){T:{if((c|0)!=(j|0)){if(y[c+N|0]){break T}}else{c=j}if((c|0)==(m|0)){break S}l=(m|0)!=2;t=(m|0)<3;h=0;while(1){if((h|0)==8){break S}U:{if(!l){g=0;o=0;while(1){if((o|0)>=(L|0)){break U}c=x[i>>2]+D(x[i+8>>2],o)|0;x[C+12>>2]=c&1;x[C+8>>2]=c>>1;if(!h){j=x[a+124>>2]+D(y[i+13|0],2096)|0;if(x[a+1396>>2]<=9){vl(a)}c=x[a+1392>>2];r=w[(j+((c&1023)<<1)|0)+36>>1];V:{if((r|0)>=0){I=c;r=r&65535;c=y[r+x[j+8>>2]|0];x[a+1392>>2]=I>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:r;break V}c=Im(a,j)}c=y[j+23|0]?x[x[j+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break S}x[x[q>>2]+(g<<2)>>2]=x[x[i+16>>2]+(c<<2)>>2]}c=0;while(1){if(!((c|0)>=(S|0)|(o|0)>=(L|0))){j=x[i+8>>2];r=w[(x[i+20>>2]+(y[x[x[q>>2]+(g<<2)>>2]+c|0]<<4)|0)+(h<<1)>>1];W:{if((r|0)>=0){if(!KL(a,x[a+124>>2]+D(r&65535,2096)|0,T,2,C+12|0,C+8|0,ia,j)){break S}o=o+1|0;break W}o=o+1|0;j=x[i>>2]+D(j,o)|0;x[C+8>>2]=j>>1;x[C+12>>2]=j&1}c=c+1|0;continue}break}g=g+1|0;continue}}if(t){break U}g=0;o=0;while(1){if((o|0)>=(L|0)){break U}j=x[i>>2]+D(x[i+8>>2],o)|0;c=(j|0)/(m|0)|0;x[C+12>>2]=j-D(c,m);x[C+8>>2]=c;if(!h){j=x[a+124>>2]+D(y[i+13|0],2096)|0;if(x[a+1396>>2]<=9){vl(a)}c=x[a+1392>>2];r=w[(j+((c&1023)<<1)|0)+36>>1];X:{if((r|0)>=0){I=c;r=r&65535;c=y[r+x[j+8>>2]|0];x[a+1392>>2]=I>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:r;break X}c=Im(a,j)}c=y[j+23|0]?x[x[j+2088>>2]+(c<<2)>>2]:c;if((c|0)==-1){break S}x[x[q>>2]+(g<<2)>>2]=x[x[i+16>>2]+(c<<2)>>2]}c=0;while(1){if(!((c|0)>=(S|0)|(o|0)>=(L|0))){j=x[i+8>>2];r=w[(x[i+20>>2]+(y[x[x[q>>2]+(g<<2)>>2]+c|0]<<4)|0)+(h<<1)>>1];Y:{if((r|0)>=0){if(!KL(a,x[a+124>>2]+D(r&65535,2096)|0,T,m,C+12|0,C+8|0,ia,j)){break S}o=o+1|0;break Y}o=o+1|0;j=x[i>>2]+D(j,o)|0;r=(j|0)/(m|0)|0;x[C+8>>2]=r;x[C+12>>2]=j-D(m,r)}c=c+1|0;continue}break}g=g+1|0;continue}}h=h+1|0;continue}}c=c+1|0;continue}}g=0;while(1){if((g|0)==8){break S}m=0;$=0;while(1){if((m|0)<(L|0)){Z:{if(g){break Z}c=0;while(1){if((c|0)==(j|0)){break Z}if(!y[c+N|0]){l=x[a+124>>2]+D(y[i+13|0],2096)|0;if(x[a+1396>>2]<=9){vl(a)}h=x[a+1392>>2];o=w[(l+((h&1023)<<1)|0)+36>>1];_:{if((o|0)>=0){t=h;o=o&65535;h=y[o+x[l+8>>2]|0];x[a+1392>>2]=t>>>h;h=x[a+1396>>2]-h|0;x[a+1396>>2]=(h|0)>0?h:0;h=(h|0)<0?-1:o;break _}h=Im(a,l)}h=y[l+23|0]?x[x[l+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break S}x[x[q+(c<<2)>>2]+($<<2)>>2]=x[x[i+16>>2]+(h<<2)>>2]}c=c+1|0;continue}}h=0;while(1){$:{if((h|0)>=(S|0)){break $}c=0;if((m|0)>=(L|0)){break $}while(1){if((c|0)!=(j|0)){aa:{if(y[c+N|0]){break aa}l=c<<2;o=w[(x[i+20>>2]+(y[x[x[l+q>>2]+($<<2)>>2]+h|0]<<4)|0)+(g<<1)>>1];if((o|0)<0){break aa}r=x[a+124>>2]+D(o&65535,2096)|0;M=x[l+T>>2];R=x[i+8>>2];Q=x[i>>2]+D(R,m)|0;ba:{ca:{if(W){o=0;while(1){l=1;if((o|0)>=(R|0)){break ba}aa=M+(Q<<2)|0;l=R-o|0;t=0;n=E(0);da:{I=HL(a,r);if((I|0)<0){break da}X=x[r>>2];t=(l|0)>(X|0)?X:l;X=D(X,I);if(y[r+22|0]){l=0;I=(t|0)>0?t:0;t=1;while(1){if((l|0)==(I|0)){break da}ja=l<<2;ka=ja+aa|0;n=E(n+B[ja+(x[r+28>>2]+(X<<2)|0)>>2]);B[ka>>2]=B[ka>>2]+n;n=E(n+B[r+12>>2]);l=l+1|0;continue}}l=0;I=(t|0)>0?t:0;t=1;while(1){if((l|0)==(I|0)){break da}ja=l<<2;ka=ja+aa|0;B[ka>>2]=B[ka>>2]+E(B[ja+(x[r+28>>2]+(X<<2)|0)>>2]+E(0));l=l+1|0;continue}}if(!t){break ca}l=x[r>>2];Q=l+Q|0;o=l+o|0;continue}}o=0;aa=(R|0)/x[r>>2]|0;I=(aa|0)>0?aa:0;ja=M+(Q<<2)|0;l=1;while(1){if((o|0)==(I|0)){break ba}t=o+Q|0;M=o<<2;o=o+1|0;ka=M+ja|0;M=R-t|0;X=0;n=E(0);ea:{na=HL(a,r);if((na|0)<0){break ea}t=0;X=x[r>>2];M=(M|0)>(X|0)?X:M;M=(M|0)>0?M:0;na=D(X,na)<<2;X=1;while(1){if((t|0)==(M|0)){break ea}qa=ka+(D(t,aa)<<2)|0;s=E(n+B[(na+x[r+28>>2]|0)+(t<<2)>>2]);B[qa>>2]=B[qa>>2]+s;n=y[r+22|0]?s:n;t=t+1|0;continue}}if(X){continue}break}}l=0}if(!l){break S}}c=c+1|0;continue}break}m=m+1|0;h=h+1|0;continue}break}$=$+1|0;continue}break}g=g+1|0;continue}}if(!x[a+80>>2]){Db(q)}x[a+92>>2]=F;fb=C+16|0;k=k+1|0;continue}}_(6325,13274,3302,5634);p()}fb=N+2368|0}else{c=0}fb=ca+16|0;if(!c){fa:{ga:{ha:{c=x[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}x[a+100>>2]=0;while(1){if((Nh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break fa}x[a+100>>2]=0;while(1){if((Nh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;c=1;break a}q=x[ba+12>>2];l=x[ba+4>>2];k=x[ba+8>>2];h=1;j=x[a+992>>2];ia:{if(j){h=1092;c=j<<1;ja:{if((c|0)!=x[a+112>>2]){h=1096;g=0;if((c|0)!=x[a+116>>2]){break ja}}g=x[a+h>>2]}c=0;if(!g){break ia}h=0;i=(j|0)>0?j:0;m=a+928|0;C=a+800|0;U=g+(j<<2)|0;while(1){if(x[a+4>>2]>(h|0)){c=h<<2;ca=c+m|0;ha=c+C|0;c=0;while(1){if((c|0)!=(i|0)){j=c<<2;o=(j+x[ha>>2]|0)+(l<<2)|0;B[o>>2]=E(B[o>>2]*B[g+j>>2])+E(B[j+x[ca>>2]>>2]*B[U+((c^-1)<<2)>>2]);c=c+1|0;continue}break}h=h+1|0;continue}break}h=!x[a+992>>2]}x[a+992>>2]=q-k;j=a+928|0;i=a+800|0;m=(k|0)>(q|0);C=(m?k:q)-k|0;g=0;while(1){if(x[a+4>>2]>(g|0)){c=g<<2;U=c+j|0;ca=c+i|0;c=0;while(1){if((c|0)!=(C|0)){ha=c<<2;B[ha+x[U>>2]>>2]=B[(ha+x[ca>>2]|0)+(k<<2)>>2];c=c+1|0;continue}break}g=g+1|0;continue}break}c=0;if(!h){c=(m?q:k)-l|0;x[a+1416>>2]=c+x[a+1416>>2]}}g=c;c=0;h=x[a+4>>2];q=(h|0)>0?h:0;k=a+864|0;j=a+800|0;while(1){if((c|0)!=(q|0)){i=c<<2;x[i+k>>2]=x[i+j>>2]+(l<<2);c=c+1|0;continue}break}if(d){x[d>>2]=h}x[f>>2]=g;x[e>>2]=k;c=x[a+32>>2]-b|0}fb=ba+16|0;return c}function Lpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=fb-1728|0;fb=e;yc(b);d=fb-16|0;fb=d;i=e+1602|0;EX(d+8|0,i);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(j|0);if(!d){DX(i)}a:{b:{c:{d:{e:{f:{g:{if(!d){break g}if(!FX(i)){break g}if(!Mb(x[b>>2],x[b+8>>2],Bc(256,0))){break g}f=1;if((c|0)==64){break g}Dd(a,1048576);eg(a);d=fb-16|0;fb=d;f=e+1344|0;i=uc(d+4|0,4230);Uc(f,i);tb(i);fb=d+16|0;d=y[e+1610|0]|y[e+1611|0]<<8;x[e+144>>2]=d>>>8;x[31609]=0;x[e>>2]=d&255;i=e+68|0;O(444,i|0,e|0);d=x[31609];x[31609]=0;h:{i:{j:{k:{if((d|0)!=1){x[31609]=0;d=e+256|0;V(430,d|0,f|0,e+144|0,i|0);g=x[31609];x[31609]=0;if((g|0)==1){break k}zb(a+1298344|0,d);tb(d);tb(i);Eb(f);i=uc(d,15214);zb(a+1298356|0,i);tb(i);Ue(f,2,e+1612|0);Er(d,22,f);zb(a+1298368|0,d);tb(d);H=a,I=x[Fc(d,22)>>2],x[H+1298404>>2]=I;KC(f,2,e+1644|0);Cc(d,f);zb(a+1298308|0,d);tb(d);w[a+480188>>1]=y[e+1714|0]|y[e+1715|0]<<8;i=y[e+1718|0];x[a+480204>>2]=125e4;x[a+480208>>2]=32792;H=a,I=Ld(i,1,31),x[H+480196>>2]=I;w[a+480192>>1]=y[e+1724|0]|y[e+1725|0]<<8;w[a+480190>>1]=y[e+1726|0]|y[e+1727|0]<<8;i=Ld(y[e+1719|0],1,32);x[a+480216>>2]=i;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=i<<2;Hw(b,f);Qr(Xb(x[a+484360>>2],y[a+484376|0]),f,y[e+1708|0]|y[e+1709|0]<<8,65535,65535);$e(Xb(x[a+484360>>2],y[a+484376|0]),y[e+1710|0]|y[e+1711|0]<<8);s=gh(b);he(d,b,s?274:0);E=hc(e+1324|0,d);ub(d);x[31609]=0;f=R(151,b|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break i}x[31609]=0;S(185,d|0,b|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break i}u=hc(e+1304|0,d);ub(d);o=z[a+480188>>1];if(s){w[a+480188>>1]=o+8}B=c&1;if(!B){break h}x[31609]=0;O(223,a+484344|0,y[e+1712|0]|y[e+1713|0]<<8);d=x[31609];x[31609]=0;if((d|0)!=1){break h}g=N()|0;break c}g=N()|0;break j}g=N()|0;tb(e+68|0)}Eb(e+1344|0);break a}g=N()|0;break b}q=a+484344|0;g=0;while(1){l:{m:{n:{o:{p:{q:{if((y[e+1712|0]|y[e+1713|0]<<8)>>>0<=h>>>0){d=y[e+1716|0]|y[e+1717|0]<<8;if((d-2&65535)>>>0>=4998){break o}if(!(g&1)){break q}j=0;d=Gc(((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);break p}x[31609]=0;d=R(189,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}x[e>>2]=d;x[31609]=0;f=R(151,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break e}x[31609]=0;d=e+68|0;S(185,d|0,b|0,f+1&-2);f=x[31609];x[31609]=0;if((f|0)==1){break e}n=hc(e+256|0,d);ub(d);xc(e,1024);if(!B){break m}r=x[e>>2];if(!r){break m}x[31609]=0;d=U(196,q|0,h&65535,r|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){if(!d){break m}k=0;f=0;if(v[e+1720|0]&1){break n}r:while(1){if((k|0)==(r|0)){break m}d=Wb(x[q>>2],h);af(e+68|0,x[d>>2],x[x[d+48>>2]+12>>2],k);f=0;while(1){if((f|0)==(o|0)){k=k+1|0;continue r}x[31609]=0;d=e+144|0;O(623,n|0,d|0);i=x[31609];x[31609]=0;if((i|0)!=1){g=CX(Yc(x[e+68>>2],f),d)|g;f=f+1|0;continue}break}break}break f}break f}j=2;d=Te(2646e3/+(D(d,D(x[a+480216>>2],x[a+480196>>2]))>>>0)*1e4)}v[a+480224|0]=j;x[a+480204>>2]=d}d=z[a+480188>>1];x[31609]=0;v[e+256|0]=0;r=U(624,e+1292|0,d|0,e+256|0)|0;d=x[31609];x[31609]=0;s:{t:{if((d|0)!=1){k=a+1298320|0;i=a+480280|0;m=a+1298332|0;n=0;u:{v:{w:{x:{y:{while(1){d=x[u+8>>2];f=x[u>>2];x[31609]=0;d=U(150,f|0,d|0,8)|0;f=x[31609];x[31609]=0;z:{if((f|0)!=1){if(d){break z}h=a+906300|0;g=x[r>>2];k=0;while(1){f=z[a+480188>>1];if(f>>>0<=k>>>0){A:{x[e+248>>2]=0;x[e+252>>2]=0;x[e+240>>2]=0;x[e+244>>2]=0;x[e+232>>2]=0;x[e+236>>2]=0;x[e+224>>2]=0;x[e+228>>2]=0;if(s){break A}break t}}else{d=v[xb(g,k)|0];B:{if((d|0)<=(k|0)|d>>>0>=f>>>0){break B}d=y[(i+(d<<5)|0)+8|0];if(!d){break B}f=i+(k<<5)|0;j=y[f+8|0];if(!j){v[f+8|0]=d;break B}f=j-1|0;while(1){j=$d(h,f&255);f=In(x[j+28>>2]);if((f|0)!=255){continue}break}d=d-1&255;x[j+28>>2]=d>>>0<250?d+128|0:0}k=k+1|0;continue}break}x[31609]=0;O(625,E|0,e+256|0);d=x[31609];x[31609]=0;if((d|0)!=1){g=e+258|0;f=0;while(1){if((f|0)==8){f=0;x[31609]=0;j=P(214,e+212|0,z[e+256>>1])|0;d=x[31609];x[31609]=0;if((d|0)!=1){C:{D:{E:{F:{while(1){if(z[e+256>>1]<=f>>>0){x[31609]=0;k=U(626,e+200|0,y[e+1712|0]|y[e+1713|0]<<8,25320)|0;d=x[31609];x[31609]=0;if((d|0)==1){break D}l=e+274|0;h=0;break E}x[31609]=0;h=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){x[31609]=0;d=e+144|0;S(185,d|0,b|0,h<<5);h=x[31609];x[31609]=0;if((h|0)==1){break F}h=hc(e+68|0,d);kd(ch(x[j>>2],f),h);ub(h);f=f+1|0;ub(d);continue}break}g=N()|0;break C}g=N()|0;break C}while(1){if((y[e+1708|0]|y[e+1709|0]<<8)>>>0<=h>>>0){od(k);Rc(j);break t}G:{i=h+l|0;f=y[i|0];if(f>>>0>=z[e+256>>1]){break G}d=z[ac(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],h)>>1];if(d>>>0>=(y[e+1712|0]|y[e+1713|0]<<8)>>>0){break G}H:{g=ac(x[k>>2],d);m=z[g>>1];I:{if((m|0)==65535){w[g>>1]=f;break I}if((f|0)==(m|0)){break I}x[31609]=0;f=P(627,q|0,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break H}if((f|0)==65535){break I}H=ac(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],h),I=f,w[H>>1]=I;d=f}if(!Je(x[a+484344>>2],x[a+484348>>2],d)){break G}m=ch(x[j>>2],y[i|0]);yc(m);f=x[m>>2];x[31609]=0;f=R(154,f|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break H}s=f>>>5|0;i=0;J:while(1){f=Wb(x[q>>2],d);if(A[f+12>>2]<=i>>>0){break G}g=0;f=md(x[f>>2],x[x[f+48>>2]+12>>2],i,z[a+480188>>1]-8&65535);B=i>>>0>=s>>>0;while(1){if((g|0)==8){i=i+1|0;continue J}v[f|0]=0;v[f+1|0]=0;v[f+2|0]=0;v[f+3|0]=0;v[f+4|0]=0;v[f+5|0]=0;K:{if(B){break K}x[31609]=0;P(628,m|0,e+68|0)|0;t=x[31609];x[31609]=0;if((t|0)==1){break H}if(v[e+68|0]>=0){break K}v[f|0]=61;v[f+1|0]=y[(e+240|0)+(g<<1)|0];t=y[e+68|0]&31;v[e+144|0]=t;if(t){Of(e+144|0,15);v[f+3|0]=20;v[f+5|0]=y[e+144|0]|208}v[f+2|0]=1;v[f+4|0]=y[e+69|0]+3>>>2}f=f+6|0;g=g+1|0;continue}}}g=N()|0;od(k);break C}h=h+1|0;continue}}g=N()|0}Rc(j);break s}g=N()|0;break s}h=f<<1;i=h+(e+240|0)|0;d=z[a+480192>>1]+1&65535;j=a+900380|0;k=z[x[a+8>>2]+58>>1];while(1){L:{M:{m=d&65535;if(m>>>0<=k>>>0){if(x[j+(m<<2)>>2]){break M}}else{d=65535}d=d&65535;break L}d=d+1|0;continue}break}w[i>>1]=d;j=h+(e+224|0)|0;h=z[g+h>>1];w[j>>1]=h;N:{if((d|0)!=65535){x[31609]=0;d=U(251,a|0,d|0,h+1&65535)|0;h=x[31609];x[31609]=0;O:{P:{if((h|0)!=1){if(!d){break N}x[31609]=0;h=e+144|0;O(288,h|0,4475);i=x[31609];x[31609]=0;if((i|0)==1){break P}x[31609]=0;x[e>>2]=f+1;i=e+68|0;S(629,i|0,h|0,e|0);j=x[31609];x[31609]=0;if((j|0)==1){break O}Ac(d+492|0,i);tb(i);Eb(h);break N}g=N()|0;break s}g=N()|0;break s}g=N()|0;Eb(e+144|0);break s}w[i>>1]=0}f=f+1|0;continue}}g=N()|0;break s}g=N()|0;break s}x[31609]=0;h=R(151,u|0)|0;d=x[31609];x[31609]=0;Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((d|0)!=1){x[31609]=0;d=R(151,u|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Y}x[31609]=0;f=e+256|0;S(185,f|0,u|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break Y}d=hc(e+68|0,f);ub(f);if((h|0)==4674381){break U}if((h|0)==5068115){break T}if((h|0)==726487106){break X}if((h|0)==844387158){break S}f=0;if((h|0)==1280004692){break W}if((h|0)==1314144592){break V}if((h|0)!=1397445204){break R}x[31609]=0;f=R(189,d|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break v}f=f>>>0<256?48:f>>>8|0;x[a+480228>>2]=f;x[a+480232>>2]=f>>>1;f=0;while(1){if(z[a+480188>>1]<=f>>>0){break R}x[31609]=0;h=P(630,d|0,e+256|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break y}if(h){w[(i+(f<<5)|0)+6>>1]=z[e+256>>1]>>>10;H=xb(x[r>>2],f),I=y[e+259|0],v[H|0]=I}f=f+1|0;continue}}g=N()|0;break s}g=N()|0;break s}if(g&1){break R}v[a+480224|0]=2;x[31609]=0;F=+ia(631,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break Q}if(!(F>1e-8)){break R}H=a,I=Te(2646e3/(F*+(D(x[a+480216>>2],x[a+480196>>2])>>>0))*1e4),x[H+480204>>2]=I;break R}while(1){Z:{if(z[a+480188>>1]<=f>>>0){break R}h=x[d>>2];x[31609]=0;h=U(150,h|0,x[e+76>>2],1)|0;j=x[31609];x[31609]=0;if((j|0)==1){break x}if(!h){break R}h=Fb(e+256|0);x[31609]=0;S(358,d|0,h|0,-1);j=x[31609];x[31609]=0;if((j|0)!=1){ug(e,3,Kb(h),_c(x[e+260>>2],y[e+267|0]));x[31609]=0;j=e+144|0;O(218,j|0,e|0);l=x[31609];x[31609]=0;if((l|0)==1){break Z}gm((i+(f<<5)|0)+9|0,j);tb(j);tb(h);f=f+1|0;continue}}break}g=N()|0;tb(h);break u}while(1){if((y[e+1712|0]|y[e+1713|0]<<8)>>>0<=f>>>0){break R}h=x[d>>2];x[31609]=0;h=U(150,h|0,x[e+76>>2],1)|0;j=x[31609];x[31609]=0;if((j|0)==1){break w}if(!h){break R}if(!Bn(x[a+484344>>2],x[a+484348>>2],f&65535)){break R}h=Fb(e+256|0);x[31609]=0;S(358,d|0,h|0,-1);j=x[31609];x[31609]=0;_:{if((j|0)==1){break _}j=x[q>>2];x[31609]=0;O(283,Wb(j,f)|0,h|0);j=x[31609];x[31609]=0;if((j|0)==1){break _}tb(h);f=f+1|0;continue}break}g=N()|0;tb(h);break u}x[31609]=0;P(183,d|0,1)|0;f=x[31609];x[31609]=0;if((f|0)==1){break v}x[31609]=0;f=R(202,d|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break v}x[31609]=0;V(336,m|0,d|0,f|0,2);f=x[31609];x[31609]=0;if((f|0)!=1){break R}break v}x[31609]=0;P(632,d|0,e|0)|0;f=x[31609];x[31609]=0;$:{if((f|0)!=1){f=Fb(e+256|0);x[31609]=0;S(358,d|0,f|0,-1);h=x[31609];x[31609]=0;if((h|0)==1){break $}if(!Nd(f,12698)){x[31609]=0;h=e+144|0;S(258,h|0,22,f|0);j=x[31609];x[31609]=0;if((j|0)==1){break $}zb(k,h);tb(h)}tb(f);break R}g=N()|0;break u}g=N()|0;tb(f);break u}x[31609]=0;n=R(151,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break v}}ub(d);continue}break}g=N()|0;break u}g=N()|0;break u}g=N()|0;break u}g=N()|0;break u}g=N()|0}ub(d);break s}g=N()|0;break c}aa:{ba:{d=y[e+1720|0]|y[e+1721|0]<<8|(y[e+1722|0]<<16|y[e+1723|0]<<24);if(!(d&2)){break ba}h=(((d&8?z[a+480188>>1]:o)&65535)+((y[e+1610|0]|y[e+1611|0]<<8)>>>0>591?n:0)|0)+(d>>>4&1)|0;d=0;ca:while(1){f=0;if((y[e+1712|0]|y[e+1713|0]<<8)>>>0<=d>>>0){break ba}while(1){da:{if((f|0)!=(h|0)){i=x[b+8>>2];g=x[b>>2];x[31609]=0;i=U(150,g|0,i|0,4)|0;g=x[31609];x[31609]=0;if((g|0)==1){break aa}if(i){break da}}d=d+1|0;continue ca}x[31609]=0;O(633,y[e+1610|0]|y[e+1611|0]<<8,b|0);i=x[31609];x[31609]=0;if((i|0)==1){break aa}f=f+1|0;continue}}}x[31609]=0;n=P(214,e+188|0,255)|0;d=x[31609];x[31609]=0;if((d|0)!=1){q=e+76|0;h=0;while(1){ea:{d=h;fa:{if((d|0)==255){q=a+900380|0;m=a+484380|0;i=a+946304|0;o=IC(e+68|0);l=IC(e+144|0);g=0;while(1){ga:{ha:{ia:{if((g|0)==256){s=e+258|0;k=0;break ia}x[31609]=0;f=e+256|0;O(634,b|0,f|0);d=x[31609];x[31609]=0;if((d|0)==1){break ha}x[31609]=0;d=R(151,b|0)|0;h=x[31609];x[31609]=0;ja:{ka:{la:{if((h|0)!=1){x[31609]=0;S(185,e|0,b|0,d|0);h=x[31609];x[31609]=0;if((h|0)==1){break la}h=hc(e+40|0,e);ub(e);if((y[e+1726|0]|y[e+1727|0]<<8)>>>0>g>>>0){j=e+28|0;Ue(j,2,f);x[31609]=0;O(218,e|0,j|0);f=x[31609];x[31609]=0;if((f|0)==1){break ja}Ac((i+(g<<5)|0)+32|0,e);tb(e)}if(!d){break ga}if((y[e+1726|0]|y[e+1727|0]<<8)>>>0>g>>>0){break ka}break ga}g=N()|0;break fa}g=N()|0;break fa}x[31609]=0;d=(m+D(g,104)|0)+104|0;O(279,d|0,32);f=x[31609];x[31609]=0;ma:{na:{oa:{if((f|0)!=1){xp(d);x[31609]=0;O(635,h|0,e|0);f=x[31609];x[31609]=0;if((f|0)==1){break ja}j=x[e>>2];x[d>>2]=j;x[d+24>>2]=x[e+4>>2];if(y[e+8|0]>=2){j=j>>>1|0;x[d>>2]=j;w[d+34>>1]=z[d+34>>1]|1}if(y[e+9|0]>=2){x[d>>2]=j>>>1;w[d+34>>1]=z[d+34>>1]|64}j=2;switch(y[e+11|0]-1|0){case 0:break na;case 1:break oa;default:break ma}}break ja}j=6}w[d+34>>1]=z[d+34>>1]|j}x[d+4>>2]=x[e+12>>2];x[d+8>>2]=x[e+16>>2];w[d+30>>1]=z[e+20>>1]>>>7;f=y[e+22|0];pa:{if((f|0)==128){j=z[d+34>>1]|256;w[d+34>>1]=j;break pa}w[d+28>>1]=(f<<24>>24)+128;j=z[d+34>>1]}w[d+34>>1]=j|32;v[d+36|0]=y[e+23|0];j=y[e+10|0];if(j&2){f=e+28|0;Jb(f,l,g);bp(f);j=y[e+10|0]}if(j&5){w[d+34>>1]=z[d+34>>1]|16384}if(!(j&8)){break ga}d=e+28|0;Jb(d,o,g);bp(d);f=0;while(1){if((f|0)==8){break ga}d=f<<1;qa:{if(z[d+(e+224|0)>>1]!=(g|0)){break qa}d=x[q+(z[d+(e+240|0)>>1]<<2)>>2];if(!d){break qa}v[d+14|0]=0}f=f+1|0;continue}}g=N()|0;ub(h);break fa}while(1){ra:{sa:{if((y[e+1724|0]|y[e+1725|0]<<8)>>>0<=k>>>0){if(!(c&2)){break sa}g=0;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{while(1){if(z[a+480190>>1]<=g>>>0){break sa}g=g+1|0;c=m+D(g,104)|0;_l(c,(+(v[c+36|0]-49|0)+ +v[c+37|0]*-.0078125)/-12);w[c+36>>1]=0;d=z[c+34>>1];if(!(d&16384)){d=Zc(e+256|0,d&1?16:8,d&64?3:1,0,11);x[31609]=0;U(215,d|0,c|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){continue}g=N()|0;break fa}x[31609]=0;f=R(151,b|0)|0;d=x[31609];x[31609]=0;Ba:{if((d|0)==1){break Ba}x[31609]=0;P(183,b|0,12)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Ba}d=Fb(e+256|0);x[31609]=0;S(270,b|0,d|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break Aa}Be(c+43|0,d);x[31609]=0;c=e+40|0;O(383,c|0,16475);f=x[31609];x[31609]=0;if((f|0)==1){break za}x[e+140>>2]=g;h=x[a+1298404>>2];x[31609]=0;f=e+28|0;S(636,f|0,h|0,d|0);h=x[31609];x[31609]=0;if((h|0)==1){break ya}x[31609]=0;V(430,e|0,c|0,e+140|0,f|0);h=x[31609];x[31609]=0;if((h|0)==1){break xa}h=x[a+1298472>>2];x[31609]=0;S(385,h|0,2,e|0);h=x[31609];x[31609]=0;if((h|0)==1){break wa}tb(e);tb(f);Eb(c);tb(d);continue}break}g=N()|0;break fa}g=N()|0;break ta}g=N()|0;break ta}g=N()|0;break ua}g=N()|0;break va}g=N()|0;tb(e)}tb(e+28|0)}Eb(e+40|0)}tb(d);break fa}d=x[ch(x[n>>2],k)>>2];x[31609]=0;d=R(154,d|0)|0;f=x[31609];x[31609]=0;Ca:{Da:{if((f|0)!=1){if(!d){k=k+1|0;continue}d=ch(x[n>>2],k);yc(d);x[31609]=0;O(637,d|0,e+256|0);d=x[31609];x[31609]=0;if((d|0)==1){break Da}i=Nb(e);x[31609]=0;S(638,b|0,i|0,z[e+256>>1]);d=x[31609];x[31609]=0;if((d|0)==1){break Ca}k=k+1|0;d=x[q+(k<<2)>>2];if(!d|y[d+34|0]){break ra}x[d+4>>2]=32;f=0;Nv(d,0);B=d+108|0;t=d+236|0;while(1){if((f|0)==96){break ra}h=y[f+s|0];Ea:{if(h>>>0>=z[e+256>>1]){break Ea}g=Se(x[i>>2],h);C=f+12|0;G=ac(t,C);h=y[g|0];j=h+1|0;w[G>>1]=j;if(h>>>0>=z[a+480190>>1]){break Ea}h=m+D(j,104)|0;v[h+38|0]=y[e+354|0]&3;v[h+39|0]=y[e+355|0];v[h+40|0]=y[e+356|0];v[h+41|0]=y[e+357|0];w[h+32>>1]=y[g+1|0]<<1;v[h+37|0]=y[g+2|0];h=j-1|0;Jb(e+40|0,o,h);if(Gb(x[x[e+40>>2]>>2],x[e+44>>2])){v[d+14|0]=0}Jb(e+40|0,l,h);if(!Gb(x[x[e+40>>2]>>2],x[e+44>>2])){break Ea}H=xb(B,C),I=61,v[H|0]=I}f=f+1|0;continue}}g=N()|0;break fa}g=N()|0;break fa}g=N()|0;Ce(i);break fa}Rc(n);fc(r);ub(u);ub(E);f=1;break g}Ce(i);continue}}g=N()|0;break fa}ub(h);g=g+1|0;continue}}x[31609]=0;O(634,b|0,e+144|0);f=x[31609];x[31609]=0;Fa:{Ga:{Ha:{Ia:{if((f|0)!=1){x[31609]=0;f=R(151,b|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break Ia}x[31609]=0;i=e+68|0;f=(f|0)==32?428:f;g=f?(y[e+1610|0]|y[e+1611|0]<<8)>>>0>513?f+4|0:f:f;S(185,i|0,b|0,g|0);f=x[31609];x[31609]=0;if((f|0)==1){break Ha}f=hc(e+256|0,i);j=He(e,kd(ch(x[n>>2],d),f));ub(f);h=d+1|0;ub(i);if(d>>>0>=(y[e+1724|0]|y[e+1725|0]<<8)>>>0){break ea}x[31609]=0;d=h&65535;i=U(251,a|0,d|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break Ga}break Fa}g=N()|0;break fa}g=N()|0;break fa}g=N()|0;break fa}if(!i){break ea}f=e+68|0;Ue(f,2,e+144|0);x[31609]=0;d=e+256|0;O(218,d|0,f|0);f=x[31609];x[31609]=0;Ja:{if((f|0)!=1){Ac(i+492|0,d);tb(d);if(!g){break ea}x[31609]=0;O(637,j|0,d|0);d=x[31609];x[31609]=0;Ka:{if((d|0)!=1){d=3;k=0;if((y[e+1610|0]|y[e+1611|0]<<8)>>>0>=513){break Ka}m=0;break Ja}break Fa}x[31609]=0;m=R(189,j|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break Fa}if((y[e+1610|0]|y[e+1611|0]<<8)>>>0<514){break Ja}x[31609]=0;d=R(151,j|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){break Ja}break Fa}break Fa}x[i>>2]=y[e+358|0]|y[e+359|0]<<8;v[e+40|0]=0;v[e+41|0]=1;v[e+42|0]=2;v[e+43|0]=3;v[e+28|0]=0;v[e+29|0]=1;v[e+30|0]=2;v[e+31|0]=3;v[e+140|0]=0;v[e+141|0]=2;v[e+142|0]=1;v[e+143|0]=2;v[i+16|0]=y[(e+40|0)+((y[e+360|0]|y[e+361|0]<<8)&3)|0];v[i+17|0]=y[(e+28|0)+(y[e+361|0]&3)|0];v[i+18|0]=y[(e+140|0)+((y[e+360|0]|y[e+361|0]<<8)>>>12&3)|0];while(1){La:{Ma:{if((k|0)==4){if(!(v[i+60|0]&1|y[i+16|0]==3)){x[i>>2]=32767}ck(i,127,1);bk(i,0,1);if(!m){break ea}x[31609]=0;O(639,j|0,e+68|0);d=x[31609];x[31609]=0;if((d|0)==1){break Fa}if(m&2){ck(i,JD(x[a+480208>>2],+((y[e+70|0]|y[e+71|0]<<8)>>>0)),1);bk(i,y[e+72|0],1)}v[i+25|0]=y[e+69|0]==1;if(!(m&4)){break ea}v[i+31|0]=y[e+75|0]+1;d=v[e+76|0];v[i+34|0]=d+1;if((d|0)<0){v[i+30|0]=y[e+83|0]+1}if(!y[e+80|0]){break Ma}g=i+108|0;f=0;while(1){if((f|0)==128){break Ma}d=f+1|0;x[e+64>>2]=d+v[e+80|0];AX(e- -64|0);H=xb(g,f),I=x[e+64>>2],v[H|0]=I;f=d;continue}}if(!(d&1)){break La}x[31609]=0;O(640,j|0,e+68|0);f=x[31609];x[31609]=0;if((f|0)==1){break Fa}v[e+64|0]=0;v[e+65|0]=1;v[e+66|0]=2;v[e+67|0]=2;g=Wh(i,y[(e- -64|0)+k|0]);f=y[e+68|0];o=f&1;v[g+12|0]=y[g+12|0]&232|((k|0)==3?0-o&16:0)|f<<1&4|f>>>1&2|o;v[e+63|0]=y[e+69|0];v[e+62|0]=16;f=y[Qb(e+63|0,e+62|0)|0];x[31609]=0;O(293,g|0,f|0);f=x[31609];x[31609]=0;if((f|0)!=1){f=y[e+70|0];v[g+15|0]=f;v[g+16|0]=f;v[g+13|0]=y[e+71|0];v[g+14|0]=y[e+72|0];f=0;o=x[g>>2];l=Sd(o,x[g+4>>2]);while(1){if((f|0)==(l|0)){break La}s=yb(o,f);g=q+(f<<2)|0;w[s>>1]=y[g|0]|y[g+1|0]<<8;H=s,I=Ld(y[g+2|0]|y[g+3|0]<<8,0,64),v[H+2|0]=I;f=f+1|0;continue}}break Fa}Nv(i,0);break ea}k=k+1|0;d=d>>>1|0;continue}}g=N()|0;ub(j)}Rc(n);break s}ub(j);continue}}g=N()|0;break s}g=N()|0}fc(r);break c}while(1){d=x[n>>2];x[31609]=0;d=U(150,d|0,x[e+264>>2],1)|0;i=x[31609];x[31609]=0;Na:{if((i|0)!=1){if(!d){break m}x[31609]=0;j=R(197,n|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break f}m=0;if((j|0)!=255){break Na}x[31609]=0;m=R(197,n|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){x[31609]=0;j=R(197,n|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break Na}}break f}break f}if(j&127){d=Wb(x[q>>2],h);i=md(x[d>>2],x[x[d+48>>2]+12>>2],f,k&65535);GE(e+68|0);if(j&1){x[31609]=0;d=R(197,n|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break l}v[e+68|0]=d}if(j&2){x[31609]=0;d=R(197,n|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break l}v[e+69|0]=d}if(j&4){x[31609]=0;d=R(197,n|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break l}v[e+70|0]=d}if(j&8){x[31609]=0;d=R(197,n|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break l}v[e+71|0]=d}if(j&16){x[31609]=0;d=R(197,n|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break l}v[e+72|0]=d}if(j&32){x[31609]=0;d=R(197,n|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break l}v[e+73|0]=d}if(j&64){x[31609]=0;d=R(197,n|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break l}v[e+74|0]=d}t=CX(i,e+68|0);x[e+144>>2]=m;x[e+40>>2]=r+(f^-1);C=x[Hb(e+144|0,e+40|0)>>2];j=0;d=i;while(1){if((j|0)!=(C|0)){d=D(z[a+480188>>1],6)+d|0;l=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);v[d|0]=l;v[d+1|0]=l>>>8;v[d+2|0]=l>>>16;v[d+3|0]=l>>>24;l=y[i+4|0]|y[i+5|0]<<8;v[d+4|0]=l;v[d+5|0]=l>>>8;j=j+1|0;continue}break}g=g|t}f=(f+m|0)+1|0;while(1){if(f>>>0>=r>>>0){k=k+1|0;f=f-r|0;continue}break}if(o>>>0>(k&65535)>>>0){continue}break}}ub(n);h=h+1|0;continue}break}break f}fb=e+1728|0;return f|0}g=N()|0;ub(n);break c}g=N()|0;break c}g=N()|0}ub(u)}ub(E)}Q(g|0);p()}function Fsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;d=fb-1120|0;fb=d;yc(b);i=fb-16|0;fb=i;h=d+884|0;e_(i+8|0,h);g=x[i+12>>2];kc(i,x[b>>2],x[b+8>>2],x[i+8>>2],x[i+12>>2]);e=x[i+4>>2];if((e|0)==(g|0)){Vb(b,x[i+12>>2])}fb=i+16|0;e=(e|0)==(g|0);if(!e){d_(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!g_(h)){break o}if(!Mb(x[b>>2],x[b+8>>2],Bc(f_(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)),hb))){break o}f=1;if((c|0)==64){break o}Dd(a,16777216);eg(a);x[a+480208>>2]=x[a+480208>>2]|16809984;g=d+448|0;sr(g,32);e=x[d+460>>2];f=a+1074320|0;x[f>>2]=x[d+456>>2];x[f+4>>2]=e;e=x[d+452>>2];x[a+1074312>>2]=x[d+448>>2];x[a+1074316>>2]=e;Lb(Lb(a+1074312|0,57,y[d+887|0]>5),114,1);e=kp(d+840|0);C=e,E=Ld(y[d+1084|0],1,31),x[C+8>>2]=E;C=e,E=Ld(y[d+1085|0],1,12),x[C+4>>2]=E;C=e,E=Bb(y[d+1086|0]|y[d+1087|0]<<8),x[C>>2]=E;nE(a+1298412|0,e);w[a+480188>>1]=32;e=d+36|0;c_(e,3,d+1088|0);Er(g,1,e);zb(a+1298368|0,g);tb(g);p:{if(y[d+887|0]<=5){gg(e,3924);break p}f=fb-16|0;fb=f;e=uc(f+4|0,3993);Uc(d+36|0,e);tb(e);fb=f+16|0}x[31609]=0;g=d+448|0;f=d+36|0;S(370,g|0,f|0,y[d+887|0]);e=x[31609];x[31609]=0;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((e|0)!=1){zb(a+1298344|0,g);tb(g);Eb(f);e=uc(g,15218);zb(a+1298356|0,e);tb(e);C=a,E=x[Fc(g,26)>>2],x[C+1298404>>2]=E;Ue(f,3,d+892|0);Cc(g,f);zb(a+1298308|0,g);tb(g);x[a+480228>>2]=256;x[a+480200>>2]=384/(z[a+480188>>1]+3>>>0);G:{if(y[d+887|0]>5){break G}C=d,E=Bb(y[d+1112|0]|y[d+1113|0]<<8),w[C+448>>1]=E;w[d+36>>1]=1;C=a,E=z[qe(g,f)>>1],x[C+480196>>2]=E;C=d,E=Bb(y[d+1114|0]|y[d+1115|0]<<8),w[C+448>>1]=E;w[d+36>>1]=1;C=a,E=D(z[qe(g,f)>>1],1e4),x[C+480204>>2]=E;C=d,E=Bc(((Bb(y[d+1116|0]|y[d+1117|0]<<8)<<8)+2047>>>0)/4095|0,0),x[C+448>>2]=E;x[d+36>>2]=256;C=a,E=x[Hb(g,f)>>2],x[C+480200>>2]=E;C=d,E=Bb(y[d+1118|0]|y[d+1119|0]<<8),w[C+448>>1]=E;Hf(g,127);h=a+480280|0;f=0;g=z[d+448>>1];while(1){if((f|0)==(g|0)){break G}C=d,E=Bc(((Pk(b)<<8)+2047>>>0)/4095|0,0),w[C+36>>1]=E;w[d+344>>1]=256;C=h+(f<<5)|0,E=z[Oc(d+36|0,d+344|0)>>1],w[C+4>>1]=E;f=f+1|0;continue}}dd(b,$b(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)));B=He(d+820|0,b);x[31609]=0;f=d+808|0;O(375,f|0,B|0);b=x[31609];x[31609]=0;H:{I:{J:{K:{L:{if((b|0)!=1){x[31609]=0;g=d+448|0;S(376,g|0,f|0,1346458707);b=x[31609];x[31609]=0;if((b|0)==1){break H}x[31609]=0;e=U(150,x[d+448>>2],x[d+456>>2],2)|0;b=x[31609];x[31609]=0;if((b|0)==1){break K}if(!e){break I}x[31609]=0;e=R(273,g|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break K}if((e-1&65535)>>>0>126){break I}w[a+480188>>1]=e;ub(g);x[31609]=0;S(376,g|0,f|0,1397706311);b=x[31609];x[31609]=0;if((b|0)!=1){break L}a=N()|0;break c}a=N()|0;break b}x[31609]=0;e=U(150,x[d+448>>2],x[d+456>>2],2)|0;b=x[31609];x[31609]=0;if((b|0)==1){break E}if(!e){break I}x[31609]=0;h=d+448|0;e=R(273,h|0)|0;b=x[31609];x[31609]=0;M:{if((b|0)==1){break M}w[d+36>>1]=e;g=y[a+484376|0];f=x[a+484360>>2];x[31609]=0;e=R(273,h|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break M}$e(Xb(f,g),e);x[31609]=0;e=R(202,h|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break M}Hf(d+36|0,bm(e>>>1|0));e=y[a+484376|0];b=x[a+484360>>2];x[31609]=0;S(276,Xb(b,e)|0,h|0,z[d+36>>1]);b=x[31609];x[31609]=0;if((b|0)!=1){break J}}break E}a=N()|0;ub(d+448|0);break c}b=d+448|0;ub(b);x[31609]=0;S(376,b|0,d+808|0,1480806221);b=x[31609];x[31609]=0;if((b|0)==1){break F}x[31609]=0;e=U(150,x[d+448>>2],x[d+456>>2],3)|0;b=x[31609];x[31609]=0;if((b|0)!=1){if(e){break D}e=d+924|0;f=160;while(1){N:{b=f;if(!b){b=0;break N}f=b-1|0;if(y[e+f|0]==32){continue}}break}x[31609]=0;V(343,a+1298332|0,e|0,b|0,4);b=x[31609];x[31609]=0;if((b|0)!=1){break C}break B}break B}ub(d+448|0);f=0;break q}a=N()|0;break c}a=N()|0;Eb(d+36|0);break a}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}x[31609]=0;f=d+448|0;e=R(273,f|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){x[31609]=0;V(336,a+1298332|0,f|0,e|0,4);b=x[31609];x[31609]=0;if((b|0)!=1){break C}}break B}f=d+448|0;ub(f);x[31609]=0;S(376,f|0,d+808|0,1413697073);b=x[31609];x[31609]=0;if((b|0)==1){break A}x[31609]=0;e=R(197,f|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break y}if(e){break z}x[31609]=0;e=P(149,f|0,2648)|0;b=x[31609];x[31609]=0;if((b|0)==1){break y}if(!e){break z}b=0;x[31609]=0;g=R(281,f|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break y}f=a+480280|0;while(1){if((b|0)==32){break z}e=f+(b<<5)|0;x[e>>2]=x[e>>2]&-1025|!(g>>>b&1)<<10;b=b+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}k=d+448|0;ub(k);x[31609]=0;S(376,k|0,d+808|0,1413697074);b=x[31609];x[31609]=0;if((b|0)==1){break x}x[31609]=0;e=U(150,x[d+448>>2],x[d+456>>2],12)|0;b=x[31609];x[31609]=0;if((b|0)==1){break w}O:{if(!e){break O}x[31609]=0;f=d+36|0;O(377,f|0,k|0);b=x[31609];x[31609]=0;if((b|0)==1){break w}e=_e(f);b=gc(f);i=b_(f);h=Ab(f);g=a_(f);e=D(Ld(Bb(y[e|0]|y[e+1|0]<<8),32,999),1e4);b=Aua(Bb(y[b|0]|y[b+1|0]<<8),0,1e4,0);j=hb;b=b+32768|0;j=b>>>0<32768?j+1|0:j;C=a,E=((Bc((j&65535)<<16|b>>>16,j>>>16|0)>>>0)%1e4|0)+e|0,x[C+480204>>2]=E;C=a,E=Ld(Bb(y[i|0]|y[i+1|0]<<8),1,255),x[C+480196>>2]=E;b=16/(Ld(Bb(y[g|0]|y[g+1|0]<<8),1,16)>>>0)|0;x[a+480216>>2]=b;C=a,E=D(Ld(Bb(y[h|0]|y[h+1|0]<<8),1,16),b),x[C+480220>>2]=E;if(!Bb(z[d+36>>1])){break O}x[31609]=0;e=R(273,k|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break w}x[a+480208>>2]=x[a+480208>>2]&-17|!e<<4}f=d+448|0;ub(f);x[31609]=0;S(376,f|0,d+808|0,1414942540);b=x[31609];x[31609]=0;if((b|0)==1){break v}x[31609]=0;e=U(150,x[d+448>>2],x[d+456>>2],2)|0;b=x[31609];x[31609]=0;if((b|0)==1){break t}if(!e){break u}x[31609]=0;e=R(273,f|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break t}w[d+36>>1]=e;w[d+344>>1]=z[a+480188>>1];h=a+480280|0;g=z[Oc(d+36|0,d+344|0)>>1];b=0;while(1){if((b|0)==(g|0)){break u}x[31609]=0;f=R(273,d+448|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break t}w[d+36>>1]=f;w[d+344>>1]=4096;C=h+(b<<5)|0,E=z[Oc(d+36|0,d+344|0)>>1]>>>6&255,w[C+6>>1]=E;b=b+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}g=d+448|0;ub(g);x[31609]=0;f=d+36|0;S(376,f|0,d+808|0,1296652368);b=x[31609];x[31609]=0;if((b|0)==1){break s}x[31609]=0;e=U(150,x[d+36>>2],x[d+44>>2],56)|0;b=x[31609];x[31609]=0;if((b|0)==1){break d}if(!e){break r}x[31609]=0;O(378,f|0,g|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}if((Bb(y[d+482|0]|y[d+483|0]<<8)|0)!=4){break r}if((Bb(y[d+496|0]|y[d+497|0]<<8)|0)!=257){break r}C=d,E=Bb(y[d+488|0]|y[d+489|0]<<8),w[C+344>>1]=E;w[d+796>>1]=16384;b=z[Oc(d+344|0,d+796|0)>>1];f=b>>>24|0;b=(b<<8)+2048|0;f=b>>>0<2048?f+1|0:f;C=a,E=Bc((f&4095)<<20|b>>>12,f>>>12|0),x[C+480200>>2]=E;h=a+480280|0;b=0;while(1){if(Bb(y[d+486|0]|y[d+487|0]<<8)>>>0<=(b&65535)>>>0){break r}x[31609]=0;O(379,d+36|0,d+344|0);e=x[31609];x[31609]=0;if((e|0)==1){break d}P:{if(y[d+344|0]){break P}f=Bb(y[d+346|0]|y[d+347|0]<<8);if(f>>>0>=z[a+480188>>1]){break P}g=h+(f<<5)|0;C=g,E=Bc(((Bb(y[d+350|0]|y[d+351|0]<<8)<<8)+2047>>>0)/4095|0,0),w[C+4>>1]=E;e=Bb(y[d+348|0]|y[d+349|0]<<8);f=e>>>26|0;e=(e<<6)+2048|0;f=e>>>0<2048?f+1|0:f;C=g,E=Bc((f&4095)<<20|e>>>12,f>>>12|0)&255,w[C+6>>1]=E}b=b+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+36|0;ub(b);x[31609]=0;S(380,b|0,d+808|0,1396788530);b=x[31609];x[31609]=0;if((b|0)==1){break e}C=d,E=wb(x[d+36>>2]),x[C+760>>2]=E;j=c&2;k=a+946304|0;o=a+484380|0;g=d+450|0;f=wb(x[d+40>>2]);Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{while(1){n=x[d+760>>2];if(!Ib(n,f)){b=d+36|0;Rc(b);x[31609]=0;S(380,b|0,d+808|0,1396788560);b=x[31609];x[31609]=0;if((b|0)==1){break f}C=d,E=wb(x[d+36>>2]),x[C+784>>2]=E;g=d+450|0;f=wb(x[d+40>>2]);break Q}x[31609]=0;e=P(381,n|0,d+448|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break S}_:{$:{if(!e){break $}b=Bb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break $}if(Bb(z[d+496>>1])>>>0>1){break $}if(Bb(z[d+478>>1])>>>0>1){break $}if(b>>>0>z[a+480190>>1]){w[a+480190>>1]=b}x[31609]=0;h=o+D(b,104)|0;O(382,d+448|0,h|0);b=x[31609];x[31609]=0;aa:{ba:{ca:{if((b|0)==1){break ca}b=d+796|0;Vi(b,3,g);x[31609]=0;i=d+344|0;O(218,i|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break ba}Ac(k+(Bb(z[d+448>>1])<<5)|0,i);tb(i);if(!j){break $}b=z[d+522>>1]|z[d+524>>1]<<16;x[31609]=0;e=P(149,n|0,$b(b)-8|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break ca}if(!e){break $}if(Bb(z[d+478>>1])){break aa}Zc(i,(Bb(y[d+480|0]|y[d+481|0]<<8)|0)==8?8:16,(Bb(y[d+484|0]|y[d+485|0]<<8)|0)==1?1:2,!Bb(y[d+482|0]|y[d+483|0]<<8),0);x[31609]=0;U(215,i|0,h|0,n|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break aa}a=N()|0;break R}a=N()|0;break R}a=N()|0;break R}l=Fb(d+344|0);b=z[d+498>>1];x[31609]=0;S(270,n|0,l|0,Bb(b)|0);b=x[31609];x[31609]=0;if((b|0)==1){break U}Be(h+43|0,l);if((Bb(z[d+478>>1])|0)==1){x[31609]=0;i=d+784|0;O(383,i|0,16475);b=x[31609];x[31609]=0;if((b|0)==1){break _}x[31609]=0;h=d+772|0;S(258,h|0,0,l|0);b=x[31609];x[31609]=0;if((b|0)==1){break Z}x[31609]=0;e=d+796|0;V(384,e|0,i|0,z[d+448>>1],h|0);b=x[31609];x[31609]=0;if((b|0)==1){break Y}b=x[a+1298472>>2];x[31609]=0;S(385,b|0,2,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break X}tb(e);tb(h);Eb(i)}tb(l)}Qf(d+760|0);continue}break}a=N()|0;break T}a=N()|0;break V}a=N()|0;break W}a=N()|0;tb(d+796|0)}tb(d+772|0)}Eb(d+784|0);break T}a=N()|0}tb(l);break R}a=N()|0}Rc(d+36|0);break c}da:{while(1){ea:{h=x[d+784>>2];if(!Ib(h,f)){Rc(d+36|0);x[31609]=0;S(380,d+796|0,d+808|0,1447382614);b=x[31609];x[31609]=0;if((b|0)!=1){break da}a=N()|0;break c}x[31609]=0;e=P(386,h|0,d+448|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break ea}fa:{ga:{if(!e){break ga}b=Bb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break ga}if(Bb(z[d+502>>1])){break ga}if(b>>>0>z[a+480190>>1]){w[a+480190>>1]=b}x[31609]=0;e=o+D(b,104)|0;O(387,d+448|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break ea}b=d+796|0;Vi(b,3,g);x[31609]=0;i=d+344|0;O(218,i|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break ea}Ac(k+(Bb(z[d+448>>1])<<5)|0,i);tb(i);if(!j){break ga}b=z[d+478>>1];Zc(i,(Bb(z[d+482>>1])|0)==8?8:16,Bb(b)&1?2:1,1,0);x[31609]=0;U(215,i|0,e|0,h|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break fa}}Qf(d+784|0);continue}}break}a=N()|0;Rc(d+36|0);break c}x[31609]=0;e=d+808|0;S(380,d+784|0,e|0,1413828182);b=x[31609];x[31609]=0;if((b|0)==1){break h}x[31609]=0;S(380,d+772|0,e|0,1346719318);b=x[31609];x[31609]=0;if((b|0)==1){break j}x[31609]=0;S(380,d+760|0,e|0,1229869908);b=x[31609];x[31609]=0;if((b|0)==1){break l}C=d,E=wb(x[d+760>>2]),x[C+12>>2]=E;r=d+394|0;s=d+346|0;t=d+500|0;l=d+450|0;n=wb(x[d+764>>2]);while(1){ha:{ia:{ja:{ka:{q=x[d+12>>2];if(!Ib(q,n)){Rc(d+760|0);x[31609]=0;S(380,d+344|0,d+808|0,1346458692);b=x[31609];x[31609]=0;if((b|0)!=1){break ka}a=N()|0;break k}x[31609]=0;e=P(388,q|0,d+448|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break n}if(!e){break ha}if(Bb(z[d+478>>1])){break ha}b=z[d+448>>1];x[31609]=0;e=U(251,a|0,Bb(b)|0,0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break n}if(!e){break ha}b=Bb(z[d+448>>1]);if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=b}b=d+344|0;Vi(b,3,l);x[31609]=0;f=d+36|0;O(218,f|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break ja}Ac(e+492|0,f);tb(f);v[e+33|0]=2;if((ze(w[d+482>>1])|0)>0){v[e+15|0]=y[e+15|0]|1;b=ze(w[d+482>>1]);f=b>>>24|0;b=(b<<8&-256)+2047|0;j=f&255;C=e,E=Bc(Cua(b,b>>>0<2047?j+1|0:j,4095,0),hb),x[C+8>>2]=E}i=e+108|0;h=e+236|0;f=0;while(1){la:{x[d+36>>2]=128;x[d+344>>2]=128;b=f&255;g=d+36|0;if(b>>>0>=A[Hb(g,d+344|0)>>2]){x[31609]=0;O(389,g|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break la}C=d,E=Ti(x[d+36>>2]),x[C+344>>2]=E;h=Pf(g);g=z[a+480190>>1];f=z[d+480>>1];while(1){b=x[d+344>>2];if(Ib(b,h)){b=z[dp(b)>>1];if(g>>>0>(b-1&65535)>>>0){C=o+D(b,104)|0,E=Bb(f),w[C+30>>1]=E}ah(d+344|0);continue}break}Yv(d+36|0);ck(e,127,1);bk(e,0,1);b=Bb(z[d+498>>1]);if(!b){x[e>>2]=0;b=z[d+484>>1];x[31609]=0;V(390,e|0,0,Bb(b)|0,d+796|0);b=x[31609];x[31609]=0;if((b|0)==1){break n}b=z[d+488>>1];x[31609]=0;V(390,e|0,1,Bb(b)|0,d+772|0);b=x[31609];x[31609]=0;if((b|0)==1){break n}b=z[d+486>>1];x[31609]=0;V(390,e|0,2,Bb(b)|0,d+784|0);b=x[31609];x[31609]=0;if((b|0)!=1){break ha}break n}x[31609]=0;S(391,q|0,d+344|0,((b|0)==1?98:102)|0);b=x[31609];x[31609]=0;ma:{na:{oa:{if((b|0)!=1){f=Bb(z[d+344>>1]);j=f&1;if(!j){break ia}b=f&24;if(b){break oa}b=0;break na}a=N()|0;break m}if((b|0)!=8){break ma}b=1}v[e+25|0]=b}pa:{qa:{ra:{sa:{if(!(f&2)){break sa}x[31609]=0;f=U(392,d+332|0,s|0,24)|0;b=x[31609];x[31609]=0;if((b|0)==1){break ra}x[31609]=0;u=+ia(393,f|0);b=x[31609];x[31609]=0;if((b|0)==1){break qa}tb(f);if(!(u>20)){break sa}ck(e,JD(x[a+480208>>2],u),1)}if(Bb(z[d+344>>1])&4){break pa}break ia}a=N()|0;break m}a=N()|0;tb(f);break m}x[31609]=0;f=U(392,d+320|0,r|0,24)|0;b=x[31609];x[31609]=0;ta:{if((b|0)!=1){x[31609]=0;u=+ia(393,f|0);b=x[31609];x[31609]=0;if((b|0)==1){break ta}tb(f);bk(e,Zl(u*127/24),1);break ia}a=N()|0;break m}a=N()|0;tb(f);break m}else{g=t+(b<<1)|0;C=ac(h,b),E=y[g|0],w[C>>1]=E;b=xb(i,b);C=b,E=iw(v[g+1|0]+y[b|0]|0),v[C|0]=E;f=f+1|0;continue}}break}a=N()|0;break m}e=x[d+348>>2];b=x[d+344>>2];x[31609]=0;r=a+484344|0;O(223,r|0,Sf(b,e)&65535);b=x[31609];x[31609]=0;ua:{if((b|0)!=1){x[d+32>>2]=x[a+480204>>2];x[d+28>>2]=x[a+480196>>2];C=d,E=wb(x[d+344>>2]),x[C+24>>2]=E;j=c&1;k=wb(x[d+348>>2]);while(1){va:{wa:{xa:{ya:{za:{Aa:{m=x[d+24>>2];if(!Ib(m,k)){x[31609]=0;S(376,d+36|0,d+808|0,1414414669);b=x[31609];x[31609]=0;if((b|0)!=1){break Aa}a=N()|0;break ua}if(!j){break va}c=x[m+8>>2];b=x[m>>2];x[31609]=0;c=U(150,b|0,c|0,24)|0;b=x[31609];x[31609]=0;if((b|0)==1){break za}if(!c){break va}x[31609]=0;s=R(273,m|0)|0;b=x[31609];x[31609]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){v[d+464|0]=0;x[d+456>>2]=0;x[d+460>>2]=0;x[d+448>>2]=0;x[d+452>>2]=0;x[31609]=0;e=d+448|0;O(394,m|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break Ea}x[31609]=0;n=R(273,m|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break Da}x[31609]=0;t=R(273,m|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break Ca}x[31609]=0;l=R(273,m|0)|0;b=x[31609];x[31609]=0;Fa:{if((b|0)==1){break Fa}c=x[m+8>>2];b=x[m>>2];x[31609]=0;c=U(150,b|0,c|0,D(D(l,t),5)|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break Fa}if(!(c&n>>>0<2)){break va}x[31609]=0;c=U(196,r|0,s|0,t|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break Fa}if(!c){break va}b=x[r>>2];x[31609]=0;O(395,Wb(b,s)|0,e|0);b=x[31609];x[31609]=0;if((b|0)!=1){break Ba}}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}v[d+12|0]=0;b=ee(d+36|0,0,d+12|0);x[31609]=0;o=U(371,d+760|0,l|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break wa}q=0;Ga:while(1){if((q|0)==(t|0)){od(o);break va}b=Wb(x[r>>2],s);af(d+36|0,x[b>>2],x[x[b+48>>2]+12>>2],q);b=0;while(1){if((b|0)==(l|0)){q=q+1|0;continue Ga}f=Ng(d+12|0);if(z[a+480188>>1]>b>>>0){f=Yc(x[d+36>>2],b)}x[31609]=0;O(396,m|0,d|0);c=x[31609];x[31609]=0;Ha:{if((c|0)==1){break Ha}c=y[d|0];if((c-1&255)>>>0<=119){c=c+1|0;v[f|0]=c;C=ac(x[o>>2],b),E=c,v[C|0]=E}c=y[d+1|0];if(c){v[f+1|0]=c;C=ac(x[o>>2],b),E=c,v[C+1|0]=E}c=y[d+4|0];if(c){v[f+2|0]=1;v[f+4|0]=n?c-16|0:c>>>2|0}i=y[d+887|0];h=y[d+3|0];g=y[d+2|0];c=ac(x[o>>2],b);e=y[c+1|0];c=y[c|0];x[31609]=0;ya(373,a|0,f|0,g|0,h|0,i|0,c|0,e|0,d+32|0,d+28|0);c=x[31609];x[31609]=0;if((c|0)==1){break Ha}b=b+1|0;continue}break}break}a=N()|0;od(o);break ua}x[31609]=0;c=U(150,x[d+36>>2],x[d+44>>2],38)|0;b=x[31609];x[31609]=0;if((b|0)!=1){if(!c){break xa}x[31609]=0;h=R(273,d+36|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break ya}g=a+480280|0;f=d+452|0;b=0;Ia:{while(1){if(h>>>0<=(b&65535)>>>0){break xa}x[31609]=0;e=U(150,x[d+36>>2],x[d+44>>2],36)|0;c=x[31609];x[31609]=0;Ja:{if((c|0)!=1){if(e){break Ja}break xa}break ya}x[31609]=0;O(397,d+36|0,d+448|0);c=x[31609];x[31609]=0;if((c|0)!=1){Ka:{if(Bb(z[d+448>>1])){break Ka}if(Bb(z[d+450>>1])>>>0>=z[a+480188>>1]){break Ka}Ue(d,3,f);x[31609]=0;e=d+12|0;O(218,e|0,d|0);c=x[31609];x[31609]=0;if((c|0)==1){break Ia}gm((g+(Bb(z[d+450>>1])<<5)|0)+9|0,e);tb(e)}b=b+1|0;continue}break}break ya}break ya}break ya}a=N()|0;break ua}a=N()|0;ub(d+36|0);break ua}ub(d+36|0);Rc(d+344|0);Rc(d+772|0);Rc(d+784|0);Rc(d+796|0);f=1;break q}a=N()|0;break ua}Qf(d+24|0);continue}}a=N()|0}Rc(d+344|0);break k}a=N()|0;break m}b=0;while(1){if(y[d+445|0]<=b>>>0){break ha}x[31609]=0;g=d+36|0;O(398,q|0,g|0);f=x[31609];x[31609]=0;La:{Ma:{if((f|0)!=1){v[d|0]=0;v[d+1|0]=2;v[d+2|0]=1;v[d+3|0]=2;C=d,E=(Bb(z[d+484>>1])|0)!=0,v[C+32|0]=E;C=d,E=(Bb(z[d+486>>1])|0)!=0,v[C+33|0]=E;C=d,E=(Bb(z[d+488>>1])|0)!=0,v[C+34|0]=E;C=d,E=j&(Bb(z[d+490>>1])|0)!=0,v[C+35|0]=E;if(!y[(d+32|0)+b|0]|b>>>0>3){break La}h=(b|0)!=3;if(!h&(v[e+100|0]&1)){break La}x[31609]=0;f=g;g=y[b+d|0];S(399,f|0,e|0,g|0);f=x[31609];x[31609]=0;if((f|0)==1){break Ma}if(!h){v[e+100|0]=y[e+100|0]|16}Na:{switch(g|0){case 0:if(Bb(y[d+48|0]|y[d+49|0]<<8)&1){f=Bb(y[d+46|0]|y[d+47|0]<<8)&32767}else{f=0}x[e>>2]=f;break La;case 2:break Na;default:break La}}if(!(Bb(y[d+48|0]|y[d+49|0]<<8)&2)){break La}C=d,E=Bb(y[d+42|0]|y[d+43|0]<<8),w[C+28>>1]=E;w[d+24>>1]=1;k=z[qe(d+28|0,d+24|0)>>1];i=si(Bc(((Bb(y[d+38|0]|y[d+39|0]<<8)<<6|48)>>>0)/100|0,0));C=d,E=Bb(y[d+40|0]|y[d+41|0]<<8),w[C+28>>1]=E;w[d+24>>1]=1;h=Eh(256/z[qe(d+28|0,d+24|0)>>1]|0);g=z[d+448>>1];f=y[d+44|0]|y[d+45|0]<<8;x[31609]=0;g=Bb(g);f=Bb(f);ja(400,a|0,g|0,y[(f>>>0<6?f:0)+24992|0],255/(k>>>0)|0,i|0,h|0);f=x[31609];x[31609]=0;if((f|0)!=1){break La}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}b=b+1|0;continue}}Qf(d+12|0);continue}}ke(d+808|0);ub(B)}fb=d+1120|0;return f|0}a=N()|0}Rc(d+760|0);break k}a=N()|0}Rc(d+772|0);break i}a=N()|0}Rc(d+784|0);break g}a=N()|0}Rc(d+796|0);break c}a=N()|0;break c}a=N()|0;break c}a=N()|0;ub(d+36|0)}ke(d+808|0)}ub(B)}Q(a|0);p()}function lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;m=fb-1168|0;fb=m;yc(b);a:{b:{c:{d:{e=m+1144|0;e:{if(!ps(b,e)){break e}if(!mR(e)){break e}if((y[m+1152|0]|y[m+1153|0]<<8|(y[m+1154|0]<<16|y[m+1155|0]<<24))!=(Lh(x[b>>2])|0)){break e}if((y[m+1160|0]|y[m+1161|0]<<8|(y[m+1162|0]<<16|y[m+1163|0]<<24))!=(jf(b)|0)){break e}d=1;if((c|0)==64){break e}d=0;e=m+1088|0;Rb(e,0,56);f=-2;f:{if(!e){break f}x[e+44>>2]=0;x[e+48>>2]=0;x[e+52>>2]=0;x[e+20>>2]=0;x[e+24>>2]=0;x[e+8>>2]=0;h=x[e+32>>2];if(!h){x[e+32>>2]=1214;h=1214}if(!x[e+36>>2]){x[e+36>>2]=1215}h=ib[h|0](x[e+40>>2],1,43784)|0;f=-4;if(!h){break f}x[e+28>>2]=h;x[h+43780>>2]=1;x[h+10992>>2]=0;x[h+10996>>2]=0;x[h>>2]=0;x[h+11008>>2]=15;x[h+11e3>>2]=1;x[h+11004>>2]=0;f=0}if(f){break e}d=y[m+1160|0]|y[m+1161|0]<<8|(y[m+1162|0]<<16|y[m+1163|0]<<24);x[m+1084>>2]=d;J=y[m+1164|0]|y[m+1165|0]<<8|(y[m+1166|0]<<16|y[m+1167|0]<<24);S=FZ(m+1072|0,J);while(1){if(!(!J|!d|(g|0)==1)){x[m+32>>2]=1024;h=m+48|0;g=m+32|0;V=x[Hb(g,m+1084|0)>>2];d=Zb(m+40|0,h,V);e=x[d>>2];d=x[d+4>>2];x[31609]=0;Yn(159,g,b,e,d);g=x[31609];x[31609]=0;if((g|0)==1){break b}d=h;g=V;e=ba^-1;while(1){if(g>>>0<4){while(1){if(g){e=x[(((y[d|0]^e)&255)<<2)+79312>>2]^e>>>8;g=g-1|0;d=d+1|0;continue}break}g=e^-1}else{e=x[(((y[d|0]^e)&255)<<2)+79312>>2]^e>>>8;e=e>>>8^x[(((e^y[d+1|0])&255)<<2)+79312>>2];e=e>>>8^x[(((e^y[d+2|0])&255)<<2)+79312>>2];e=e>>>8^x[(((e^y[d+3|0])&255)<<2)+79312>>2];g=g-4|0;d=d+4|0;continue}break}ba=g;x[m+1092>>2]=V;x[m+1088>>2]=h;x[m+1104>>2]=J;x[m+1100>>2]=x[S>>2]+ca;C=fb-16|0;fb=C;e=-2;q=m+1088|0;g:{if(!q){break g}i=x[q+28>>2];if(!i){break g}fa=x[q+4>>2];x[i+11e3>>2]=0;h:{if(x[i+43780>>2]<0){break h}if(x[i+11004>>2]){break g}d=x[i+11008>>2];e=0;x[i+11004>>2]=0;g=x[i+10996>>2];if(!g){X=(d|0)>0?11:10;I=i+11012|0;h=x[q+4>>2];n=x[i+10992>>2];while(1){x[C+12>>2]=h;x[C+8>>2]=32768-n;B=x[q>>2];d=0;E=0;F=0;K=0;W=0;L=0;T=0;Y=0;Z=fb-144|0;fb=Z;i:{j:{M=n+I|0;if(M>>>0>=I>>>0){G=x[C+8>>2]+M|0;H=G-I|0;$=(I^-1)+G|0;if(!(H&$)){break j}}x[C+8>>2]=0;x[C+12>>2]=0;l=-3;break i}k=x[C+12>>2];u=k+B|0;O=x[i+60>>2];s=x[i+40>>2];g=x[i+36>>2];r=x[i+32>>2];h=x[i+56>>2];f=x[i+4>>2];l=-1;o=M;j=B;n=-1;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{t=x[i>>2];switch(t|0){case 10:case 17:case 21:case 35:case 36:case 37:case 39:break m;case 2:break s;case 53:break w;case 26:break y;case 25:break z;case 24:break A;case 23:break B;case 18:break C;case 16:break D;case 14:break E;case 51:break H;case 6:break I;case 3:break J;case 34:break K;case 42:break L;case 41:break M;case 32:break N;case 27:break O;case 11:break P;case 38:break Q;case 9:break R;case 52:break S;case 7:break T;case 5:break U;case 1:break V;case 0:break W;default:break l}}x[i+28>>2]=1;h=0;x[i+8>>2]=0;x[i+12>>2]=0;x[i+16>>2]=1;s=0;g=0;r=0;f=0;if(X&1){break V}break r}if((k|0)<=0){l=1;x[i>>2]=1;break k}x[i+8>>2]=y[B|0];j=B+1|0;break s}if((k|0)<=0){break t}W=f+8|0;j=B+1|0;h=y[B|0]<<f|h;d=2;break q}d=4;break q}L=h;break G}d=7;break q}d=8;break q}E=g;break F}F=h;break x}l=1;if((k|0)<=0){break u}f=f+8|0;j=B+1|0;break p}e=g;d=f;break v}k=2;break o}n=0;t=34;break m}d=1;break q}d=3;break q}d=5;break q}d=6;break q}d=9;break q}d=10;break q}d=11;break q}d=12;break q}d=13;break q}d=14;break q}d=15;break q}d=16;break q}d=17;break q}d=18;break q}k=1;break o}x[i>>2]=32;break k}x[i>>2]=5;l=1;break k}if(j>>>0>=u>>>0){x[i>>2]=2;l=1;break k}g=y[j|0];x[i+12>>2]=g;j=j+1|0;t=36;d=x[i+8>>2];e=256<<(d>>>4);if(e>>>0>32768|e>>>0>H>>>0|(((g|d<<8)>>>0)%31|g&32)){break n}g=0;if((d&15)!=8){break n}}d=0}X:while(1){Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{switch(d|0){case 0:if(f>>>0>2){break Ca}d=1;continue;case 9:break ha;case 10:break ia;case 11:break ja;case 12:break ka;case 13:break la;case 14:break ma;case 15:break na;case 16:break oa;case 17:break pa;case 8:break va;case 7:break wa;case 6:break xa;case 5:break ya;case 4:break za;case 3:break Aa;case 2:break Ba;case 1:break Da;default:break qa}}while(1){if(j>>>0>=u>>>0){x[i>>2]=3;l=1;break k}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}}d=h&7;x[i+20>>2]=d;e=d>>>1|0;x[i+24>>2]=e;f=f-3|0;h=h>>>3|0;if(d>>>0>=2){break ua}W=f;break ra}f=W&-8;h=h>>>(W&7)|0;g=0;d=0;break ta}while(1){if(j>>>0>=u>>>0){x[i>>2]=6;l=1;break k}h=y[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}d=1;break ta}if(j>>>0>=u>>>0){x[i>>2]=7;l=1;break k}v[(g+i|0)+10528|0]=y[j|0];j=j+1|0;d=2;break ta}while(1){if(j>>>0>=u>>>0){x[i>>2]=51;l=1;break k}h=y[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}break $}if(o>>>0<G>>>0){v[o|0]=r;g=g-1|0;o=o+1|0;h=L;break aa}n=2;t=52;h=L;break m}if(o>>>0<G>>>0){break sa}n=2;t=9;break m}if(j>>>0<u>>>0){d=G-o|0;e=u-j|0;d=d>>>0<e>>>0?d:e;d=d>>>0<g>>>0?d:g;g=g-d|0;o=zc(o,j,d)+d|0;j=d+j|0;break _}x[i>>2]=38;l=1;break k}n=-1;t=10;E=0;Ea:{switch(e-1|0){case 0:x[i+3552>>2]=84215045;x[i+3556>>2]=84215045;x[i+44>>2]=288;x[i+48>>2]=32;d=i+3560|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3568|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3576|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i- -64|0;e=0;while(1){k=144;if((e|0)==144){while(1){e=256;if((k|0)==256){while(1){k=280;if((e|0)==280){while(1){if((k|0)==288){break ea}v[d|0]=8;k=k+1|0;d=d+1|0;continue}}else{v[d|0]=7;e=e+1|0;d=d+1|0;continue}}}else{v[d|0]=9;k=k+1|0;d=d+1|0;continue}}}else{v[d|0]=8;e=e+1|0;d=d+1|0;continue}};case 2:break m;default:break Ea}}d=0;break ga}while(1){Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{switch(d|0){case 0:if(g>>>0>3){break Ja}if(!f){f=0;break Ia}if(f>>>0>7){break Ga}d=3;continue X;case 1:v[(g+i|0)+10528|0]=h;f=f-8|0;h=h>>>8|0;break Fa;default:break Ka}}g=g+1|0;break Ha}g=z[i+10528>>1];if((g^z[i+10530>>1])==65535){break aa}t=39;n=-1;break m}d=4;continue X}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(o>>>0<G>>>0){v[o|0]=y[(O-r&$)+I|0];o=o+1|0;O=O+1|0;d=7;break ba}n=2;t=53;break m}while(1){if(j>>>0>=u>>>0){x[i>>2]=27;l=1;h=F;break k}F=y[j|0]<<f|F;j=j+1|0;f=f+8|0;if(s>>>0>f>>>0){continue}break}d=6;break ba}if(j>>>0>=u>>>0){x[i>>2]=26;l=1;break k}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=4;if(f>>>0<15){break ba}d=5;break ba}while(1){if(j>>>0>=u>>>0){x[i>>2]=25;l=1;break k}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(s>>>0>f>>>0){continue}break}d=3;break ba}if(o>>>0>=G>>>0){n=2;t=24;break m}v[o|0]=g;o=o+1|0;break ca}if(j>>>0>=u>>>0){x[i>>2]=23;l=1;break k}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=0;if(f>>>0<15){break ba}d=1;break ba}while(1){if(j>>>0>=u>>>0){x[i>>2]=18;l=1;break k}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(s>>>0>f>>>0){continue}break}Y=r-16|0;d=3;break da}if(j>>>0>=u>>>0){x[i>>2]=16;l=1;break k}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=1;if(f>>>0<15){break da}d=2;break da}while(1){if(j>>>0>=u>>>0){x[i>>2]=14;l=1;break k}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}d=1;break fa}d=E+22273|0;while(1){if(j>>>0>=u>>>0){x[i>>2]=11;l=1;g=E;break k}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;K=v[d|0];if(f>>>0<K>>>0){continue}break}d=1}while(1){La:{Ma:{Na:{if(!d){if(E>>>0>2){break Na}K=v[E+22273|0];if(K>>>0<=f>>>0){break La}d=9;continue X}d=E<<2;x[(d+i|0)+44>>2]=x[d+80848>>2]+((-1<<K^-1)&h);E=E+1|0;f=f-K|0;h=h>>>K|0;break Ma}g=0;Rb(i+7040|0,0,288);d=0;break fa}d=0;continue}d=1;continue}}while(1){Oa:{Pa:{Qa:{if(!d){if(A[i+52>>2]<=g>>>0){break Qa}if(f>>>0>2){break Oa}d=10;continue X}v[(y[g+80864|0]+i|0)+7040|0]=h&7;g=g+1|0;f=f-3|0;h=h>>>3|0;break Pa}x[i+52>>2]=19;break ea}d=0;continue}d=1;continue}}T=x[i+24>>2];d=0}while(1){Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{switch(d|0){case 0:d=0;if((T|0)<0){break ca}H=Rb(Z,0,64);e=D(T,3488)+i|0;da=Rb(e+352|0,0,3200);ea=i+44|0;P=x[i+24>>2];k=x[ea+(P<<2)>>2];aa=e- -64|0;while(1){if((d|0)!=(k|0)){e=(y[d+aa|0]<<2)+H|0;x[e>>2]=x[e>>2]+1;d=d+1|0;continue}break};x[H+64>>2]=0;x[H+68>>2]=0;l=0;d=1;e=0;while(1){if((d|0)!=16){n=d<<2;d=d+1|0;n=x[n+H>>2];e=n+e<<1;x[(H- -64|0)+(d<<2)>>2]=e;l=l+n|0;continue}break};R=0;n=-1;if((e|0)!=65536){t=35;if(l>>>0>1){break m}}t=aa+2336|0;while(1){if(k>>>0>R>>>0){l=y[R+aa|0];_a:{if(!l){break _a}d=(H- -64|0)+(l<<2)|0;e=x[d>>2];x[d>>2]=e+1;d=0;k=l;while(1){if(k){d=e&1|d<<1;e=e>>>1|0;k=k-1|0;continue}break}if(l>>>0<=10){e=1<<l;l=l<<9|R;while(1){if(d>>>0>1023){break _a}w[(d<<1)+da>>1]=l;d=d+e|0;continue}}e=((d&1023)<<1)+da|0;k=w[e>>1];$a:{if(k){e=n;n=k;break $a}w[e>>1]=n;e=n-2|0}d=d>>>9|0;while(1){d=d>>>1|0;k=d&1;if(l>>>0>=12){k=t+(k+(n^-1)<<1)|0;n=w[k>>1];if(!n){w[k>>1]=e;n=e;e=e-2|0}l=l-1|0;continue}break}w[t+(k+(n^-1)<<1)>>1]=R;n=e}R=R+1|0;P=x[i+24>>2];k=x[ea+(P<<2)>>2];continue}break};d=0;if((P|0)!=2){break Sa}break Wa;case 1:k=w[(((h&1023)<<1)+i|0)+7328>>1];ab:{if((k|0)>=0){if(k>>>0<512|k>>>9>>>0>f>>>0){break ab}break Va}if(f>>>0<11){break ab}e=i+9376|0;d=10;while(1){k=w[e+((h>>>d&1)+(k^-1)<<1)>>1];if((k|0)<0){l=d+2|0;d=d+1|0;if(f>>>0>=l>>>0){continue}}break}if((k|0)>=0){break Va}}d=11;continue X;case 2:r=w[(((h&1023)<<1)+i|0)+7328>>1];if((r|0)>=0){break Ya}e=i+9376|0;d=10;while(1){l=h>>>d|0;d=d+1|0;r=w[e+((l&1)+(r^-1)<<1)>>1];if((r|0)<0){continue}break};break Xa;default:break Za}}d=v[Y+18468|0]+((-1<<s^-1)&h)|0;f=f-s|0;h=h>>>s|0;e=(i+10532|0)+g|0;Rb(e,(r|0)==16?y[e-1|0]:0,d);d=d+g|0;break Wa}d=r>>>9|0;r=r&511}f=f-d|0;h=h>>>d|0;if(r>>>0>15){break Ua}v[(g+i|0)+10532|0]=r;d=g+1|0}e=x[i+48>>2];g=x[i+44>>2];l=e+g|0;if(l>>>0<=d>>>0){break Ta}if(f>>>0<=14){if((u-j|0)<=1){g=d;d=1;continue}h=y[j|0]<<f|y[j+1|0]<<f+8|h;j=j+2|0;f=f|16}g=d}d=2;continue}if(!((r|0)!=16|g)){n=-1;g=0;t=17;r=16;break m}Y=r-16|0;s=v[r+22253|0];if(s>>>0<=f>>>0){break Ra}d=12;continue X}if((d|0)!=(l|0)){t=21;g=d;n=-1;break m}l=i+10532|0;zc(i- -64|0,l,g);zc(i+3552|0,g+l|0,e);P=x[i+24>>2];g=d}T=P-1|0;x[i+24>>2]=T;d=0;continue}d=3;continue}}d=2}bb:while(1){cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{switch(d|0){case 0:k=w[(((h&1023)<<1)+i|0)+352>>1];sb:{if((k|0)>=0){if(k>>>0<512|k>>>9>>>0>f>>>0){break sb}break cb}if(f>>>0<11){break sb}e=i+2400|0;d=10;while(1){k=w[e+((h>>>d&1)+(k^-1)<<1)>>1];if((k|0)<0){l=d+2|0;d=d+1|0;if(f>>>0>=l>>>0){continue}}break}if((k|0)>=0){break cb}}d=13;continue X;case 1:g=w[(((h&1023)<<1)+i|0)+352>>1];if((g|0)>=0){break qb}e=i+2400|0;d=10;while(1){l=h>>>d|0;d=d+1|0;g=w[e+((l&1)+(g^-1)<<1)>>1];if((g|0)<0){continue}break};break pb;case 3:break fb;case 4:break gb;case 5:break lb;case 6:break mb;case 2:break rb;default:break nb}}n=i+2400|0;t=i+352|0;while(1){d=u-j|0;if(!((G-o|0)>1&(d|0)>=4)){if(f>>>0>14){break cb}if((d|0)<=1){d=0;continue bb}h=y[j|0]<<f|y[j+1|0]<<f+8|h;f=f|16;j=j+2|0;break cb}if(f>>>0>14){l=j}else{h=(y[j|0]|y[j+1|0]<<8)<<f|h;f=f|16;l=j+2|0}g=w[t+((h&1023)<<1)>>1];tb:{if((g|0)<0){d=10;while(1){e=h>>>d|0;d=d+1|0;g=w[n+((e&1)+(g^-1)<<1)>>1];if((g|0)<0){continue}break}break tb}d=g>>>9|0}f=f-d|0;h=h>>>d|0;if(g&256){j=l;break ob}if(f>>>0>14){e=f}else{h=(y[l|0]|y[l+1|0]<<8)<<f|h;l=l+2|0;e=f|16}j=l;k=w[t+((h&1023)<<1)>>1];ub:{if((k|0)<0){d=10;while(1){f=h>>>d|0;d=d+1|0;k=w[n+((f&1)+(k^-1)<<1)>>1];if((k|0)<0){continue}break}break ub}d=k>>>9|0}v[o|0]=g;f=e-d|0;h=h>>>d|0;if(!(k&256)){v[o+1|0]=k;o=o+2|0;continue}break}o=o+1|0;g=k;break ob}d=g>>>9|0;g=g&511}f=f-d|0;h=h>>>d|0;if(g>>>0>255){break ob}d=14;continue X}e=g&511;g=256;if((e|0)==256){break Z}d=e-257<<2;g=x[d+80336>>2];s=0;if(e-285>>>0<4294967276){break eb}s=x[d+80464>>2];if(s>>>0>f>>>0){d=15;continue X}d=3;continue}if(!g){g=-1;break jb}g=g-1|0;d=18;continue X}f=f-s|0;h=F>>>s|0;r=((-1<<s^-1)&F)+r|0;break kb}k=w[(((h&1023)<<1)+i|0)+3840>>1];vb:{if((k|0)<0){e=i+5888|0;d=10;while(1){l=h>>>d|0;d=d+1|0;k=w[e+((l&1)+(k^-1)<<1)>>1];if((k|0)<0){continue}break}break vb}d=k>>>9|0;k=k&511}f=f-d|0;F=h>>>d|0;d=k<<2;r=x[d+80592>>2];s=0;if(k-30>>>0<4294967270){h=F;break kb}s=x[d+80720>>2];if(s>>>0<=f>>>0){break ib}d=17;continue X}O=o-I|0;d=(O-r&$)+I|0;if((d>>>0<o>>>0?o:d)+g>>>0>G>>>0){break hb}while(1){if(g>>>0>=3){v[o|0]=y[d|0];v[o+1|0]=y[d+1|0];v[o+2|0]=y[d+2|0];g=g-3|0;d=d+3|0;o=o+3|0;continue}break}if(!g){g=0;break jb}v[o|0]=y[d|0];if((g|0)==2){v[o+1|0]=y[d+1|0]}o=g+o|0}d=2;continue}d=6;continue}d=7;continue}k=w[(((h&1023)<<1)+i|0)+3840>>1];wb:{if((k|0)>=0){if(k>>>0<512|k>>>9>>>0>f>>>0){break wb}break db}if(f>>>0<11){break wb}e=i+5888|0;d=10;while(1){k=w[e+((h>>>d&1)+(k^-1)<<1)>>1];if((k|0)<0){l=d+2|0;d=d+1|0;if(f>>>0>=l>>>0){continue}}break}if((k|0)>=0){break db}}d=16;continue X}f=f-s|0;g=((-1<<s^-1)&h)+g|0;h=h>>>s|0}if(f>>>0>14){break db}if((u-j|0)<=1){d=4;continue}h=y[j|0]<<f|y[j+1|0]<<f+8|h;f=f|16;j=j+2|0}d=5;continue}d=1;continue}}if(!g|!f){break _}if(f>>>0>7){break $}d=5;continue}f=f-8|0;L=h>>>8|0;r=h&255;d=6;continue}if(g){break Y}g=0}if(v[i+20|0]&1){break p}d=0;continue}d=7;continue}}h=0;d=f>>>3|0;e=j-B|0;e=e>>>0<=j>>>0?e:0;d=d>>>0<e>>>0?d:e;if((f&-8)==d<<3){j=j-d|0;t=34;e=0;d=0;f=0;n=0;if(!(X&1)){break m}k=0;break o}_(6874,13252,2797,6884);p()}while(1){xb:{yb:{zb:{Ab:{Bb:{switch(k|0){case 0:if(e>>>0>3){n=0;t=34;g=e;f=d;break m}f=0;if(!d){g=e;break xb}if(d>>>0>7){break Ab}k=1;continue;case 1:break Bb;default:break zb}}while(1){if(j>>>0>=u>>>0){x[i>>2]=41;l=1;g=e;f=d;break k}h=y[j|0]<<d|h;l=d>>>0>4294967287;j=j+1|0;d=d+8|0;if(l){continue}break}}k=h&255;h=h>>>8|0;d=d-8|0;break yb}if(j>>>0>=u>>>0){x[i>>2]=42;l=1;break k}k=y[j|0];j=j+1|0;e=g;d=f}x[i+16>>2]=x[i+16>>2]<<8|k;e=e+1|0;k=0;continue}k=2;continue}}g=1}x[i>>2]=t;l=n}d=f>>>3|0;e=j-B|0;e=e>>>0<=j>>>0?e:0;d=d>>>0<e>>>0?d:e;j=j-d|0;f=f-(d<<3)|0}x[i+4>>2]=f;x[i+60>>2]=O;x[i+40>>2]=s;x[i+36>>2]=g;x[i+32>>2]=r;x[i+56>>2]=(((f&63)>>>0<32?-1<<f:0)^-1)&h;x[C+12>>2]=j-B;f=o-M|0;x[C+8>>2]=f;if((l|0)<0){break i}j=(f>>>0)%5552|0;g=x[i+28>>2];h=g>>>16|0;k=g&65535;Cb:while(1){Db:{e=0;if(!f){break Db}d=M;while(1)if((e|7)>>>0>=j>>>0){e=j&8184;while(1){if((e|0)!=(j|0)){e=e+1|0;k=y[d|0]+k|0;h=k+h|0;d=d+1|0;continue}break}f=f-j|0;h=(h>>>0)%65521|0;k=(k>>>0)%65521|0;M=j+M|0;j=5552;continue Cb}else{g=y[d|0]+k|0;n=g+y[d+1|0]|0;F=n+y[d+2|0]|0;L=F+y[d+3|0]|0;E=L+y[d+4|0]|0;o=E+y[d+5|0]|0;B=o+y[d+6|0]|0;k=B+y[d+7|0]|0;h=k+(B+(o+(E+(L+(F+(n+(g+h|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;e=e+8|0;continue}}break}g=h<<16|k;x[i+28>>2]=g;if(l){break i}l=0;if(!(X&1)){break i}l=(g|0)!=x[i+16>>2]?-2:0}fb=Z+144|0;x[i+43780>>2]=l;g=x[C+12>>2];x[q>>2]=g+x[q>>2];x[q+4>>2]=x[q+4>>2]-g;x[q+8>>2]=g+x[q+8>>2];x[q+48>>2]=x[i+28>>2];g=x[C+8>>2];x[i+10996>>2]=g;d=x[q+16>>2];g=d>>>0>g>>>0?g:d;zc(x[q+12>>2],x[i+10992>>2]+I|0,g);x[q+12>>2]=g+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-g;x[q+20>>2]=g+x[q+20>>2];d=x[i+10996>>2];x[i+10996>>2]=d-g;n=g+x[i+10992>>2]&32767;x[i+10992>>2]=n;if((l|0)<0){break h}if(!((l|0)!=1|fa)){e=-5;break g}if(l){e=0;h=x[q+4>>2];if(!h|!x[q+16>>2]){break g}if((d|0)==(g|0)){continue}break g}break}e=(d|0)==(g|0);break g}d=x[q+16>>2];g=d>>>0>g>>>0?g:d;zc(x[q+12>>2],(x[i+10992>>2]+i|0)+11012|0,g);x[q+12>>2]=g+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-g;x[q+20>>2]=g+x[q+20>>2];d=x[i+10996>>2];x[i+10996>>2]=d-g;x[i+10992>>2]=g+x[i+10992>>2]&32767;if(x[i+43780>>2]){break g}e=(d|0)==(g|0);break g}e=-3}fb=C+16|0;g=e;d=x[m+1084>>2]-V|0;x[m+1084>>2]=d;e=J+ca|0;J=x[m+1104>>2];ca=e-J|0;continue}break}b=m+1088|0;Eb:{if(!b){break Eb}d=x[b+28>>2];if(!d){break Eb}ib[x[b+36>>2]](x[b+40>>2],d);x[b+28>>2]=0}d=0;if(!((y[m+1156|0]|y[m+1157|0]<<8|(y[m+1158|0]<<16|y[m+1159|0]<<24))!=(ba|0)|(g|0)!=1|J)){se(m+24|0,x[S>>2],x[S+4>>2]);b=Md(m+16|0);x[31609]=0;g=x[b+4>>2];x[m+8>>2]=x[b>>2];x[m+12>>2]=g;b=hg(555,m+48|0,x[m+24>>2],x[m+28>>2],m+8|0);g=x[31609];x[31609]=0;if((g|0)==1){break d}x[31609]=0;d=U(913,a|0,b|0,c|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}ub(b)}fc(S)}fb=m+1168|0;return d|0}a=N()|0;break a}a=N()|0;ub(b);break a}a=N()|0}fc(S);Q(a|0);p()}function kqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=E(0),C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=E(0),P=E(0),S=0,V=0,W=0,Z=0,_=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=E(0),oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=E(0);t=fb-96|0;fb=t;yc(c);a:{while(1){b:{if(!Mb(x[c>>2],x[c+8>>2],4)){break b}j=t+76|0;d=fb-16|0;fb=d;c:{if(!Mb(x[c>>2],x[c+8>>2],3)){h=0;while(1){if((h|0)!=3){dh(h+j|0);h=h+1|0;continue}break}break c}dx(d+8|0,j);sd(d,c,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d:{e:{if(!jd(j,15110,3)){j=t+32|0;d=fb-16|0;fb=d;f:{if(!Mb(x[c>>2],x[c+8>>2],7)){h=0;while(1){if((h|0)!=7){dh(h+j|0);h=h+1|0;continue}break}break f}Jr(d+8|0,j);sd(d,c,x[d+8>>2],x[d+12>>2])}fb=d+16|0;M=0;j=3;while(1){if((j|0)==7){break d}d=v[(t+32|0)+j|0];if((d|0)<0){break e}j=j+1|0;M=d&255|M<<7;continue}}g:{if(jd(t+76|0,14256,3)){break g}if(!WX(c,13691)){break g}Vb(c,Rg(c)+16|0);continue}d=t+76|0;if(!jd(d,28558,3)){continue}if(!jd(d,28562,3)){continue}if(!y[t+76|0]){Ih(c,2);continue}if(kV(t+76|0)){break b}}j=0;break a}Vb(c,M);continue}break}yc(c);d=t+76|0;wD(d,c);Z=x[t+76>>2];c=Ze(d);S=Nb(t- -64|0);x[31609]=0;da=R(592,t+60|0)|0;d=x[31609];x[31609]=0;h:{i:{j:{if((d|0)!=1){IB(Rb(x[da>>2],0,6668));x[t+48>>2]=0;x[t+52>>2]=0;x[t+40>>2]=0;x[t+44>>2]=0;x[t+32>>2]=0;x[t+36>>2]=0;x[31609]=0;ea=R(593,t+20|0)|0;d=x[31609];x[31609]=0;k:{if((d|0)!=1){M=0;while(1){F=x[da>>2];g=Gc(Z,ba);_=x[ea>>2];K=t+32|0;d=0;l=0;r=fb-17152|0;fb=r;x[r+17148>>2]=0;l:{m:{n:{if(y[F+6152|0]!=255|(g|0)<5){break n}if(!jq(F+6152|0,c)){break n}j=mz(y[c+1|0],y[c+2|0],x[F+6148>>2])+iq(c)|0;x[r+17148>>2]=j;if((g|0)==(j|0)){j=g;break m}o:{if((g|0)>=(j+4|0)){if(jq(c,c+j|0)){break o}}x[r+17148>>2]=0;break n}if(j){break m}}h=c;n=Rb(F,0,6668)+6148|0;s=r+17148|0;L=g-4|0;H=(L|0)>0?L:0;while(1){p:{q:{r:{s:{if((l|0)==(H|0)){l=g;break s}if(!TL(h)){break q}f=mz(y[h+1|0],y[h+2|0],x[n>>2]);j=f+iq(h)|0;i=4;q=l+4|0;t:{while(1){if(!(i>>>0>2303|f)){if((L|0)<=((i<<1)+l|0)){break t}f=0;k=h+i|0;u:{if(!jq(h,k)){break u}e=i-iq(h)|0;m=iq(k)+e|0;if((g|0)<(m+(i+q|0)|0)){break u}if(!jq(h,k+m|0)){break u}x[n>>2]=e;f=e;j=i}i=i+1|0;continue}break}if(!f|(g|0)<(j+l|0)){break t}q=g-l|0;i=0;e=0;while(1){v:{w:{if((e|0)!=10){k=(e|0)!=0;J=i;i=h+i|0;i=(J+mz(y[i+1|0],y[i+2|0],f)|0)+iq(i)|0;if((q|0)<(i+4|0)){break v}if(jq(h,h+i|0)){break w}k=0}else{k=1}break v}e=e+1|0;continue}break}if(!k){break t}d=j;break s}if((g|0)!=(j|0)|l){break r}l=0;d=g}x[s>>2]=d;d=l;break p}x[n>>2]=0}h=h+1|0;l=l+1|0;continue}break}j=x[r+17148>>2];if((g|0)>=(d+j|0)?j:0){break m}x[K>>2]=d;o=0;break l}C=c+d|0;x[F+6152>>2]=y[C|0]|y[C+1|0]<<8|(y[C+2|0]<<16|y[C+3|0]<<24);x[K+4>>2]=d;x[K>>2]=d+j;x[K+8>>2]=y[C+3|0]>191?1:2;wa=K,xa=WL(y[C+1|0],y[C+2|0]),x[wa+12>>2]=xa;x[K+16>>2]=4-(y[C+1|0]>>>1&3);wa=K,xa=lz(y[C+1|0],y[C+2|0]),x[wa+20>>2]=xa;if(!_){o=kz(y[C+1|0]);break l}d=r+17136|0;VL(d,C+4|0,j-4|0);if(!(v[C+1|0]&1)){ve(d,16)}x:{if(x[K+16>>2]==3){o=0;d=r+17136|0;ka=r+3728|0;h=ka;l=0;j=y[C+1|0];e=D((j>>>3&1)+(j>>>4&1)|0,3)+(y[C+2|0]>>>2&3)|0;e=e-((e|0)!=0)|0;i=y[C+3|0]>191?1:2;y:{if(j&8){k=ve(d,9);i=i<<1;l=ve(d,i+7|0);break y}k=ve(d,i|8)>>>i|0}j=D(e,40);n=j+81184|0;L=j+81504|0;s=D(e,23)+80992|0;j=-1;e=0;z:{while(1){g=y[C+3|0];H=ve(d,12);w[h+4>>1]=H;f=ve(d,9);w[h+6>>1]=f;if((f&65535)>>>0>288){break z}f=g>>>0>191?l<<4:l;wa=h,xa=ve(d,8),v[wa+10|0]=xa;g=ve(d,y[C+1|0]&8?4:9);v[h+13|0]=22;v[h+14|0]=0;x[h>>2]=s;w[h+8>>1]=g;A:{if(ve(d,1)){g=ve(d,2);v[h+11|0]=g;if(!(g&255)){break z}g=ve(d,1);w[h+18>>1]=65287;v[h+12|0]=g;if(y[h+11|0]==2){B:{if(!(g&255)){x[h>>2]=n;v[h+18|0]=8;l=0;g=39;break B}x[h>>2]=L;l=y[C+1|0]&8?8:6;g=30}v[h+14|0]=g;v[h+13|0]=l;f=f&3855}g=ve(d,10);wa=h,xa=ve(d,3),v[wa+21|0]=xa;wa=h,xa=ve(d,3),v[wa+22|0]=xa;wa=h,xa=ve(d,3),v[wa+23|0]=xa;l=g<<5;break A}v[h+11|0]=0;v[h+12|0]=0;l=ve(d,15);wa=h,xa=ve(d,4),v[wa+18|0]=xa;g=ve(d,3);v[h+20|0]=255;v[h+19|0]=g}v[h+17|0]=l&31;v[h+15|0]=l>>>10;v[h+16|0]=l>>>5&31;e=(H&65535)+e|0;C:{if(y[C+1|0]&8){g=ve(d,1);break C}g=z[h+8>>1]>499}v[h+24|0]=g;wa=h,xa=ve(d,1),v[wa+25|0]=xa;g=ve(d,1);v[h+27|0]=f>>>12&15;v[h+26|0]=g;h=h+28|0;l=f<<4;i=i-1|0;if(i){continue}break}j=(x[d+4>>2]+e|0)>(x[d+8>>2]+(k<<3)|0)?-1:k}if(!((j|0)<0|x[r+17140>>2]>x[r+17144>>2])){g=x[d+4>>2];f=x[d+8>>2];i=r+900|0;h=x[F+6144>>2];e=h-j|0;h=(h|0)<(j|0)?h:j;e=zc(i+12|0,(((e|0)>0?e:0)+F|0)+6156|0,h);l=x[d>>2]+(x[d+4>>2]/8|0)|0;d=(f-g|0)/8|0;zc(e+h|0,l,d);VL(i,e,d+h|0);D:{j=x[F+6144>>2]>=(j|0);if(!j){break D}oa=F+2304|0;pa=r+8608|0;qa=r+3840|0;while(1){if((y[C+1|0]&8?2:1)>>>0<=o>>>0){break D}ra=Rb(qa,0,4608);e=x[K+8>>2];h=D(D(e,o),28)+ka|0;d=0;la=(e|0)>0?e:0;n=r+900|0;L=n+2940|0;H=n+7548|0;sa=n+16156|0;aa=F+6152|0;while(1){if((d|0)!=(la|0)){f=D(d,28)+h|0;J=z[f+4>>1];W=x[n+4>>2];u=D(d,39)+sa|0;e=H;s=d;g=fb-48|0;fb=g;d=f;I=y[d+25|0];G=D(!y[d+13|0]+(y[d+14|0]!=0)|0,28)+81824|0;E:{if(y[aa+1|0]&8){k=y[d+27|0];f=y[z[d+8>>1]+81920|0];i=f&3;v[g+47|0]=i;v[g+46|0]=i;f=f>>>2|0;v[g+45|0]=f;v[g+44|0]=f;break E}f=(y[aa+3|0]&16)>>>4&(s|0)!=0;m=f?12:0;q=z[d+8>>1]>>>f|0;while(1){if((q|0)>=0){k=3;i=1;while(1){if((k|0)>=0){f=y[(k+m|0)+81936|0];v[(g+44|0)+k|0]=((q>>>0)/(i>>>0)>>>0)%(f>>>0);k=k-1|0;i=D(f,i);continue}break}m=m+4|0;q=q-i|0;continue}break}G=m+G|0;k=-16}i=g;fa=g+44|0;q=0;while(1){F:{G:{H:{if((q|0)==4){break H}f=y[q+G|0];if(!f){break H}if(k&8){zc(i,u,f);break G}m=y[q+fa|0];if(!m){Rb(i,0,f);Rb(u,0,f);break G}ga=(k|0)>=0?-1:-1<<m^-1;l=0;while(1){if((f|0)==(l|0)){break G}V=ve(n,m);v[l+u|0]=(V|0)==(ga|0)?-1:V;v[i+l|0]=V;l=l+1|0;continue}}v[i+2|0]=0;v[i|0]=0;v[i+1|0]=0;break F}k=k<<1;q=q+1|0;i=f+i|0;u=f+u|0;continue}break}I:{i=y[d+14|0];if(i){f=2-I|0;l=y[d+23|0]<<f;q=y[d+22|0]<<f;m=y[d+21|0]<<f;u=y[d+13|0];k=0;while(1){if(i>>>0<=k>>>0){break I}f=g+(k+u|0)|0;v[f|0]=m+y[f|0];v[f+1|0]=q+y[f+1|0];v[f+2|0]=l+y[f+2|0];k=k+3|0;continue}}if(!y[d+24|0]){break I}k=0;while(1){if((k|0)==10){break I}f=g+k|0;v[f+11|0]=y[f+11|0]+y[k+81960|0];k=k+1|0;continue}}f=I+1|0;k=0;A=jz(E(2048),((((y[aa+3|0]&224)==96)<<1)-y[d+10|0]|0)+258|0);while(1){if(y[d+13|0]+(i&255)>>>0>k>>>0){wa=e+(k<<2)|0,ya=jz(A,y[g+k|0]<<f),B[wa>>2]=ya;k=k+1|0;i=y[d+14|0];continue}break}fb=g+48|0;l=L+D(s,2304)|0;k=e;fa=J+W|0;A=E(0);f=x[n+4>>2];g=x[n>>2]+((f|0)/8|0)|0;e=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);e=(e<<24|(e&65280)<<8|(e>>>8&65280|e>>>24))<<(f&7);q=d;ta=d+18|0;ua=d+15|0;m=f|-8;u=g+4|0;G=x[d>>2];I=z[d+6>>1];d=0;while(1){J:{K:{if((I|0)>0){g=d+1|0;f=y[d+ua|0];ga=(w[(f<<1)+86384>>1]<<1)+82e3|0;V=y[d+ta|0];if(f>>>0>=16){ha=y[f+86448|0];va=32-ha|0;while(1){ia=y[G|0]>>>1|0;ja=(I|0)<(ia|0)?I:ia;A=B[k>>2];while(1){f=e>>>27|0;d=5;while(1){f=w[ga+(f<<1)>>1];if((f|0)<0){e=e<<d;i=f&7;f=(e>>>32-i|0)-(f>>3)|0;m=d+m|0;d=i;continue}break}d=f>>>8|0;m=d+m|0;e=e<<d;i=0;while(1){if((i|0)!=2){J=f&15;L:{if((J|0)==15){m=m+ha|0;d=e<<ha;while(1){if((m|0)>=0){d=y[u|0]<<m|d;u=u+1|0;m=m-8|0;continue}break}J=(e>>>va|0)+15|0;e=J;M:{if((e|0)<=128){O=B[(e<<2)+86544>>2];break M}ma=e>>>0<1024;e=ma?e<<3:e;W=e<<1&64;P=E(E((e&63)-W|0)/E(W+(e&2147483584)|0));O=E((ma?E(16):E(256))*E(E(E(P*E(E(P*E(.2222222238779068))+E(1.3333333730697632)))+E(1))*B[(e+W>>>4&268435452)+86544>>2]))}O=E(E(A*O)*E(d>>31|1));break L}d=e;O=E(A*B[(((d>>>27&16|J)^16)<<2)+86480>>2])}B[l>>2]=O;f=f>>>4|0;l=l+4|0;i=i+1|0;e=(J|0)!=0;m=e+m|0;e=d<<e;continue}break}while(1){if((m|0)>=0){e=y[u|0]<<m|e;u=u+1|0;m=m-8|0;continue}break}ja=ja-1|0;if(ja){continue}break}k=k+4|0;G=G+1|0;I=I-ia|0;if((I|0)<=0){break K}d=(V|0)>0;V=V-1|0;if(d){continue}break}break K}while(1){W=y[G|0]>>>1|0;J=(I|0)<(W|0)?I:W;A=B[k>>2];while(1){d=e>>>27|0;f=5;while(1){d=w[ga+(d<<1)>>1];if((d|0)<0){e=e<<f;i=d&7;d=(e>>>32-i|0)-(d>>3)|0;m=f+m|0;f=i;continue}break}f=d>>>8|0;m=f+m|0;e=e<<f;f=0;while(1){if((f|0)!=2){i=d&15;B[l>>2]=A*B[(((i|e>>>27&16)^16)<<2)+86480>>2];d=d>>>4|0;l=l+4|0;f=f+1|0;i=(i|0)!=0;m=i+m|0;e=e<<i;continue}break}while(1){if((m|0)>=0){e=y[u|0]<<m|e;u=u+1|0;m=m-8|0;continue}break}J=J-1|0;if(J){continue}break}k=k+4|0;G=G+1|0;I=I-W|0;if((I|0)<=0){break K}d=(V|0)>0;V=V-1|0;if(d){continue}break}break K}f=1-I|0;while(1){N:{g=y[q+26|0]?86368:86336;d=y[g+(e>>>28|0)|0];if(!(d&8)){d=y[g+(d>>>3|0)+(e<<4>>>32-(d&3))|0]}g=d&7;m=g+m|0;if(((m+(u-x[n>>2]<<3)|0)-24|0)>(fa|0)){break N}f=f-1|0;if(!f){f=y[G|0];if(f>>>0<2){break N}G=G+1|0;A=B[k>>2];k=k+4|0;f=f>>>1|0}e=e<<g;if(d>>>0>=128){B[l>>2]=(e|0)<0?E(-A):A;m=m+1|0;e=e<<1}if(d&64){B[l+4>>2]=(e|0)<0?E(-A):A;m=m+1|0;e=e<<1}f=f-1|0;if(!f){g=y[G|0];if(g>>>0<2){break N}G=G+1|0;A=B[k>>2];k=k+4|0;f=g>>>1|0}if(d&32){B[l+8>>2]=(e|0)<0?E(-A):A;m=m+1|0;e=e<<1}if(d&16){B[l+12>>2]=(e|0)<0?E(-A):A;m=m+1|0;e=e<<1}while(1){if((m|0)>=0){e=y[u|0]<<m|e;u=u+1|0;m=m-8|0;continue}break}l=l+16|0;continue}break}x[n+4>>2]=fa;break J}d=g;continue}break}d=s+1|0;continue}break}d=y[F+6155|0];O:{if(d&16){l=n+16195|0;f=0;g=fb-16|0;fb=g;d=L;k=d+2304|0;H=x[h>>2];m=y[h+14|0];u=y[h+13|0];s=m+u|0;e=g+4|0;x[e+8>>2]=-1;x[e>>2]=-1;x[e+4>>2]=-1;while(1){if((f|0)!=(s|0)){G=f+H|0;q=y[G|0];i=0;P:{while(1){if(i>>>0>=q>>>0){break P}I=(i<<2)+k|0;if(B[I>>2]==E(0)){i=i+2|0;if(B[I+4>>2]==E(0)){continue}}break}x[e+((f>>>0)%3<<2)>>2]=f;q=y[G|0]}f=f+1|0;k=(q<<2)+k|0;continue}break}if(u){e=x[g+4>>2];f=x[g+8>>2];e=(e|0)>(f|0)?e:f;f=x[g+12>>2];e=(e|0)>(f|0)?e:f;x[g+12>>2]=e;x[g+8>>2]=e;x[g+4>>2]=e}e=m?3:1;k=s-e|0;f=0;while(1){if((e|0)!=(f|0)){s=f+k|0;i=s-e|0;if((i|0)<=x[(g+4|0)+(f<<2)>>2]){i=y[aa+1|0]<<28>>31&3}else{i=y[i+l|0]}v[l+s|0]=i;f=f+1|0;continue}break}s=x[h>>2];H=g+4|0;q=w[h+36>>1]&1;i=0;m=y[aa+1|0]&8?7:64;while(1){u=i+s|0;e=y[u|0];if(e){k=y[aa+3|0]&32;Q:{R:{if(x[H+((i>>>0)%3<<2)>>2]>=(i|0)){break R}f=y[i+l|0];if(f>>>0>=m>>>0){break R}O=k?E(1.4142135381698608):E(1);S:{if(y[aa+1|0]&8){f=f<<3;A=B[f+87076>>2];P=B[f+87072>>2];break S}P=jz(E(1),f+1>>>1<<q);f=f&1;A=f?E(1):P;P=f?P:E(1)}P=E(O*P);O=E(O*A);f=0;while(1){if((e|0)!=(f|0)){k=(f<<2)+d|0;A=B[k>>2];B[k+2304>>2]=A*O;B[k>>2]=A*P;f=f+1|0;continue}break}break Q}if(!k){break Q}SL(d,e)}i=i+1|0;d=(y[u|0]<<2)+d|0;continue}break}fb=g+16|0;break O}if((d&224)!=96){break O}SL(L,576)}i=n+7708|0;d=0;while(1){if((d|0)!=(la|0)){e=y[F+6153|0];f=(y[h+12|0]!=0)<<1<<((D((e>>>3&1)+(e>>>4&1)|0,3)+(y[F+6154|0]>>>2&3)|0)==2);l=L+D(d,2304)|0;k=l;if(y[h+14|0]){n=x[h>>2]+y[h+13|0]|0;m=D(f,72)+k|0;g=m;e=i;while(1){s=y[n|0];if(s){q=s<<1;H=0;while(1){if((s|0)!=(H|0)){B[e>>2]=B[g>>2];B[e+4>>2]=B[(s<<2)+g>>2];B[e+8>>2]=B[(q<<2)+g>>2];g=g+4|0;H=H+1|0;e=e+12|0;continue}break}n=n+3|0;g=(q<<2)+g|0;continue}break}zc(m,i,e-i|0);e=f-1|0}else{e=31}while(1){g=0;if((e|0)>0){while(1){if((g|0)!=8){n=g<<2;s=n+k|0;A=B[s+72>>2];P=B[n+87136>>2];O=B[n+87168>>2];n=(17-g<<2)+k|0;na=B[n>>2];B[s+72>>2]=E(A*P)-E(O*na);B[n>>2]=E(A*O)+E(na*P);g=g+1|0;continue}break}k=k+72|0;e=e-1|0;continue}break}g=l;e=D(d,1152)+F|0;k=y[h+11|0];if(f){RL(g,e,87200,f);g=D(f,72)+g|0;e=D(f,36)+e|0}T:{if((k|0)==2){k=32-f|0;f=fb-80|0;fb=f;s=f|8;H=f|4;while(1){if((k|0)>0){n=zc(f,g,72);q=x[e+20>>2];x[g+16>>2]=x[e+16>>2];x[g+20>>2]=q;q=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=q;q=x[e+4>>2];x[g>>2]=x[e>>2];x[g+4>>2]=q;J=n;n=e+24|0;iz(J,g+24|0,n);iz(H,g+48|0,n);iz(s,e,n);g=g+72|0;e=e+36|0;k=k-1|0;continue}break}fb=f+80|0;break T}RL(g,e,D((k|0)==3,72)+87200|0,32-f|0)}f=0;l=l+72|0;while(1){g=1;if(f>>>0<=31){while(1){if(g>>>0<=17){e=(g<<2)+l|0;B[e>>2]=-B[e>>2];g=g+2|0;continue}break}l=l+144|0;f=f+2|0;continue}break}h=h+28|0;d=d+1|0;continue}break}UL(oa,ra,18,x[K+8>>2],_,pa);o=o+1|0;_=D(x[K+8>>2],1152)+_|0;continue}}h=r+900|0;g=x[h+8>>2]>>>3|0;f=x[h+4>>2]+7>>>3|0;d=g-f|0;e=(d|0)>=511?511:d;if((d|0)>0){hl(F+6156|0,(h+(d>>>0>511?g-511|0:f)|0)+12|0,e)}x[F+6144>>2]=e;break x}IB(F);break l}l=r+17136|0;o=0;i=0;k=0;g=r+770|0;h=r;d=0;U:{V:{W:{j=y[C+3|0];f=j>>>6|0;switch(f-1|0){case 2:break U;case 0:break W;default:break V}}d=(j>>>2&12)+4|0;break U}d=32}j=y[C+1|0];X:{if((j&6)==6){j=32;e=88604;break X}if(!(j&8)){j=30;e=88607;break X}n=y[C+2|0];e=n>>>2&3;j=lz(j,n)>>>((f|0)!=3)|0;j=j?j:192;if(j>>>0<=55){j=(e|0)==2?12:8;e=88628;break X}j=j>>>0<=95?27:(e|0)!=1?30:27;e=88616}v[h+768|0]=j;v[h+769|0]=(d|0)<(j|0)?d:j;j=e;f=88512;while(1){d=y[h+768|0];if(o>>>0>=d>>>0){f=h+834|0;o=0;while(1){e=d<<1&510;if(e>>>0>o>>>0){Y:{if(!y[g+o|0]){j=6;break Y}j=2;if((y[C+1|0]&6)==6){break Y}j=ve(l,2);d=y[h+768|0]}v[f+o|0]=j;o=o+1|0;continue}break}j=g;d=0;k=e;while(1){if((d|0)!=(k|0)){i=y[j|0];if(i){e=19>>>y[d+f|0]&3|4}else{e=0}j=j+1|0;n=D(i,3)-6|0;A=E(0);i=4;while(1){if(i){if(e&i){L=ve(l,6);s=(L|0)/3|0;A=E(B[(n+(D(s,-3)+L|0)<<2)+88640>>2]*E(2097152>>>s|0))}B[h>>2]=A;i=i>>>1|0;h=h+4|0;continue}break}d=d+1|0;continue}break}o=y[r+769|0];d=y[r+768|0];d=d>>>0<o>>>0?o:d;while(1){if((d|0)!=(o|0)){v[(g+(o<<1)|0)+1|0]=0;o=o+1|0;continue}break}}else{if((k|0)==(o|0)){f=y[j|0]+88512|0;k=y[j+2|0]+o|0;i=y[j+1|0];j=j+3|0}n=g+(o<<1)|0;d=y[ve(l,i)+f|0];v[n|0]=d;e=y[h+769|0];if(o>>>0<e>>>0){d=y[ve(l,i)+f|0];e=y[h+769|0]}v[n+1|0]=e?d:0;o=o+1|0;continue}break}j=0;g=Rb(r+3840|0,0,4608);H=F+2304|0;q=r+8608|0;o=0;Z:{while(1){if((o|0)==3){break Z}m=g+(j<<2)|0;n=r+17136|0;h=0;k=x[K+16>>2]|1;L=(k|0)>0?k:0;C=r+770|0;e=576;while(1){if((h|0)!=4){l=m+(D(h,k)<<2)|0;i=0;while(1){if(y[r+768|0]<<1>>>0>i>>>0){_:{f=y[i+C|0];if(!f){break _}if(f>>>0<=16){s=(-1<<f-1)+1|0;d=0;while(1){if((d|0)==(L|0)){break _}wa=(d<<2)+l|0,ya=E(ve(n,f)+s|0),B[wa>>2]=ya;d=d+1|0;continue}}d=2<<f-17;f=ve(n,(d-(d>>>3|0)|0)+3|0);u=d>>>1|0;s=d|1;d=0;while(1){if((d|0)==(L|0)){break _}J=f;f=(f>>>0)/(s>>>0)|0;B[(d<<2)+l>>2]=J-(u+D(s,f)|0)|0;d=d+1|0;continue}}i=i+1|0;l=(e<<2)+l|0;e=18-e|0;continue}break}h=h+1|0;continue}break}j=(k<<2)+j|0;if((j|0)==12){d=(o<<2)+r|0;j=g;h=y[r+769|0];e=g+D(h,72)|0;zc(e+2304|0,e,D(y[r+768|0]-h|0,72));l=0;while(1){if(y[r+768|0]>l>>>0){h=0;while(1){if((h|0)!=12){e=(h<<2)+j|0;B[e>>2]=B[d>>2]*B[e>>2];e=e+2304|0;B[e>>2]=B[d+12>>2]*B[e>>2];h=h+1|0;continue}break}d=d+24|0;j=j+72|0;l=l+1|0;continue}break}UL(H,g,12,x[K+8>>2],_,q);Rb(g,0,4608);_=D(x[K+8>>2],768)+_|0;j=0}o=o+1|0;if(x[r+17140>>2]<=x[r+17144>>2]){continue}break}IB(F);o=0;break l}j=1}o=D(kz(y[F+6153|0]),j)}fb=r+17152|0;d=x[t+32>>2];if((d|0)<0|!d){break h}j=x[t+44>>2];if((j|0)!=(ca|0)?ca:0){break h}d=x[t+40>>2];if((d|0)!=(M|0)?M:0){break h}if(d-3>>>0<4294967294|(j|0)<=0){break i}x[t+16>>2]=0;wa=t,xa=Gc(Z,ba),x[wa+12>>2]=xa;h=t+16|0;e=t+12|0;M=x[Zj(K,h,e)>>2];x[t+16>>2]=0;wa=t,xa=Gc(Z,ba),x[wa+12>>2]=xa;h=x[Zj(K,h,e)>>2];g=h>>31;$:{if(!o){break $}e=x[ea>>2];x[31609]=0;U(594,S|0,e|0,e+(D(d,o)<<1)|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break $}c=T(124540)|0;if((gb|0)==($(124540)|0)){Y(c|0)|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;M=d;ca=j;if((c|0)!=1){break h}c=N()|0}od(ea);break k}if(($c(x[S>>2],x[S+4>>2])>>>0)/(d>>>0)>>>0>268435456){break i}c=c+M|0;ca=j;M=d;ba=ba-(g+(h>>>0>Z>>>0)|0)|0;Z=Z-h|0;if(!!Z&(ba|0)>=0|(ba|0)>0){continue}break}break h}c=N()|0}MT(da);break j}c=N()|0}od(S);Kc(t+76|0);Q(c|0);p()}M=d;ca=j}j=0;aa:{if(!ca|!M){break aa}c=x[S>>2];d=x[S+4>>2];if(mc(c,d)){break aa}if(($c(c,d)>>>0)/(M>>>0)>>>0>268435456){break aa}Vu(a,b);b=D(b,104)+a|0;a=b+484380|0;wa=a,xa=($c(x[S>>2],x[S+4>>2])>>>0)/(M>>>0)|0,x[wa>>2]=xa;d=b+484414|0;c=z[d>>1];w[d>>1]=(M|0)==2?c|65:c&65470|1;Gh(a);j=le(x[a>>2],x[b+484400>>2]);if(!j){break aa}XU(wb(x[S>>2]),wb(x[S+4>>2]),x[a+20>>2]);j=le(x[a>>2],x[a+20>>2])}od(ea);MT(da);od(S);Kc(t+76|0)}fb=t+96|0;return j|0}function bD(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=E(0),u=0,C=0,G=0,H=0,I=E(0),K=0,L=0,M=0,N=0,O=0,P=E(0);r=fb-1520|0;fb=r;e=r+8|0;N=Rb(e,0,1512),O=-1,x[N+1420>>2]=O;v[r+56|0]=1;x[r+48>>2]=a+b;x[r+40>>2]=a;l=fb-1024|0;fb=l;v[e+1377|0]=1;a:{if(!Rt(e)){break a}b=y[e+1375|0];if(!(b&2)){bc(e,34);break a}if(b&4){bc(e,34);break a}if(b&1){bc(e,34);break a}if(x[e+1116>>2]!=1){bc(e,34);break a}b=y[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!ez(e,l+1018|0,6)|y[l+1018|0]!=102|(y[l+1019|0]!=105|y[l+1020|0]!=115)){break b}if(y[l+1021|0]!=104|y[l+1022|0]!=101|y[l+1023|0]!=97){break b}if((ff(e)|0)!=100){break b}if(ff(e)){break b}bc(e,38);break a}bc(e,34);break a}if((ff(e)|0)!=1){bc(e,34);break a}if(!ez(e,l+1018|0,6)){bc(e,10);break a}if(!cz(l+1018|0)){bc(e,34);break a}if(rj(e)){bc(e,34);break a}b=ff(e);x[e+4>>2]=b;if(!b){bc(e,34);break a}if(b>>>0>=17){bc(e,5);break a}b=rj(e);x[e>>2]=b;if(!b){bc(e,34);break a}rj(e);rj(e);rj(e);b=ff(e);g=b>>>4|0;x[e+116>>2]=1<<g;i=b&15;x[e+112>>2]=1<<i;if(i-14>>>0<=4294967287){bc(e,20);break a}if(b+32<<24>>24>=0){bc(e,20);break a}c:{if(g>>>0<i>>>0){bc(e,20);break c}if(!(ff(e)&1)){bc(e,34);break c}if(!Rt(e)){break a}if(!dz(e)){break a}if(!fz(e)){break a}d:{e:{if((Nh(e)|0)==3){while(1){if((f|0)!=6){N=(l+1018|0)+f|0,O=Nh(e),v[N|0]=O;f=f+1|0;continue}break}if(!cz(l+1018|0)){bc(e,20);break c}b=bz(e);f=ue(e,b+1|0);x[e+20>>2]=f;if(!f){break e}f=0;i=(b|0)>0?b:0;while(1){if((f|0)!=(i|0)){g=Nh(e);v[x[e+20>>2]+f|0]=g;f=f+1|0;continue}break}v[b+x[e+20>>2]|0]=0;b=bz(e);x[e+28>>2]=0;x[e+24>>2]=b;if((b|0)<=0){break d}b=ue(e,b<<2);x[e+28>>2]=b;if(b){break d}bc(e,3);break c}bc(e,20);break c}bc(e,3);break c}b=0;while(1){f:{g:{if(x[e+24>>2]>(b|0)){i=bz(e);f=ue(e,i+1|0);g=b<<2;x[g+x[e+28>>2]>>2]=f;if(!x[g+x[e+28>>2]>>2]){break g}f=0;j=(i|0)>0?i:0;while(1){if((f|0)==(j|0)){break f}h=Nh(e);v[x[g+x[e+28>>2]>>2]+f|0]=h;f=f+1|0;continue}}if(!(Nh(e)&1)){bc(e,20);break c}GL(e,y[e+1376|0]);v[e+1376|0]=0;while(1){b=fz(e);GL(e,b);v[e+1376|0]=0;if(b){continue}break}f=0;if(!dz(e)){break a}if(!NL(e)){if(x[e+100>>2]!=21){break a}x[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){g=b<<24;i=0;while(1){if((i|0)!=8){g=g>>31&79764919^g<<1;i=i+1|0;continue}break}x[(b<<2)+495328>>2]=g;b=b+1|0;continue}break}if((Nh(e)|0)==5){while(1){if((f|0)!=6){N=(l+1018|0)+f|0,O=Nh(e),v[N|0]=O;f=f+1|0;continue}break}if(!cz(l+1018|0)){bc(e,20);break c}b=rc(e,8)+1|0;x[e+120>>2]=b;b=ue(e,D(b,2096));x[e+124>>2]=b;if(!b){bc(e,3);break c}Rb(b,0,D(x[e+120>>2],2096));h:{while(1){i:{j:{if(x[e+120>>2]>(m|0)){b=x[e+124>>2];if((rc(e,8)&255)!=66){bc(e,20);break c}if((rc(e,8)&255)!=67){bc(e,20);break c}if((rc(e,8)&255)!=86){bc(e,20);break c}h=D(m,2096)+b|0;N=h,O=rc(e,8)&255|rc(e,8)<<8,x[N>>2]=O;N=h,O=rc(e,8)&255|(rc(e,8)<<8&65280|rc(e,8)<<16),x[N+4>>2]=O;g=0;f=rc(e,1);if(!f){g=rc(e,1)}v[h+23|0]=g;b=x[h+4>>2];if(!(x[h>>2]|!b)){bc(e,20);break c}k:{if(g&255){j=oo(e,b);break k}j=ue(e,b);x[h+8>>2]=j}if(!j){bc(e,3);break c}i=0;if(f){break j}g=0;while(1){f=x[h+4>>2];if((f|0)<=(g|0)){break i}l:{m:{if(y[h+23|0]){if(!rc(e,1)){break m}}b=rc(e,5)+1|0;v[g+j|0]=b;if((b&255)!=32){i=i+1|0;break l}bc(e,20);break c}v[g+j|0]=255}g=g+1|0;continue}}b=rc(e,6)+1&255;f=0;n:{while(1){if((b|0)==(f|0)){break n}f=f+1|0;if(!rc(e,16)){continue}break}bc(e,20);break c}b=rc(e,6)+1|0;x[e+128>>2]=b;b=ue(e,D(b,1596));x[e+260>>2]=b;o:{if(b){o=e+132|0;p:while(1){if(x[e+128>>2]<=(C|0)){break o}b=rc(e,16);w[o+(C<<1)>>1]=b;b=b&65535;if(b>>>0>=2){bc(e,20);break c}if(!b){b=x[e+260>>2]+D(C,1596)|0;N=b,O=rc(e,8),v[N|0]=O;N=b,O=rc(e,16),w[N+2>>1]=O;N=b,O=rc(e,16),w[N+4>>1]=O;N=b,O=rc(e,6),v[N+6|0]=O;N=b,O=rc(e,8),v[N+7|0]=O;g=rc(e,4)+1|0;v[b+8|0]=g;i=b+9|0;f=0;while(1){if((g&255)>>>0>f>>>0){N=f+i|0,O=rc(e,8),v[N|0]=O;f=f+1|0;g=y[b+8|0];continue}break}bc(e,4);break c}b=x[e+260>>2]+D(C,1596)|0;f=rc(e,5);v[b|0]=f;k=b+1|0;g=0;j=-1;while(1)if((f&255)>>>0<=g>>>0){i=j+1|0;j=b+82|0;h=b+65|0;m=b+49|0;n=b+33|0;f=0;while(1){q:{if((f|0)!=(i|0)){N=f+n|0,O=rc(e,3)+1|0,v[N|0]=O;q=f+m|0;g=rc(e,2);v[q|0]=g;if(!(g&255)){break q}g=rc(e,8);v[f+h|0]=g;if(x[e+120>>2]>(g&255)){break q}bc(e,20);break c}j=2;N=b,O=rc(e,2)+1|0,v[N+1588|0]=O;f=rc(e,4);x[b+1592>>2]=2;i=0;w[b+338>>1]=0;v[b+1589|0]=f;w[b+340>>1]=1<<f;h=b+338|0;m=0;while(1){if(y[b|0]>m>>>0){f=n+y[k+m|0]|0;g=0;while(1){if(y[f|0]>g>>>0){j=rc(e,y[b+1589|0]);w[h+(x[b+1592>>2]<<1)>>1]=j;j=x[b+1592>>2]+1|0;x[b+1592>>2]=j;g=g+1|0;continue}break}m=m+1|0;continue}break}while(1){if((i|0)<(j|0)){f=z[h+(i<<1)>>1];g=(l+16|0)+(i<<2)|0;w[g+2>>1]=i;w[g>>1]=f;i=i+1|0;j=x[b+1592>>2];continue}break}FL(l+16|0,j,1216);j=x[b+1592>>2];f=((j|0)<=1?1:j)-1|0;g=0;r:{while(1){if((f|0)==(g|0)){f=b+838|0;g=0;break r}i=l+16|0;k=z[i+(g<<2)>>1];g=g+1|0;if((k|0)!=z[i+(g<<2)>>1]){continue}break}bc(e,20);break c}while(1){if((g|0)<(j|0)){v[f+g|0]=y[((l+16|0)+(g<<2)|0)+2|0];g=g+1|0;j=x[b+1592>>2];continue}break}q=b+1088|0;g=2;while(1){if((g|0)<(j|0)){x[l+12>>2]=0;x[l+8>>2]=0;j=0;s=(g|0)>0?g:0;i=h+(g<<1)|0;k=65536;m=-1;while(1){if((j|0)!=(s|0)){n=h+(j<<1)|0;f=z[n>>1];if(!((m|0)>=(f|0)|z[i>>1]<=f>>>0)){x[l+12>>2]=j;f=z[n>>1];m=f}if(!((f|0)>=(k|0)|z[i>>1]>=f>>>0)){x[l+8>>2]=j;k=z[n>>1]}j=j+1|0;continue}break}f=q+(g<<1)|0;v[f|0]=x[l+12>>2];v[f+1|0]=x[l+8>>2];g=g+1|0;j=x[b+1592>>2];continue}break}K=(j|0)>(K|0)?j:K;C=C+1|0;continue p}g=0;s:{while(1){if(1<<y[q|0]<=(g|0)){break s}s=rc(e,8)-1|0;w[(j+(f<<4)|0)+(g<<1)>>1]=s;g=g+1|0;if(x[e+120>>2]>s<<16>>16){continue}break}bc(e,20);break c}f=f+1|0;continue}}else{f=rc(e,4);v[g+k|0]=f;f=f&255;j=(f|0)>(j|0)?f:j;g=g+1|0;f=y[b|0];continue}}}bc(e,3);break c}b=rc(e,6)+1|0;x[e+264>>2]=b;b=ue(e,D(b,24));x[e+396>>2]=b;if(!b){bc(e,3);break c}m=0;Rb(b,0,D(x[e+264>>2],24));h=e+268|0;t:while(1){if(x[e+264>>2]>(m|0)){b=x[e+396>>2];f=rc(e,16);w[h+(m<<1)>>1]=f;if((f&65535)>>>0>=3){bc(e,20);break c}i=D(m,24)+b|0;N=i,O=rc(e,24),x[N>>2]=O;b=rc(e,24);x[i+4>>2]=b;if(b>>>0<A[i>>2]){bc(e,20);break c}N=i,O=rc(e,24)+1|0,x[N+8>>2]=O;N=i,O=rc(e,6)+1|0,v[N+12|0]=O;b=rc(e,8);v[i+13|0]=b;f=0;if(x[e+120>>2]<=(b&255)){bc(e,20);break c}while(1){b=y[i+12|0];if(b>>>0>f>>>0){g=(l+16|0)+f|0;j=rc(e,3);if(rc(e,1)){b=rc(e,5)}else{b=0}v[g|0]=j+(b<<3);f=f+1|0;continue}break}b=ue(e,b<<4);x[i+20>>2]=b;k=0;if(!b){bc(e,3);break c}while(1){u:{if(y[i+12|0]>k>>>0){b=y[(l+16|0)+k|0];f=0;while(1){if((f|0)==8){break u}v:{if(b>>>f&1){g=rc(e,8);C=f<<1;j=k<<4;w[C+(j+x[i+20>>2]|0)>>1]=g;if(x[e+120>>2]>w[C+(j+x[i+20>>2]|0)>>1]){break v}bc(e,20);break c}w[(x[i+20>>2]+(k<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}}f=ue(e,x[(x[e+124>>2]+D(y[i+13|0],2096)|0)+4>>2]<<2);x[i+16>>2]=f;if(!f){bc(e,3);break c}b=0;Rb(f,0,x[(x[e+124>>2]+D(y[i+13|0],2096)|0)+4>>2]<<2);while(1){f=x[e+124>>2]+D(y[i+13|0],2096)|0;if(x[f+4>>2]>(b|0)){f=x[f>>2];j=ue(e,f);g=b<<2;x[g+x[i+16>>2]>>2]=j;j=b;if(x[g+x[i+16>>2]>>2]){while(1){if((f|0)>0){f=f-1|0;v[f+x[g+x[i+16>>2]>>2]|0]=(j|0)%y[i+12|0];j=(j|0)/y[i+12|0]|0;continue}break}b=b+1|0;continue}else{bc(e,3);break c}}break}m=m+1|0;continue t}k=k+1|0;continue}}break}b=rc(e,6)+1|0;x[e+400>>2]=b;b=ue(e,D(b,40));x[e+404>>2]=b;if(!b){bc(e,3);break c}Rb(b,0,D(x[e+400>>2],40));i=0;while(1){if(x[e+400>>2]>(i|0)){b=x[e+404>>2];if(rc(e,16)){bc(e,20);break c}b=D(i,40)+b|0;f=ue(e,D(x[e+4>>2],3));x[b+4>>2]=f;if(!f){bc(e,3);break c}if(rc(e,1)){f=rc(e,4)+1|0}else{f=1}v[b+8|0]=f;w:{if(rc(e,1)){g=rc(e,8)+1|0;w[b>>1]=g;f=0;j=x[e+4>>2];if((j|0)<(g&65535)){bc(e,20);break c}while(1){if(z[b>>1]<=f>>>0){break w}j=rc(e,Jm(j-1|0));g=D(f,3);v[g+x[b+4>>2]|0]=j;j=rc(e,Jm(x[e+4>>2]-1|0));v[(g+x[b+4>>2]|0)+1|0]=j;j=x[e+4>>2];g=g+x[b+4>>2]|0;h=y[g|0];if((j|0)<=(h|0)){bc(e,20);break c}g=y[g+1|0];if(g>>>0>=j>>>0){bc(e,20);break c}f=f+1|0;if((g|0)!=(h|0)){continue}break}bc(e,20);break c}w[b>>1]=0}if(rc(e,2)){bc(e,20);break c}f=0;x:{if(y[b+8|0]>=2){while(1){if(x[e+4>>2]<=(f|0)){break x}g=rc(e,4);j=D(f,3);v[(j+x[b+4>>2]|0)+2|0]=g;f=f+1|0;if(y[(j+x[b+4>>2]|0)+2|0]<y[b+8|0]){continue}break}bc(e,20);break c}while(1){if(x[e+4>>2]<=(f|0)){break x}v[(x[b+4>>2]+D(f,3)|0)+2|0]=0;f=f+1|0;continue}}g=b+24|0;j=b+9|0;f=0;y:{while(1){if(y[b+8|0]<=f>>>0){break y}rc(e,8);h=f+j|0;N=h,O=rc(e,8),v[N|0]=O;k=rc(e,8);v[f+g|0]=k;if(x[e+128>>2]<=y[h|0]){bc(e,20);break c}f=f+1|0;if(x[e+264>>2]>(k&255)){continue}break}bc(e,20);break c}i=i+1|0;continue}break}N=e,O=rc(e,6)+1|0,x[N+408>>2]=O;f=e+412|0;g=0;z:{while(1){if(x[e+408>>2]<=(g|0)){break z}b=f+D(g,6)|0;N=b,O=rc(e,1),v[N|0]=O;N=b,O=rc(e,16),w[N+2>>1]=O;N=b,O=rc(e,16),w[N+4>>1]=O;i=rc(e,8);v[b+1|0]=i;if(z[b+2>>1]){bc(e,20);break c}if(z[b+4>>1]){bc(e,20);break c}g=g+1|0;if(x[e+400>>2]>(i&255)){continue}break}bc(e,20);break c}LL(e);x[e+992>>2]=0;i=e+996|0;g=K<<1;j=e+928|0;h=e+800|0;f=0;while(1){if(x[e+4>>2]>(f|0)){b=f<<2;k=b+h|0;N=k,O=ue(e,x[e+116>>2]<<2),x[N>>2]=O;m=b+j|0;N=m,O=ue(e,x[e+116>>2]<<1&2147483646),x[N>>2]=O;n=b+i|0;b=ue(e,g);x[n>>2]=b;k=x[k>>2];if(b?!k|!x[m>>2]:1){bc(e,3);break c}Rb(k,0,x[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!EL(e,0,x[e+112>>2])){break a}if(!EL(e,1,x[e+116>>2])){break a}x[e+104>>2]=x[e+112>>2];i=x[e+116>>2];x[e+108>>2]=i;b=x[e+264>>2];h=(b|0)>0?b:0;b=(i|0)/2|0;j=0;while(1){if((f|0)!=(h|0)){g=x[e+396>>2]+D(f,24)|0;k=x[g+4>>2];m=b>>>0>k>>>0?k:b;k=x[g>>2];g=(m-(b>>>0>k>>>0?k:b)>>>0)/A[g+8>>2]|0;j=(g|0)>(j|0)?g:j;f=f+1|0;continue}break}b=i<<1&2147483646;f=D(x[e+4>>2],(j<<2)+4|0);b=b>>>0>f>>>0?b:f;x[e+12>>2]=b;A:{B:{if(!x[e+80>>2]){break B}f=x[e+92>>2];if((f|0)!=x[e+84>>2]){break A}if(f>>>0>=(b+x[e+88>>2]|0)+1512>>>0){break B}bc(e,3);break c}if(x[e+1380>>2]==-1){x[e+52>>2]=y[e+48|0]?0:x[e+32>>2]-x[e+36>>2]|0;f=1;break a}x[e+52>>2]=0;f=1;break a}_(7344,13274,4196,8845);p()}b=rc(e,5);g=0;while(1){f=x[h+4>>2];if((f|0)<=(g|0)){break i}k=rc(e,Jm(f-g|0));b=b+1|0;if((b|0)>=32){bc(e,20);break c}f=g+k|0;if((f|0)>x[h+4>>2]){bc(e,20);break c}else{Rb(g+j|0,b,k);g=f;continue}}}C:{D:{E:{F:{G:{H:{if(y[h+23|0]){if(f>>2>(i|0)){break H}if(x[e+16>>2]<(f|0)){x[e+16>>2]=f;f=x[h+4>>2]}b=ue(e,f);x[h+8>>2]=b;if(!b){bc(e,3);break c}zc(b,j,x[h+4>>2]);qj(e,j,x[h+4>>2]);v[h+23|0]=0;j=x[h+8>>2];f=x[h+4>>2]}b=0;i=(f|0)>0?f:0;g=0;while(1){if((g|0)==(i|0)){break G}b=((y[g+j|0]-11&255)>>>0<244)+b|0;g=g+1|0;continue}}x[h+2092>>2]=i;b=h+2092|0;if(i){break F}g=0;i=0;break E}x[h+2092>>2]=b;b=ue(e,f<<2);x[h+32>>2]=b;if(b){b=h+2092|0;g=0;break D}bc(e,3);break c}f=ue(e,i);x[h+8>>2]=f;if(!f){bc(e,3);break c}f=oo(e,x[h+2092>>2]<<2);x[h+32>>2]=f;if(!f){bc(e,3);break c}g=oo(e,x[b>>2]<<2);if(!g){break C}f=x[h+4>>2];i=x[h+2092>>2]}f=(i<<3)+f|0;if(f>>>0<=A[e+16>>2]){break D}x[e+16>>2]=f}n=x[h+4>>2];f=0;i=fb-128|0;fb=i;o=Rb(i,0,128);i=(n|0)>0?n:0;while(1){I:{J:{if((f|0)!=(i|0)){if(y[f+j|0]==255){break J}i=f}if((i|0)==(n|0)){f=1;if(!x[h+2092>>2]){break I}_(15796,13274,1103,7588);p()}f=i+j|0;k=y[f|0];if(k>>>0<32){CL(h,0,i,0,k,g);q=1;k=y[f|0]+1|0;f=1;K:{while(1){if((f|0)==(k|0)){L:while(1){M:{f=1;i=i+1|0;if((n|0)<=(i|0)){break I}G=i+j|0;k=y[G|0];if((k|0)==255){continue}f=k;if(f>>>0>=32){break M}while(1){if((f|0)<=0){f=0;break I}H=o+(f<<2)|0;s=x[H>>2];if(!s){f=f-1|0;continue}break}x[H>>2]=0;CL(h,Hm(s),i,q,k,g);q=q+1|0;k=y[G|0];if((k|0)==(f|0)){continue}while(1){if((f|0)>=(k|0)){continue L}G=o+(k<<2)|0;if(x[G>>2]){break K}x[G>>2]=s+(1<<32-k);k=k-1|0;continue}}break}}else{x[o+(f<<2)>>2]=1<<32-f;f=f+1|0;continue}break}_(15329,13274,1118,7588);p()}_(15840,13274,1133,7588);p()}_(15336,13274,1104,7588);p()}f=f+1|0;continue}break}fb=o+128|0;if(!f){if(y[h+23|0]){qj(e,g,0)}bc(e,20);break c}f=x[b>>2];if(f){f=ue(e,(f<<2)+4|0);x[h+2084>>2]=f;if(!f){bc(e,3);break c}f=ue(e,(x[h+2092>>2]<<2)+4|0);x[h+2088>>2]=f;if(!f){bc(e,3);break c}x[h+2088>>2]=f+4;x[f>>2]=-1;f=0;k=0;N:{O:{P:{if(y[h+23|0]){while(1){k=x[h+2092>>2];if((k|0)<=(f|0)){break P}i=f<<2;N=i+x[h+2084>>2]|0,O=Hm(x[i+x[h+32>>2]>>2]),x[N>>2]=O;f=f+1|0;continue}}while(1){if(x[h+4>>2]>(f|0)){if(BL(y[h+23|0],y[f+j|0])){N=x[h+2084>>2]+(k<<2)|0,O=Hm(x[x[h+32>>2]+(f<<2)>>2]),x[N>>2]=O;k=k+1|0}f=f+1|0;continue}break}if(x[h+2092>>2]!=(k|0)){break O}}FL(x[h+2084>>2],k,1217);x[x[h+2084>>2]+(x[h+2092>>2]<<2)>>2]=-1;i=0;f=x[h+(y[h+23|0]?2092:4)>>2];s=(f|0)>0?f:0;Q:{while(1){if((i|0)!=(s|0)){f=i;k=y[h+23|0];f=k?x[(f<<2)+g>>2]:f;G=y[f+j|0];R:{if(!BL(k,G)){break R}H=i<<2;n=Hm(x[H+x[h+32>>2]>>2]);f=x[h+2092>>2];k=0;while(1){if((f|0)>=2){o=f>>>1|0;L=o+k|0;q=n>>>0<A[x[h+2084>>2]+(L<<2)>>2];f=q?o:f-o|0;k=q?k:L;continue}break}f=k<<2;if((n|0)!=x[f+x[h+2084>>2]>>2]){break Q}if(y[h+23|0]){x[f+x[h+2088>>2]>>2]=x[g+H>>2];v[x[h+8>>2]+k|0]=G;break R}x[f+x[h+2088>>2]>>2]=i}i=i+1|0;continue}break}break N}_(12315,13274,1230,9998);p()}_(7529,13274,1200,9998);p()}}if(y[h+23|0]){qj(e,g,x[h+2092>>2]<<2);qj(e,x[h+32>>2],x[h+2092>>2]<<2);qj(e,j,x[h+4>>2]);x[h+32>>2]=0}g=0;j=0;f=h+36|0;while(1){if((g|0)!=1024){w[f+(g<<1)>>1]=65535;g=g+1|0;continue}break}i=x[h+(y[h+23|0]?2092:4)>>2];i=(i|0)>=32767?32767:i;i=(i|0)>0?i:0;while(1){if((i|0)!=(j|0)){S:{if(y[x[h+8>>2]+j|0]>10){break S}T:{if(y[h+23|0]){g=Hm(x[x[h+2084>>2]+(j<<2)>>2]);break T}g=x[x[h+32>>2]+(j<<2)>>2]}while(1){if(g>>>0>1023){break S}w[f+(g<<1)>>1]=j;g=(1<<y[x[h+8>>2]+j|0])+g|0;continue}}j=j+1|0;continue}break}f=rc(e,4);v[h+21|0]=f;f=f&255;if(f>>>0>=3){bc(e,20);break c}if(f){N=h,P=DL(rc(e,32)),B[N+12>>2]=P;N=h,P=DL(rc(e,32)),B[N+16>>2]=P;N=h,O=rc(e,4)+1|0,v[N+20|0]=O;N=h,O=rc(e,1),v[N+22|0]=O;g=x[h>>2];i=x[h+4>>2];U:{if(y[h+21|0]==1){u=J(Qt(+E(E(mq(+E(i|0)))/E(g|0))));V:{if(F(u)<2147483648){f=~~u;break V}f=-2147483648}u=+(g|0);M=J(mk(+E(E(f|0)+E(1)),u));W:{if(F(M)<2147483648){g=~~M;break W}g=-2147483648}f=((g|0)<=(i|0))+f|0;t=E(f|0);if(mk(+E(t+E(1)),u)<=+(i|0)){j=-1}else{u=J(mk(+t,u));X:{if(F(u)<2147483648){g=~~u;break X}g=-2147483648}j=(g|0)>(i|0)?-1:f}if((j|0)>=0){break U}bc(e,20);break c}j=D(g,i)}x[h+24>>2]=j;if(!j){bc(e,20);break c}g=0;f=oo(e,j<<1);if(!f){bc(e,3);break c}Y:{while(1){j=x[h+24>>2];if((j|0)<=(g|0)){break Y}i=rc(e,y[h+20|0]);if((i|0)!=-1){w[f+(g<<1)>>1]=i;g=g+1|0;continue}break}qj(e,f,x[h+24>>2]<<1);bc(e,20);break c}Z:{_:{if(y[h+21|0]==1){o=y[h+23|0];$:{if(o){g=x[b>>2];if(g){break $}break Z}g=x[h+4>>2]}b=ue(e,D(x[h>>2],g)<<2);x[h+28>>2]=b;if(!b){qj(e,f,x[h+24>>2]<<1);bc(e,3);break c}b=0;i=x[h+(o?2092:4)>>2];q=(i|0)>0?i:0;t=E(0);while(1){if((b|0)==(q|0)){break _}i=o?x[x[h+2088>>2]+(b<<2)>>2]:b;j=x[h>>2];g=0;k=1;while(1){if((g|0)<(j|0)){I=E(t+E(E(E(z[f+(((i>>>0)/(k>>>0)>>>0)%A[h+24>>2]<<1)>>1])*B[h+16>>2])+B[h+12>>2]));B[(x[h+28>>2]+(D(b,j)<<2)|0)+(g<<2)>>2]=I;t=y[h+22|0]?I:t;g=g+1|0;j=x[h>>2];if((g|0)>=(j|0)){continue}n=x[h+24>>2];Aua(n,0,k,0);if(hb){qj(e,f,n<<1);bc(e,20);break c}else{k=D(k,n);continue}}break}b=b+1|0;continue}}b=ue(e,j<<2);x[h+28>>2]=b;if(!b){break h}g=0;t=E(0);while(1){j=x[h+24>>2];if((j|0)<=(g|0)){break Z}I=E(t+E(E(E(z[f+(g<<1)>>1])*B[h+16>>2])+B[h+12>>2]));B[x[h+28>>2]+(g<<2)>>2]=I;t=y[h+22|0]?I:t;g=g+1|0;continue}}v[h+21|0]=2;j=x[h+24>>2]}qj(e,f,j<<1)}m=m+1|0;continue}break}bc(e,3);break c}qj(e,f,x[h+24>>2]<<1);bc(e,3);break c}bc(e,20);break c}bc(e,3);break c}v[i+x[g+x[e+28>>2]>>2]|0]=0;b=b+1|0;continue}}f=0}fb=l+1024|0;aa:{ba:{if(!f){x[d>>2]=x[r+104>>2]?1:x[r+108>>2];hz(e);break ba}f=r+8|0;b=ue(f,1512);if(b){N=c,O=x[zc(b,f,1512)+32>>2]-a|0,x[N>>2]=O;x[d>>2]=0;break aa}hz(r+8|0)}b=0}fb=r+1520|0;return b}function wI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;r=fb-48|0;fb=r;a:{b:{if(c>>>0>2){break b}c=c<<2;H=x[c+104892>>2];I=x[c+104880>>2];while(1){c=x[b+4>>2];c:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=td(b)}if(fl(c)){continue}break}w=1;d:{e:{switch(c-43|0){case 0:case 2:break e;default:break d}}w=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break d}c=td(b)}f:{g:{h:{i:{n=c&-33;j:{if((n|0)==73){k:{while(1){f=h;if((f|0)==7){break k}c=x[b+4>>2];l:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=td(b)}h=f+1|0;if(v[f+4953|0]==(c|32)){continue}break}m:{if((f|0)==2){h=3;break m}if((f|0)==7){break k}n=(d|0)!=0;if(!d|f>>>0<3){break j}if((h|0)==8){break k}}c=x[b+116>>2];if((c|0)>=0|(c|0)>0){x[b+4>>2]=x[b+4>>2]-1}if(!d|h>>>0<4){break k}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}h=h-1|0;if(h>>>0>3){continue}break}}k=fb-16|0;fb=k;l=(q(E(E(w|0)*E(Infinity))),j(2));c=l&2147483647;n:{if(c-8388608>>>0<=2130706431){d=c<<25;b=(c>>>7|0)+1065353216|0;break n}d=l<<25;b=l>>>7|2147418112;if(c>>>0>=2139095040){break n}d=0;b=0;if(!c){break n}b=G(c);$f(k,c,0,0,0,b+81|0);i=x[k>>2];g=x[k+4>>2];d=x[k+8>>2];b=x[k+12>>2]^65536|16265-b<<16}x[r>>2]=i;x[r+4>>2]=g;x[r+8>>2]=d;x[r+12>>2]=l&-2147483648|b;fb=k+16|0;i=x[r+8>>2];g=x[r+12>>2];l=x[r>>2];m=x[r+4>>2];break a}if((n|0)!=78){break f}n=(d|0)!=0;while(1){if((h|0)==2){break i}c=x[b+4>>2];o:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break o}c=td(b)}f=h+9995|0;h=h+1|0;if(v[f|0]==(c|32)){continue}break}}switch(h|0){case 3:break i;case 0:break f;default:break h}}p:{c=x[b+4>>2];q:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break q}c=td(b)}if((c|0)==40){h=1;break p}g=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];r:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break r}c=td(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){h=h+1|0;continue}break}g=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>=0|(c|0)>0){x[b+4>>2]=x[b+4>>2]-1}s:{if(n){if(h){break s}break a}break g}while(1){if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}h=h-1|0;if(h){continue}break}break a}c=x[b+116>>2];if((c|0)>0){c=1}else{c=(c|0)>=0}if(c){x[b+4>>2]=x[b+4>>2]-1}}x[31484]=28;Bi(b,0,0);break b}t:{if((c|0)!=48){break t}h=x[b+4>>2];u:{if((h|0)!=x[b+104>>2]){x[b+4>>2]=h+1;h=y[h|0];break u}h=td(b)}if((h&-33)==88){n=0;f=fb-432|0;fb=f;c=x[b+4>>2];v:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break v}c=td(b)}w:{x:{while(1){if((c|0)!=48){y:{if((c|0)!=46){break w}c=x[b+4>>2];if((c|0)==x[b+104>>2]){break y}x[b+4>>2]=c+1;c=y[c|0];break x}}else{c=x[b+4>>2];if((c|0)!=x[b+104>>2]){J=1;x[b+4>>2]=c+1;c=y[c|0]}else{J=1;c=td(b)}continue}break}c=td(b)}u=1;if((c|0)!=48){break w}while(1){c=s;s=c-1|0;t=t-!c|0;c=x[b+4>>2];z:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break z}c=td(b)}if((c|0)==48){continue}break}J=1}m=1073676288;A:{while(1){B:{h=c;C:{D:{L=c-48|0;if(L>>>0<10){break D}M=(c|0)!=46;h=c|32;if(M&h-97>>>0>5){break A}if(M){break D}if(u){break B}u=1;s=i;t=g;break C}c=(c|0)>57?h-87|0:L;E:{if((g|0)<=0&i>>>0<=7|(g|0)<0){n=c+(n<<4)|0;break E}if(!g&i>>>0<=28){kh(f+48|0,c);Xd(f+32|0,C,F,l,m,0,0,0,1073414144);C=x[f+32>>2];F=x[f+36>>2];l=x[f+40>>2];m=x[f+44>>2];Xd(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],C,F,l,m);Ug(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],k,o,z,B);z=x[f+8>>2];B=x[f+12>>2];k=x[f>>2];o=x[f+4>>2];break E}if(!c|p){break E}Xd(f+80|0,C,F,l,m,0,0,0,1073610752);Ug(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],k,o,z,B);z=x[f+72>>2];B=x[f+76>>2];p=1;k=x[f+64>>2];o=x[f+68>>2]}i=i+1|0;g=i?g:g+1|0;J=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0]}else{c=td(b)}continue}break}c=46}F:{if(!J){c=x[b+116>>2];if((c|0)>0){c=1}else{c=(c|0)>=0}G:{H:{if(c){c=x[b+4>>2];x[b+4>>2]=c-1;if(!d){break H}x[b+4>>2]=c-2;if(!u){break G}x[b+4>>2]=c-3;break G}if(d){break G}}Bi(b,0,0)}dj(f+96|0,+(w|0)*0);k=x[f+96>>2];o=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break F}if((g|0)<=0&i>>>0<=7|(g|0)<0){l=i;m=g;while(1){n=n<<4;l=l+1|0;m=l?m:m+1|0;if((l|0)!=8|m){continue}break}}I:{J:{K:{if((c&-33)==80){l=vI(b,d);c=hb;m=c;if(l|(c|0)!=-2147483648){break I}if(d){c=x[b+116>>2];if((c|0)>0){c=1}else{c=(c|0)>=0}if(c){break K}break J}k=0;o=0;Bi(b,0,0);c=0;b=0;break F}l=0;m=0;if(x[b+116>>2]<0){break I}}x[b+4>>2]=x[b+4>>2]-1}l=0;m=0}if(!n){dj(f+112|0,+(w|0)*0);k=x[f+112>>2];o=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break F}b=u?s:i;g=(u?t:g)<<2|b>>>30;c=l+(b<<2)|0;g=g+m|0;b=0-H|0;i=c-32|0;d=i;g=(c>>>0<l>>>0?g+1|0:g)-(c>>>0<32)|0;c=g;if((c|0)>0){b=1}else{b=b>>>0<d>>>0&(c|0)>=0}if(b){x[31484]=68;kh(f+160|0,w);Xd(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);Xd(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);k=x[f+128>>2];o=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break F}b=H-226|0;c=b>>31;if((g|0)>=(c|0)&b>>>0<=i>>>0|(c|0)<(g|0)){if((n|0)>=0){while(1){Ug(f+416|0,k,o,z,B,0,0,0,-1073807360);b=yV(k,o,z,B,1073610752);c=(b|0)>=0;b=c;Ug(f+400|0,k,o,z,B,b?x[f+416>>2]:k,b?x[f+420>>2]:o,b?x[f+424>>2]:z,b?x[f+428>>2]:B);b=i;i=b-1|0;g=g-!b|0;z=x[f+408>>2];B=x[f+412>>2];k=x[f+400>>2];o=x[f+404>>2];n=c|n<<1;if((n|0)>=0){continue}break}}g=g-((H>>31)+(i>>>0<H>>>0)|0)|0;b=(i-H|0)+32|0;g=b>>>0<32?g+1|0:g;c=b>>>0<I>>>0&(g|0)<=0|(g|0)<0?(b|0)>0?b:0:I;L:{if((c|0)>=113){kh(f+384|0,w);s=x[f+392>>2];t=x[f+396>>2];C=x[f+384>>2];F=x[f+388>>2];l=0;b=0;break L}dj(f+352|0,ok(1,144-c|0));kh(f+336|0,w);C=x[f+336>>2];F=x[f+340>>2];s=x[f+344>>2];t=x[f+348>>2];uI(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],C,F,s,t);e=x[f+376>>2];K=x[f+380>>2];l=x[f+372>>2];b=x[f+368>>2]}d=!(n&1)&((gn(k,o,z,B,0,0,0,0)|0)!=0&(c|0)<32);Un(f+320|0,d|n);Xd(f+304|0,C,F,s,t,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);c=b;Ug(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,l,e,K);b=d;Xd(f+288|0,C,F,s,t,b?0:k,b?0:o,b?0:z,b?0:B);Ug(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);Gz(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],c,l,e,K);b=x[f+240>>2];d=x[f+244>>2];c=x[f+248>>2];l=x[f+252>>2];if(!gn(b,d,c,l,0,0,0,0)){x[31484]=68}tI(f+224|0,b,d,c,l,i);k=x[f+224>>2];o=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break F}x[31484]=68;kh(f+208|0,w);Xd(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);Xd(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);k=x[f+176>>2];o=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[r+16>>2]=k;x[r+20>>2]=o;x[r+24>>2]=b;x[r+28>>2]=c;fb=f+432|0;i=x[r+24>>2];g=x[r+28>>2];l=x[r+16>>2];m=x[r+20>>2];break a}if(x[b+116>>2]<0){break t}x[b+4>>2]=x[b+4>>2]-1}h=b;k=c;f=d;d=0;n=0;e=fb-8976|0;fb=e;K=0-H|0;J=K-I|0;M:{N:{while(1){if((k|0)!=48){O:{if((k|0)!=46){break M}b=x[h+4>>2];if((b|0)==x[h+104>>2]){break O}x[h+4>>2]=b+1;k=y[b|0];break N}}else{b=x[h+4>>2];if((b|0)!=x[h+104>>2]){x[h+4>>2]=b+1;k=y[b|0]}else{k=td(h)}d=1;continue}break}k=td(h)}o=1;if((k|0)!=48){break M}while(1){b=i;i=b-1|0;g=g-!b|0;b=x[h+4>>2];P:{if((b|0)!=x[h+104>>2]){x[h+4>>2]=b+1;k=y[b|0];break P}k=td(h)}if((k|0)==48){continue}break}d=1}x[e+784>>2]=0;Q:{R:{b=(k|0)==46;c=k-48|0;S:{T:{U:{if(b|c>>>0<=9){while(1){V:{if(b&1){if(!o){i=l;g=m;o=1;break V}b=!d;break U}l=l+1|0;m=l?m:m+1|0;if((n|0)<=2044){u=(k|0)==48?u:l;b=(e+784|0)+(n<<2)|0;if(p){c=(D(x[b>>2],10)+k|0)-48|0}x[b>>2]=c;d=1;c=p+1|0;b=(c|0)==9;p=b?0:c;n=b+n|0;break V}if((k|0)==48){break V}x[e+8960>>2]=x[e+8960>>2]|1;u=18396}b=x[h+4>>2];W:{if((b|0)!=x[h+104>>2]){x[h+4>>2]=b+1;k=y[b|0];break W}k=td(h)}b=(k|0)==46;c=k-48|0;if(b|c>>>0<10){continue}break}}i=o?i:l;g=o?g:m;if(!(!d|(k&-33)!=69)){k=vI(h,f);b=hb;o=b;X:{if(k|(b|0)!=-2147483648){break X}if(!f){break S}k=0;o=0;if(x[h+116>>2]<0){break X}x[h+4>>2]=x[h+4>>2]-1}b=g+o|0;i=i+k|0;g=i>>>0<k>>>0?b+1|0:b;break R}b=!d;if((k|0)<0){break T}}if(x[h+116>>2]<0){break T}x[h+4>>2]=x[h+4>>2]-1}if(!b){break R}x[31484]=28}Bi(h,0,0);i=0;g=0;c=0;b=0;break Q}b=x[e+784>>2];if(!b){dj(e,+(w|0)*0);i=x[e+8>>2];g=x[e+12>>2];c=x[e+4>>2];b=x[e>>2];break Q}if(!((i|0)!=(l|0)|(g|0)!=(m|0)|(l>>>0>9&(m|0)>=0|(m|0)>0)|(b>>>I|0?(I|0)<=30:0))){kh(e+48|0,w);Un(e+32|0,b);Xd(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);i=x[e+24>>2];g=x[e+28>>2];c=x[e+20>>2];b=x[e+16>>2];break Q}b=K>>>1|0;if(b>>>0<i>>>0&(g|0)>=0|(g|0)>0){x[31484]=68;kh(e+96|0,w);Xd(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);Xd(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);i=x[e+72>>2];g=x[e+76>>2];c=x[e+68>>2];b=x[e+64>>2];break Q}b=H-226|0;c=i>>>0<b>>>0;b=b>>31;if(c&(g|0)<=(b|0)|(b|0)>(g|0)){x[31484]=68;kh(e+144|0,w);Xd(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);Xd(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);i=x[e+120>>2];g=x[e+124>>2];c=x[e+116>>2];b=x[e+112>>2];break Q}if(p){if((p|0)<=8){b=(e+784|0)+(n<<2)|0;h=x[b>>2];while(1){h=D(h,10);p=p+1|0;if((p|0)!=9){continue}break}x[b>>2]=h}n=n+1|0}p=i;Y:{if((i|0)<(u|0)|(u|0)>=9|(i|0)>17){break Y}if((i|0)==9){kh(e+192|0,w);Un(e+176|0,x[e+784>>2]);Xd(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);i=x[e+168>>2];g=x[e+172>>2];c=x[e+164>>2];b=x[e+160>>2];break Q}if((p|0)<=8){kh(e+272|0,w);Un(e+256|0,x[e+784>>2]);Xd(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);kh(e+224|0,x[(0-p<<2)+104880>>2]);yS(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);i=x[e+216>>2];g=x[e+220>>2];c=x[e+212>>2];b=x[e+208>>2];break Q}b=(D(p,-3)+I|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}kh(e+352|0,w);Un(e+336|0,c);Xd(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);kh(e+304|0,x[(p<<2)+104808>>2]);Xd(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);i=x[e+296>>2];g=x[e+300>>2];c=x[e+292>>2];b=x[e+288>>2];break Q}while(1){b=n;n=b-1|0;if(!x[(e+784|0)+(n<<2)>>2]){continue}break}u=0;d=(p|0)%9|0;Z:{if(!d){c=0;break Z}c=0;d=(p|0)<0?d+9|0:d;_:{if(!b){b=0;break _}i=x[(0-d<<2)+104880>>2];g=1e9/(i|0)|0;k=0;h=0;while(1){l=k;m=e+784|0;k=m+(h<<2)|0;n=x[k>>2];f=(n>>>0)/(i>>>0)|0;l=l+f|0;x[k>>2]=l;l=!l&(c|0)==(h|0);c=l?c+1&2047:c;p=l?p-9|0:p;k=D(g,n-D(f,i)|0);h=h+1|0;if((h|0)!=(b|0)){continue}break}if(!k){break _}x[m+(b<<2)>>2]=k;b=b+1|0}p=(p-d|0)+9|0}while(1){h=(e+784|0)+(c<<2)|0;f=(p|0)<36;$:{while(1){aa:{if(f){break aa}if((p|0)!=36){break $}if(A[h>>2]<=10384592){break aa}p=36;break $}n=b+2047|0;d=0;while(1){l=b;k=n&2047;n=(e+784|0)+(k<<2)|0;b=x[n>>2];m=b>>>3|0;b=b<<29;i=b+d|0;g=m;g=b>>>0>i>>>0?g+1|0:g;if(!g&i>>>0<1000000001){d=0}else{d=Cua(i,g,1e9,0);b=Aua(d,hb,-1e9,-1);i=b+i|0}x[n>>2]=i;b=(c|0)==(k|0)?l:i?l:k;i=l-1&2047;b=(i|0)!=(k|0)?l:b;n=k-1|0;if((c|0)!=(k|0)){continue}break}u=u-29|0;b=l;if(!d){continue}break}c=c-1&2047;if((c|0)==(b|0)){k=(b+2046&2047)<<2;b=e+784|0;l=k+b|0;x[l>>2]=x[l>>2]|x[b+(i<<2)>>2];b=i}p=p+9|0;x[(e+784|0)+(c<<2)>>2]=d;continue}break}ba:{ca:while(1){i=b+1&2047;k=(e+784|0)+((b-1&2047)<<2)|0;while(1){l=(p|0)>45?9:1;g=(p|0)!=36;da:{while(1){d=c;h=0;ea:{while(1){fa:{c=d+h&2047;if((c|0)==(b|0)){break fa}c=x[(e+784|0)+(c<<2)>>2];m=x[(h<<2)+104832>>2];if(c>>>0<m>>>0){break fa}if(c>>>0>m>>>0){break ea}h=h+1|0;if((h|0)!=4){continue}}break}if(g){break ea}h=0;i=0;g=0;l=0;m=0;while(1){c=d+h&2047;if((c|0)==(b|0)){b=b+1&2047;x[(e+(b<<2)|0)+780>>2]=0}Un(e+768|0,x[(e+784|0)+(c<<2)>>2]);Xd(e+752|0,i,g,l,m,0,0,1342177280,1075633366);Ug(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);l=x[e+744>>2];m=x[e+748>>2];i=x[e+736>>2];g=x[e+740>>2];h=h+1|0;if((h|0)!=4){continue}break}kh(e+720|0,w);Xd(e+704|0,i,g,l,m,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);l=x[e+712>>2];m=x[e+716>>2];i=0;g=0;k=x[e+704>>2];o=x[e+708>>2];f=u+113|0;h=f-H|0;p=(h|0)<(I|0);c=p?(h|0)>0?h:0:I;if((c|0)<=112){break da}break ba}u=l+u|0;c=b;if((b|0)==(d|0)){continue}break}m=1e9>>>l|0;n=-1<<l^-1;h=0;c=d;while(1){g=h;f=e+784|0;h=f+(d<<2)|0;o=x[h>>2];g=g+(o>>>l|0)|0;x[h>>2]=g;g=!g&(c|0)==(d|0);c=g?c+1&2047:c;p=g?p-9|0:p;h=D(m,n&o);d=d+1&2047;if((d|0)!=(b|0)){continue}break}if(!h){continue}if((c|0)!=(i|0)){x[f+(b<<2)>>2]=h;b=i;continue ca}x[k>>2]=x[k>>2]|1;continue}break}break}dj(e+656|0,ok(1,225-c|0));uI(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],k,o,l,m);C=x[e+696>>2];F=x[e+700>>2];z=x[e+688>>2];B=x[e+692>>2];dj(e+640|0,ok(1,113-c|0));BR(e+672|0,k,o,l,m,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);i=x[e+672>>2];g=x[e+676>>2];s=x[e+680>>2];t=x[e+684>>2];Gz(e+624|0,k,o,l,m,i,g,s,t);Ug(e+608|0,z,B,C,F,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);l=x[e+616>>2];m=x[e+620>>2];k=x[e+608>>2];o=x[e+612>>2]}n=d+4&2047;ga:{if((n|0)==(b|0)){break ga}n=x[(e+784|0)+(n<<2)>>2];ha:{if(n>>>0<=499999999){if(!n&(d+5&2047)==(b|0)){break ha}dj(e+496|0,+(w|0)*.25);Ug(e+480|0,i,g,s,t,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);s=x[e+488>>2];t=x[e+492>>2];i=x[e+480>>2];g=x[e+484>>2];break ha}if((n|0)!=5e8){dj(e+592|0,+(w|0)*.75);Ug(e+576|0,i,g,s,t,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);s=x[e+584>>2];t=x[e+588>>2];i=x[e+576>>2];g=x[e+580>>2];break ha}N=+(w|0);if((d+5&2047)==(b|0)){dj(e+528|0,N*.5);Ug(e+512|0,i,g,s,t,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);s=x[e+520>>2];t=x[e+524>>2];i=x[e+512>>2];g=x[e+516>>2];break ha}dj(e+560|0,N*.75);Ug(e+544|0,i,g,s,t,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);s=x[e+552>>2];t=x[e+556>>2];i=x[e+544>>2];g=x[e+548>>2]}if((c|0)>111){break ga}BR(e+464|0,i,g,s,t,0,0,0,1073676288);if(gn(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break ga}Ug(e+448|0,i,g,s,t,0,0,0,1073676288);s=x[e+456>>2];t=x[e+460>>2];i=x[e+448>>2];g=x[e+452>>2]}Ug(e+432|0,k,o,l,m,i,g,s,t);Gz(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],z,B,C,F);l=x[e+424>>2];m=x[e+428>>2];k=x[e+416>>2];o=x[e+420>>2];ia:{if((J-2|0)>=(f&2147483647)){break ia}x[e+408>>2]=l;x[e+412>>2]=m&2147483647;x[e+400>>2]=k;x[e+404>>2]=o;Xd(e+384|0,k,o,l,m,0,0,0,1073610752);d=yV(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);b=(d|0)>=0;l=b?x[e+392>>2]:l;m=b?x[e+396>>2]:m;k=b?x[e+384>>2]:k;o=b?x[e+388>>2]:o;u=b+u|0;if(!(p&((c|0)!=(h|0)|(d|0)<0)&(gn(i,g,s,t,0,0,0,0)|0)!=0)&(u+110|0)<=(J|0)){break ia}x[31484]=68}tI(e+368|0,k,o,l,m,u);i=x[e+376>>2];g=x[e+380>>2];c=x[e+372>>2];b=x[e+368>>2]}x[r+40>>2]=i;x[r+44>>2]=g;x[r+32>>2]=b;x[r+36>>2]=c;fb=e+8976|0;i=x[r+40>>2];g=x[r+44>>2];l=x[r+32>>2];m=x[r+36>>2];break a}g=0}x[a>>2]=l;x[a+4>>2]=m;x[a+8>>2]=i;x[a+12>>2]=g;fb=r+48|0}function dra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;e=fb-416|0;fb=e;yc(b);f=e+411|0;d=BE(b,f);if(!d){TY(f)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!d){break j}if(!UY(f)){break j}F=1;if((c|0)==64){break j}H=He(e+388|0,b);x[31609]=0;d=e+376|0;O(508,d|0,H|0);b=x[31609];x[31609]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((b|0)!=1){x[31609]=0;f=e+356|0;S(509,f|0,d|0,20041);b=x[31609];x[31609]=0;if((b|0)==1){break t}F=0;x[31609]=0;d=R(172,x[e+356>>2])|0;b=x[31609];x[31609]=0;if((b|0)==1){break l}if(!d){break k}x[31609]=0;d=P(510,f|0,e+265|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break l}if(!d){break k}x[31609]=0;O(246,a|0,16384);b=x[31609];x[31609]=0;if((b|0)==1){break l}x[a+480208>>2]=8;x[31609]=0;d=U(266,a+1074312|0,9,1)|0;b=x[31609];x[31609]=0;if((b|0)==1){break l}x[31609]=0;d=U(266,d|0,114,1)|0;b=x[31609];x[31609]=0;if((b|0)==1){break l}x[31609]=0;d=P(267,d|0,21)|0;b=x[31609];x[31609]=0;if((b|0)==1){break l}x[31609]=0;P(267,d|0,30)|0;b=x[31609];x[31609]=0;if((b|0)==1){break l}x[31609]=0;d=P(1,e+252|0,8280)|0;b=x[31609];x[31609]=0;if((b|0)==1){break q}zb(a+1298344|0,d);tb(d);x[31609]=0;d=P(1,e+240|0,10767)|0;b=x[31609];x[31609]=0;if((b|0)==1){break p}zb(a+1298356|0,d);tb(d);x[31609]=0;f=P(1,e+228|0,18149)|0;b=x[31609];x[31609]=0;if((b|0)==1){break o}d=15140;b=y[e+415|0];switch(b-16|0){case 1:break m;case 0:break s;default:break r}}g=N()|0;break a}g=N()|0;break b}d=15121;break m}if(!b){break n}d=22292;break m}g=N()|0;break c}g=N()|0;break c}g=N()|0;break c}d=13338}x[31609]=0;d=P(1,e+216|0,d|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break e}x[31609]=0;i=e+192|0;S(2,i|0,f|0,d|0);b=x[31609];x[31609]=0;if((b|0)==1){break f}zb(a+1298368|0,i);tb(i);tb(d);tb(f);I=a,J=x[Fc(i,4)>>2],x[I+1298404>>2]=J;d=e+84|0;Ue(d,3,e+265|0);x[31609]=0;O(218,i|0,d|0);b=x[31609];x[31609]=0;if((b|0)==1){break g}zb(a+1298308|0,i);tb(i);pi(d,3,e+297|0);x[31609]=0;S(369,i|0,4,d|0);b=x[31609];x[31609]=0;if((b|0)==1){break h}zb(a+1298320|0,i);tb(i);x[a+480200>>2]=y[e+321|0]+1;I=a,J=Ld(y[e+322|0],1,255),x[I+480196>>2]=J;I=a,J=D(Ld(y[e+323|0],4,255),1e4),x[I+480204>>2]=J;d=x[a+484360>>2];b=y[a+484376|0];x[31609]=0;aa(348,Xb(d,b)|0,e+356|0,y[e+317|0]|y[e+318|0]<<8,65535,65535);b=x[31609];x[31609]=0;if((b|0)==1){break l}$e(Xb(x[a+484360>>2],y[a+484376|0]),y[e+319|0]|y[e+320|0]<<8);w[a+480188>>1]=0;h=a+480280|0;i=e+324|0;b=0;while(1){if((b|0)==32){x[31609]=0;h=e+192|0;f=e+376|0;S(509,h|0,f|0,17741);b=x[31609];x[31609]=0;if((b|0)!=1){i=kd(e+356|0,h);ub(h);b=x[i>>2];x[31609]=0;d=R(154,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break l}x[31609]=0;V(336,a+1298332|0,i|0,d|0,0);b=x[31609];x[31609]=0;if((b|0)==1){break l}x[31609]=0;S(509,h|0,f|0,21321);b=x[31609];x[31609]=0;if((b|0)!=1){j=kd(i,h);ub(h);b=x[j>>2];x[31609]=0;d=R(172,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break l}u:{v:{if(d){x[31609]=0;S(509,h|0,f|0,16723);b=x[31609];x[31609]=0;if((b|0)==1){break u}x[31609]=0;G=R(197,j|0)|0;b=x[31609];x[31609]=0;w:{if((b|0)!=1){r=c&2;h=a+946304|0;i=a+484380|0;f=0;while(1){if(G>>>0<=(f&255)>>>0){break w}x[31609]=0;l=R(197,j|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break v}if(!l){break w}d=x[j+8>>2];b=x[j>>2];x[31609]=0;d=U(150,b|0,d|0,56)|0;b=x[31609];x[31609]=0;if((b|0)==1){break v}if(!d){break w}if(l>>>0>z[a+480190>>1]){w[a+480190>>1]=l}x[31609]=0;k=i+D(l,104)|0;O(279,k|0,0);b=x[31609];x[31609]=0;if((b|0)==1){break v}fp(k);x[31609]=0;S(317,j|0,h+(l<<5)|0,32);b=x[31609];x[31609]=0;if((b|0)==1){break v}x[31609]=0;O(320,j|0,k+43|0);b=x[31609];x[31609]=0;if((b|0)==1){break v}x:{if(y[e+415|0]<=15){x[31609]=0;g=R(189,j|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break x}break v}x[31609]=0;g=R(151,j|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break v}}x[k+24>>2]=g<<1;x[31609]=0;d=R(151,j|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break v}x[k>>2]=d;x[31609]=0;d=R(151,j|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break v}x[k+4>>2]=d;x[31609]=0;d=R(151,j|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break v}x[k+8>>2]=d;if(d){w[k+34>>1]=z[k+34>>1]|2;x[k+8>>2]=d+x[k+4>>2]}x[31609]=0;d=R(197,j|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break v}if(y[e+415|0]<=15){w[k+30>>1]=d}x[31609]=0;d=R(197,j|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break v}m=z[k+34>>1];B=8;if(d&1){m=m|1;w[k+34>>1]=m;x[k>>2]=x[k>>2]>>>1;x[k+4>>2]=x[k+4>>2]>>>1;x[k+8>>2]=x[k+8>>2]>>>1;B=16}w[k+34>>1]=m&65531|d<<1&4;b=Zc(e+84|0,B,1,0,((d&12)!=0)<<3);y:{if(!r){break y}x[31609]=0;U(215,b|0,k|0,e+192|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break y}break v}f=f+1|0;continue}}break v}ub(e+192|0)}x[31609]=0;d=e+192|0;f=e+376|0;S(509,d|0,f|0,18761);b=x[31609];x[31609]=0;z:{if((b|0)!=1){n=kd(j,d);ub(d);b=x[n>>2];x[31609]=0;d=R(172,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break l}if(!d){break z}q=Nb(e+84|0);t=Nb(e+180|0);s=Nb(e+168|0);x[31609]=0;S(509,e+148|0,f|0,17750);b=x[31609];x[31609]=0;A:{if((b|0)==1){break A}b=x[e+160>>2];x[e+56>>2]=x[e+156>>2];x[e+60>>2]=b;x[e- -64>>2]=x[e+164>>2];x[31609]=0;b=x[e+152>>2];x[e+48>>2]=x[e+148>>2];x[e+52>>2]=b;O(511,e+48|0,q|0);b=x[31609];x[31609]=0;if((b|0)==1){break A}x[31609]=0;S(509,e+128|0,f|0,17744);b=x[31609];x[31609]=0;if((b|0)==1){break A}b=x[e+140>>2];x[e+32>>2]=x[e+136>>2];x[e+36>>2]=b;x[e+40>>2]=x[e+144>>2];x[31609]=0;b=x[e+132>>2];x[e+24>>2]=x[e+128>>2];x[e+28>>2]=b;O(511,e+24|0,t|0);b=x[31609];x[31609]=0;if((b|0)==1){break A}x[31609]=0;S(509,e+108|0,f|0,17734);b=x[31609];x[31609]=0;if((b|0)==1){break A}b=x[e+120>>2];x[e+8>>2]=x[e+116>>2];x[e+12>>2]=b;x[e+16>>2]=x[e+124>>2];x[31609]=0;b=x[e+112>>2];x[e>>2]=x[e+108>>2];x[e+4>>2]=b;O(511,e|0,s|0);b=x[31609];x[31609]=0;if((b|0)==1){break A}x[31609]=0;k=R(197,n|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break A}j=a+484380|0;while(1){if(k>>>0<=(u&255)>>>0){_o(s);_o(t);_o(q);break z}x[31609]=0;d=e+72|0;O(198,d|0,n|0);b=x[31609];x[31609]=0;B:{if((b|0)!=1){F=Jc(d);C:{D:{if(!y[e+72|0]){break D}f=x[n+8>>2];d=x[n>>2];b=y[F|0];x[31609]=0;d=U(150,d|0,f|0,D(b,14)+32|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break A}if(!d){break D}x[31609]=0;o=U(251,a|0,y[e+72|0],0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break A}if(o){break C}}b=y[F|0];x[31609]=0;P(183,n|0,D(b,14)+32|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break B}break A}x[31609]=0;S(317,n|0,o+492|0,32);b=x[31609];x[31609]=0;if((b|0)==1){break A}l=o+88|0;G=o+68|0;r=o+48|0;h=o+236|0;b=0;m=0;while(1){if(y[F|0]<=(m&255)>>>0){break B}x[31609]=0;O(512,n|0,e+192|0);d=x[31609];x[31609]=0;if((d|0)==1){break A}d=y[e+192|0];E:{if(!d|d>>>0>z[a+480190>>1]){break E}if(y[e+193|0]>=129){v[e+193|0]=128}while(1){d=b&255;i=y[e+193|0];if(d>>>0>i>>>0){d=x[q+4>>2];b=x[q>>2];x[31609]=0;V(513,r|0,y[e+195|0],b|0,d|0);b=x[31609];x[31609]=0;if((b|0)==1){break A}d=x[t+4>>2];b=x[t>>2];x[31609]=0;V(513,G|0,y[e+197|0],b|0,d|0);b=x[31609];x[31609]=0;if((b|0)==1){break A}d=x[s+4>>2];b=x[s>>2];x[31609]=0;V(513,l|0,y[e+205|0],b|0,d|0);b=x[31609];x[31609]=0;if((b|0)==1){break A}x[o>>2]=(y[e+198|0]|y[e+199|0]<<8)+1>>>1;d=j+D(y[e+192|0],104)|0;F:{if(y[e+195|0]&64){w[d+30>>1]=y[e+194|0];break F}w[d+34>>1]=z[d+34>>1]|32768}w[e+106>>1]=y[e+196|0]<<1;w[e+104>>1]=254;I=d,J=z[Oc(e+106|0,e+104|0)>>1],w[I+28>>1]=J;v[d+38|0]=y[(y[e+203|0]&3)+25060|0];E=y[e+202|0];v[d+39|0]=E;f=y[e+201|0]+3>>>2|0;v[d+40|0]=f;v[d+41|0]=y[e+200|0];b=i+1|0;if(E){f=si(Bc(((f<<8|E>>>1)>>>0)/(E>>>0)|0,0))}else{f=255}v[d+39|0]=f;if(!(y[e+197|0]&64)){break E}w[d+34>>1]=z[d+34>>1]|32}else{I=ac(h,d),J=y[e+192|0],w[I>>1]=J;b=b+1|0;continue}break}}m=m+1|0;continue}}break A}u=u+1|0;continue}}g=N()|0;_o(s);_o(t);_o(q);break c}g=N()|0;break c}F=1;o=Nb(e+180|0);G:{if(!(c&1)){break G}x[31609]=0;d=e+192|0;S(509,d|0,e+376|0,21076);b=x[31609];x[31609]=0;H:{I:{J:{K:{L:{M:{if((b|0)!=1){h=kd(n,d);b=x[h>>2];x[31609]=0;c=R(172,b|0)|0;b=x[31609];x[31609]=0;N:{O:{P:{if((b|0)!=1){ub(d);if(!c){break N}x[31609]=0;d=R(189,h|0)|0;c=x[31609];x[31609]=0;b=1;if((c|0)==1){break P}x[31609]=0;f=d+1|0;O(514,o|0,f|0);c=x[31609];x[31609]=0;if((c|0)==1){break P}while(1){if((b|0)==(f|0)){break N}x[31609]=0;d=R(189,h|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break O}x[31609]=0;i=e+84|0;S(185,i|0,h|0,d|0);c=x[31609];x[31609]=0;if((c|0)==1){break O}c=hc(e+192|0,i);kd(ch(x[o>>2],b),c);ub(c);b=b+1|0;ub(i);continue}}g=N()|0;ub(e+192|0);break H}g=N()|0;break H}g=N()|0;break H}x[31609]=0;d=e+192|0;S(509,d|0,e+376|0,16720);b=x[31609];x[31609]=0;if((b|0)==1){break J}C=kd(h,d);b=x[C>>2];x[31609]=0;c=R(172,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break K}ub(d);if(!c){break M}x[31609]=0;E=R(197,C|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break I}B=0;Q:{R:{S:while(1){T:{if(E>>>0<=(B&65535)>>>0){x[31609]=0;P(149,C|0,1)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break T}break I}m=32;U:{if(y[e+415|0]<16){break U}x[31609]=0;O(515,C|0,e+192|0);b=x[31609];x[31609]=0;if((b|0)==1){break Q}m=y[e+192|0];if(m>>>0<=z[a+480188>>1]|m>>>0>32){break U}w[a+480188>>1]=m}b=0;while(1){f=b&65535;if(f>>>0>=m>>>0){B=B+1|0;continue S}x[31609]=0;d=R(189,C|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break R}if(!(!d|f>>>0>31|f>>>0<z[a+480188>>1])){w[a+480188>>1]=b+1}b=b+1|0;continue}}break}x[31609]=0;q=a+484344|0;O(223,q|0,E|0);b=x[31609];x[31609]=0;if((b|0)==1){break I}G=e+194|0;n=0;while(1){if((n|0)==(E|0)){break M}t=Fb(e+84|0);V:{if(y[e+415|0]<16){c=32;i=64;break V}x[31609]=0;O(515,C|0,e+192|0);b=x[31609];x[31609]=0;if((b|0)==1){break L}d=y[e+193|0];c=y[e+192|0];b=e+72|0;bf(b,G,16,3);x[31609]=0;f=e+168|0;O(218,f|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break L}zb(t,f);tb(f);i=d+1|0}x[31609]=0;d=U(196,q|0,n&65535,i|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break L}W:{if(!d){x[31609]=0;P(183,C|0,c<<1)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break W}break L}b=x[q>>2];x[31609]=0;O(283,Wb(b,n)|0,t|0);b=x[31609];x[31609]=0;if((b|0)==1){break L}r=i-1|0;k=0;while(1){s=k&65535;if(s>>>0>=c>>>0){break W}x[31609]=0;d=R(189,C|0)|0;b=x[31609];x[31609]=0;X:{if((b|0)!=1){if(!d){break X}b=x[o>>2];if(Sf(b,x[o+4>>2])>>>0<=d>>>0|s>>>0>=z[a+480188>>1]){break X}A=ch(b,d);yc(A);f=0;Y:while(1){d=f;if(i>>>0<=d>>>0){break X}f=x[A+8>>2];b=x[A>>2];x[31609]=0;f=U(150,b|0,f|0,1)|0;b=x[31609];x[31609]=0;Z:{_:{$:{aa:{ba:{if((b|0)!=1){if(!f){break X}b=Wb(x[q>>2],n);b=md(x[b>>2],x[x[b+48>>2]+12>>2],d,s);x[31609]=0;h=R(197,A|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break L}j=h<<24>>24;g=(j&252)>>>2|0;switch((j&3)-1|0){case 2:break _;case 1:break $;case 0:break aa;default:break ba}}break L}f=(d+g|0)+1|0;continue}f=0;if(!d){continue}f=Wb(x[q>>2],n);l=md(x[f>>2],x[x[f+48>>2]+12>>2],d-1|0,s);while(1){f=y[l|0]|y[l+1|0]<<8|(y[l+2|0]<<16|y[l+3|0]<<24);v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;f=y[l+4|0]|y[l+5|0]<<8;v[b+4|0]=f;v[b+5|0]=f>>>8;f=d+1|0;if((d|0)==(r|0)){continue Y}b=D(z[a+480188>>1],6)+b|0;h=g&255;d=f;g=g-1|0;if(h){continue}break}continue}if(d>>>0<=g>>>0){break Z}f=Wb(x[q>>2],n);h=md(x[f>>2],x[x[f+48>>2]+12>>2],g,s);f=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;f=y[h+4|0]|y[h+5|0]<<8;v[b+4|0]=f;v[b+5|0]=f>>>8;break Z}if(g&1){x[31609]=0;h=R(197,A|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break L}v[b|0]=h>>>0>120?-1:h}if(g&2){x[31609]=0;h=R(197,A|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break L}v[b+1|0]=h}B=0;m=0;ca:{if(g&4){x[31609]=0;m=R(197,A|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break ca}}f=0;if(g&8){x[31609]=0;h=R(197,A|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break ca}B=h&15;f=h>>>4|0}l=0;u=0;if(g&16){x[31609]=0;u=R(197,A|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break ca}}if((j|0)<0){x[31609]=0;l=R(197,A|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break ca}}g=fb-16|0;fb=g;h=g+14|0;RY(h,B,u);j=Jc(h);h=g+12|0;RY(h,((f-1&255)>>>0<6?f+15|0:f)&255,l);l=Jc(h);da:{ea:{fa:{if(y[g+14|0]==10){h=y[l|0];f=y[j|0]&15;v[j|0]=f?-1:h;u=h|f<<8;f=y[g+12|0];if((f|0)!=10){break fa}f=0;v[g+12|0]=0;break fa}if(y[g+12|0]!=10){break ea}f=y[l|0]&15;v[l|0]=f?-1:0;u=f<<8;f=y[g+14|0]}if(u-256>>>0>4294967038){break ea}if(ri(f)>>>0>=ri(10)>>>0){break ea}v[b+5|0]=u;v[b+2|0]=15;v[b+3|0]=10;v[b+4|0]=u>>>8;break da}if(m){v[b+2|0]=1;v[b+4|0]=m+2>>>2}vw(g+14|0,j,g+12|0,l);h=y[g+14|0];f=y[g+12|0];if((h|0)==20|(f|0)!=(h|0)?h:0){if(!f){v[b+5|0]=y[j|0];v[b+3|0]=h;break da}if(!m){em(g+10|0,b,h,y[j|0],f,y[l|0]);break da}if(ri(h)>>>0>ri(f)>>>0){v[b+5|0]=y[j|0];v[b+3|0]=h;break da}}v[b+5|0]=y[l|0];v[b+3|0]=f}fb=g+16|0;break Z}break L}f=d+1|0;continue}}break L}k=k+1|0;continue}}tb(t);n=n+1|0;continue}}g=N()|0;break H}g=N()|0;break H}g=N()|0;break H}x[31609]=0;d=e+192|0;S(509,d|0,e+376|0,20048);b=x[31609];x[31609]=0;ga:{ha:{if((b|0)!=1){f=kd(C,d);b=x[f>>2];x[31609]=0;c=R(172,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break ha}ub(d);if(!c){break G}while(1){if(!Xj(x[a+484344>>2],x[a+484348>>2])){break G}c=x[f+8>>2];b=x[f>>2];x[31609]=0;c=U(150,b|0,c|0,16)|0;b=x[31609];x[31609]=0;if((b|0)==1){break ga}if(!c){break G}x[31609]=0;c=e+192|0;O(394,f|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){b=x[a+484344>>2];x[31609]=0;O(395,Wb(b,0)|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){continue}}break}g=N()|0;break H}g=N()|0;break H}g=N()|0;ub(e+192|0);break H}g=N()|0;break H}g=N()|0;tb(t);break H}g=N()|0;ub(e+192|0);break H}g=N()|0;break H}g=N()|0}Rc(o);break c}Rc(o);break k}g=N()|0;ub(e+192|0);break c}g=N()|0;break c}g=N()|0;break c}g=N()|0;break c}r=h+(b<<5)|0;Ve(r);f=v[b+i|0];d=f<<1&254;w[r+4>>1]=(d|0)==254?256:d;ia:{if((f|0)<0){x[r>>2]=x[r>>2]|1024;break ia}w[a+480188>>1]=b+1}x[31609]=0;O(516,e+356|0,r+9|0);d=x[31609];x[31609]=0;if((d|0)==1){break i}b=b+1|0;continue}}g=N()|0;break c}ub(e+356|0);ke(e+376|0);ub(H)}fb=e+416|0;return F|0}g=N()|0;break c}g=N()|0;break c}g=N()|0;break c}g=N()|0;tb(d);break d}g=N()|0}tb(f)}ub(e+356|0)}ke(e+376|0)}ub(H);Q(g|0);p()}function gta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;e=fb-240|0;fb=e;yc(b);f=fb-16|0;fb=f;g=e+218|0;cw(f+8|0,g);h=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);m=x[f+4>>2];if((m|0)==(h|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(h|0)==(m|0);if(!f){N_(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}if(!O_(g)){break n}d=1;if((c|0)==64){break n}Dd(a,1024);eg(a);x[a+480208>>2]=x[a+480208>>2]|12;bg(a+1074312|0,21);d=Bb(y[e+234|0]|y[e+235|0]<<8);if(d){x[a+480204>>2]=D(d,1e4)}d=Bb(y[e+232|0]|y[e+233|0]<<8);if(d){x[a+480196>>2]=d}if(!y[e+228|0]){Uh(a,1)}yE(b,a+1298308|0,$b(y[e+222|0]|y[e+223|0]<<8|(y[e+224|0]<<16|y[e+225|0]<<24))-14|0);d=e+112|0;b=He(d,b);x[31609]=0;f=e+204|0;O(346,f|0,b|0);g=x[31609];x[31609]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((g|0)!=1){ub(b);x[31609]=0;S(347,d|0,f|0,1395544366);b=x[31609];x[31609]=0;if((b|0)==1){break s}x[31609]=0;b=R(277,x[e+112>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break y}if(!b){break r}x[31609]=0;b=R(273,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break y}x[31609]=0;f=R(273,d|0)|0;g=x[31609];x[31609]=0;A:{if((g|0)==1){break A}x[31609]=0;P(183,d|0,4)|0;g=x[31609];x[31609]=0;if((g|0)==1){break A}g=y[a+484376|0];h=x[a+484360>>2];x[31609]=0;aa(348,Xb(h,g)|0,d|0,b|0,65535,65535);b=x[31609];x[31609]=0;if((b|0)!=1){break z}}break y}d=N()|0;ub(b);break a}$e(Xb(x[a+484360>>2],y[a+484376|0]),f);f=e+112|0;ub(f);x[31609]=0;S(347,f|0,e+204|0,1346458708);b=x[31609];x[31609]=0;if((b|0)==1){break x}x[31609]=0;g=R(277,x[e+112>>2])|0;b=x[31609];x[31609]=0;if((b|0)==1){break w}d=0;b=0;if(!g){break t}x[31609]=0;g=R(273,f|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break w}w[a+480188>>1]=g;if((g-33&65535)>>>0<65504){break t}x[31609]=0;b=R(273,f|0)|0;n=x[31609];x[31609]=0;if((n|0)==1){break w}x[31609]=0;O(223,a+484344|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break w}b=0;x[31609]=0;n=R(281,f|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break w}switch(n-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}d=N()|0;ub(e+112|0);break b}d=N()|0;break b}d=N()|0;ub(e+112|0);break b}if(n){break t}}b=1}f=e+112|0;ub(f);if(!b){break o}x[31609]=0;d=e+184|0;S(347,d|0,e+204|0,1398157625);b=x[31609];x[31609]=0;if((b|0)==1){break d}x[31609]=0;b=R(277,x[e+184>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break c}if(!b){break q}x[31609]=0;P(183,d|0,2)|0;b=x[31609];x[31609]=0;if((b|0)==1){break c}x[31609]=0;b=R(281,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break c}G=a,H=Te((+(b>>>0)*2.3283064365386963e-10+ +(A[a+480204>>2]/1e4>>>0))*1e4),x[G+480204>>2]=H;b=0;x[31609]=0;P(349,d|0,f|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}f=a+480280|0;g=z[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(g|0)){G=e,H=Bb(z[(e+112|0)+(b<<1)>>1]),x[G+48>>2]=H;x[e+32>>2]=180;d=x[Cd(e+48|0,e+32|0)>>2];m=d>>31<<7|d>>>25;d=d<<7;G=f+(b<<5)|0,H=Gc(Bua(d-11475|0,m-(d>>>0<11475)|0,90,0),hb)+128|0,w[G+4>>1]=H;b=b+1|0;continue}else{B:{x[31609]=0;P(183,e+184|0,16)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break B}break c}}break}x[31609]=0;b=U(150,x[e+184>>2],x[e+192>>2],2)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}C:{if(b){x[31609]=0;b=R(273,e+184|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break C}w[e+48>>1]=b;w[e+32>>1]=256;G=a,H=z[Oc(e+48|0,e+32|0)>>1],x[G+480200>>2]=H}x[31609]=0;b=e+184|0;P(183,b|0,128)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}x[31609]=0;b=P(349,b|0,e+48|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){if(!b){break q}d=z[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(d|0)){G=e,H=Bb(z[(e+48|0)+(b<<1)>>1]),x[G+32>>2]=H;x[e+20>>2]=128;G=f+(b<<5)|0,H=x[Cd(e+32|0,e+20|0)>>2]/2&255,w[G+6>>1]=H;b=b+1|0;continue}else{x[a+480228>>2]=x[a+480228>>2]<<1;break q}}break c}break c}d=N()|0;break b}ub(e+112|0);break p}ub(e+184|0);x[31609]=0;b=e+112|0;S(347,b|0,e+204|0,1413830740);d=x[31609];x[31609]=0;D:{E:{if((d|0)!=1){x[31609]=0;d=R(277,x[e+112>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}if(!d){break D}x[31609]=0;O(350,b|0,e+48|0);d=x[31609];x[31609]=0;if((d|0)==1){break e}if((Bb(y[e+58|0]|y[e+59|0]<<8)|0)!=65535){break E}x[31609]=0;P(183,b|0,1)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break E}break e}d=N()|0;break b}x[31609]=0;b=e+112|0;d=R(202,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}x[31609]=0;V(336,a+1298332|0,b|0,d|0,2);b=x[31609];x[31609]=0;if((b|0)==1){break e}}ub(e+112|0);x[31609]=0;b=e+48|0;S(347,b|0,e+204|0,1229869908);d=x[31609];x[31609]=0;if((d|0)==1){break h}x[31609]=0;d=R(277,x[e+48>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break l}F:{if(!d){break F}x[31609]=0;b=R(273,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}x[31609]=0;d=U(150,x[e+48>>2],x[e+56>>2],D(f,(b>>>14&2)+50|0)|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break g}if(!d){break H}w[a+480190>>1]=f;m=a+946304|0;g=a+484380|0;h=a+480190|0;k=e+130|0;l=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){x[31609]=0;b=R(273,e+48|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break I}break g}M:{if(l){i=b}else{x[31609]=0;d=R(273,e+48|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break M}i=d+1|0}w[e+20>>1]=i;x[31609]=0;d=e+112|0;O(351,e+48|0,d|0);j=x[31609];x[31609]=0;if((j|0)==1){break L}j=z[e+20>>1];if((j-4e3&65535)>>>0>=61537){G=h,H=z[qe(h,e+20|0)>>1],w[G>>1]=H;q=y[e+236|0]|y[e+237|0]<<8|(y[e+238|0]<<16|y[e+239|0]<<24);x[31609]=0;V(352,d|0,g+D(j,104)|0,$b(q)|0,n|0);d=x[31609];x[31609]=0;if((d|0)==1){break K}j=e+32|0;Rk(j,2,k);x[31609]=0;d=e+184|0;O(218,d|0,j|0);j=x[31609];x[31609]=0;if((j|0)==1){break J}Ac(m+(z[e+20>>1]<<5)|0,d);tb(d)}b=b+1|0;continue}break}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break f}if((b|0)!=4){break F}w[e+112>>1]=z[a+480190>>1];w[e+184>>1]=255;b=e+184|0;G=a,H=z[Oc(e+112|0,b)>>1],w[G+480192>>1]=H;x[31609]=0;S(347,b|0,e+204|0,1229278806);b=x[31609];x[31609]=0;if((b|0)==1){break j}m=e+114|0;N:while(1){O:{x[31609]=0;b=U(150,x[e+48>>2],x[e+56>>2],15)|0;d=x[31609];x[31609]=0;if((d|0)==1){break O}if(!b){break G}x[31609]=0;O(353,e+48|0,e+32|0);b=x[31609];x[31609]=0;if((b|0)==1){break k}b=Bb(z[e+32>>1]);if(b>>>0>=z[a+480192>>1]){continue}d=g+D(b,104)|0;v[d+144|0]=y[e+40|0];f=y[e+39|0];v[d+143|0]=255;v[d+145|0]=f;x[31609]=0;b=b+1&65535;d=U(251,a|0,b|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break k}if(!d){continue}G=e,H=Bb(y[e+37|0]|y[e+38|0]<<8),w[G+112>>1]=H;w[e+20>>1]=4095;b=e+112|0;f=e+20|0;G=d,H=z[Oc(b,f)>>1],x[G>>2]=H;h=y[e+35|0];if((h|0)==255){continue}x[31609]=0;k=e+184|0;h=P(149,k|0,D(h,34)+2|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break k}if(!h){continue}x[31609]=0;O(354,k|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break k}v[d+60|0]=y[d+60|0]|1;b=z[e+112>>1];x[e+24>>2]=16;x[e+28>>2]=240;G=e,H=Bb(b),x[G+20>>2]=H;b=uE(f);x[31609]=0;O(293,d+48|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break k}b=0;f=x[d+48>>2];k=x[d+52>>2];h=Sd(f,k);while(1)if(b>>>0>=h>>>0){b=y[e+36|0];if((b|0)!=255){v[d+64|0]=b;v[d+63|0]=b;v[d+60|0]=y[d+60|0]|4}if(mc(f,k)){continue N}b=h-1|0;v[d+62|0]=b;v[d+61|0]=b;v[d+60|0]=y[d+60|0]|2;continue N}else{v[e+20|0]=64;l=m+(b<<1)|0;v[e+16|0]=y[l|0];j=Qb(e+20|0,e+16|0);q=yb(f,b);v[q+2|0]=y[j|0];w[q>>1]=y[l+1|0];b=b+1|0;continue}}break}break k}ub(e+48|0);break p}ub(e+184|0)}b=e+48|0;ub(b);x[31609]=0;S(355,e+184|0,e+204|0,1145131092);d=x[31609];x[31609]=0;if((d|0)==1){break m}G=e,H=wb(x[e+184>>2]),x[G+20>>2]=H;m=a+484344|0;t=c&1;q=b|4;u=wb(x[e+188>>2]);r=(n|0)!=841887798;B=(n|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{f=x[e+20>>2];if(!Ib(f,u)){Rc(e+184|0);x[31609]=0;S(347,e+112|0,e+204|0,1346458702);b=x[31609];x[31609]=0;if((b|0)!=1){break aa}d=N()|0;break b}x[31609]=0;P(183,f|0,4)|0;b=x[31609];x[31609]=0;if((b|0)!=1){x[31609]=0;k=R(273,f|0)|0;b=x[31609];x[31609]=0;ba:{if((b|0)!=1){x[31609]=0;l=R(273,f|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break R}l=r?l:(l>>>0)/A[a+480196>>2]|0;if(!t|k>>>0>255){break P}x[31609]=0;b=U(196,m|0,k|0,l|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break R}if(b){break ba}break P}d=N()|0;break Q}if(!r){j=0;x[31609]=0;P(183,f|0,4)|0;b=x[31609];x[31609]=0;if((b|0)==1){break R}while(1){s=j&65535;if(s>>>0>=z[a+480188>>1]){break P}x[31609]=0;b=R(273,f|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break $}x[31609]=0;d=e+48|0;S(185,d|0,f|0,b+(b&1)&65535);b=x[31609];x[31609]=0;if((b|0)==1){break S}g=hc(e+112|0,d);ub(d);x[e+48>>2]=0;x[e+52>>2]=0;d=0;ca:{while(1){b=x[g>>2];x[31609]=0;b=U(150,b|0,x[e+120>>2],6)|0;h=x[31609];x[31609]=0;if((h|0)==1){break ca}i=b;b=x[e+48>>2];if(i&b>>>0<l>>>0){h=Wb(x[m>>2],k);b=md(x[h>>2],x[x[h+48>>2]+12>>2],b,s);x[31609]=0;h=e+32|0;O(356,h|0,g|0);i=x[31609];x[31609]=0;da:{ea:{if((i|0)!=1){i=Jc(h);C=_e(h);E=Yi(h);F=gc(h);o=v[e+32|0];if((o-1&255)>>>0>95){break ea}v[b|0]=o+13;if(!x[e+52>>2]){break da}v[b+3|0]=19;x[e+16>>2]=15;G=b,H=y[Cd(q,e+16|0)|0]|208,v[G+5|0]=H;break da}break T}if((o|0)>=0){break da}if(x[e+52>>2]){v[b+3|0]=19;x[e+16>>2]=15;G=b,H=y[Cd(q,e+16|0)|0]|192,v[G+5|0]=H;break da}v[b|0]=254}if(y[i|0]){v[b+2|0]=1;v[e+16|0]=64;G=b,H=y[Qb(i,e+16|0)|0],v[G+4|0]=H}i=y[C|0];if(i){v[b+1|0]=i}i=y[E|0];o=y[F|0];if(i|o){Cf(b,i,o)}h=v[h+5|0];b=h&255;i=e+48|0;if((h|0)<0){x[31609]=0;h=R(197,g|0)|0;o=x[31609];x[31609]=0;if((o|0)==1){break T}b=h|b<<8&32512}d=b+d|0;hE(i,d,x[a+480196>>2]);continue}break}ub(g);j=j+1|0;continue}break}break T}b=Wb(x[m>>2],k);G=e,H=wb(x[b>>2]),x[G+48>>2]=H;l=wb(x[b+4>>2]);while(1){b=x[e+48>>2];if(!Ib(b,l)){break P}x[31609]=0;O(357,e+32|0,f|0);d=x[31609];x[31609]=0;if((d|0)!=1){v[e+15|0]=0;fa:{if(!B){d=x[e+32>>2];x[e+112>>2]=d;g=e+112|0;h=Jc(g);k=_e(g);g=Yi(g);if(d<<24>>24>0){v[b|0]=(D((d&240)>>>4|0,12)+(d&15)|0)+12}d=y[h|0];if(d>>>0>=4){v[b+2|0]=1;v[b+4|0]=(d>>>2|0)-1;d=y[h|0]}v[b+1|0]=d<<4&48|y[k|0]>>>4;d=y[k|0]&15;v[e+15|0]=d;g=y[g|0];v[b+5|0]=g;break fa}d=x[e+32>>2];x[e+8>>2]=d;x[e+4>>2]=d;d=e+16|0;ep(d,e+4|0,b);g=e+112|0;ZD(g,e+15|0,b+5|0);YD(g,d);G=b,H=y[b+1|0]|y[xb(e+32|0,0)|0]&48,v[G+1|0]=H;g=y[b+5|0];d=y[e+15|0]}Cf(b,d&255,g);d=y[b+3|0];ga:{if(d>>>0>11){break ga}d=1<<d;ha:{if(!(d&2240)){if(!(d&12)){break ga}if(!y[b+5|0]){break ha}break ga}d=y[b+5|0];g=d&240;if(g){v[b+5|0]=g;break ga}if(d){break ga}}v[b+3|0]=0}tg(e+48|0);continue}break}d=N()|0;break Q}d=N()|0;break Q}x[31609]=0;b=R(277,x[e+112>>2])|0;d=x[31609];x[31609]=0;ia:{ja:{ka:{la:{ma:{if((d|0)!=1){if(b){f=Fb(e+48|0);b=0;na:{while(1){oa:{x[31609]=0;d=U(150,x[e+112>>2],x[e+120>>2],1)|0;g=x[31609];x[31609]=0;if((g|0)==1){break oa}if(!d){break na}if(Xj(x[a+484344>>2],x[a+484348>>2])>>>0<=b>>>0){break na}x[31609]=0;S(358,e+112|0,f|0,32);d=x[31609];x[31609]=0;if((d|0)==1){break oa}d=x[m>>2];x[31609]=0;O(283,Wb(d,b)|0,f|0);d=x[31609];x[31609]=0;if((d|0)==1){break oa}b=b+1|0;continue}break}d=N()|0;tb(f);break ma}tb(f)}b=e+112|0;ub(b);x[31609]=0;S(347,b|0,e+204|0,1414679374);b=x[31609];x[31609]=0;if((b|0)==1){break la}x[31609]=0;b=R(277,x[e+112>>2])|0;d=x[31609];x[31609]=0;if((d|0)==1){break V}if(!b){break ia}d=a+480280|0;f=Fb(e+48|0);b=0;while(1){x[31609]=0;g=U(150,x[e+112>>2],x[e+120>>2],1)|0;h=x[31609];x[31609]=0;if((h|0)==1){break ka}if(!(z[a+480188>>1]>b>>>0&g)){break ja}x[31609]=0;S(358,e+112|0,f|0,32);g=x[31609];x[31609]=0;if((g|0)==1){break ka}gm((d+(b<<5)|0)+9|0,f);b=b+1|0;continue}}d=N()|0}ub(e+112|0);break b}d=N()|0;break b}d=N()|0;tb(f);break U}tb(f)}b=e+112|0;ub(b);x[31609]=0;S(355,b|0,e+204|0,1145129300);b=x[31609];x[31609]=0;if((b|0)==1){break W}G=e,H=wb(x[e+112>>2]),x[G+48>>2]=H;d=a+484380|0;f=c&2;g=wb(x[e+116>>2]);pa:{qa:{ra:{sa:{ta:{ua:{while(1){b=x[e+48>>2];if(!Ib(b,g)){c=e+112|0;Rc(c);b=Fb(e+48|0);if((n|0)!=841887798){break ta}x[31609]=0;c=P(1,c|0,9506)|0;d=x[31609];x[31609]=0;if((d|0)==1){break ua}zb(b,c);tb(c);break sa}x[31609]=0;c=R(273,b|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break X}va:{if(!(!f|c>>>0>=z[a+480190>>1])){c=d+D(c,104)|0;h=z[c+138>>1];h=Zc(e+184|0,h&1?16:8,h&64?2:1,1,0);x[31609]=0;U(215,h|0,c+104|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break va}}Qf(e+48|0);continue}break}break X}d=N()|0;break Y}x[31609]=0;c=e+112|0;S(347,c|0,e+204|0,1447383635);d=x[31609];x[31609]=0;wa:{xa:{ya:{za:{Aa:{if((d|0)!=1){x[31609]=0;d=R(277,x[e+112>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break ra}if(!d){break xa}x[31609]=0;c=R(281,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break Aa}x[31609]=0;d=e+32|0;O(268,d|0,4292);f=x[31609];x[31609]=0;if((f|0)==1){break za}x[e+20>>2]=c>>>4;x[31609]=0;x[e+16>>2]=c&15;c=e+184|0;V(359,c|0,d|0,e+20|0,e+16|0);f=x[31609];x[31609]=0;if((f|0)==1){break ya}zb(b,c);tb(c);Eb(d);break wa}d=N()|0;break Y}d=N()|0;break Z}d=N()|0;break Z}d=N()|0;Eb(e+32|0);break Z}x[31609]=0;c=P(1,e+184|0,8509)|0;d=x[31609];x[31609]=0;if((d|0)==1){break _}zb(b,c);tb(c)}ub(e+112|0)}x[31609]=0;c=P(1,e+32|0,8509)|0;d=x[31609];x[31609]=0;if((d|0)==1){break qa}zb(a+1298344|0,c);tb(c);x[31609]=0;c=P(1,e+20|0,10149)|0;d=x[31609];x[31609]=0;if((d|0)==1){break pa}zb(a+1298356|0,c);tb(c);zb(a+1298368|0,b);G=a,H=x[Fc(e+16|0,28)>>2],x[G+1298404>>2]=H;tb(b);d=1;break o}d=N()|0;break Z}d=N()|0;break Y}d=N()|0;break Y}d=N()|0;break Q}d=N()|0}ub(e+112|0)}tb(b);break b}d=N()|0;Rc(e+112|0);break b}d=N()|0;break b}d=N()|0}ub(e+112|0);break b}d=N()|0;ub(g);break Q}d=N()|0;break Q}d=N()|0}Rc(e+184|0);break b}Qf(e+20|0);continue}}d=0}ke(e+204|0)}fb=e+240|0;return d|0}d=N()|0;break b}d=N()|0;break f}d=N()|0;ub(e+184|0);break f}d=N()|0;break f}d=N()|0;break f}d=N()|0;break b}d=N()|0}ub(e+48|0);break b}d=N()|0;ub(e+112|0);break b}d=N()|0;break b}d=N()|0;ub(e+184|0)}ke(e+204|0)}Q(d|0);p()}function epa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-336|0;fb=d;yc(b);k=d+324|0;a:{if(!gp(b,k)){break a}if(!iX(k)){break a}r=He(d+304|0,b);q=Nb(d+292|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((c|0)==64){x[31609]=0;e=d+40|0;O(664,e|0,r|0);b=x[31609];x[31609]=0;if((b|0)==1){break v}break x}x[31609]=0;e=d+40|0;O(665,e|0,r|0);b=x[31609];x[31609]=0;if((b|0)==1){break w}}Cv(q,e);ke(e);x[31609]=0;b=d+40|0;S(666,b|0,q|0,1413891155);e=x[31609];x[31609]=0;y:{z:{if((e|0)!=1){x[31609]=0;e=P(667,b|0,14199)|0;k=x[31609];x[31609]=0;if((k|0)==1){break z}ub(b);if((c|0)!=64&e){break y}break b}b=N()|0;break c}b=N()|0;ub(d+40|0);break c}x[31609]=0;O(246,a|0,4194304);b=x[31609];x[31609]=0;if((b|0)==1){break d}x[a+480208>>2]=12;x[31609]=0;b=d+272|0;S(666,b|0,q|0,1280592212);e=x[31609];x[31609]=0;if((e|0)==1){break e}x[31609]=0;e=R(154,x[d+272>>2])|0;k=x[31609];x[31609]=0;if((k|0)==1){break g}x[31609]=0;S(455,b|0,a+1298308|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break g}Nc(Xb(x[a+484360>>2],y[a+484376|0]));k=Nb(d+260|0);v[d+259|0]=0;v[d+258|0]=0;x[31609]=0;S(668,d+244|0,q|0,1196314451);b=x[31609];x[31609]=0;if((b|0)==1){break i}o=a+484360|0;t=d,u=wb(x[d+244>>2]),x[t+240>>2]=u;n=d+228|0;m=wb(x[d+248>>2]);A:{while(1){b=x[d+240>>2];if(!Ib(b,m)){break A}f=He(d+40|0,b);x[31609]=0;e=d+28|0;h=P(669,f|0,e|0)|0;b=x[31609];x[31609]=0;B:{C:{if((b|0)!=1){b=1;if(!(h&y[d+37|0]==1)){break B}t=a,u=Ld(y[d+38|0],z[a+480188>>1],127),w[t+480188>>1]=u;x[31609]=0;h=R(670,d+184|0)|0;b=x[31609];x[31609]=0;D:{E:{F:{if((b|0)!=1){i=d+172|0;bf(i,e,9,1);x[31609]=0;b=d+136|0;O(218,b|0,i|0);e=x[31609];x[31609]=0;if((e|0)==1){break F}e=d+16|0;Zb(e,n,10);nm(e,b);tb(b);b=Xb(x[a+484360>>2],y[a+484376|0]);if(mc(x[b>>2],x[b+4>>2])){break D}x[31609]=0;b=R(274,o|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break m}if((b|0)!=255){break E}b=2;break C}b=N()|0;break k}b=N()|0;break l}b=Xb(x[a+484360>>2],y[a+484376|0])}x[31609]=0;e=d+160|0;O(671,e|0,n|0);i=x[31609];x[31609]=0;if((i|0)==1){break m}pp(b,e);tb(e);x[31609]=0;O(665,d+172|0,f|0);b=x[31609];x[31609]=0;if((b|0)!=1){t=d,u=wb(x[d+172>>2]),x[t+156>>2]=u;j=wb(x[d+176>>2]);while(1){G:{H:{I:{J:{K:{b=x[d+156>>2];if(Ib(b,j)){mp(d+136|0,b);qi(d+16|0,x[b>>2],x[b+4>>2]);e=x[d+16>>2];if((e|0)==1212960847){break K}b=0;if((e|0)!=1312903248){break G}while(1){e=b&65535;if(e>>>0>=z[a+480188>>1]){break G}x[31609]=0;i=U(150,x[d+136>>2],x[d+144>>2],2)|0;g=x[31609];x[31609]=0;if((g|0)==1){break I}if(!i){break G}x[31609]=0;i=d+8|0;O(198,i|0,d+136|0);g=x[31609];x[31609]=0;if((g|0)!=1){GC(h,e,y[d+8|0],y[Jc(i)|0],d+259|0,k);b=b+1|0;continue}break}break I}b=0;if(z[d+220>>1]==65535|z[d+222>>1]==65535){break J}b=y[a+484376|0];e=x[a+484360>>2];x[31609]=0;W(672,Xb(e,b)|0);b=x[31609];x[31609]=0;if((b|0)!=1){b=0;x[31609]=0;O(673,k|0,h|0);e=x[31609];x[31609]=0;if((e|0)!=1){break J}}b=N()|0;break H}if(A[d+20>>2]<9){break G}e=0;x[31609]=0;P(183,d+136|0,2)|0;b=x[31609];x[31609]=0;i=65535;L:{if((b|0)!=1){while(1){x[31609]=0;b=U(150,x[d+136>>2],x[d+144>>2],1)|0;g=x[31609];x[31609]=0;M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((g|0)!=1){if(!b){break G}x[31609]=0;g=R(197,d+136|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break I}b=4;switch(g|0){case 0:break G;case 14:break N;case 13:break O;case 12:break Q;case 8:break R;case 7:break S;case 2:break T;case 6:break U;case 5:break V;case 3:case 4:break W;case 1:break X;default:break P}}break I}b=Xb(x[a+484360>>2],y[a+484376|0]);if(z[d+220>>1]==65535){t=d,u=cm(x[b>>2],x[b+4>>2]),w[t+220>>1]=u}b=cm(x[b>>2],x[b+4>>2]);x[31609]=0;w[d+222>>1]=b;b=P(674,d+136|0,d+258|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break I}Y:{Z:{switch(b-254|0){case 1:b=65535;break Y;case 0:break Z;default:break Y}}b=65534}g=y[a+484376|0];l=x[a+484360>>2];x[31609]=0;O(537,Xb(l,g)|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break I}i=(i&65535)==65535?e:i;break M}x[31609]=0;b=R(189,d+136|0)|0;l=x[31609];x[31609]=0;if((l|0)!=1){_:{if(b>>>0<(i&65535)>>>0){b=z[d+224>>1];break _}b=b-i|0;w[d+224>>1]=b}$e(Xb(x[a+484360>>2],y[a+484376|0]),b&65535);if((g|0)!=3){break M}x[31609]=0;P(183,d+136|0,1)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break M}}break I}x[31609]=0;b=d+8|0;O(198,b|0,d+136|0);g=x[31609];x[31609]=0;if((g|0)!=1){GC(h,y[d+8|0],y[Jc(b)|0],-1,d+259|0,k);break M}break I}b=1}x[31609]=0;P(183,d+136|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break M}break I}x[31609]=0;b=R(197,d+136|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break I}v[d+227|0]=b;break M}x[31609]=0;b=R(197,d+136|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break I}v[d+226|0]=b;break M}x[31609]=0;b=P(632,d+136|0,d+8|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break I}if(y[d+8|0]|!b|(y[d+10|0]|y[d+9|0]!=255)){break P}if(y[d+11|0]|y[d+12|0]!=1){break P}if(!y[d+13|0]){break M}}ub(d+136|0);b=1;break J}x[31609]=0;b=d+8|0;O(549,b|0,d+136|0);g=x[31609];x[31609]=0;if((g|0)!=1){g=Jc(b);GC(h,y[d+8|0],y[_e(b)|0],y[g|0],d+259|0,k);break M}break I}x[31609]=0;b=d+8|0;O(198,b|0,d+136|0);g=x[31609];x[31609]=0;if((g|0)==1){break L}g=x[d+196>>2];s=Xc(g,x[d+200>>2]);l=y[d+8|0];if(s>>>0<=l>>>0){break M}b=Jc(b);t=xb(g,l),u=(y[b|0]>>>2|0)+1|0,v[t|0]=u}e=e+1|0;continue}}break I}break I}ke(d+172|0);break C}b=N()|0;ub(d+136|0)}ke(d+172|0);break l}ub(d+136|0);dm(d+156|0);continue}}b=N()|0;break l}b=N()|0;break k}ar(h)}ub(f);if(!b){Qf(d+240|0);continue}break}e=0;if((b|0)!=2){break s}}e=0;Vj(o,0);b=x[k>>2];if(mc(b,x[k+4>>2])){break s}if(!(c&2)){break t}x[31609]=0;S(668,d+136|0,q|0,1347244868);b=x[31609];x[31609]=0;$:{if((b|0)!=1){t=d,u=wb(x[d+136>>2]),x[t+16>>2]=u;i=a+946304|0;e=a+484380|0;b=a+480190|0;o=d+53|0;n=d+57|0;g=wb(x[d+140>>2]);m=y[d+258|0];while(1){h=x[d+16>>2];if(!Ib(h,g)){Rc(d+136|0);b=x[k>>2];break t}aa:{ba:{ca:{if(!m){x[31609]=0;f=d+40|0;j=P(675,h|0,f|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break aa}if(!j){break ba}j=y[d+92|0]|y[d+93|0]<<8;l=j+1|0;w[d+8>>1]=l;if(j>>>0>3998){break ca}t=b,u=z[qe(b,d+8|0)>>1],w[t>>1]=u;x[31609]=0;O(676,f|0,e+D(l&65535,104)|0);f=x[31609];x[31609]=0;if((f|0)==1){break aa}j=d+28|0;hX(j,o);x[31609]=0;f=d+172|0;O(218,f|0,j|0);j=x[31609];x[31609]=0;if((j|0)==1){break u}Ac(i+(z[d+8>>1]<<5)|0,f);tb(f);break ca}x[31609]=0;f=d+40|0;j=P(677,h|0,f|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break u}if(!j){break ba}j=y[d+96|0]|y[d+97|0]<<8;l=j+1|0;w[d+8>>1]=l;if(j>>>0>3998){break ca}t=b,u=z[qe(b,d+8|0)>>1],w[t>>1]=u;x[31609]=0;O(678,f|0,e+D(l&65535,104)|0);f=x[31609];x[31609]=0;if((f|0)==1){break u}j=d+28|0;hX(j,n);x[31609]=0;f=d+172|0;O(218,f|0,j|0);j=x[31609];x[31609]=0;if((j|0)==1){break $}Ac(i+(z[d+8>>1]<<5)|0,f);tb(f)}f=z[d+8>>1];if((f-1&65535)>>>0>3998){break ba}j=Zc(d+40|0,8,1,0,2);x[31609]=0;U(215,j|0,e+D(f,104)|0,h|0)|0;h=x[31609];x[31609]=0;if((h|0)!=1){break ba}break u}Qf(d+16|0);continue}break}break u}b=N()|0;break j}break u}b=N()|0;break c}b=N()|0;break c}b=N()|0;Rc(d+136|0);break j}b=FC(b,0);x[a+480196>>2]=y[b+43|0];x[a+480204>>2]=D(y[b+42|0],1e4);$e(Xb(x[a+484360>>2],y[a+484376|0]),z[b+40>>1]);i=a+480280|0;b=0;while(1){if(z[a+480188>>1]>b>>>0){e=i+(b<<5)|0;Ve(e);h=FC(x[k>>2],0);t=e,u=y[xb(x[h+12>>2],b)|0],w[t+6>>1]=u;t=e,u=y[xb(x[h>>2],b)|0],w[t+4>>1]=u;Jb(d+40|0,x[h+24>>2],b);t=e,u=x[e>>2]&-257|(Gb(x[x[d+40>>2]>>2],x[d+44>>2])?256:0),x[t>>2]=u;b=b+1|0;continue}break}x[31609]=0;b=P(1,d+172|0,(y[d+258|0]?17182:17039)|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break n}zb(a+1298344|0,b);tb(b);x[31609]=0;b=P(1,d+28|0,10153)|0;e=x[31609];x[31609]=0;if((e|0)==1){break o}zb(a+1298356|0,b);tb(b);t=a,u=x[Fc(d+40|0,4)>>2],x[t+1298404>>2]=u;e=1;if(!(c&1)|!z[a+480188>>1]){break s}x[31609]=0;S(668,d+16|0,q|0,1146045008);b=x[31609];x[31609]=0;if((b|0)==1){break p}b=x[d+20>>2];c=x[d+16>>2];x[31609]=0;i=a+484344|0;O(223,i|0,Sf(c,b)&65535);b=x[31609];x[31609]=0;if((b|0)==1){break r}t=d,u=wb(x[d+16>>2]),x[t+240>>2]=u;g=wb(x[d+20>>2]);while(1){h=x[d+240>>2];if(!Ib(h,g)){da:{ea:{b=x[k>>2];e=x[k+4>>2];if(Bv(b,e)>>>0<2){break ea}o=y[d+259|0];c=0;while(1){if(Bv(b,e)>>>0<=c>>>0){break ea}g=x[a+484344>>2];j=x[a+484348>>2];f=Mj(x[a+484360>>2],c&255);l=x[f>>2];h=FC(b,c);n=z[h+36>>1];if(Je(g,j,z[ac(l,n)>>1])){x[31609]=0;e=P(368,f|0,n|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break da}fa:{if(!o){break fa}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break fa}n=EC(x[h+24>>2],b);f=Wb(x[i>>2],e);ga:{if(n){Ae(f,Vh(ip(We(Oe(d+40|0,20,145),0),b&65535)));break ga}Ae(f,Vh(ip(We(Oe(d+40|0,9,y[xb(x[h>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;Ae(Wb(x[i>>2],e),Vh(We(Oe(b,16,y[h+43|0]),0)));Ae(Wb(x[i>>2],e),Vh(We(Oe(b,17,y[h+42|0]),0)));e=x[k+4>>2];b=x[k>>2]}c=c+1|0;continue}}Rc(d+16|0);e=1;break s}b=N()|0;break q}b=x[h>>2];x[31609]=0;b=R(154,b|0)|0;c=x[31609];x[31609]=0;ha:{ia:{ja:{ka:{la:{ma:{na:{if((c|0)==1){break na}x[31609]=0;c=R(151,h|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break na}if((b|0)!=(c|0)){break ha}b=x[h>>2];x[31609]=0;b=P(679,b|0,8)|0;c=x[31609];x[31609]=0;if((c|0)==1){break na}if(!b){break ha}x[31609]=0;o=P(674,h|0,d+258|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break ia}x[31609]=0;n=R(189,h|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break ja}x[31609]=0;b=U(196,i|0,o|0,n|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break ja}if(!b){break ha}f=0;while(1){if((f|0)==(n|0)){break ha}b=Wb(x[i>>2],o);af(d+8|0,x[b>>2],x[x[b+48>>2]+12>>2],f);x[31609]=0;b=R(189,h|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break ma}oa:{if(b>>>0>=3){x[31609]=0;c=d+136|0;S(185,c|0,h|0,b-2|0);b=x[31609];x[31609]=0;if((b|0)==1){break ka}e=hc(d+40|0,c);ub(c);while(1){b=x[e>>2];x[31609]=0;b=U(150,b|0,x[d+48>>2],3)|0;c=x[31609];x[31609]=0;if((c|0)==1){break oa}if(b){x[31609]=0;b=d+136|0;O(198,b|0,e|0);c=x[31609];x[31609]=0;pa:{qa:{ra:{sa:{if((c|0)!=1){w[d+156>>1]=z[a+480188>>1]-1;t=d,u=y[Jc(b)|0],w[t+6>>1]=u;c=Yc(x[d+8>>2],z[Oc(d+156|0,d+6|0)>>1]);b=v[d+136|0];if((b|0)>=0){break pa}x[31609]=0;b=R(197,e|0)|0;m=x[31609];x[31609]=0;if((m|0)==1){break la}if(y[d+258|0]){break ra}if((b|0)!=255){break sa}b=254;break qa}break la}if(b>>>0>128){break qa}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break qa}b=b>>>0<85?b+36|0:b}v[c|0]=b;b=y[d+136|0]}if(b&64){x[31609]=0;b=R(197,e|0)|0;m=x[31609];x[31609]=0;if((m|0)==1){break la}v[c+1|0]=b+1;b=y[d+136|0]}if(b&32){x[31609]=0;b=R(197,e|0)|0;m=x[31609];x[31609]=0;if((m|0)==1){break la}v[d+156|0]=b;v[d+6|0]=127;b=y[Qb(d+156|0,d+6|0)|0];v[c+2|0]=1;v[c+4|0]=b+1>>>1;b=y[d+136|0]}if(!(b&16)){continue}x[31609]=0;b=d+156|0;O(198,b|0,e|0);m=x[31609];x[31609]=0;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{if((m|0)!=1){b=y[Jc(b)|0];v[c+5|0]=b;switch(y[d+156|0]-1|0){case 72:break ua;case 71:break va;case 70:break wa;case 61:break xa;case 60:break ya;case 53:break za;case 52:break Aa;case 51:break Ba;case 50:break Da;case 43:break Ea;case 42:break Fa;case 41:break Ga;case 40:break Ha;case 31:break Ia;case 30:break Ja;case 23:break Ka;case 22:break La;case 21:break Ma;case 20:break Na;case 18:break Oa;case 17:break Pa;case 15:break Qa;case 16:break Ra;case 14:break Sa;case 13:break Ta;case 12:break Ua;case 11:break Va;case 10:break Wa;case 3:break Xa;case 2:break Ya;case 1:break Za;case 0:break _a;default:break ta}}break la}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4|15;continue}v[c+5|0]=b<<3|15;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4;continue}v[c+5|0]=b<<3&240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1|240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b&15;continue}if(b>>>0<=1){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1&15;continue}v[c+3|0]=2;t=c,u=Av(b,y[d+258|0])|240,v[t+5|0]=u;continue}v[c+3|0]=2;t=c,u=Av(b,y[d+258|0]),v[t+5|0]=u;continue}v[c+3|0]=3;t=c,u=Av(b,y[d+258|0])|240,v[t+5|0]=u;continue}v[c+3|0]=3;t=c,u=Av(b,y[d+258|0]),v[t+5|0]=u;continue}v[c+3|0]=4;if(y[d+258|0]){continue}v[c+5|0]=(b&252)>>>2;continue}v[c+3|0]=20;v[c+5|0]=b&1|16;continue}v[c+3|0]=6;v[c+5|0]=b&240;continue}v[c+3|0]=6;v[c+5|0]=(b&240)>>>4;continue}v[c+3|0]=20;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=b&15|48;continue}v[c+3|0]=7;v[c+5|0]=b|240;continue}v[c+3|0]=7;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=b&15|64;continue}v[c+3|0]=10;x[31609]=0;b=R(197,e|0)|0;m=x[31609];x[31609]=0;if((m|0)!=1){break Ca}break la}v[c+3|0]=15;continue}v[c+3|0]=20;v[c+5|0]=b&15|192;continue}v[c+3|0]=20;v[c+5|0]=b&15|208;continue}v[c+3|0]=12;b=(b&254)>>>1|0}v[c+5|0]=b;x[31609]=0;P(183,e|0,1)|0;b=x[31609];x[31609]=0;if((b|0)!=1){continue}break la}v[c+5|0]=0;v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=b&15|176;continue}v[c+3|0]=20;v[c+5|0]=b&15|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=b&15|32;continue}v[c+3|0]=20;v[c+5|0]=b&15|128;continue}v[c+3|0]=0;continue}break}ub(e)}f=f+1|0;continue}break}break la}b=N()|0;break q}b=N()|0;break q}b=N()|0;ub(e);break q}b=N()|0;break q}b=N()|0;break q}b=N()|0;break q}Qf(d+240|0);continue}}Rc(d+244|0);gX(k);ub(d+272|0);break b}b=N()|0}Rc(d+16|0);break j}b=N()|0;break j}b=N()|0;break j}b=N()|0;break j}b=N()|0}ar(h)}ub(f)}Rc(d+244|0);break h}b=N()|0}gX(k);break f}b=N()|0}ub(d+272|0);break c}b=N()|0;break c}b=N()|0}ke(q);ub(r);Q(b|0);p()}ke(q);ub(r)}fb=d+336|0;return e|0}function hua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=fb-416|0;fb=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{e=d+408|0;s:{if(!vi(b,e)){break s}if(!j0(e)){break s}o=1;if((c|0)==64){break s}q=He(d+388|0,b);x[31609]=0;e=d+376|0;O(263,e|0,q|0);b=x[31609];x[31609]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((b|0)!=1){x[31609]=0;b=d+208|0;S(264,b|0,e|0,1229866575);e=x[31609];x[31609]=0;if((e|0)==1){break K}x[31609]=0;o=P(265,b|0,d+366|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break M}ub(b);if(!o){break t}x[31609]=0;O(246,a|0,524288);e=x[31609];x[31609]=0;N:{if((e|0)==1){break N}eg(a);x[a+480208>>2]=12;B=a,C=Ld(Bb(z[d+374>>1]),1,127),w[B+480188>>1]=C;B=d,C=Bb(z[d+366>>1]),w[B+208>>1]=C;w[d+320>>1]=255;e=d+320|0;B=a,C=z[Oc(b,e)>>1],w[B+480192>>1]=C;B=d,C=Bb(z[d+368>>1]),w[B+208>>1]=C;w[d+320>>1]=3999;B=a,C=z[Oc(b,e)>>1],w[B+480190>>1]=C;x[31609]=0;b=U(266,a+1074312|0,6,1)|0;e=x[31609];x[31609]=0;if((e|0)==1){break N}x[31609]=0;b=P(267,b|0,21)|0;e=x[31609];x[31609]=0;if((e|0)==1){break N}x[31609]=0;P(267,b|0,13)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break L}}b=N()|0;break b}b=N()|0;break a}b=N()|0;ub(d+208|0);break b}x[31609]=0;b=P(1,d+352|0,9298)|0;e=x[31609];x[31609]=0;if((e|0)==1){break c}zb(a+1298344|0,b);tb(b);x[31609]=0;b=P(1,d+340|0,10333)|0;e=x[31609];x[31609]=0;if((e|0)==1){break d}zb(a+1298356|0,b);tb(b);x[31609]=0;b=d+320|0;O(268,b|0,4336);e=x[31609];x[31609]=0;if((e|0)==1){break e}x[31609]=0;e=d+300|0;O(269,e|0,d+412|0);f=x[31609];x[31609]=0;if((f|0)==1){break g}x[31609]=0;g=d+264|0;O(269,g|0,d+413|0);f=x[31609];x[31609]=0;if((f|0)==1){break i}x[31609]=0;f=d+208|0;V(89,f|0,b|0,e|0,g|0);h=x[31609];x[31609]=0;if((h|0)==1){break j}zb(a+1298368|0,f);tb(f);tb(g);tb(e);Eb(b);B=a,C=x[Fc(f,28)>>2],x[B+1298404>>2]=C;x[31609]=0;f=d+376|0;S(264,b|0,f|0,1312902469);g=x[31609];x[31609]=0;if((g|0)==1){break k}x[31609]=0;g=R(154,x[d+320>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break m}x[31609]=0;h=a+1298308|0;S(270,b|0,h|0,g|0);b=x[31609];x[31609]=0;if((b|0)==1){break m}x[31609]=0;S(264,e|0,f|0,1397706311);b=x[31609];x[31609]=0;if((b|0)==1){break n}Nc(Xb(x[a+484360>>2],y[a+484376|0]));f=a+484360|0;j=Bb(z[d+370>>1]);e=0;O:{while(1){P:{if(j>>>0<=(e&65535)>>>0){break P}x[31609]=0;b=U(150,x[d+300>>2],x[d+308>>2],46)|0;g=x[31609];x[31609]=0;Q:{if((g|0)!=1){if(!b){break P}x[31609]=0;b=d+208|0;O(271,d+300|0,b|0);g=x[31609];x[31609]=0;if((g|0)!=1){if(!Ad(x[a+1298312>>2],y[a+1298319|0])){break Q}x[31609]=0;O(272,h|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break Q}}b=N()|0;break o}b=N()|0;break o}x[31609]=0;i=R(273,d+300|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break O}b=Xb(x[a+484360>>2],y[a+484376|0]);if(!mc(x[b>>2],x[b+4>>2])){x[31609]=0;b=R(274,f|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break O}if((b|0)==255){break P}b=Xb(x[a+484360>>2],y[a+484376|0])}x[31609]=0;g=d+288|0;O(275,g|0,d+208|0);k=x[31609];x[31609]=0;if((k|0)==1){break O}pp(b,g);tb(g);b=y[a+484376|0];g=x[a+484360>>2];x[31609]=0;S(276,Xb(g,b)|0,d+300|0,i|0);b=x[31609];x[31609]=0;if((b|0)==1){break O}e=e+1|0;continue}break}Vj(f,0);x[31609]=0;S(264,d+264|0,d+376|0,1229869908);b=x[31609];x[31609]=0;if((b|0)!=1){x[31609]=0;b=R(277,x[d+264>>2])|0;e=x[31609];x[31609]=0;if((e|0)==1){break p}R:{S:{if(!b){break S}j=a+484380|0;i=a+946304|0;e=1;T:{while(1){b=e&65535;if(b>>>0>z[a+480192>>1]){x[31609]=0;S(264,d+188|0,d+376|0,1447382614);b=x[31609];x[31609]=0;if((b|0)!=1){break T}break p}x[31609]=0;h=d+208|0;O(278,d+264|0,h|0);f=x[31609];x[31609]=0;if((f|0)==1){break p}f=y[d+238|0]|y[d+239|0]<<8;x[31609]=0;b=U(251,a|0,b|0,Bb(f)|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break R}U:{V:{if(!b){break V}if(Bb(y[d+238|0]|y[d+239|0]<<8)>>>0>3999){break V}g=d+112|0;xE(g,2,h);x[31609]=0;f=d+136|0;O(218,f|0,g|0);k=x[31609];x[31609]=0;if((k|0)==1){break U}Ac(b+492|0,f);tb(f);xE(g,2,h);x[31609]=0;O(218,f|0,g|0);h=x[31609];x[31609]=0;if((h|0)==1){break p}Ac(i+(Bb(y[d+238|0]|y[d+239|0]<<8)<<5)|0,f);tb(f);x[b>>2]=0;B=b,C=ze((y[d+254|0]|y[d+255|0]<<8)<<16>>16)+128&65535,x[B+8>>2]=C;xc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=y[d+238|0]|y[d+239|0]<<8;x[31609]=0;b=j+D(Bb(b),104)|0;O(279,b|0,0);h=x[31609];x[31609]=0;if((h|0)==1){break p}B=d,C=Bb(y[d+240|0]|y[d+241|0]<<8),w[B+136>>1]=C;w[d+112>>1]=64;B=b,C=z[Oc(f,g)>>1]<<2,w[B+30>>1]=C;f=$b(y[d+242|0]|y[d+243|0]<<8|(y[d+244|0]<<16|y[d+245|0]<<24));g=Aua(f,f>>31,8303,0);f=hb;g=g+4181|0;f=g>>>0<4181?f+1|0:f;B=b,C=Gc(Bua(g,f,8363,0),hb),x[B+24>>2]=C;f=$b(y[d+250|0]|y[d+251|0]<<8|(y[d+252|0]<<16|y[d+253|0]<<24));if(!f){break V}g=Bb(y[d+256|0]|y[d+257|0]<<8);if(!(g&3)){break V}h=$b(y[d+246|0]|y[d+247|0]<<8|(y[d+248|0]<<16|y[d+249|0]<<24));x[b+4>>2]=h;x[b+8>>2]=f+h;f=z[b+34>>1];w[b+34>>1]=f|2;if(!(g&2)){break V}w[b+34>>1]=f|6}e=e+1|0;continue}break}break p}b=x[d+200>>2];x[d+32>>2]=x[d+196>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+204>>2];x[31609]=0;b=x[d+192>>2];x[d+24>>2]=x[d+188>>2];x[d+28>>2]=b;V(280,d+24|0,0,a|0,0);b=x[31609];x[31609]=0;if((b|0)==1){break p}x[31609]=0;S(264,d+168|0,d+376|0,1346719318);b=x[31609];x[31609]=0;if((b|0)==1){break p}b=x[d+180>>2];x[d+8>>2]=x[d+176>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+184>>2];x[31609]=0;b=x[d+172>>2];x[d>>2]=x[d+168>>2];x[d+4>>2]=b;V(280,d|0,1,a|0,y[d+412|0]>2|0);b=x[31609];x[31609]=0;if((b|0)==1){break p}b=z[a+480192>>1]+1&65535;f=b>>>0<=1?1:b;g=a+900380|0;b=1;while(1){if((b|0)==(f|0)){break S}e=x[g+(b<<2)>>2];if(!(!e|v[e+60|0]&1)){x[e>>2]=32767}b=b+1|0;continue}}b=d+264|0;ub(b);x[31609]=0;e=d+376|0;S(264,d+208|0,e|0,1346458708);f=x[31609];x[31609]=0;if((f|0)==1){break x}x[31609]=0;f=R(172,x[d+208>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break y}if(!(c&1)|f^1){break J}x[31609]=0;S(264,b|0,e|0,1347305805);e=x[31609];x[31609]=0;if((e|0)==1){break z}x[31609]=0;P(183,b|0,1)|0;b=x[31609];x[31609]=0;if((b|0)==1){break B}b=z[d+372>>1];x[31609]=0;k=a+484344|0;O(223,k|0,Bb(b)|0);b=x[31609];x[31609]=0;if((b|0)==1){break B}j=Nb(d+156|0);i=0;W:{while(1){if(Bb(z[d+372>>1])>>>0<=i>>>0){od(j);ub(d+264|0);if(c&4){e=0;if(!t){break w}f=a+480280|0;g=z[a+480188>>1];b=0;while(1)if((b|0)==(g|0)){e=1;break w}else{e=f+(b<<5)|0;v[e+8|0]=1;x[e>>2]=x[e>>2]|33554432;b=b+1|0;continue}}if(!r){break u}break v}x[31609]=0;e=d+208|0;b=R(273,e|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break D}x[31609]=0;g=R(281,e|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break E}x[31609]=0;f=d+112|0;S(185,f|0,e|0,g|0);e=x[31609];x[31609]=0;if((e|0)==1){break F}h=hc(d+136|0,f);ub(f);x[31609]=0;e=U(196,k|0,i&65535,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break H}X:{if(e){n=Fb(d+100|0);x[31609]=0;O(282,d+264|0,n|0);e=x[31609];x[31609]=0;if((e|0)==1){break I}e=x[k>>2];x[31609]=0;O(283,Wb(e,i)|0,n|0);e=x[31609];x[31609]=0;if((e|0)==1){break I}l=0;e=Wb(x[k>>2],i);af(d+88|0,x[e>>2],x[x[e+48>>2]+12>>2],0);Nc(j);u=(b>>>0<=1?1:b)-1|0;Y:while(1){b=x[h>>2];x[31609]=0;b=U(150,b|0,x[d+144>>2],1)|0;e=x[31609];x[31609]=0;if((e|0)==1){break X}Z:{if(!b){break Z}x[31609]=0;b=R(197,h|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break I}if(!b){B=d,C=wb(x[j>>2]),x[B+84>>2]=C;e=wb(x[j+4>>2]);while(1){b=x[d+84>>2];if(Ib(b,e)){Ae(Wb(x[k>>2],i),We(Oe(d+112|0,y[b|0],y[b+1|0]),l));ge(d+84|0);continue}else{Nc(j);if((l|0)==(u|0)){break Z}b=Wb(x[k>>2],i);l=l+1|0;af(d+112|0,x[b>>2],x[x[b+48>>2]+12>>2],l);b=x[d+116>>2];x[d+88>>2]=x[d+112>>2];x[d+92>>2]=b;continue Y}}}w[d+116>>1]=0;x[d+112>>2]=0;g=d+112|0;if(b>>>0<=z[a+480188>>1]){g=Yc(x[d+88>>2],b-1|0)}x[31609]=0;b=R(197,h|0)|0;e=x[31609];x[31609]=0;_:{$:{if((e|0)!=1){aa:{if(!(b&1)){break aa}x[31609]=0;e=R(197,h|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break I}if((e|0)!=31){if((e-1&255)>>>0>252){break aa}e=(D(e>>>4|0,12)+(e&15)|0)+13|0}else{e=255}v[g|0]=e}if(!(b&2)){break _}x[31609]=0;e=R(197,h|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){break $}}break I}v[g+1|0]=e}if(!(b&60)){continue}e=0;m=0;if(b&4){x[31609]=0;m=R(197,h|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break I}}if(b&8){x[31609]=0;e=R(197,h|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break I}}f=0;s=0;if(b&16){x[31609]=0;s=R(197,h|0)|0;A=x[31609];x[31609]=0;if((A|0)==1){break I}}if(b&32){x[31609]=0;f=R(197,h|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break I}}b=d+84|0;g0(b,s,f);f=Jc(b);b=d+82|0;g0(b,m,e);e=Jc(b);b=y[d+82|0];ba:{if((b|0)!=13){if(b){break ba}b=0;if(y[d+84|0]==13){break ba}}rg(d+84|0,d+82|0);rg(f,e);b=y[d+82|0]}m=d+80|0;em(m,g,y[d+84|0],y[f|0],b&255,y[e|0]);if(f0(y[d+80|0],y[d+81|0])){b=x[vb(d+76|0,wb(x[j>>2]))>>2];x[31609]=0;S(284,j|0,b|0,m|0);b=x[31609];x[31609]=0;if((b|0)==1){break W}}b=y[g+3|0];if((b|0)==43){t=1;continue}if((b|0)!=31){continue}r=1;continue}break}tb(n)}ub(h);i=i+1|0;continue}break}break I}break I}break p}b=N()|0;break o}b=N()|0;break o}b=N()|0;break b}e=0;if(c&4){break w}break u}b=N()|0;tb(n);break G}b=N()|0}ub(h);break C}b=N()|0;break C}b=N()|0;break C}b=N()|0}od(j);break A}b=N()|0}ub(d+264|0);break q}b=N()|0;break q}b=N()|0;break q}b=N()|0;break o}v[d+156|0]=0;v[d+157|0]=80;v[d+158|0]=0;v[d+159|0]=150;v[d+160|0]=0;v[d+161|0]=80;v[d+162|0]=0;v[d+163|0]=255;x[31609]=0;S(264,d+264|0,d+376|0,1146310725);b=x[31609];x[31609]=0;ca:{da:{if((b|0)!=1){x[31609]=0;b=R(277,x[d+264>>2])|0;f=x[31609];x[31609]=0;if((f|0)!=1){if(!b){f=e;break ca}x[31609]=0;j=R(273,d+264|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break da}g=a+480280|0;b=0;f=e;while(1){if((b|0)==(j|0)){x[31609]=0;O(285,d+264|0,d+156|0);b=x[31609];x[31609]=0;if((b|0)!=1){break ca}break da}x[31609]=0;h=R(197,d+264|0)|0;i=x[31609];x[31609]=0;ea:{fa:{if((i|0)!=1){if(z[a+480188>>1]<=b>>>0){break ea}if(!e){break fa}i=g+(b<<5)|0;x[i>>2]=x[i>>2]&-33554433|((h|0)!=0)<<25;break ea}break da}if(h){break ea}f=1;v[(g+(b<<5)|0)+8|0]=1}b=b+1|0;continue}}break da}b=N()|0;break q}b=N()|0;ub(d+264|0);break q}e=d+264|0;ub(e);ga:{ha:{if(f&1){x[31609]=0;b=$d(a+906300|0,0);W(286,b|0);f=x[31609];x[31609]=0;if((f|0)==1){break r}x[b+24>>2]=655376;x[b+28>>2]=0;x[b+16>>2]=810369604;x[b+20>>2]=1869112133;x[d+264>>2]=0;g=b+48|0;c0(b+32|0,g,e);x[31609]=0;f=P(36,d+136|0,9587)|0;h=x[31609];x[31609]=0;if((h|0)==1){break ha}wE(g,f);tb(f);x[31609]=0;f=P(36,d+112|0,9551)|0;g=x[31609];x[31609]=0;if((g|0)==1){break ga}rw(b+80|0,f);tb(f);x[31609]=0;O(287,b+4|0,8);f=x[31609];x[31609]=0;if((f|0)==1){break r}b0(e,y[d+157|0],y[d+159|0],y[d+161|0],y[d+163|0]);e=x[d+268>>2];b=x[b+4>>2];f=x[d+264>>2];v[b|0]=f;v[b+1|0]=f>>>8;v[b+2|0]=f>>>16;v[b+3|0]=f>>>24;v[b+4|0]=e;v[b+5|0]=e>>>8;v[b+6|0]=e>>>16;v[b+7|0]=e>>>24}if(r){break v}break u}b=N()|0;break q}b=N()|0;break q}h=a+902204|0;b=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{while(1){if((b|0)==32){break u}x[d+88>>2]=D(b,127)>>>5;x[31609]=0;e=d+156|0;O(288,e|0,4093);f=x[31609];x[31609]=0;if((f|0)!=1){x[31609]=0;f=d+100|0;j=d+88|0;O(289,f|0,j|0);g=x[31609];x[31609]=0;if((g|0)==1){break wa}x[31609]=0;g=d+264|0;S(290,g|0,e|0,f|0);i=x[31609];x[31609]=0;if((i|0)==1){break va}fe(d+68|0,g);qf(Pe(h,b),x[d+68>>2],x[d+72>>2]);tb(g);tb(f);Eb(e);x[31609]=0;O(288,e|0,4075);i=x[31609];x[31609]=0;if((i|0)==1){break ta}x[31609]=0;O(289,f|0,j|0);i=x[31609];x[31609]=0;if((i|0)==1){break sa}x[31609]=0;S(290,g|0,e|0,f|0);i=x[31609];x[31609]=0;if((i|0)==1){break ra}fe(d+60|0,g);qf(Pe(h,b|32),x[d+60>>2],x[d+64>>2]);tb(g);tb(f);Eb(e);x[31609]=0;O(288,e|0,4066);i=x[31609];x[31609]=0;if((i|0)==1){break pa}x[31609]=0;O(289,f|0,j|0);i=x[31609];x[31609]=0;if((i|0)==1){break oa}x[31609]=0;S(290,g|0,e|0,f|0);i=x[31609];x[31609]=0;if((i|0)==1){break na}fe(d+52|0,g);qf(Pe(h,b|64),x[d+52>>2],x[d+56>>2]);tb(g);tb(f);Eb(e);x[31609]=0;O(288,e|0,4039);i=x[31609];x[31609]=0;if((i|0)==1){break la}x[31609]=0;O(289,f|0,j|0);j=x[31609];x[31609]=0;if((j|0)==1){break ka}x[31609]=0;S(290,g|0,e|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break ja}fe(d+44|0,g);qf(Pe(h,b|96),x[d+44>>2],x[d+48>>2]);b=b+1|0;tb(d+264|0);tb(d+100|0);Eb(e);continue}break}b=N()|0;break q}b=N()|0;break ua}b=N()|0;tb(d+100|0)}Eb(d+156|0);break q}b=N()|0;break q}b=N()|0;break qa}b=N()|0;tb(d+100|0)}Eb(d+156|0);break q}b=N()|0;break q}b=N()|0;break ma}b=N()|0;tb(d+100|0)}Eb(d+156|0);break q}b=N()|0;break q}b=N()|0;break ia}b=N()|0;tb(d+100|0)}Eb(d+156|0);break q}x[31609]=0;S(264,d+264|0,d+376|0,1397575756);b=x[31609];x[31609]=0;xa:{if((b|0)!=1){x[31609]=0;b=R(172,x[d+264>>2])|0;e=x[31609];x[31609]=0;if((e|0)!=1){ya:{if(!(c&2)|b^1){break xa}f=a+484380|0;e=1;while(1){g=e&65535;if(g>>>0>z[a+480190>>1]){break xa}x[31609]=0;c=d+264|0;b=R(281,c|0)|0;h=x[31609];x[31609]=0;za:{if((h|0)!=1){x[31609]=0;h=R(281,c|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break ya}if(!(b&7)){break za}g=f+D(g,104)|0;x[g>>2]=h;b=Zc(d+156|0,b&4?32:b&2?16:8,1,1,0);x[31609]=0;U(215,b|0,g|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break za}break ya}break ya}e=e+1|0;continue}}}b=N()|0;ub(d+264|0);break q}b=N()|0;break q}ub(d+264|0);ub(d+208|0);ub(d+300|0);ub(d+320|0)}ke(d+376|0);ub(q)}fb=d+416|0;return o|0}b=N()|0}ub(d+208|0);break o}b=N()|0;ub(d+264|0)}ub(d+300|0);break l}b=N()|0;break l}b=N()|0}ub(d+320|0);break b}b=N()|0;break b}b=N()|0;tb(d+264|0);break h}b=N()|0}tb(d+300|0);break f}b=N()|0}Eb(d+320|0);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0}ke(d+376|0)}ub(q);Q(b|0);p()}function Moa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;e=fb-320|0;fb=e;yc(b);a:{b:{c:{f=e+224|0;if(!Dv(b,f)){break c}if(!QW(f)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(PW(f),hb))){break c}d=1;if((c|0)==64){break c}Dd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;i=Fb(e+212|0);d=y[e+264|0]|y[e+265|0]<<8;l=(d|0)==20479?y[e+278|0]|y[e+279|0]<<8:d-16464|0;d:{e:{f:{g:{h:{i:{switch(d>>>12|0){case 0:f=0;if((d|0)!=520){break d}x[31609]=0;d=P(1,e+200|0,12393)|0;g=x[31609];x[31609]=0;if((g|0)!=1){zb(i,d);break e}b=N()|0;break a;case 1:j:{if((d|0)!=4896){break j}d=y[e+286|0]|y[e+287|0]<<8;if(d){break j}if(!((y[e+262|0]|y[e+263|0]<<8)&65455|(y[e+276|0]|y[e+256|0]&15))){k:{if(v[e+275|0]<0){x[a+1074308>>2]=18219008;x[31609]=0;d=P(1,e+200|0,14827)|0;f=x[31609];x[31609]=0;if((f|0)!=1){break k}b=N()|0;break a}x[a+1074308>>2]=16777376;x[31609]=0;d=P(1,e+200|0,13461)|0;f=x[31609];x[31609]=0;if((f|0)==1){break h}}zb(i,d);tb(d);x[31609]=0;f=1;U(266,a+1074312|0,81,1)|0;d=x[31609];x[31609]=0;g=1;if((d|0)!=1){break d}break b}if(y[e+276|0]|d|(y[e+277|0]|(y[e+262|0]|y[e+263|0]<<8))){break j}f=0;x[31609]=0;d=P(1,e+200|0,9492)|0;g=x[31609];x[31609]=0;if((g|0)!=1){zb(i,d);break e}b=N()|0;break a}x[31609]=0;d=P(1,e+200|0,8494)|0;f=x[31609];x[31609]=0;k=1;if((f|0)!=1){zb(i,d);tb(d);break f}b=N()|0;break a;case 2:x[31609]=0;d=P(1,e+200|0,6808)|0;f=x[31609];x[31609]=0;g=1;if((f|0)!=1){zb(i,d);tb(d);break f}b=N()|0;break a;case 3:l:{m:{n:{o:{if(d>>>0<=12820){x[31609]=0;f=P(1,e+200|0,8573)|0;g=x[31609];x[31609]=0;if((g|0)!=1){zb(i,f);tb(f);break o}b=N()|0;break a}x[31609]=0;f=e+200|0;O(445,f|0,4015);g=x[31609];x[31609]=0;if((g|0)==1){break n}x[31609]=0;x[e+188>>2]=(y[e+264|0]|y[e+265|0]<<8)-12820;g=e+48|0;S(446,g|0,f|0,e+188|0);h=x[31609];x[31609]=0;if((h|0)==1){break m}zb(i,g);tb(g);Eb(f)}f=y[e+264|0]|y[e+265|0]<<8;if(f>>>0<12807){break g}g=y[e+280|0]|y[e+281|0]<<8|(y[e+282|0]<<16|y[e+283|0]<<24);if(g){break l}break g}b=N()|0;break a}b=N()|0;Eb(e+200|0);break a}f=GF(f,g);g=kp(e+48|0);x[g+32>>2]=f;x[31609]=0;O(447,a+1298412|0,g|0);f=x[31609];x[31609]=0;if((f|0)!=1){break g}b=N()|0;break a;case 4:if((d|0)==16640){f=0;x[31609]=0;d=P(1,e+200|0,8340)|0;h=x[31609];x[31609]=0;g=1;if((h|0)!=1){zb(i,d);tb(d);x[31609]=0;U(266,a+1074312|0,81,1)|0;d=x[31609];x[31609]=0;h=0;if((d|0)==1){break b}break d}b=N()|0;break a}x[31609]=0;f=e+48|0;S(442,f|0,d|0,y[e+278|0]|y[e+279|0]<<8);d=x[31609];x[31609]=0;p:{q:{r:{if((d|0)!=1){zb(i,f);tb(f);x[a+480260>>2]=1;if((l|0)<4201){break r}x[31609]=0;U(266,a+1074312|0,7,1)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}break q}b=N()|0;break a}if((l|0)<2386){break p}}x[31609]=0;U(266,a+1074312|0,38,1)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}}f=0;x[31609]=0;P(267,a+1074312|0,118)|0;d=x[31609];x[31609]=0;g=1;h=1;if((d|0)==1){break b}break d;case 5:if((d|0)!=21575){d=d&4095;x[a+1074308>>2]=d<<16|(d>>>0>296?y[e+278|0]|y[e+279|0]<<8:0)&65535;x[31609]=0;d=P(1,e+200|0,18262)|0;f=x[31609];x[31609]=0;s:{t:{u:{if((f|0)!=1){f=x[a+1074308>>2];x[31609]=0;g=e+188|0;O(134,g|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break u}f=0;x[31609]=0;h=e+48|0;S(2,h|0,d|0,g|0);k=x[31609];x[31609]=0;if((k|0)==1){break t}zb(i,h);tb(h);tb(g);break e}b=N()|0;break a}b=N()|0;break s}b=N()|0;tb(e+188|0)}tb(d);break a}f=0;x[31609]=0;d=P(1,e+200|0,8557)|0;g=x[31609];x[31609]=0;if((g|0)!=1){zb(i,d);break e}b=N()|0;break a;case 6:f=0;x[31609]=0;d=P(1,e+200|0,8340)|0;g=x[31609];x[31609]=0;if((g|0)!=1){zb(i,d);tb(d);x[31609]=0;U(266,a+1074312|0,81,1)|0;d=x[31609];x[31609]=0;g=0;if((d|0)==1){break b}break d}b=N()|0;break a;case 7:f=0;x[31609]=0;d=P(1,e+200|0,8352)|0;g=x[31609];x[31609]=0;if((g|0)!=1){zb(i,d);break e}b=N()|0;break a;default:break i}}f=0;if((d|0)!=51712){break d}x[31609]=0;d=P(1,e+200|0,9291)|0;g=x[31609];x[31609]=0;if((g|0)!=1){zb(i,d);break e}b=N()|0;break a}b=N()|0;break a}x[31609]=0;f=U(266,a+1074312|0,7,1)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}x[31609]=0;f=U(266,f|0,23,1)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}x[31609]=0;f=U(266,f|0,38,1)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}x[31609]=0;U(266,f|0,107,1)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}g=1;x[a+480260>>2]=1;f=0;h=0;if(d>>>0>12820){break d}}x[31609]=0;d=e+188|0;W(694,d|0);f=x[31609];x[31609]=0;v:{w:{x:{if((f|0)!=1){f=y[e+264|0]|y[e+265|0]<<8;x[e+164>>2]=f>>>8&15;x[31609]=0;x[e+148>>2]=f&255;h=e+176|0;O(444,h|0,e+148|0);f=x[31609];x[31609]=0;if((f|0)==1){break x}f=0;x[31609]=0;j=e+48|0;aa(695,j|0,d|0,i|0,e+164|0,h|0);m=x[31609];x[31609]=0;if((m|0)==1){break w}zb(i,j);tb(j);tb(h);Eb(d);h=0;break d}b=N()|0;break a}b=N()|0;break v}b=N()|0;tb(e+176|0)}Eb(e+188|0);break a}tb(d);g=0;k=0;h=0}x[31609]=0;d=P(1,e+188|0,15125)|0;j=x[31609];x[31609]=0;y:{z:{A:{B:{if((j|0)!=1){zb(a+1298344|0,d);tb(d);x[31609]=0;d=P(1,e+176|0,10490)|0;j=x[31609];x[31609]=0;if((j|0)==1){break B}zb(a+1298356|0,d);tb(d);m=zb(a+1298368|0,i);E=a,F=x[Fc(e+48|0,x[a+1074308>>2]?22:4)>>2],x[E+1298404>>2]=F;if(g){x[31609]=0;d=P(267,a+1074312|0,77)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}x[31609]=0;d=P(267,d|0,78)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}x[31609]=0;d=P(267,d|0,79)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}x[31609]=0;d=P(267,d|0,80)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}x[31609]=0;d=P(267,d|0,82)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}x[31609]=0;d=P(267,d|0,96)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}x[31609]=0;P(267,d|0,113)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}}d=y[e+264|0]|y[e+265|0]<<8;if(d>>>0<=4865){x[31609]=0;P(267,a+1074312|0,118)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}d=y[e+264|0]|y[e+265|0]<<8}g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|(d&65535)>>>0>12819|f}x[31609]=0;d=a+901404|0;W(696,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break b}if(!f){lr(d)}f=e+164|0;Vi(f,1,e+224|0);x[31609]=0;d=e+48|0;O(218,d|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break y}zb(a+1298308|0,d);tb(d);d=y[e+262|0]|y[e+263|0]<<8;if(d&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(d&1){x[a+480208>>2]=x[a+480208>>2]|131072}f=y[e+264|0]|y[e+265|0]<<8;if(!(!(d&64)&(f|0)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}d=y[e+273|0];x[a+480196>>2]=d;if(!(!k|(d|0)!=255?d:0)){x[a+480196>>2]=6}d=y[e+274|0];x[a+480204>>2]=d>>>0<33?k?125e4:32e4:D(d,1e4);v[e+48|0]=y[e+272|0];v[e+164|0]=64;d=y[Qb(e+48|0,e+164|0)|0];x[a+480200>>2]=d<<2;if(!(d|f>>>0>4895)){x[a+480200>>2]=256}g=y[e+275|0];if((y[e+266|0]|y[e+267|0]<<8)!=1|g>>>0>7){break A}x[e+48>>2]=(g<<4)+16&240;x[e+164>>2]=127;d=x[Cd(e+48|0,e+164|0)>>2];break z}b=N()|0;break a}b=N()|0;break a}d=32;if((g|16)==18){break z}f=g&127;d=48;if(!f){break z}x[e+48>>2]=f;x[e+164>>2]=16;d=x[Ye(e+48|0,e+164|0)>>2]}f=d;x[a+480228>>2]=f;d=0;j=x[a+1074308>>2]!=0|g<<24>>24<0;if(!j){E=a,F=Bc(Cua(f<<3|5,f>>>29|0,11,0),hb),x[E+480228>>2]=F}w[a+480188>>1]=4;x[a+480232>>2]=h?(l|0)<3299?64:36:36;h=a+480280|0;B=e+288|0;l=tc(e+160|0);while(1){if((d|0)==32){if(!z[a+480188>>1]){w[a+480188>>1]=1}d=y[a+484376|0];f=x[a+484360>>2];x[31609]=0;aa(348,Xb(f,d)|0,b|0,y[e+256|0]|y[e+257|0]<<8,255,254);d=x[31609];x[31609]=0;if((d|0)!=1){s=Nb(e+164|0);x[31609]=0;U(213,b|0,s|0,y[e+258|0]|y[e+259|0]<<8)|0;d=x[31609];x[31609]=0;C:{if((d|0)!=1){t=Nb(e+148|0);x[31609]=0;U(213,b|0,t|0,y[e+260|0]|y[e+261|0]<<8)|0;d=x[31609];x[31609]=0;D:{E:{F:{G:{H:{if((d|0)!=1){I:{if(y[e+277|0]!=252){break I}d=0;x[31609]=0;O(697,b|0,e+48|0);f=x[31609];x[31609]=0;if((f|0)==1){break E}g=0;J:{while(1){if((d|0)==32){K:{if(x[a+1074308>>2]!=18219008|z[a+480188>>1]>31){break I}if(!(g&1)){break J}x[31609]=0;d=P(1,e+136|0,14858)|0;f=x[31609];x[31609]=0;if((f|0)==1){break K}zb(m,d);tb(d);break I}}else{L:{M:{f=y[(e+48|0)+d|0];if(!(f&32)){break M}if(k){Qc(e+136|0,l,d);if(Gb(x[x[e+136>>2]>>2],x[e+140>>2])){break M}}w[(h+(d<<5)|0)+4>>1]=(((f&15)<<8|8)>>>0)/15;break L}g=f>>>0<16|g}d=d+1|0;continue}break}b=N()|0;break D}x[31609]=0;d=P(1,e+136|0,8541)|0;f=x[31609];x[31609]=0;if((f|0)==1){break H}zb(m,d);tb(d)}w[e+48>>1]=y[e+258|0]|y[e+259|0]<<8;w[e+36>>1]=3999;f=z[Oc(e+48|0,e+36|0)>>1];w[a+480190>>1]=f;h=c&2;u=a+946304|0;r=a+484380|0;o=e+96|0;d=0;l=0;j=0;q=0;N:{O:{P:{Q:{R:{S:{T:{while(1){if((f&65535)>>>0<=d>>>0){d=q&65535;if(!(d|!(k&l))&(y[e+264|0]|y[e+265|0]<<8)!=4864){break R}if(!k){break Q}x[31609]=0;f=U(266,a+1074312|0,79,d>>>0>1|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break O}x[31609]=0;g=f;f=d>>>0<2;g=U(266,g|0,107,f|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break O}x[31609]=0;U(266,g|0,38,f|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break O}x[31609]=0;P(127,m|0,(d>>>0>1?17226:17233)|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break O}if(f){break Q}x[a+480228>>2]=48;break Q}f=ac(x[s>>2],d);f=y[f|0]|y[f+1|0]<<8;x[31609]=0;f=P(149,b|0,f<<4)|0;g=x[31609];x[31609]=0;if((g|0)==1){break G}U:{V:{if(!f){break V}x[31609]=0;g=e+48|0;f=P(698,b|0,g|0)|0;n=x[31609];x[31609]=0;if((n|0)==1){break G}if(!f){break V}x[31609]=0;n=d+1|0;C=r+D(n,104)|0;S(699,g|0,C|0,k|0);f=x[31609];x[31609]=0;if((f|0)==1){break G}A=e+24|0;Vi(A,1,o);x[31609]=0;f=e+36|0;O(218,f|0,A|0);A=x[31609];x[31609]=0;if((A|0)==1){break U}Ac(u+(n<<5)|0,f);tb(f);if(y[e+48|0]>1){break V}W:{if(!h|!(y[e+64|0]|y[e+65|0]<<8|(y[e+66|0]<<16|y[e+67|0]<<24))){break W}g=NW(g);x[31609]=0;g=P(149,b|0,g|0)|0;n=x[31609];x[31609]=0;if((n|0)==1){break T}if(!g){break W}MW(f,y[e+78|0],y[e+79|0],(y[e+266|0]|y[e+267|0]<<8)==1);x[31609]=0;U(215,f|0,C|0,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break S}j=y[e+39|0]==10|j;l=1}q=y[e+88|0]|y[e+89|0]<<8|q}d=d+1|0;f=z[a+480190>>1];continue}break}b=N()|0;break D}b=N()|0;break D}b=N()|0;break D}x[31609]=0;d=P(1,e+48|0,9766)|0;f=x[31609];x[31609]=0;if((f|0)==1){break P}zb(m,d);tb(d)}if(j&1){break N}break F}b=N()|0;break D}b=N()|0;break D}x[31609]=0;d=P(1,e+36|0,17166)|0;f=x[31609];x[31609]=0;X:{if((f|0)!=1){x[31609]=0;P(74,m|0,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break X}tb(d);break F}b=N()|0;break D}b=N()|0;tb(d);break D}b=N()|0;break D}b=N()|0;break D}b=N()|0;break D}Y:{if(!(c&1)){break Y}c=y[e+264|0]|y[e+265|0]<<8;w[e+24>>1]=y[e+260|0]|y[e+261|0]<<8;w[e+16>>1]=255;u=z[Oc(e+24|0,e+16|0)>>1];x[31609]=0;k=a+484344|0;O(223,k|0,u|0);d=x[31609];x[31609]=0;if((d|0)!=1){j=c>>>0<4896;h=0;l=0;m=0;Z:{_:{while(1){if((h|0)==(u|0)){if(!(j&1)){break Y}a=z[a+480188>>1];if((a|0)>(l+m|0)|(a|0)<=(l-m|0)){break Y}c=fb-16|0;fb=c;a=wb(x[k>>2]);x[c+12>>2]=a;d=wb(x[k+4>>2]);while(1){if(Ib(a,d)){b=wb(x[a>>2]);f=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,f)){if(y[b+3|0]==31){v[b+3|0]=20;v[b+5|0]=y[b+5|0]|128}b=x[tg(a+12|0)>>2];continue}break}fb=a+16|0;a=x[Ul(c+12|0)>>2];continue}else{fb=c+16|0}break}break Y}x[31609]=0;c=U(196,k|0,h&65535,64)|0;d=x[31609];x[31609]=0;$:{if((d|0)==1){break $}aa:{if(!c){break aa}c=ac(x[t>>2],h);c=y[c|0]|y[c+1|0]<<8;if(!c){break aa}x[31609]=0;c=P(149,b|0,c<<4)|0;d=x[31609];x[31609]=0;if((d|0)==1){break $}if(!c){break aa}x[31609]=0;P(183,b|0,2)|0;c=x[31609];x[31609]=0;if((c|0)==1){break $}d=0;c=Wb(x[k>>2],h);af(e+24|0,x[c>>2],x[x[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break aa}f=d;x[31609]=0;c=R(197,b|0)|0;d=x[31609];x[31609]=0;ba:{if((d|0)!=1){d=c<<24>>24;if(d){break ba}d=64;if((f|0)==63){continue}c=Wb(x[k>>2],h);d=f+1|0;af(e+16|0,x[c>>2],x[x[c+48>>2]+12>>2],d);c=x[e+20>>2];x[e+24>>2]=x[e+16>>2];x[e+28>>2]=c;continue}b=N()|0;break D}g=Ng(e+16|0);r=d&31;if(r>>>0<z[a+480188>>1]){g=Yc(x[e+24>>2],r)}o=d&255;if(o&32){x[31609]=0;c=e+14|0;O(198,c|0,b|0);n=x[31609];x[31609]=0;ca:{da:{ea:{if((n|0)!=1){n=Jc(c);c=y[e+14|0];if(c>>>0>239){break ea}c=LW((D(c>>>4|0,12)+(c&15)|0)+13|0);break da}b=N()|0;break D}fa:{switch(c-254|0){case 0:break da;case 1:break fa;default:break ca}}c=0}v[g|0]=c}v[g+1|0]=y[n|0]}if(o&64){x[31609]=0;c=R(197,b|0)|0;o=x[31609];x[31609]=0;if((o|0)==1){break _}c=c<<24>>24;v[e+14|0]=c;ga:{if((c|0)<=-64){v[g+2|0]=2;c=c&127;break ga}v[g+2|0]=1;v[e+13|0]=64;c=y[Qb(e+14|0,e+13|0)|0]}v[g+4|0]=c}ha:{if((d|0)>=0){break ha}x[31609]=0;c=e+14|0;O(198,c|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break Z}BD(g,y[e+14|0],y[Jc(c)|0],0);c=y[g+3|0];ia:{if((c|0)!=10){if((c|0)!=31){if((c|0)!=20){break ha}c=y[g+5|0];if((c&240)!=160|(y[e+264|0]|y[e+265|0]<<8)>>>0>4895){break ha}if((q&65535)>>>0>1){break ia}d=y[r+B|0]&127;if(d>>>0>=16){break ia}ja:{switch(c-160|0){case 0:case 2:v[g+5|0]=d&8?-116:-125;break ha;case 1:case 3:v[g+5|0]=d&8?-125:-116;break ha;default:break ja}}if(c>>>0>167){break ia}v[g+5|0]=136;break ha}c=y[g+5|0];if(c>>>0>15){j=0;break ha}if(c>>>0<=7){m=m+1|0;break ha}l=((c|0)!=8)+l|0;break ha}if(y[g+5|0]|(y[e+264|0]|y[e+265|0]<<8)>>>0>4865){break ha}}v[g+3|0]=37}d=f;continue}}h=h+1|0;continue}break}b=N()|0;break D}b=N()|0;break D}b=N()|0;break D}b=N()|0;break D}od(t);od(s);tb(i);d=1;break c}b=N()|0}od(t);break C}b=N()|0}od(s);break a}b=N()|0;break a}f=h+(d<<5)|0;Ve(f);g=y[d+B|0];q=g&126;ka:{if((g|0)!=255){g=g<<24>>24;w[a+480188>>1]=d+1;if(j){w[f+4>>1]=g&8?204:51}if((g|0)>=0){break ka}}x[f>>2]=1024}if((q-16&255)>>>0<=13){w[f+4>>1]=128;f=e+48|0;Qc(f,l,d);bp(f)}d=d+1|0;continue}}b=N()|0;break a}fb=e+320|0;return d|0}b=N()|0}tb(i);Q(b|0);p()}function Boa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,V=0,W=0;f=fb-480|0;fb=f;yc(b);e=fb-16|0;fb=e;k=f+276|0;vW(e+8|0,k);l=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);g=x[e+4>>2];if((g|0)==(l|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(l|0);if(!e){uW(k)}a:{if(!e){break a}if(!wW(k)){break a}d=1;if((c|0)==64){break a}Dd(a,134217728);k=f+8|0;gg(k,3953);x[31609]=0;e=f+116|0;S(702,e|0,k|0,y[f+280|0]|y[f+281|0]<<8);l=x[31609];x[31609]=0;b:{c:{d:{if((l|0)!=1){zb(a+1298344|0,e);tb(e);Eb(k);k=uc(e,8990);zb(a+1298356|0,k);tb(k);V=a,W=x[Fc(e,28)>>2],x[V+1298404>>2]=W;x[a+480188>>2]=4;V=a,W=Bb(y[f+412|0]|y[f+413|0]<<8),x[V+480196>>2]=W;e=y[f+416|0]|y[f+417|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;V=a,W=tW(Bb(e)),x[V+480204>>2]=W;ow(Xb(x[a+484360>>2],y[a+484376|0]),f+284|0,y[f+282|0]);m=a+946304|0;t=a+484380|0;q=a+480190|0;j=a+480188|0;o=Nb(f+264|0);u=Nb(f+252|0);e:{while(1){f:{g:{h:{i:{j:{k:{l:{if(Bb(y[f+476|0]|y[f+477|0]<<8)>>>0>(h&65535)>>>0){x[31609]=0;e=R(273,b|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break i}w[f+228>>1]=e;if((e-4e3&65535)>>>0<=61536){break c}d=Bb(y[f+478|0]|y[f+479|0]<<8);if((Bb(y[f+280|0]|y[f+281|0]<<8)|0)==2){x[31609]=0;e=R(281,b|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break j}d=e-2|0}x[31609]=0;e=f+8|0;S(185,e|0,b|0,d|0);k=x[31609];x[31609]=0;if((k|0)==1){break k}g=hc(f+116|0,e);ub(e);C=z[qe(q,f+228|0)>>1];w[q>>1]=C;x[31609]=0;l=D(z[f+228>>1],104)+t|0;O(279,l|0,1);e=x[31609];x[31609]=0;m:{n:{o:{if((e|0)==1){break o}if(Bb(y[f+280|0]|y[f+281|0]<<8)>>>0>1){break n}x[31609]=0;O(703,g|0,l+43|0);e=x[31609];x[31609]=0;if((e|0)==1){break o}x[31609]=0;P(183,g|0,1)|0;e=x[31609];x[31609]=0;if((e|0)==1){break o}x[31609]=0;S(331,g|0,m+(z[f+228>>1]<<5)|0,30);e=x[31609];x[31609]=0;if((e|0)!=1){break m}}d=N()|0;break f}e=Fb(f+8|0);x[31609]=0;S(358,g|0,e|0,257);k=x[31609];x[31609]=0;p:{q:{if((k|0)==1){break q}Be(l+43|0,e);x[31609]=0;P(183,g|0,1)|0;k=x[31609];x[31609]=0;if((k|0)==1){break q}x[31609]=0;S(358,g|0,e|0,31);k=x[31609];x[31609]=0;if((k|0)==1){break q}Ac(m+(z[f+228>>1]<<5)|0,e);if(!(v[f+124|0]&1)){break p}x[31609]=0;P(183,g|0,1)|0;k=x[31609];x[31609]=0;if((k|0)!=1){break p}}d=N()|0;tb(e);break f}tb(e)}x[31609]=0;O(704,g|0,f+8|0);e=x[31609];x[31609]=0;r:{if((e|0)==1){break r}d=fb-16|0;fb=d;e=$b(y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24));x[l>>2]=e;v[d+15|0]=y[f+12|0];v[d+14|0]=64;V=l,W=y[Qb(d+15|0,d+14|0)|0]<<2,w[V+30>>1]=W;i=$b(y[f+14|0]|y[f+15|0]<<8|(y[f+16|0]<<16|y[f+17|0]<<24));x[l+4>>2]=i;k=$b(y[f+14|0]|y[f+15|0]<<8|(y[f+16|0]<<16|y[f+17|0]<<24))+$b(y[f+18|0]|y[f+19|0]<<8|(y[f+20|0]<<16|y[f+21|0]<<24))|0;x[l+8>>2]=k;if(e>>>0<=i>>>0){i=e-1|0;x[l+4>>2]=i}if(e>>>0<k>>>0){x[l+8>>2]=e;k=e}s:{if(i>>>0>k>>>0){x[l+4>>2]=0;x[l+8>>2]=0;break s}if(i>>>0>=k>>>0){break s}w[l+34>>1]=z[l+34>>1]|2;V=yb(l+68|0,0),W=i,x[V>>2]=W}fb=d+16|0;t:{switch(Bb(y[f+280|0]|y[f+281|0]<<8)|0){case 2:v[l+37|0]=y[f+26|0]<<3;break;case 0:break g;default:break t}}x[31609]=0;O(210,u|0,C|0);e=x[31609];x[31609]=0;if((e|0)==1){break r}x[31609]=0;O(705,o|0,C|0);e=x[31609];x[31609]=0;if((e|0)==1){break r}k=Vd(x[o>>2],z[f+228>>1]-1|0);Nc(k);x[31609]=0;e=R(273,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break l}d=x[b+8>>2];i=x[b>>2];x[31609]=0;d=U(150,i|0,d|0,e<<3)|0;i=x[31609];x[31609]=0;if((i|0)==1){break l}if(d){x[31609]=0;O(706,k|0,e|0);d=x[31609];x[31609]=0;if((d|0)==1){break l}x[f+248>>2]=0;if(!(y[l+34|0]&2)|e){break h}e=x[l+4>>2];x[f+240>>2]=e;l=x[l+8>>2];x[31609]=0;x[f+244>>2]=l-e;O(707,k|0,f+240|0);e=x[31609];x[31609]=0;if((e|0)!=1){break g}d=N()|0;break f}ub(g);break c}d=N()|0;break f}u:{v:{w:{x:{if(Bb(y[f+280|0]|y[f+281|0]<<8)){B=y[f+283|0];w[f+238>>1]=4;E=128;break x}x[31609]=0;E=R(273,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){d=N()|0;break e}e=y[f+280|0]|y[f+281|0]<<8;B=y[f+283|0];w[f+238>>1]=4;if(!Bb(e)){break w}}l=x[b+8>>2];e=0;while(1){y:{if((e&65535)>>>0>=E>>>0){break y}x[31609]=0;k=R(273,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break v}if((k|0)==65535){break y}x[31609]=0;B=R(273,b|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break v}x[31609]=0;k=R(273,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break v}w[f+238>>1]=k;if(k>>>0>127){break c}V=j,W=z[qe(j,f+238|0)>>1],w[V>>1]=W;x[31609]=0;P(183,b|0,D(k,B)<<2)|0;k=x[31609];x[31609]=0;if((k|0)==1){break v}e=e+1|0;continue}break}x[31609]=0;P(149,b|0,l|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break u}}e=z[j>>1];x[31609]=0;F=P(708,f+240|0,e|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){J=a+484344|0;T=c&1;G=Bb(y[f+414|0]|y[f+415|0]<<8);k=0;l=0;while(1){z:{A:{B:{C:{if((k&65535)>>>0>=E>>>0){break C}D:{if(!Bb(y[f+280|0]|y[f+281|0]<<8)){d=z[f+238>>1];e=k;break D}x[31609]=0;e=R(273,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break z}if((e|0)==65535){break C}x[31609]=0;B=R(273,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break z}x[31609]=0;d=R(273,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break z}w[f+238>>1]=d}g=x[b+8>>2];h=x[b>>2];x[31609]=0;n=g;H=B&65535;g=H<<2;d=U(150,h|0,n|0,D(g,d&65535)|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break z}if(!d){break C}if(!T){break B}x[31609]=0;K=e&65535;e=U(196,J|0,K|0,H|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break z}if(!e){break B}r=0;E:while(1){if((r|0)==(H|0)){break A}e=Wb(x[J>>2],K);af(f+228|0,x[e>>2],x[x[e+48>>2]+12>>2],r);e=0;s=0;F:{G:{switch((G&3)-1|0){case 0:s=!(r&3);break F;case 1:s=!(r&1);break F;case 2:break G;default:break F}}s=(r&3)!=3}L=0;while(1){if(z[f+238>>1]<=e>>>0){r=r+1|0;continue E}h=x[F>>2];g=Yc(x[f+228>>2],e);x[31609]=0;d=f+224|0;O(357,d|0,b|0);i=x[31609];x[31609]=0;if((i|0)==1){break z}i=D(e,9)+h|0;h=Jc(d);n=_e(d);v[g+1|0]=y[f+224|0];j=y[h|0];v[g|0]=j;h=y[Yi(d)|0];v[g+5|0]=h;m=g+5|0;if(j){v[g|0]=j+25;v[i+8|0]=0;v[i|0]=0;v[i+1|0]=0;v[i+2|0]=0;v[i+3|0]=0;v[i+4|0]=0;v[i+5|0]=0;v[i+6|0]=0;v[i+7|0]=0;h=y[g+5|0]}j=h&255;n=y[n|0];H:{I:{if(n>>>0>=240){d=j|(n&15)<<8;if(d){v[g+3|0]=17;V=g,W=Zl(+(tW(d)>>>0)/1e4),v[V+5|0]=W;j=0;break H}break I}I=j>>>4|0;M=j<<4;d=I|M;J:{switch(n|0){case 0:if(h&255){v[g+3|0]=1;j=0;break H}break I;case 1:v[g+3|0]=2;j=0;break H;case 2:v[g+3|0]=3;j=0;break H;case 3:v[f+220|0]=15;V=i,W=y[Qb(m,f+220|0)|0]|16,v[V|0]=W;v[i+7|0]=0;v[i+1|0]=0;v[i+2|0]=0;break I;case 4:v[f+220|0]=15;V=i,W=y[Qb(m,f+220|0)|0]|32,v[V|0]=W;v[i+7|0]=0;v[i+1|0]=0;v[i+2|0]=0;break I;case 5:v[i+7|0]=0;v[i+2|0]=0;v[i+1|0]=h;v[i|0]=0;break I;case 6:v[i+7|0]=0;v[i+2|0]=h;v[i|0]=0;v[i+1|0]=0;break I;case 7:v[g+3|0]=23;j=0;l=0;break H;case 8:v[g+3|0]=0;j=1;l=d;break H;case 9:v[g+3|0]=19;v[f+220|0]=15;V=g,W=y[Qb(m,f+220|0)|0]|16,v[V+5|0]=W;j=0;break H;case 10:v[g+3|0]=19;v[f+220|0]=15;V=g,W=y[Qb(m,f+220|0)|0]|32,v[V+5|0]=W;j=0;break H;case 11:v[i+3|0]=d;break I;case 12:v[g+4|0]=h;j=1;v[g+2|0]=1;v[i+3|0]=0;v[g+3|0]=0;break H;case 13:d=h&255;K:{L:{if(d>>>0>=16){v[g+2|0]=4;h=(h&240)>>>4|0;break L}if(!d){break K}v[g+2|0]=3}v[g+4|0]=h}v[i+3|0]=0;break I;case 14:v[g+3|0]=19;v[g+5|0]=!(h&255);j=0;break H;case 15:v[g+3|0]=16;v[g+5|0]=(h&240)>>>4;G=h&15;j=0;break H;case 16:v[i+5|0]=0;v[i+4|0]=h;break I;case 17:v[i+6|0]=j&15?h:0;break I;case 18:v[g+3|0]=14;j=0;break H;case 19:v[i+8|0]=0;v[i+7|0]=h;v[i+2|0]=0;v[i|0]=0;v[i+1|0]=0;break I;case 20:v[g+3|0]=12;j=0;break H;case 22:d=y[g+1|0];M:{if(!d){break M}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<d>>>0){break M}h=h-1|0;v[m|0]=h;x[31609]=0;R(709,f+116|0)|0;n=x[31609];x[31609]=0;if((n|0)==1){break z}x[f+220>>2]=9;d=Vd(j,d-1|0);V=f,W=Ud(x[d>>2],x[d+4>>2]),x[V+112>>2]=W;if(A[Hb(f+220|0,f+112|0)>>2]<=(h&255)>>>0){break M}v[g+2|0]=15;v[g+4|0]=y[g+5|0]}break I;case 23:d=y[g+1|0];N:{if(!d){break N}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<d>>>0){break N}h=h-1|0;v[m|0]=h;d=Vd(j,d-1|0);j=x[d>>2];n=Ud(j,x[d+4>>2]);d=h&255;if(n>>>0<=d>>>0){break N}d=Vd(j,d);h=z[d+8>>1];O:{if(h){break O}h=0;j=z[q>>1];if(!oi(j)){break O}h=j+1|0;w[q>>1]=h;w[d+8>>1]=h}v[g+1|0]=h}break I;case 24:d=y[g+1|0];P:{if(!d){break P}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<d>>>0){break P}h=h-1|0;v[m|0]=h;x[31609]=0;R(709,f+8|0)|0;n=x[31609];x[31609]=0;if((n|0)==1){break z}x[f+220>>2]=9;d=Vd(j,d-1|0);V=f,W=Ud(x[d>>2],x[d+4>>2]),x[V+112>>2]=W;if(A[Hb(f+220|0,f+112|0)>>2]>(h&255)>>>0){v[g+2|0]=15;v[g+4|0]=y[g+5|0]}d=ac(x[u>>2],y[g+1|0]-1|0);h=z[d>>1];Q:{if(h){break Q}h=0;j=z[q>>1];if(!oi(j)){break Q}h=j+1|0;w[q>>1]=h;w[d>>1]=h}v[g+1|0]=h}break I;case 25:d=y[g+1|0];R:{if(!d){break R}j=x[o>>2];if(Ud(j,x[o+4>>2])>>>0<d>>>0){break R}h=h-1|0;v[m|0]=h;d=Vd(j,d-1|0);j=x[d>>2];n=Ud(j,x[d+4>>2]);d=h&255;if(n>>>0<=d>>>0){break R}d=Vd(j,d);h=z[d+10>>1];S:{if(h){break S}h=0;j=z[q>>1];if(!oi(j)){break S}h=j+1|0;w[q>>1]=h;w[d+10>>1]=h}v[g+1|0]=h}break I;case 29:v[g+5|0]=d;v[g+3|0]=11;if(j&15){v[m|0]=M|15;j=0;break H}j=0;if((h&255)>>>0<16){break H}v[m|0]=I|240;break H;case 32:if((h&255)>>>0>=16){v[i+3|0]=I;break I}v[g+3|0]=19;v[g+5|0]=h|192;j=0;break H;case 33:v[g+3|0]=19;v[f+220|0]=15;V=g,W=y[Qb(m,f+220|0)|0]|208,v[V+5|0]=W;j=0;break H;case 34:v[g+3|0]=19;v[f+220|0]=15;V=g,W=y[Qb(m,f+220|0)|0]|144,v[V+5|0]=W;j=0;break H;case 73:v[g+3|0]=10;j=0;break H;case 78:if((h&112|128)==224){v[g+3|0]=19;j=0;break H}break I;case 79:if((h&255)>>>0<=31){v[g+3|0]=16;j=0;G=0;break H}v[g+3|0]=17;j=0;break H;default:break J}}}v[g+3|0]=0;j=1}n=0;d=y[i+3|0];if(!(y[g+2|0]|!d)){n=d;h=d>>>4|0;d=d>>>0<16;v[g+4|0]=d?n:h;v[g+2|0]=d?6:5;n=1}T:{if(!j){break T}h=y[i+1|0];U:{if(h){v[g+3|0]=2;break U}h=y[i+2|0];if(h){v[g+3|0]=3;break U}h=y[i|0];if(h){v[g+3|0]=19;break U}h=y[i+7|0];if(h){v[g+3|0]=4;v[i+8|0]=h;break U}h=y[i+4|0];if(h){v[g+3|0]=5;v[i+5|0]=h;break U}d=y[i+3|0];if(!(!d|n)){v[g+5|0]=d;v[g+3|0]=11;if(d&15){h=d|-16;break U}h=d|15;break U}h=y[i+6|0];if(h){v[g+3|0]=8;break U}if(s){v[g+3|0]=20;s=0;h=97;break U}s=0;if(!(l&255)|L){break T}v[g+5|0]=l;v[g+3|0]=24;h=l&15?l|-16:l|15;L=1}v[m|0]=h}e=e+1|0;continue}}}x[a+480228>>2]=256/z[a+480188>>1];j=1;Uh(a,1);if(Bb(y[f+280|0]|y[f+281|0]<<8)){V:{while(1){a=x[b+8>>2];e=x[b>>2];x[31609]=0;a=U(150,e|0,a|0,2)|0;e=x[31609];x[31609]=0;if((e|0)==1){break z}if(!a){break V}x[31609]=0;a=R(273,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break z}if((a|0)==65535){break V}x[31609]=0;P(183,b|0,2)|0;a=x[31609];x[31609]=0;if((a|0)==1){break z}x[31609]=0;a=R(281,b|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){x[31609]=0;P(183,b|0,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){continue}}break}break z}x[31609]=0;P(183,b|0,34)|0;a=x[31609];x[31609]=0;if((a|0)==1){break z}}W:{if(!(c&2)){break W}while(1){a=j&65535;if(a>>>0>C>>>0){break W}X:{c=D(a,104)+t|0;if(!x[c>>2]){break X}e=Zc(f+228|0,8,1,0,0);x[31609]=0;U(215,e|0,c|0,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break z}e=x[o>>2];if(Ud(e,x[o+4>>2])>>>0<a>>>0){break X}h=a-1|0;d=Vd(e,h);a=0;l=0;i=fb-112|0;fb=i;Y:{g=x[c>>2];if(!le(g,x[c+20>>2])){break Y}q=x[d>>2];e=Ud(q,x[d+4>>2]);if(e>>>0<2){break Y}k=Xo(i+8|0,c);x[k+20>>2]=0;x[k>>2]=0;Z:{while(1){if((a|0)==(e|0)){break Z}_:{m=Vd(q,a);r=x[m>>2];if(r>>>0>=g>>>0){break _}m=x[m+4>>2];if(m>>>0>g-r>>>0|268435456-m>>>0<l>>>0){break _}l=l+m|0;x[k>>2]=l;a=a+1|0;continue}break}e=a}if(!Gh(k)){break Y}m=k+68|0;l=0;a=0;while(1){if((a|0)==(e|0)){nn(c);a=Xo(c,k);x[a+4>>2]=0;x[a+8>>2]=x[a>>2];w[a+34>>1]=z[a+34>>1]|2;break Y}n=x[k+20>>2]+l|0;q=x[c+20>>2];g=Vd(x[d>>2],a);zc(n,q+x[g>>2]|0,x[g+4>>2]);x[g>>2]=l;if(a-10>>>0>=4294967287){V=yb(m,a-1|0),W=l,x[V>>2]=W}a=a+1|0;l=x[g+4>>2]+l|0;continue}}fb=i+112|0;a=z[ac(x[u>>2],h)>>1];if(a){zC(c,D(a,104)+t|0,0,x[c>>2],0)}a=Vd(x[o>>2],h);V=f,W=wb(x[a>>2]),x[V+228>>2]=W;e=wb(x[a+4>>2]);while(1){a=x[f+228>>2];if(!Ib(a,e)){break X}k=z[a+8>>1];if(k){zC(c,D(k,104)+t|0,x[a>>2],x[a+4>>2],1)}k=z[a+10>>1];if(k){zC(c,D(k,104)+t|0,x[a>>2],x[a+4>>2],0)}xm(f+228|0);continue}}j=j+1|0;continue}}xv(F);d=1;break b}x[31609]=0;P(183,b|0,D(g,z[f+238>>1])|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break A}break z}k=k+1|0;continue}break}d=N()|0;xv(F);break e}d=N()|0;break e}d=N()|0;break e}d=N()|0;break e}d=N()|0;break f}d=N()|0;break e}d=N()|0;break e}d=N()|0;break e}d=0;while(1){if(e>>>0<=(d&65535)>>>0){break g}x[31609]=0;l=R(281,b|0)|0;i=x[31609];x[31609]=0;$:{if((i|0)==1){break $}x[31609]=0;x[f+240>>2]=l;l=R(281,b|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break $}x[31609]=0;x[f+244>>2]=l;O(707,k|0,f+240|0);l=x[31609];x[31609]=0;if((l|0)==1){break $}d=d+1|0;continue}break}d=N()|0;break f}ub(g);h=h+1|0;continue}break}ub(g)}od(u);rW(o);break d}d=N()|0;Eb(f+8|0)}Q(d|0);p()}d=0}od(u);rW(o)}fb=f+480|0;return d|0}function Hna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=fb-576|0;fb=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{g=d+496|0;l:{if(!CD(b,g)){break l}if(!wV(g)){break l}if(!Mb(x[b>>2],x[b+8>>2],Bc(vV(g),hb))){break l}e=1;if((c|0)==64){break l}Dd(a,4);eg(a);v[a+1074368|0]=4;l=Fb(d+484|0);k=d+534|0;m:{if(!(jd(k,18435,20)|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))!=276)){r=41080;e=48;if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break m}e=rq(d+513|0,0,20)?1154:34;break m}r=41080;if(!jd(k,18414,20)){break m}e=d+104|0;pi(e,3,k);x[31609]=0;g=d+192|0;S(369,g|0,4,e|0);e=x[31609];x[31609]=0;n:{if((e|0)!=1){zb(l,g);tb(g);if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))!=1852141647|(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))!=542396493){break n}e=1048;break m}b=N()|0;break a}if(!jd(k,18162,12)){e=16;if((y[d+546|0]|y[d+547|0]<<8|(y[d+548|0]<<16|y[d+549|0]<<24))==538976288&(y[d+550|0]|y[d+551|0]<<8|(y[d+552|0]<<16|y[d+553|0]<<24))==538976288){break m}v[a+1074368|0]=5;break m}if(!jd(k,11673,20)){e=48;break m}if(!jd(k,25456,15)){x[31609]=0;g=P(267,a+1074312|0,54)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}x[31609]=0;P(267,g|0,51)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}r=41072;e=16;break m}o:{if(jd(k,25472,14)){if(jd(k,25487,14)){break o}}x[31609]=0;g=P(267,a+1074312|0,57)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}x[31609]=0;P(267,g|0,51)|0;g=x[31609];x[31609]=0;e=16;if((g|0)!=1){break m}break b}e=jd(k,18250,11)?16:256}f=d+104|0;B=d+513|0;pi(f,3,B);x[31609]=0;g=d+192|0;O(218,g|0,f|0);n=x[31609];x[31609]=0;p:{q:{r:{s:{t:{if((n|0)!=1){zb(a+1298308|0,g);tb(g);x[a+480260>>2]=1;x[a+480264>>2]=31999;$e(Xb(x[a+484360>>2],y[a+484376|0]),y[d+562|0]|y[d+563|0]<<8);w[a+480188>>1]=y[d+564|0]|y[d+565|0]<<8;w[d+192>>1]=y[d+568|0]|y[d+569|0]<<8;w[d+104>>1]=255;K=a,L=z[Oc(g,f)>>1],w[K+480192>>1]=L;g=y[d+572|0]|y[d+573|0]<<8;if(g){x[a+480196>>2]=g}g=y[d+574|0]|y[d+575|0]<<8;if(g){g=D(g,1e4);g=g>>>0>=1e7?1e7:g;x[a+480204>>2]=g>>>0<=32e4?32e4:g}g=y[d+570|0]|y[d+571|0]<<8;x[a+480208>>2]=g<<4&16|g<<3&32768;f=x[a+484360>>2];n=y[a+484376|0];x[31609]=0;aa(348,Xb(f,n)|0,b|0,y[d+560|0]|y[d+561|0]<<8,65535,65535);f=x[31609];x[31609]=0;if((f|0)==1){break b}f=g>>>12&1?(e|0)==34?146:e:e;if(!(y[d+560|0]|y[d+561|0]<<8|f>>>0>1023)){g=y[a+484376|0];e=x[a+484360>>2];x[31609]=0;W(762,Xb(e,g)|0);g=x[31609];x[31609]=0;if((g|0)==1){break b}}x[31609]=0;P(149,b|0,(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))+60|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}if((y[d+554|0]|y[d+555|0]<<8)>>>0>=260){x[31609]=0;S(763,b|0,d+496|0,a|0);g=x[31609];x[31609]=0;if((g|0)==1){break b}}v[d+483|0]=0;C=c&2;G=a+946304|0;s=a+484380|0;H=a+900380|0;I=d+122|0;o=d+225|0;n=Nb(d+468|0);t=1;g=-1;while(1){e=t&65535;if(e>>>0>z[a+480192>>1]){if(!(!(f&2)|u&255)){f=rq(B,0,20)?f|16:f}if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){break r}if(c&3){x[31609]=0;S(763,b|0,d+496|0,a|0);c=x[31609];x[31609]=0;if((c|0)==1){break q}}if(!C){break r}e=1;while(1){c=e&65535;if(c>>>0>z[a+480190>>1]){break r}o=x[n>>2];x[31609]=0;U(215,yb(o,c-1|0)|0,D(c,104)+s|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}x[31609]=0;j=R(151,b|0)|0;i=x[31609];x[31609]=0;u:{v:{if((i|0)!=1){Ih(b,4);x[31609]=0;S(764,b|0,d+192|0,(j?j:263)|0);j=x[31609];x[31609]=0;if((j|0)==1){break s}w:{if((f|0)==1){j=x[d+192>>2];if((j|0)!=263){f=16;if((j|0)!=245){break w}x[a+1074308>>2]=16777381;x[31609]=0;f=P(1,d+180|0,13461)|0;j=x[31609];x[31609]=0;if((j|0)!=1){zb(l,f);tb(f);f=17;break w}b=N()|0;break c}x[a+1074308>>2]=16777395;x[31609]=0;f=P(1,d+168|0,13352)|0;j=x[31609];x[31609]=0;if((j|0)!=1){zb(l,f);tb(f);f=17;break w}b=N()|0;break c}if(y[d+219|0]|y[d+220|0]<<8){break w}j=x[d+192>>2];if(!(!(f&2)|(y[d+221|0]|y[d+222|0]<<8|(y[d+223|0]<<16|y[d+224|0]<<24))|(j|0)!=263)){f=f|16;break w}if(!(!(f&256)|(j|0)==29)){f=f&-257;break w}if(!(f&160)){break w}f=(j|0)==33?f:0}x[31609]=0;j=U(251,a|0,e|0,0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break s}if(!j){break u}j=(e<<2)+H|0;e=x[j>>2];x[31609]=0;O(765,d+192|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break s}e=y[d+218|0];x:{if((g|0)==-1){g=e;break x}if(!(f&32)|(e|0)==(g|0)){break x}f=f&-161|128}e=y[d+219|0]|y[d+220|0]<<8;if(!e){break u}x[31609]=0;i=y[d+439|0];h=y[d+435|0]|y[d+436|0]<<8;m=y[d+434|0];q=y[d+433|0];S(766,d+156|0,a|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break t}f=i|(h|(m|q))?f&-4:f;j=x[j>>2]+236|0;e=12;i=x[d+156>>2];h=$c(i,x[d+160>>2]);y:{while(1){z:{if((e|0)==108){if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){Nc(n)}e=0;x[31609]=0;j=P(767,d+144|0,y[d+219|0]|y[d+220|0]<<8)|0;i=x[31609];x[31609]=0;if((i|0)!=1){break z}b=N()|0;break y}m=ac(j,e);if(h>>>0>z[m>>1]){K=m,L=z[ac(i,z[ac(j,e)>>1])>>1],w[K>>1]=L}e=e+1|0;continue}break}A:{B:{C:{D:{while(1){i=y[d+219|0]|y[d+220|0]<<8;if(e>>>0>=i>>>0){e=0;if((y[d+554|0]|y[d+555|0]<<8)>>>0<=259){break v}E:{while(1){if(e>>>0>=i>>>0){break v}m=y[yb(x[n>>2],e)+3|0];i=x[yb(x[j>>2],e)>>2];x[31609]=0;h=d+72|0;S(185,h|0,b|0,((m|0)==10?(i+1>>>1|0)+16|0:i)|0);i=x[31609];x[31609]=0;if((i|0)!=1){i=hc(d+104|0,h);ub(h);h=x[d+156>>2];if(!(!C|$c(h,x[d+160>>2])>>>0<=e>>>0)){m=z[ac(h,e)>>1];h=yb(x[n>>2],e);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);x[31609]=0;x[d+68>>2]=h;x[d+8>>2]=h;h=ba(768,D(m,104)+s|0,d+8|0,i|0,d+483|0)|0;m=x[31609];x[31609]=0;if((m|0)==1){break E}E=h^1|E}ub(i);e=e+1|0;i=y[d+219|0]|y[d+220|0]<<8;continue}break}b=N()|0;break A}b=N()|0;ub(i);break A}x[31609]=0;q=d+104|0;O(769,b|0,q|0);i=x[31609];x[31609]=0;if((i|0)==1){break B}i=d+72|0;h=y[d+118|0];F:{if(!(h&48|y[d+121|0]!=173)){Zc(i,8,1,0,10);break F}Zc(i,h&16?16:8,h&32?3:1,0,2)}x[31609]=0;O(770,n|0,i|0);h=x[31609];x[31609]=0;if((h|0)!=1){K=yb(x[j>>2],e),L=x[d+104>>2],x[K>>2]=L;J=y[d+121|0];h=x[d+156>>2];if($c(h,x[d+160>>2])>>>0>e>>>0){m=z[ac(h,e)>>1];x[31609]=0;h=D(m,104)+s|0;O(771,q|0,h|0);q=x[31609];x[31609]=0;if((q|0)==1){break D}v[h+38|0]=y[o+202|0];v[h+39|0]=y[o+203|0];v[h+40|0]=y[o+204|0];v[h+41|0]=y[o+205|0];h=d+92|0;Rk(h,3,I);x[31609]=0;O(218,i|0,h|0);h=x[31609];x[31609]=0;if((h|0)==1){break C}Ac((m<<5)+G|0,i);tb(i);f=(y[d+118|0]&3)!=3?f:f&2?f|4:f}u=u|J;e=e+1|0;F=y[xf(x[n+4>>2])+3|0]==10|F;continue}break}b=N()|0;break A}b=N()|0;break A}b=N()|0;break A}b=N()|0}wc(j)}od(d+156|0);break c}b=N()|0;break c}wc(j);od(d+156|0)}t=t+1|0;continue}}b=N()|0;break a}b=N()|0;break c}b=N()|0;break c}G:{if(!(E&1)){break G}x[31609]=0;c=P(1,d+104|0,16687)|0;e=x[31609];x[31609]=0;H:{if((e|0)!=1){e=x[a+1298472>>2];x[31609]=0;S(385,e|0,2,c|0);e=x[31609];x[31609]=0;if((e|0)==1){break H}tb(c);break G}b=N()|0;break c}b=N()|0;tb(c);break c}x[31609]=0;c=P(412,b|0,5558)|0;e=x[31609];x[31609]=0;if((e|0)==1){break q}if(c){x[31609]=0;c=R(151,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break q}x[31609]=0;V(336,a+1298332|0,b|0,c|0,0);c=x[31609];x[31609]=0;if((c|0)==1){break q}f=f|16}x[31609]=0;o=P(412,b|0,14179)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}if(o){x[31609]=0;c=R(151,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break d}x[31609]=0;e=a+901404|0;S(772,b|0,e|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break d}DD(e);f=f|16}x[31609]=0;c=P(412,b|0,13951)|0;e=x[31609];x[31609]=0;if((e|0)==1){break d}if(!c){break p}x[31609]=0;c=R(151,b|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){w[d+192>>1]=c>>>5;K=d,L=Xj(x[a+484344>>2],x[a+484348>>2]),w[K+72>>1]=L;c=z[Oc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break p}x[31609]=0;j=d+192|0;O(580,b|0,j|0);i=x[31609];x[31609]=0;I:{if((i|0)==1){break I}i=x[a+484344>>2];x[31609]=0;O(581,Wb(i,e)|0,j|0);j=x[31609];x[31609]=0;if((j|0)==1){break I}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31609]=0;c=P(412,b|0,13956)|0;e=x[31609];x[31609]=0;if((e|0)==1){break d}J:{if(!c){break J}x[31609]=0;c=R(151,b|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){w[d+192>>1]=(c>>>0)/20;w[d+72>>1]=z[a+480188>>1];c=a+480280|0;j=z[Oc(d+192|0,d+72|0)>>1];e=0;while(1){if((e|0)==(j|0)){f=f|16;break J}x[31609]=0;S(424,b|0,(c+(e<<5)|0)+9|0,20);i=x[31609];x[31609]=0;if((i|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}c=x[b+8>>2];e=x[b>>2];x[31609]=0;c=U(150,e|0,c|0,8)|0;e=x[31609];x[31609]=0;if((e|0)==1){break d}if(c){c=x[b+8>>2];x[31609]=0;S(425,d+192|0,a|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break h}f=(c|0)==x[b+8>>2]?f:f|16}K:{if(!(f&16)){break K}if(f&4){x[a+1074308>>2]=17367040;x[31609]=0;c=P(1,d+192|0,14729)|0;e=x[31609];x[31609]=0;if((e|0)!=1){zb(l,c);tb(c);break K}b=N()|0;break c}if(!(f&2)){break K}x[a+1074308>>2]=18219008;x[31609]=0;c=P(1,d+192|0,14950)|0;e=x[31609];x[31609]=0;if((e|0)==1){break g}zb(l,c);tb(c)}L:{M:{N:{O:{P:{Q:{R:{if((y[k|0]|y[k+1|0]<<8|(y[k+2|0]<<16|y[k+3|0]<<24))==1852141647&(y[k+4|0]|y[k+5|0]<<8|(y[k+6|0]<<16|y[k+7|0]<<24))==542396493){x[31609]=0;c=U(392,d+72|0,d+542|0,12)|0;e=x[31609];x[31609]=0;if((e|0)==1){break R}x[31609]=0;e=d+156|0;S(258,e|0,1,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break Q}x[31609]=0;f=R(773,e|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break P}x[a+1074308>>2]=f;tb(e);v[a+1074368|0]=A[a+1074308>>2]<19007257?4:5;tb(c);f=24}if(!(!x[a+1074308>>2]|f&8)){v[a+1074368|0]=0;Uv(a+1074312|0)}c=f&32;S:{if(!c){break S}v[a+1074368|0]=5;if(!o){lr(a+901404|0)}if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break S}x[31609]=0;U(266,a+1074312|0,4,1)|0;e=x[31609];x[31609]=0;if((e|0)==1){break d}}if(!Ad(x[l+4>>2],y[l+11|0])){break L}if(!(f&256)|u&255|g+1>>>0>1){break M}x[31609]=0;c=P(1,d+156|0,8292)|0;g=x[31609];x[31609]=0;if((g|0)==1){break N}zb(l,c);tb(c);break L}b=N()|0;break c}b=N()|0;break O}b=N()|0;tb(d+156|0)}tb(c);break c}b=N()|0;break c}if(c){x[31609]=0;c=P(1,d+156|0,12085)|0;g=x[31609];x[31609]=0;if((g|0)!=1){zb(l,c);tb(c);break L}b=N()|0;break c}x[31609]=0;c=P(1,d+156|0,9766)|0;g=x[31609];x[31609]=0;if((g|0)==1){break f}zb(l,c);tb(c)}v[d+67|0]=0;if(z[a+480192>>1]){x[31609]=0;c=P(435,a|0,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break i}v[d+67|0]=c}x[31609]=0;ba(436,a|0,b|0,1,d+67|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break i}e=x[a+1074308>>2];T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if(y[d+67|0]){if(e>>>0>18284543){break fa}x[a+1074308>>2]=18284544;break fa}if(e>>>0<18284544){break ea}}x[31609]=0;c=P(1,d+52|0,18262)|0;b=x[31609];x[31609]=0;if((b|0)==1){break da}g=x[a+1074308>>2];x[31609]=0;b=d+40|0;O(774,b|0,g|0);g=x[31609];x[31609]=0;if((g|0)==1){break ca}x[31609]=0;g=d+92|0;S(2,g|0,c|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break ba}zb(l,g);tb(g);tb(b);tb(c);e=x[a+1074308>>2]}ga:{if(e-1>>>0>19005952){break ga}b=x[a+484344>>2];f=x[a+484348>>2];if(!Je(b,f,254)){b=y[a+484376|0];c=x[a+484360>>2];x[31609]=0;W(775,Xb(c,b)|0);b=x[31609];x[31609]=0;if((b|0)==1){break i}f=x[a+484348>>2];b=x[a+484344>>2]}if(Je(b,f,255)){break ga}UC(Xb(x[a+484360>>2],y[a+484376|0]),255,65535)}x[31609]=0;c=d+40|0;O(776,c|0,4102);b=x[31609];x[31609]=0;if((b|0)==1){break $}b=y[d+554|0]|y[d+555|0]<<8;x[d+12>>2]=b>>>8;x[31609]=0;x[d+24>>2]=b&255;g=d+28|0;O(444,g|0,d+24|0);b=x[31609];x[31609]=0;if((b|0)==1){break _}x[31609]=0;b=d+92|0;V(430,b|0,c|0,d+12|0,g|0);e=x[31609];x[31609]=0;if((e|0)==1){break Z}e=zb(a+1298344|0,b);tb(b);tb(g);Eb(c);f=zb(a+1298368|0,l);K=a,L=x[Fc(b,x[(x[a+1074308>>2]?41072:r)>>2])>>2],x[K+1298404>>2]=L;if(!y[d+483|0]){break U}zb(a+1298380|0,e);x[31609]=0;b=P(1,b|0,15377)|0;k=x[31609];x[31609]=0;if((k|0)==1){break X}zb(e,b);tb(b);x[31609]=0;b=P(1,c|0,10117)|0;c=x[31609];x[31609]=0;if((c|0)==1){break W}zb(a+1298356|0,b);tb(b);x[31609]=0;b=P(1,g|0,10118)|0;c=x[31609];x[31609]=0;if((c|0)==1){break V}zb(a+1298392|0,b);break T}b=N()|0;break c}b=N()|0;break aa}b=N()|0;tb(d+40|0)}tb(c);break c}b=N()|0;break c}b=N()|0;break Y}b=N()|0;tb(d+28|0)}Eb(d+40|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31609]=0;b=P(1,d+92|0,10118)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}zb(a+1298356|0,b)}tb(b);e=1;if(F&1){x[31609]=0;a=P(1,d+12|0,17166)|0;b=x[31609];x[31609]=0;if((b|0)==1){break k}x[31609]=0;P(74,f|0,a|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break j}tb(a)}wc(n);tb(l)}fb=d+576|0;return e|0}b=N()|0;break c}b=N()|0;tb(a);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}wc(n);break a}b=N()|0}tb(l);Q(b|0);p()}function fR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;a:{if(z[x[x[a+48>>2]+12>>2]+480188>>1]!=z[x[x[b+48>>2]+12>>2]+480188>>1]){break a}if((a|0)!=(b|0)){c=x[b>>2];g=x[b+4>>2];d=Hk(c,g);f=fb-16|0;fb=f;b:{if(hw(a)>>>0>=d>>>0){h=x[a>>2];i=Hk(h,x[a+4>>2]);if(i>>>0<d>>>0){e=fb-16|0;fb=e;x[e+12>>2]=c;x[e+12>>2]=x[e+12>>2]+D(i,6);fb=e+16|0;e=x[e+12>>2];uA(c,e,h);sA(a,e,g,d-Hk(x[a>>2],x[a+4>>2])|0);break b}jR(f+8|0,c,g,h);Jd(a,x[f+12>>2]);break b}gR(a);xZ(a,tD(a,d));sA(a,c,g,d)}fb=f+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];eR(a+24|0,b+24|0);FE(a+36|0,b+36|0);if(x[x[x[a+48>>2]+12>>2]+480180>>2]==x[x[x[b+48>>2]+12>>2]+480180>>2]){break a}c=wb(x[a>>2]);x[l+12>>2]=c;m=wb(x[a+4>>2]);while(1){if(!Ib(c,m)){break a}d=0;g=fb-112|0;fb=g;k=x[x[a+48>>2]+12>>2];f=x[k+480180>>2];h=x[x[x[b+48>>2]+12>>2]+480180>>2];c:{if((f|0)==(h|0)){break c}e=y[c+3|0];d:{e:{if((f|0)!=16){break e}i=y[c+5|0];if(!((e|0)!=19|(i|0)!=144)){v[c+3|0]=0;f=1;break d}d=5;f=1;if((e|0)!=5){break e}v[c+5|0]=i>>>1&7|i&240;break d}if(!((h|0)==67108864|(e|0)!=45)){v[c+5|0]=159;d=20;v[c+3|0]=20;break d}if((e|0)!=46){d=e;break d}d=13;v[c+3|0]=13;v[c+5|0]=y[c+5|0]+3>>>2}n=(f|0)==32|(f|0)==16777216|(f|0)==2;f:{g:{h:{i:{j:{k:{if((h|0)==2){e=9;j=1;i=PD(2);if((d&255)!=9){break k}v[c+5|0]=y[c+5|0]+1>>>1;break h}j=(h|0)==32|(h|0)==16777216;e=9;i=PD(h);if((d&255)!=9){break k}if((f|0)!=2){break h}e=y[c+5|0];if((e|0)!=164){break j}v[c+5|0]=145;d=h&16777248?20:28;v[c+3|0]=d;break g}if((d&255)!=32){e=d;break h}d=x[i+84>>2];if(Ui(d,32)){break i}e=31;if(!Ui(d,31)){break i}v[c+3|0]=31;break h}o=c,p=si(e<<1),v[o+5|0]=p;break g}e=32}l:{if((f|0)==16777216){d=y[c|0];m:{if(!Wg(d)){d=e;break m}j=x[i+84>>2];d=(d|0)==252?31:32;if(!Ui(j,d)){d=Ui(j,31)?31:0}w[g+4>>1]=999;o=g,p=Cj(e,y[c+5|0]),w[o+110>>1]=p;o=c,p=(D(z[Oc(g+4|0,g+110|0)>>1],127)>>>0)/999|0,v[o+5|0]=p;v[c+2|0]=0;v[c+3|0]=d;v[c|0]=0;v[c+1|0]=0}n:{o:{p:{e=d&255;switch(e-33|0){case 1:break g;case 2:case 3:break n;case 0:break o;default:break p}}if((e|0)!=20){break g}d=y[c+5|0];if((d&240)!=112|(d&15)>>>0<13){break l}v[c+5|0]=124;break l}d=20;v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>4|208;break g}q:{j=v[c+5|0];r:{if((j|0)>=0){v[c+3|0]=3;e=-128-j|0;d=3;break r}e=128;if((j|0)==-128){break q}v[c+3|0]=2;e=j&127;d=2}v[c+5|0]=e;if((e&255)>>>0>30){break q}v[c+5|0]=e+1>>>1|224;break g}v[g+4|0]=(e&255)+7>>>3;v[g+110|0]=15;o=c,p=y[Qb(g+4|0,g+110|0)|0]|240,v[o+5|0]=p;break g}d=e;s:{switch(f-1|0){case 0:case 3:break s;default:break g}}if(!j){break g}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{d=d&255;switch(d-1|0){case 2:break x;case 1:break y;case 0:break B;default:break C}}D:{switch(d-25|0){case 1:case 2:break f;case 4:break u;case 0:break v;case 3:break w;default:break D}}if((d|0)==13){break z}if((d|0)==19){break A}if((d|0)!=37){break f}v[c+3|0]=0;break f}if(y[c+5|0]){break f}v[c+3|0]=0;break f}Lr(c);break f}E:{switch(y[c+2|0]){case 0:case 1:v[c+2|0]=1;v[c+3|0]=0;d=y[c+5|0];v[c+5|0]=0;v[c+4|0]=d>>>0>=64?64:d;break f;case 2:break E;default:break f}}rg(c+4|0,c+5|0);v[c+2|0]=1;if(y[c+4|0]>=65){v[c+4|0]=64}v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>2|128;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}d=y[c+5|0];e=d-16>>>4|0;if(e>>>0>9){break f}if(!(1<<e&880)){if(!e){break t}if((e|0)!=1){break f}v[c+3|0]=3;v[c+5|0]=d&15|224;break f}v[c+3|0]=20;if(!(h&2)|(d|0)!=145){break f}v[c+5|0]=164;v[c+3|0]=9;break f}if(y[c|0]){break f}v[c+3|0]=20;v[c|0]=(h|0)==2?-2:-1;d=y[c+5|0];if(!d){v[c+1|0]=0}v[c+5|0]=d&15|208;break f}d=y[c+5|0];if(d>>>0>=16){v[g+4|0]=14;v[g+110|0]=d>>>4;o=c,p=y[Qb(g+4|0,g+110|0)|0]|240,v[o+5|0]=p;break f}v[g+4|0]=14;v[g+110|0]=d;o=c,p=y[Qb(g+4|0,g+110|0)|0]<<4|15,v[o+5|0]=p;break f}v[c+3|0]=2;v[c+5|0]=d&15|224;break f}d=20}F:{if(!n){break F}G:{switch(h-1|0){case 0:case 3:break G;default:break F}}H:{I:{switch(y[c|0]-253|0){case 1:v[c|0]=0;if(!(d&255?(h|0)==4:0)){v[c+5|0]=0;v[c+3|0]=13;break f}v[c+4|0]=0;v[c+2|0]=1;break H;case 0:break I;default:break H}}v[c|0]=255}J:{K:{L:{M:{N:{O:{P:{Q:{R:{e=d&255;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:case 10:case 11:case 12:case 14:case 16:case 17:break f;case 13:break J;case 15:break L;case 1:break M;case 0:break N;case 9:break O;case 4:case 5:break P;case 18:break Q;default:break R}}if((e|0)!=29){break f}d=y[c+5|0];e=d&15;if((e|0)!=15|d>>>0<16){break K}v[c+5|0]=d>>>4;break f}S:{if(y[c+3|0]!=20){break S}v[c+3|0]=19;T:{U:{V:{W:{X:{Y:{Z:{_:{d=y[c+5|0];switch(d-16>>>4|0){case 4:case 5:case 8:case 9:break T;case 6:break U;case 10:break V;case 7:break W;case 3:break X;case 2:break Y;case 1:break Z;case 0:break _;default:break S}}v[c+5|0]=d&15|48;break S}v[c+5|0]=d&175^120;break S}v[c+5|0]=d&15|64;break S}v[c+5|0]=d&15|112;break S}v[c+3|0]=9;v[c+5|0]=D(d&15,17);break S}v[c+5|0]=d&15|96;break S}v[c+3|0]=0;break S}v[c+3|0]=28}break f}if(y[c+2|0]){break O}e=y[c+5|0];j=e&15;if(!((j|0)==15&e>>>0>=16)&(!j|(e&240)!=240)){break O}e=11;$:{switch((d&255)-6|0){case 1:e=8;case 0:v[c+2|0]=e;break;default:break $}}v[c+4|0]=0}d=y[c+5|0];e=d&15;if(!((e|0)!=15|d>>>0<16)){v[c+3|0]=19;v[c+5|0]=d>>>4|160;break f}if(!e|(d&240)!=240){break f}v[c+3|0]=19;v[c+5|0]=e|176;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&31;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+3|0]=28;v[c+5|0]=d|16;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|16;break f}v[c+3|0]=2;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&47;break f}if(d>>>0>=224){if((h|0)==4){v[c+3|0]=28;v[c+5|0]=d&47;break f}v[c+3|0]=19;v[c+5|0]=(d&15)+3>>>2|32;break f}v[c+3|0]=3;break f}if(y[c+5|0]>31){break f}v[c+3|0]=0;break f}if(!(!e|(d&240)!=240)){v[c+5|0]=d<<4;break f}if(e){v[c+5|0]=240;break f}if(d){v[c+5|0]=15;break f}v[c+5|0]=0;break f}d=y[c+5|0];if((d-1&255)>>>0>14){break f}v[c+5|0]=d|128;break f}if((f|0)!=16777216&(f|0)!=32|(h|0)!=2){break f}aa:{switch(y[c|0]-253|0){case 0:case 2:v[c|0]=254;break;default:break aa}}ba:{switch((d&255)-20|0){case 0:d=y[c+5|0];e=d&240;if((e|0)!=144){if((e|0)!=112){break f}v[c+3|0]=0;break f}ca:{switch(d-144|0){case 1:v[c+5|0]=164;v[c+3|0]=9;break f;case 0:break ca;default:break f}}v[c+5|0]=64;v[c+3|0]=9;break f;case 3:break ba;default:break f}}v[g+4|0]=128;o=c,p=y[Qb(g+4|0,c+5|0)|0]+1>>>1|0,v[o+5|0]=p}da:{ea:{fa:{ga:{ha:{ia:{ja:{if(!((f|0)!=16777216&(f|0)!=32)){if((h|0)!=4){break ja}d=y[c+3|0];if((d|0)==23){break ia}if((d|0)!=5){break ga}d=y[c+5|0];v[c+5|0]=(d&15)+1>>>1|d&240;break ha}if((f|0)!=4){break ja}ka:{la:{switch(h-1|0){default:if((h|0)==32|(h|0)==16777216){break ka}break;case 1:case 2:break la;case 0:case 3:break ha}}d=y[c+3|0];break ea}d=y[c+3|0];if((d|0)!=23){if((d|0)!=5){break ja}d=y[c+5|0];v[g+4|0]=d<<1&30;v[g+110|0]=15;o=c,p=y[Qb(g+4|0,g+110|0)|0]|d&240,v[o+5|0]=p;break ja}v[g+4|0]=64;o=c,p=y[Qb(g+4|0,c+5|0)|0]<<1,v[o+5|0]=p}ma:{switch(h-1|0){case 0:case 3:break ha;default:break ma}}d=y[c+3|0];break fa}v[g+4|0]=128;o=c,p=y[Qb(g+4|0,c+5|0)|0]+1>>>1|0,v[o+5|0]=p}d=y[c+3|0]}na:{switch((d&255)-16|0){case 0:v[g+4|0]=31;o=c,p=y[Qb(c+5|0,g+4|0)|0],v[o+5|0]=p;d=16;break fa;case 1:break na;default:break fa}}v[g+4|0]=32;o=c,p=y[cf(c+5|0,g+4|0)|0],v[o+5|0]=p;d=17}oa:{if((f|0)!=1){break oa}pa:{qa:{ra:{sa:{ta:{ua:{va:{e=d&255;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:break oa;case 0:case 1:case 9:break sa;case 5:break ta;case 4:break ua;default:break va}}switch(e-19|0){case 1:break qa;case 0:break ra;default:break oa}}d=6;if(y[c+5|0]){break oa}e=4;break pa}d=7;if(y[c+5|0]){break oa}e=5;break pa}if(y[c+5|0]){break oa}e=0;break pa}d=19;j=y[c+5|0];e=j+96|0;e=(e<<4|(e&240)>>>4)&255;if(!(e>>>0>8|!(1<<e&387))){v[c+3|0]=0;d=0}e=0;if(j>>>0>239){break pa}break oa}d=20;e=0;if(y[c+5|0]<240){break oa}}v[c+3|0]=e;d=e}if((h|0)!=1){break ea}wa:{xa:{ya:{za:{Aa:{if(Fl(y[c|0])){v[c|0]=0;Ba:{Ca:{e=d&255;switch(e-15|0){case 1:case 2:case 3:break wa;case 0:break Aa;case 4:break Ba;default:break Ca}}if(e){break wa}v[c+5|0]=0;d=13;v[c+3|0]=13;break wa}f=y[c+5|0];if((f&240)!=208){break ya}v[c+5|0]=f&207;break wa}Da:{e=d&255;switch(e-15|0){case 1:case 2:case 3:break wa;case 4:break za;case 0:break Aa;default:break Da}}if(!e){break xa}break wa}d=19;v[c+3|0]=19;v[c+5|0]=y[c+5|0]&15|144;break wa}f=y[c+5|0]}if((f&255)>>>0<240){break wa}v[c+3|0]=0}d=0;Ea:{switch(y[c+2|0]-1|0){case 0:d=13;v[c+3|0]=13;v[c+5|0]=y[c+4|0];break wa;case 1:d=9;v[c+3|0]=9;e=y[c+4|0];v[c+5|0]=e>>>0>=64?-1:e<<2;break wa;case 3:d=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0];break wa;case 2:d=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;break wa;case 5:d=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|176;break wa;case 4:d=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|160;break wa;case 12:d=3;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;break wa;case 11:d=2;v[c+3|0]=2;v[c+5|0]=y[c+4|0]<<2;break wa;case 10:d=4;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;break wa;case 7:d=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0];break wa;case 6:break Ea;default:break wa}}d=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4}v[c+2|0]=0;break da}if(!(d&255|(h|0)!=2)){d=0;Fa:{switch(y[c+2|0]-3|0){case 1:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0];d=11;break da;case 0:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;d=11;break da;case 3:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]|240;d=11;break da;case 2:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4|15;d=11;break da;case 10:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;d=3;break da;case 9:v[c+2|0]=0;v[c+3|0]=2;d=2;v[c+5|0]=y[c+4|0]<<2;break da;case 8:v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;d=4;break da;case 5:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0];d=5;break da;case 4:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4;d=5;break da;case 6:v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0]<<4;d=29;break da;case 7:break Fa;default:break da}}v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0];d=29;break da}if((h|0)==4){f=y[c|0];if(!(f|(y[c+5|0]&240)!=208|(d&255)!=19)){f=0;v[c+5|0]=0;v[c+3|0]=0;d=0}Ga:{if(Fl(f)){v[c+1|0]=0;e=d&255;if(!e){break Ga}if((e|0)!=19){break da}d=19;e=y[c+5|0];if((e&240)!=208){break da}d=25;v[c+3|0]=25;v[c|0]=0;v[c+5|0]=e&15;break da}if(d&255){break da}}Ha:{switch(y[c+2|0]-11|0){case 2:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;d=3;break da;case 1:v[c+2|0]=0;v[c+3|0]=2;d=2;v[c+5|0]=y[c+4|0]<<2;break da;case 0:break Ha;default:break da}}v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[(y[c+4|0]&15)+42144|0];d=4;break da}if((h|0)!=16777216&(h|0)!=32){break da}Ia:{if(d&255|((f|0)==32|(f|0)==16777216)){break Ia}d=0;Ja:{Ka:{switch(y[c+2|0]-7|0){case 2:v[c+3|0]=29;e=y[c+4|0]<<4;d=29;break Ja;case 3:v[c+3|0]=29;e=y[c+4|0];d=29;break Ja;case 0:v[c+3|0]=5;e=y[c+4|0]<<4;d=5;break Ja;case 4:break Ka;default:break Ia}}v[c+3|0]=4;e=y[c+4|0]<<4;d=4}v[c+2|0]=0;v[c+5|0]=e}e=y[c+2|0];if(e>>>0>15|!(1<<e&47480)){break da}v[g+4|0]=9;o=c,p=y[Qb(c+4|0,g+4|0)|0],v[o+4|0]=p}La:{if(y[c+2|0]!=15){break La}if($v(x[i+88>>2],15)){break La}e=d&255;if(!(!e|(e|0)==10)){if(Ui(x[i+84>>2],e)){break La}}v[c+2|0]=0;v[c+3|0]=10;Ma:{Na:{f=y[c+1|0];if(!f){break Na}d=y[c+5|0];if(z[k+480192>>1]>=f>>>0){h=y[c|0];Oa:{if(!Tc(h)){break Oa}j=x[((f<<2)+k|0)+900380>>2];if(!j){break Oa}f=z[ac(j+236|0,h-1|0)>>1]}if(!(f&65535)){break Na}}f=f&65535;if(f>>>0>z[k+480190>>1]){break Na}h=y[c+4|0];_v(g+4|0);if(h>>>0>9){break Na}d=(e|0)==10?d:0;e=ni(k,f);f=y[c+4|0];if(!f){e=Aua(x[e>>2],0,d&255,0);d=hb;e=e+32768|0;d=e>>>0<32768?d+1|0:d;d=si(Bc((d&65535)<<16|e>>>16,d>>>16|0));break Ma}d=si((x[yb(e+68|0,f-1|0)>>2]+((d&255)<<8)|0)+128>>>8|0);break Ma}d=y[c+4|0]<<3}v[c+5|0]=d;d=y[c+3|0]}Pa:{Qa:{e=d&255;switch(e-42|0){case 0:case 2:break Qa;default:break Pa}}if(Ui(x[i+84>>2],e)){break Pa}d=10;v[c+3|0]=10}f=y[c|0];Ra:{if(f>>>0>=y[i+8|0]){e=1;if(f>>>0<=y[i+9|0]){break Ra}}if(Fl(f)){Sa:{switch(f-253|0){case 1:e=y[i+70|0]!=0;break Ra;case 2:e=y[i+71|0]!=0;break Ra;case 0:e=y[i+72|0]!=0;break Ra;default:break Sa}}e=x[i>>2]==16777216;break Ra}e=!f}if(!e){v[c|0]=0}if(!Ui(x[i+84>>2],d&255)){v[c+3|0]=0}if($v(x[i+88>>2],y[c+2|0])){break c}v[c+2|0]=0}fb=g+112|0;c=x[tg(l+12|0)>>2];continue}}fb=l+16|0;return a}function aka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=0,H=E(0),I=E(0),J=0,K=0;h=fb-32|0;fb=h;c=x[a+1074308>>2];if(!(c>>>0>18285125|(c|0)==18284544)){bg(a+1074312|0,0)}c=h+12|0;i=a+1074312|0;Jb(c,i,0);b=Gb(x[x[h+12>>2]>>2],x[h+16>>2]);d=x[a+480180>>2];Jb(c,i,0);n=(d&16777248)!=0&b;B=Gb(x[x[h+12>>2]>>2],x[h+16>>2]);C=x[a+480180>>2];a:{c=x[a+1074308>>2];if(c>>>0>18874367){break a}d=a+900380|0;c=1;while(1){b:{b=c&65535;if(b>>>0<=z[a+480192>>1]){b=x[d+(b<<2)>>2];if(!b){break b}x[h+12>>2]=D(y[b+20|0],100)>>>6;x[h+24>>2]=100;J=b,K=x[Hb(h+12|0,h+24|0)>>2],v[J+20|0]=K;if(A[a+1074308>>2]>18350079&n){break b}f=v[b+26|0];v[b+26|0]=((f>>31|1)+f|0)/2;if(A[a+1074308>>2]>18285313&n){break b}ED(Wh(b,2),x[a+480180>>2]);f=x[a+1074308>>2];c:{if(f>>>0<18284544){break c}if(f>>>0>18285135){break b}if(!y[b+34|0]){break c}if(!Jj(y[b+31|0])){break c}Lb(i,2,1);if(A[a+1074308>>2]>18285135){break b}}if(!(y[b+24|0]|(y[b+23|0]|(y[b+19|0]|y[b+20|0])))){break b}Lb(i,1,1)}d:{if(!(x[a+480180>>2]&16777248)|A[a+1074308>>2]>18285313&n){break d}c=z[a+480190>>1]+1&65535;d=c>>>0<=1?1:c;f=a+484380|0;b=1;while(1){if((b|0)==(d|0)){break d}c=f+D(b,104)|0;if(!(y[c+39|0]|!(y[c+41|0]|y[c+40|0]))){v[c+39|0]=255}b=b+1|0;continue}}c=a+901404|0;d=c+288|0;b=mV(d);while(1){if((b|0)==(d|0)){e:{d=c+800|0;c=wC(d);while(1){if((c|0)==(d|0)){break e}lV(d);d=d+32|0;continue}}}else{lV(d);d=d+32|0;continue}break}c=x[a+1074308>>2];break a}c=c+1|0;continue}}f:{if(!(x[a+480180>>2]&16777252)|((c|0)==18874368|c>>>0>18874895)){break f}b=z[a+480192>>1]+1&65535;f=b>>>0<=1?1:b;g=a+900380|0;b=1;while(1){if((b|0)==(f|0)){if(!(e&1)){break f}Lb(i,3,1);c=x[a+1074308>>2]}else{d=x[g+(b<<2)>>2];if(!(!d|!y[d+31|0])){v[d+33|0]=13;e=1}b=b+1|0;continue}break}}g:{if(!(x[a+480180>>2]&16777248)|((c|0)==19005440|c>>>0>19006225)){break g}Jb(h+12|0,i,0);if(!Gb(x[x[h+12>>2]>>2],x[h+16>>2])){Jb(h+24|0,i,1);if(!Gb(x[x[h+24>>2]>>2],x[h+28>>2])){break g}}c=z[a+480192>>1]+1&65535;d=c>>>0<=1?1:c;e=a+900380|0;b=1;while(1){if((b|0)==(d|0)){break g}c=x[e+(b<<2)>>2];if(!(!c|!y[c+19|0]|!(v[c+80|0]&1))){v[c+19|0]=0}b=b+1|0;continue}}e=x[a+480180>>2];h:{i:{if(!(e&16777252)){break i}c=a+906300|0;f=uk(c);b=c;while(1){if((b|0)==(f|0)){break i}d=b;b=b+160|0;if(!Mi(y[d+16|0]|y[d+17|0]<<8|(y[d+18|0]<<16|y[d+19|0]<<24),y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24))){continue}break}s=1;d=x[a+1074308>>2];if(d>>>0>19007232){break h}while(1){if((c|0)!=(f|0)){d=h+12|0;b=fb-32|0;fb=b;e=b+8|0;k=c+80|0;VR(e,k);x[31609]=0;g=b+20|0;S(123,g|0,22,e|0);m=x[31609];x[31609]=0;j:{k:{l:{if((m|0)!=1){x[31609]=0;S(244,d|0,0,g|0);m=x[31609];x[31609]=0;if((m|0)==1){break l}Ub(g);tb(e);fb=b+32|0;break j}a=N()|0;break k}a=N()|0;Ub(b+20|0)}tb(b+8|0);Q(a|0);p()}rw(k,d);c=c+160|0;tb(d);continue}break}e=x[a+480180>>2]}d=x[a+1074308>>2]}m:{n:{o:{p:{q:{if((e|0)!=4){break q}if(d>>>0<19007257){break p}if(y[a+1074368|0]!=4|d>>>0>19071235){break q}SA(a,5);d=x[a+1074308>>2]}if(d>>>0>19202054){break o}c=19202048;if((d|0)==19202048){break n}}c=z[a+480192>>1]+1&65535;f=c>>>0<=1?1:c;g=a+900380|0;c=1;while(1){if((c|0)==(f|0)){break o}e=x[g+(c<<2)>>2];r:{if(!e|!y[e+20|0]|!y[e+31|0]){break r}b=e+236|0;k=ur(b);while(1){if((b|0)!=(k|0)){m=z[b>>1];b=b+2|0;if(!m){continue}break r}break}v[e+20|0]=0}c=c+1|0;continue}}c=d;if(c>>>0>19267583){break m}}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;f=a+900380|0;b=1;while(1){if((b|0)==(e|0)){break m}d=x[f+(b<<2)>>2];s:{if(!d){break s}c=v[d+26|0];v[d+26|0]=((c>>31|1)+c|0)/2;c=x[a+1074308>>2];if(c>>>0>18350079&n){break s}v[d+19|0]=y[d+19|0]+3>>>2}b=b+1|0;continue}}t:{if(c>>>0>19398673){break t}d=a+900380|0;e=z[a+480192>>1];b=1;while(1){f=b&65535;if(f>>>0>e>>>0){break t}f=x[d+(f<<2)>>2];if(!f|y[f+65|0]==255){b=b+1|0;continue}else{Lb(i,94,1);c=x[a+1074308>>2]}break}}u:{if(c>>>0>19399427){break u}d=a+900380|0;e=z[a+480192>>1];b=1;while(1){f=b&65535;if(f>>>0>e>>>0){break u}f=x[d+(f<<2)>>2];if(!f|y[f+36|0]>1){b=b+1|0;continue}else{Lb(i,101,1);c=x[a+1074308>>2]}break}}v:{if(c>>>0>19923027){break v}d=a+484380|0;e=z[a+480190>>1];b=1;while(1){c=b&65535;if(c>>>0>e>>>0){break v}c=d+D(c,104)|0;if(!le(x[c>>2],x[c+20>>2])|!(y[c+34|0]&20)){b=b+1|0;continue}else{Lb(i,116,1)}break}}c=fb-16|0;fb=c;w[h+4>>1]=0;x[h>>2]=a;Jb(c+8|0,a+1074312|0,0);J=h,K=Gb(x[x[c+8>>2]>>2],x[c+12>>2]),v[J+6|0]=K;fb=c+16|0;c=x[h>>2];u=x[h+4>>2];f=fb-32|0;fb=f;b=a+484344|0;d=wb(x[b>>2]);x[f+28>>2]=d;F=wb(x[b+4>>2]);while(1){if(Ib(d,F)){b=wb(x[d>>2]);G=wb(x[d+4>>2]);x[f+16>>2]=c;x[f+20>>2]=u;x[f>>2]=c;x[f+4>>2]=u;m=fb-16|0;fb=m;x[m+12>>2]=b;while(1){if(Ib(b,G)){t=z[f+4>>1];d=t+1|0;w[f+4>>1]=d;e=x[f>>2];w[f+4>>1]=z[e+480188>>1]>(d&65535)>>>0?d:0;w:{if(Wg(y[b|0])){break w}g=x[e+1074308>>2];x:{k=x[e+480180>>2];y:{z:{if((k|0)==2){if(g>>>0>18415615){break z}if(y[b+3|0]!=23){break y}Of(b+5|0,64);break y}A:{if(k&16777248){B:{C:{if(g>>>0>=18285314){if(y[f+6|0]){break C}e=0;d=0;if(g>>>0>18874367){break B}}D:{switch(y[b+3|0]-20|0){case 3:Of(b+5|0,128);break C;case 0:break D;default:break C}}d=y[b+5|0];if((d|0)!=208){if((d|0)!=192){break C}v[b|0]=254;v[b+3|0]=0;break C}v[b+3|0]=0}E:{F:{G:{if(g>>>0>=18350080){if(y[f+6|0]){break G}e=0;d=0;if(g>>>0>18874367){break B}}d=y[b+3|0];if(d>>>0>29){break F}e=1;if(!(1<<d&536873152)){break F}break E}e=0;d=0;if(g>>>0>18874367){break B}d=y[b+3|0]}e=0}d=(d|0)==24|(d|0)==22}H:{if(!(d|e)){break H}e=y[b+5|0];d=e&15;if(!d|(d|0)==15){break H}e=e&240;if(!e|(e|0)==240){break H}v[b+5|0]=y[b+3|0]==24?e:d}I:{if((g|0)==19005440|g>>>0>19005699){break I}d=z[x[f>>2]+480192>>1];if(y[f+6|0]|(!d|d>>>0>=y[b+1|0])){break I}v[b+4|0]=0;v[b+2|0]=1}if(y[b+3|0]!=18|y[b+5|0]!=17){break z}if(g>>>0>19468801){break x}if(!Ob(x[f>>2]+1074312|0,22)|y[x[f>>2]+480208|0]&4){break z}d=b+5|0;break A}if((k|0)!=4){break z}d=!y[f+6|0];J:{if((d|g>>>0<18285314)&g>>>0<=18874367){break J}if(g>>>0>19137025){break x}if(y[b+3|0]!=23|y[b+5|0]<65){break J}v[b+3|0]=0}K:{L:{M:{if(!(!(d&g>>>0<18874368)&g>>>0>=18415616)){e=y[b+3|0];d=y[b+2|0];if((e|0)!=10|(d|0)!=11){break M}e=0;v[b+3|0]=0;break K}if(g>>>0>18874639){break L}e=y[b+3|0];d=y[b+2|0]}if((d|0)!=11|(e|0)!=4){break K}d=y[b+4|0];if(!(d|y[f+6|0])){e=4;break K}e=4;o=y[b+5|0];if(!o){break K}v[b+2|0]=0;J=b,K=ew(o+(d<<4)|0),v[J+5|0]=K;break K}if(g>>>0>19007240){break x}e=y[b+3|0]}if(y[b+5|0]|(e|0)!=16){break z}d=b+3|0}v[d|0]=0}if(g>>>0>18874367){break x}}e=y[b+3|0];d=y[b+5|0]&240;N:{O:{if((e|0)!=28|(d|0)!=96){o=0}else{if(!y[f+6|0]|(k|0)!=4){break O}o=g>>>0<18350080}if(!(o|(e|0)==20&(d|0)==96)){break N}}e=D(t,-6)+b|0;while(1){if(b>>>0>e>>>0){if(!((y[e+3|0]|8)!=28|(y[e+5|0]&240)!=96)){v[e+3|0]=0}e=e+6|0;continue}break}e=y[b+3|0]}if((e|0)!=20|(d|0)!=224){break x}e=D(t,-6)+b|0;while(1){if(b>>>0<=e>>>0){break x}if(!(y[e+3|0]!=20|(y[e+5|0]&240)!=224)){v[e+3|0]=0}e=e+6|0;continue}}d=y[b+2|0];if(!((d|0)!=8|g>>>0>19333174|(g|0)==19333120)){e=y[b+4|0];d=y[b+3|0];if(!(!e|(d|0)!=7)){v[b+3|0]=11;break w}P:{Q:{switch(d-5|0){default:if((d|0)!=26){break w}break;case 1:break w;case 2:break P;case 0:break Q}}g=y[b+5|0];if(!(g&15)){v[b+2|0]=0;v[b+3|0]=5;v[b+5|0]=g|e&15;break w}R:{switch(d-5|0){case 1:break w;case 0:case 2:break P;default:break R}}if((d|0)!=26){break w}}v[b+2|0]=0;break w}S:{if(!((k|0)==16777216|(d|0)!=15)){e=y[b+3|0];if(e){break S}v[b+2|0]=0;v[b+3|0]=10;v[b+5|0]=y[b+4|0]<<3;break w}if((d|0)!=15){break w}e=y[b+3|0]}if((e&255)!=10|g>>>0>19922963){break w}if(y[b+4|0]?y[b+5|0]:1){v[b+2|0]=0;break w}v[b+3|0]=0}b=x[tg(m+12|0)>>2];continue}break}b=x[f+4>>2];x[f+8>>2]=x[f>>2];x[f+12>>2]=b;fb=m+16|0;d=x[Ul(f+28|0)>>2];continue}else{fb=f+32|0}break}T:{c=A[a+1074308>>2]<19267584;if(c&n){b=0;while(1){if((b|0)==344){break T}c=x[a+1074308>>2];d=x[b+40244>>2];Lb(i,x[b+40240>>2],c>>>0>=d>>>0|(c|0)==(d&-65536));b=b+8|0;continue}}if(!(c&((C|0)==4&B))){break T}b=0;while(1){if((b|0)==240){break T}Lb(i,x[b+40592>>2],A[a+1074308>>2]>=A[b+40596>>2]);b=b+8|0;continue}}U:{c=x[a+480180>>2];if(c&16777248){b=0;while(1){if((b|0)==72){break U}c=x[a+1074308>>2];d=x[b+40836>>2];e=d&-65536;if(!(c>>>0>=e>>>0&(c>>>0<=e>>>0|c>>>0>=d>>>0))){bg(i,x[b+40832>>2])}b=b+8|0;continue}}b=0;V:{switch(c-2|0){case 2:while(1){if((b|0)==64){break U}if(A[a+1074308>>2]<A[b+40916>>2]){bg(i,x[b+40912>>2])}b=b+8|0;continue};case 0:break V;default:break U}}while(1){if((b|0)==96){break U}if(A[a+1074308>>2]<A[b+40980>>2]){bg(i,x[b+40976>>2])}b=b+8|0;continue}}b=x[a+1074308>>2];if(!(x[a+480180>>2]!=4|b>>>0>18415615)){Lb(i,98,1);b=x[a+1074308>>2]}if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){c=b+77|0;Jb(h+12|0,i,c);bg(Lb(i,b+86|0,Gb(x[x[h+12>>2]>>2],x[h+16>>2])),c);b=b+1|0;continue}break}b=x[a+1074308>>2]}c=8;W:{if(b>>>0>=18284544){if(b>>>0>18874627){break W}c=6;if((b|0)==18874368){break W}}Lb(i,c,1)}c=x[a+1074308>>2];X:{if(y[a+480208|0]&16){if(c>>>0<=19136511){bg(i,7);break X}if(!(x[a+480180>>2]&16777248)|c>>>0>19267583){break X}Lb(i,7,1);break X}if((c|0)==19922944|c>>>0>19922997){break X}bg(i,7)}Jb(h+12|0,i,31);Y:{if(!Gb(x[x[h+12>>2]>>2],x[h+16>>2])){break Y}c=x[a+1074308>>2];if(c>>>0<19071234|c>>>0>19398722){break Y}d=a+900380|0;e=z[a+480192>>1];b=1;while(1){c=b&65535;if(c>>>0>e>>>0){break Y}Z:{c=x[d+(c<<2)>>2];if(!c){break Z}f=y[c+65|0];if(!(y[c+60|0]&4)|(f|0)==255|f>>>0<=y[c+64|0]){break Z}Lb(i,97,1);break Y}b=b+1|0;continue}}c=x[a+480180>>2];_:{if(!(c&16777218)){break _}d=a+484380|0;e=z[a+480190>>1];b=1;while(1){f=b&65535;if(f>>>0>e>>>0){break _}b=b+1|0;if(!(y[(d+D(f,104)|0)+35|0]&2)){continue}break}$:{aa:{ba:{if(!(!z[a+480192>>1]|(c|0)!=16777216)){b=x[a+1074308>>2];if(b>>>0<19398688){break aa}if(b>>>0>19464277){break ba}Lb(i,109,1)}b=x[a+1074308>>2]}if((b|0)==19922944|b>>>0>19922996){break $}}bg(i,111);b=x[a+1074308>>2]}c=x[a+480180>>2];if(!((c|0)!=2|b>>>0>19464191)){Lb(i,108,1);break _}if((c|0)==2){break _}bg(i,108)}ca:{c=x[a+1074308>>2];if(c-19333186>>>0<=589827){if(!s){break ca}b=a+906300|0;c=uk(b);while(1){if((b|0)!=(c|0)){da:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-271958638){break da}if((Xc(x[b+4>>2],x[b+8>>2])|0)!=32){break da}d=Dc(h+12|0,16887);rw(b+80|0,d);tb(d)}b=b+160|0;continue}break}c=x[a+1074308>>2]}e=!s;ea:{if(e|c>>>0>19923027){break ea}f=a+900380|0;g=z[a+480192>>1];b=1;while(1){d=b&65535;if(d>>>0>g>>>0){break ea}d=x[f+(d<<2)>>2];if(!d|y[d+30|0]!=1&z[d+28>>1]!=1){b=b+1|0;continue}else{Lb(i,121,1);c=x[a+1074308>>2]}break}}b=!s;if(!(e|c>>>0>19988488)){Lb(i,117,1);c=x[a+1074308>>2]}if(c-19333120>>>0>591359|b){break ca}b=a+906300|0;d=uk(b);while(1){if((b|0)==(d|0)){break ca}fa:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-281111764){break fa}a=x[b+4>>2];if((Xc(a,x[b+8>>2])|0)!=24){break fa}H=Pd(E(E(E((l(2,y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));I=Pd(E(E(E((l(2,y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));c=(q(H),j(2));v[a+12|0]=c;v[a+13|0]=c>>>8;v[a+14|0]=c>>>16;v[a+15|0]=c>>>24;a=x[b+4>>2];c=(q(I),j(2));v[a+16|0]=c;v[a+17|0]=c>>>8;v[a+18|0]=c>>>16;v[a+19|0]=c>>>24}b=b+160|0;continue}}fb=h+32|0}function tP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=fb-32|0;fb=j;a:{b:{c:{d:{e:{f:{if(Nd(b,22292)){Fb(a);break f}if(Nd(b,9909)){b=fb-96|0;fb=b;g=Fb(a);x[31609]=0;W(128,b- -64|0);a=x[31609];x[31609]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((a|0)!=1){x[31609]=0;x[b+40>>2]=0;a=b+52|0;c=b+40|0;O(1117,a|0,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break C}x[31609]=0;d=P(838,g|0,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break B}tb(a);x[31609]=0;d=P(985,d|0,16806)|0;f=x[31609];x[31609]=0;if((f|0)==1){break A}x[31609]=0;x[b+40>>2]=8;O(1117,a|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break z}x[31609]=0;d=P(838,d|0,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break y}tb(a);x[31609]=0;d=P(985,d|0,16806)|0;f=x[31609];x[31609]=0;if((f|0)==1){break A}x[31609]=0;x[b+40>>2]=0;O(1117,a|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break x}x[31609]=0;d=P(838,d|0,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break w}tb(a);x[31609]=0;f=P(985,d|0,15114)|0;d=x[31609];x[31609]=0;if((d|0)==1){break A}d=Nb(a);a=x[b+76>>2];if(a){x[31609]=0;x[b+16>>2]=a;a=b+28|0;O(1117,a|0,b+16|0);h=x[31609];x[31609]=0;if((h|0)==1){break v}x[31609]=0;S(1011,c|0,8980,a|0);h=x[31609];x[31609]=0;if((h|0)==1){break u}x[31609]=0;O(178,d|0,c|0);h=x[31609];x[31609]=0;if((h|0)==1){break t}tb(c);tb(a)}if(!Id(y[b+80|0])){break p}x[31609]=0;c=P(36,b+40|0,12854)|0;a=x[31609];x[31609]=0;if((a|0)==1){break r}x[31609]=0;O(178,d|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break q}tb(c);break o}a=N()|0;break h}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break j}a=N()|0;break s}a=N()|0;tb(b+40|0)}tb(b+28|0);break j}a=N()|0;break j}a=N()|0;tb(c);break j}if(!Id(y[b+81|0])){break o}x[31609]=0;c=P(36,b+40|0,12625)|0;a=x[31609];x[31609]=0;if((a|0)==1){break n}x[31609]=0;O(178,d|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break m}tb(c)}if(Id(y[b+82|0])){break l}break k}a=N()|0;break j}a=N()|0;tb(c);break j}x[31609]=0;c=P(36,b+28|0,11144)|0;a=x[31609];x[31609]=0;D:{if((a|0)!=1){x[31609]=0;O(178,d|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break D}tb(c);break k}a=N()|0;break j}a=N()|0;tb(c);break j}if(mc(x[d>>2],x[d+4>>2])){break g}x[31609]=0;f=P(985,f|0,16836)|0;a=x[31609];x[31609]=0;if((a|0)!=1){x[31609]=0;c=P(36,b+4|0,16806)|0;a=x[31609];x[31609]=0;E:{F:{G:{if((a|0)!=1){x[31609]=0;a=b+16|0;S(1118,a|0,d|0,c|0);h=x[31609];x[31609]=0;if((h|0)==1){break G}x[31609]=0;P(838,f|0,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break F}tb(a);tb(c);break g}a=N()|0;break j}a=N()|0;break E}a=N()|0;tb(b+16|0)}tb(c);break j}a=N()|0}Td(d)}xg(b- -64|0)}tb(g);break a}Td(d);xg(b- -64|0);fb=b+96|0;break f}if(Nd(b,8132)){x[j>>2]=0;br(a,j);break f}if(Nd(b,8110)){x[j>>2]=8;br(a,j);break f}if(Nd(b,10869)){x[j>>2]=0;br(a,j);break f}if(Nd(b,10641)){Dc(a,15114);break f}if(Nd(b,11419)){Dc(a,15869);break f}if(Nd(b,7412)){b=fb-48|0;fb=b;d=b+24|0;MG(d);x[31609]=0;c=b+12|0;W(145,c|0);g=x[31609];x[31609]=0;H:{I:{J:{K:{if((g|0)!=1){x[31609]=0;g=b+36|0;S(146,g|0,d|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break K}x[31609]=0;O(1059,a|0,g|0);a=x[31609];x[31609]=0;if((a|0)==1){break J}tb(g);tb(c);tb(d);fb=b+48|0;break f}a=N()|0;break H}a=N()|0;break I}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(b+24|0);break a}if(Nd(b,9925)){b=fb-16|0;fb=b;f=fb-16|0;fb=f;x[f+12>>2]=101;h=b+4|0;d=fb-96|0;fb=d;g=Nb(d+84|0);L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{c=x[f+12>>2];if(c&1){x[31609]=0;c=d+52|0;O(134,c|0,20054022);e=x[31609];x[31609]=0;if((e|0)==1){break _}x[31609]=0;O(101,g|0,c|0);e=x[31609];x[31609]=0;if((e|0)==1){break Z}tb(c);c=x[f+12>>2]}if(!(c&4)){break X}x[31609]=0;c=ca(135)|0;e=x[31609];x[31609]=0;if((e|0)==1){break W}if(!c){break Y}break X}c=N()|0;break M}c=N()|0;tb(d+52|0);break M}x[31609]=0;c=d+52|0;W(136,c|0);e=x[31609];x[31609]=0;$:{if((e|0)!=1){x[31609]=0;O(101,g|0,c|0);e=x[31609];x[31609]=0;if((e|0)==1){break $}tb(c);break X}c=N()|0;break M}c=N()|0;tb(d+52|0);break M}aa:{c=x[f+12>>2];if(!(c&32)){break aa}x[31609]=0;e=d+52|0;W(128,e|0);c=x[31609];x[31609]=0;ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{if((c|0)!=1){x[31609]=0;c=d+40|0;O(137,c|0,e|0);i=x[31609];x[31609]=0;if((i|0)==1){break ca}i=Ad(x[d+44>>2],y[d+51|0]);tb(c);if(!i){x[31609]=0;i=d+28|0;W(138,i|0);k=x[31609];x[31609]=0;if((k|0)==1){break ta}x[31609]=0;k=d+16|0;O(137,k|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break sa}x[31609]=0;S(139,c|0,i|0,k|0);e=x[31609];x[31609]=0;if((e|0)==1){break ra}x[31609]=0;O(101,g|0,c|0);e=x[31609];x[31609]=0;if((e|0)==1){break qa}tb(c);tb(k);Eb(i)}c=Np(d+52|0);if(!Ad(x[c+4>>2],y[c+11|0])){x[31609]=0;e=d+28|0;W(140,e|0);i=x[31609];x[31609]=0;if((i|0)==1){break na}x[31609]=0;i=d+40|0;S(141,i|0,e|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break ma}x[31609]=0;O(101,g|0,i|0);c=x[31609];x[31609]=0;if((c|0)==1){break la}tb(i);Eb(e)}x[31609]=0;c=d+40|0;k=d+52|0;O(142,c|0,k|0);e=x[31609];x[31609]=0;if((e|0)==1){break ja}e=Ad(x[d+44>>2],y[d+51|0]);tb(c);if(!e){x[31609]=0;e=d+28|0;W(138,e|0);i=x[31609];x[31609]=0;if((i|0)==1){break ia}x[31609]=0;i=d+16|0;O(142,i|0,k|0);k=x[31609];x[31609]=0;if((k|0)==1){break ha}x[31609]=0;S(139,c|0,e|0,i|0);k=x[31609];x[31609]=0;if((k|0)==1){break ga}x[31609]=0;O(101,g|0,c|0);k=x[31609];x[31609]=0;if((k|0)==1){break fa}tb(c);tb(i);Eb(e)}xg(d+52|0);c=x[f+12>>2];break aa}c=N()|0;break M}c=N()|0;break ba}c=N()|0;break oa}c=N()|0;break pa}c=N()|0;tb(d+40|0)}tb(d+16|0)}Eb(d+28|0);break ba}c=N()|0;break ba}c=N()|0;break ka}c=N()|0;tb(d+40|0)}Eb(d+28|0);break ba}c=N()|0;break ba}c=N()|0;break ba}c=N()|0;break da}c=N()|0;break ea}c=N()|0;tb(d+40|0)}tb(d+16|0)}Eb(d+28|0);break ba}c=N()|0}xg(d+52|0);break M}ua:{if(!(c&64)){break ua}x[31609]=0;c=ca(135)|0;e=x[31609];x[31609]=0;if((e|0)==1){break W}if(c){break ua}c=d+52|0;Fb(c);x[31609]=0;O(101,g|0,c|0);e=x[31609];x[31609]=0;if((e|0)==1){break N}tb(c)}if(y[f+12|0]&128){x[31609]=0;c=d+52|0;W(143,c|0);e=x[31609];x[31609]=0;if((e|0)==1){break V}x[31609]=0;O(101,g|0,c|0);e=x[31609];x[31609]=0;if((e|0)==1){break U}tb(c)}x[31609]=0;e=P(1,d+52|0,22292)|0;c=x[31609];x[31609]=0;if((c|0)==1){break T}x[31609]=0;c=d+4|0;S(144,c|0,g|0,e|0);i=x[31609];x[31609]=0;if((i|0)==1){break S}x[31609]=0;i=d+40|0;W(145,i|0);k=x[31609];x[31609]=0;if((k|0)==1){break R}x[31609]=0;S(146,h|0,c|0,i|0);k=x[31609];x[31609]=0;if((k|0)==1){break Q}tb(i);tb(c);tb(e);Td(g);fb=d+96|0;break L}c=N()|0;break M}c=N()|0;break M}c=N()|0;tb(d+52|0);break M}c=N()|0;break M}c=N()|0;break O}c=N()|0;break P}c=N()|0;tb(d+40|0)}tb(d+4|0)}tb(e);break M}c=N()|0;tb(d+52|0)}Td(g);Q(c|0);p()}fb=f+16|0;x[31609]=0;O(1059,a|0,h|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(h);fb=b+16|0;break f}break c}if(Nd(b,10541)){b=fb-48|0;fb=b;d=b+4|0;us(d);x[31609]=0;c=b+36|0;O(137,c|0,d|0);g=x[31609];x[31609]=0;va:{wa:{if((g|0)!=1){x[31609]=0;O(1059,a|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break wa}tb(c);xg(d);fb=b+48|0;break f}a=N()|0;break va}a=N()|0;tb(b+36|0)}xg(b+4|0);break a}if(Nd(b,11382)){b=fb-32|0;fb=b;us(b);x[31609]=0;O(1119,a|0,Np(b)|0);a=x[31609];x[31609]=0;if((a|0)!=1){xg(b);fb=b+32|0;break f}a=N()|0;xg(b);break a}if(Nd(b,9938)){b=fb-48|0;fb=b;d=b+16|0;us(d);c=x[b+28>>2];xa:{if(c){x[31609]=0;x[b+12>>2]=c;O(1117,a|0,b+12|0);a=x[31609];x[31609]=0;if((a|0)!=1){break xa}a=N()|0;xg(d);break a}Fb(a)}xg(b+16|0);fb=b+48|0;break f}if(Nd(b,12844)){us(j);b=y[j+16|0];x[31609]=0;P(36,a|0,(Id(b)?15566:15869)|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}xg(j);break f}if(Nd(b,9954)){us(j);b=y[j+17|0];x[31609]=0;P(36,a|0,(Id(b)?15566:15869)|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){xg(j);break f}break e}if(Nd(b,12297)){us(j);b=y[j+18|0];x[31609]=0;P(36,a|0,(Id(b)?15566:15869)|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){xg(j);break f}break e}if(Nd(b,12599)){b=fb-16|0;fb=b;d=fb-32|0;fb=d;g=b+4|0;c=Fb(g);x[31609]=0;W(128,d|0);f=x[31609];x[31609]=0;ya:{za:{if((f|0)!=1){x[31609]=0;O(129,c|0,Np(d)|0);f=x[31609];x[31609]=0;if((f|0)==1){break za}xg(d);fb=d+32|0;break ya}a=N()|0;break b}a=N()|0;xg(d);break b}x[31609]=0;O(1059,a|0,g|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(g);fb=b+16|0;break f}break c}if(Nd(b,8253)){b=fb-16|0;fb=b;d=fb-48|0;fb=d;g=b+4|0;c=Fb(g);x[31609]=0;f=d+24|0;O(131,f|0,4135);h=x[31609];x[31609]=0;Aa:{Ba:{Ca:{Da:{if((h|0)!=1){x[d+20>>2]=19;x[d+16>>2]=0;x[31609]=0;x[d+12>>2]=0;h=d+36|0;aa(132,h|0,f|0,d+20|0,d+16|0,d+12|0);e=x[31609];x[31609]=0;if((e|0)==1){break Da}x[31609]=0;P(74,c|0,h|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break Ca}tb(h);Eb(f);fb=d+48|0;break Aa}a=N()|0;break b}a=N()|0;break Ba}a=N()|0;tb(d+36|0)}Eb(d+24|0);break b}x[31609]=0;O(1059,a|0,g|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(g);fb=b+16|0;break f}break c}if(Nd(b,6857)){b=fb-16|0;fb=b;c=b+4|0;d=fb-32|0;fb=d;g=d+8|0;Dc(g,20215);x[31609]=0;f=d+20|0;S(123,f|0,0,g|0);h=x[31609];x[31609]=0;Ea:{Fa:{Ga:{if((h|0)!=1){x[31609]=0;O(12,c|0,f|0);h=x[31609];x[31609]=0;if((h|0)==1){break Ga}Ub(f);tb(g);fb=d+32|0;break Ea}a=N()|0;break Fa}a=N()|0;Ub(d+20|0)}tb(d+8|0);break a}x[31609]=0;O(1059,a|0,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(c);fb=b+16|0;break f}break c}if(Nd(b,6455)){b=fb-48|0;fb=b;d=uc(b+24|0,18299);x[31609]=0;c=b+12|0;O(1120,c|0,2);g=x[31609];x[31609]=0;Ha:{Ia:{Ja:{Ka:{if((g|0)!=1){x[31609]=0;g=b+36|0;S(2,g|0,d|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break Ka}x[31609]=0;O(1059,a|0,g|0);a=x[31609];x[31609]=0;if((a|0)==1){break Ja}tb(g);tb(c);tb(d);fb=b+48|0;break f}a=N()|0;break Ha}a=N()|0;break Ia}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(d);break a}if(Nd(b,11405)){b=fb-16|0;fb=b;d=fb-16|0;fb=d;Dc(d+4|0,18615);f=b+4|0;g=Fb(f);h=y[d+15|0];e=x[d+8>>2];x[31609]=0;O(93,g|0,yh(e,h)|0);h=x[31609];x[31609]=0;La:{if((h|0)!=1){Ma:{while(1){if(yh(x[d+8>>2],y[d+15|0])>>>0>c>>>0){h=y[ec(d+4|0,c)|0];x[31609]=0;O(95,g|0,h|0);h=x[31609];x[31609]=0;if((h|0)==1){break Ma}c=c+1|0;continue}break}tb(d+4|0);fb=d+16|0;break La}}a=N()|0;tb(g);tb(d+4|0);break a}x[31609]=0;O(1059,a|0,f|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(f);fb=b+16|0;break f}break c}if(Nd(b,10548)){b=fb-16|0;fb=b;d=b+4|0;qs(d,0);x[31609]=0;O(1059,a|0,d|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(d);fb=b+16|0;break f}break c}if(Nd(b,10523)){b=fb-16|0;fb=b;d=b+4|0;qs(d,2);x[31609]=0;O(1059,a|0,d|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(d);fb=b+16|0;break f}break c}if(Nd(b,10508)){b=fb-16|0;fb=b;d=b+4|0;qs(d,3);x[31609]=0;O(1059,a|0,d|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(d);fb=b+16|0;break f}break c}Fb(a)}fb=j+32|0;break d}a=N()|0;xg(j);break a}return}a=N()|0;tb(b+4|0);break a}tb(c)}Q(a|0);p()}function rta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;e=fb-416|0;fb=e;yc(b);d=e+399|0;f=C0(b,d);if(!f){IE(d)}a:{b:{c:{d:{e:{f:{if(!f){break f}if(!$_(d)){break f}if(!Mb(x[b>>2],x[b+8>>2],Bc(72,0))){break f}g=1;if((c|0)==64){break f}Dd(a,1);x[a+480208>>2]=x[a+480208>>2]&-25231361|16842752;g=y[e+408|0];w[a+480190>>1]=63;w[a+480188>>1]=g;f=a+480280|0;d=0;g:{h:{i:{while(1){if((g&65535)>>>0<=d>>>0){j:{Rb(e+320|0,0,64);r=a+484380|0;d=1;k:{l:{m:{n:{while(1){o:{f=d&65535;if(f>>>0>z[a+480190>>1]){KE(b,a+1298308|0);a$(e+312|0,b);q=Nb(e+300|0);f=y[e+409|0]|y[e+410|0]<<8;if(f){d=Nb(e+212|0);x[31609]=0;f=U(326,b|0,d|0,D(f,y[e+408|0])<<1)|0;h=x[31609];x[31609]=0;if((h|0)==1){break k}if(!f){break j}se(e+272|0,x[d>>2],x[d+4>>2]);f=Md(e+264|0);x[31609]=0;h=x[f+4>>2];x[e+40>>2]=x[f>>2];x[e+44>>2]=h;f=hg(327,e+280|0,x[e+272>>2],x[e+276>>2],e+40|0);h=x[31609];x[31609]=0;if((h|0)==1){break o}h=x[d+4>>2];g=x[d>>2];x[31609]=0;U(213,f|0,q|0,Xc(g,h)>>>1|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break n}ub(f);fc(d)}n=Nb(e+252|0);x[31609]=0;O(328,n|0,(y[e+411|0]|y[e+412|0]<<8)<<8);d=x[31609];x[31609]=0;if((d|0)==1){break i}d=0;while(1){h=y[e+411|0]|y[e+412|0]<<8;f=d&65535;if(h>>>0<=f>>>0){break l}x[e+212>>2]=h-f;x[e+160>>2]=2e3;d=e+212|0;h=x[Cd(d,e+160|0)>>2];d=Nb(d);x[31609]=0;h=U(326,b|0,d|0,h<<8)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(!h){break m}h=vb(e+248|0,wb(x[n+4>>2]));g=wb(x[d>>2]);i=wb(x[e+216>>2]);h=x[h>>2];x[31609]=0;V(329,n|0,h|0,g|0,i|0);h=x[31609];x[31609]=0;if((h|0)==1){break d}fc(d);d=f+2e3|0;continue}}h=D(f,104)+r|0;nd(h,1);g=f+(e+320|0)|0;f=Zd(b);v[g|0]=f;if(f<<24>>24>=0){C=h,E=Y_(b)<<1,x[C>>2]=E}d=d+1|0;continue}break}a=N()|0;break b}a=N()|0;ub(f);break b}fc(d);g=0;break h}se(e+232|0,x[n>>2],x[n+4>>2]);lf(e+240|0,x[e+232>>2],x[e+236>>2]);d=y[a+484376|0];f=x[a+484360>>2];x[31609]=0;O(330,Xb(f,d)|0,y[e+409|0]|y[e+410|0]<<8);d=x[31609];x[31609]=0;if((d|0)==1){break e}k=a+484344|0;t=c&1;i=0;while(1){if((y[e+409|0]|y[e+410|0]<<8)>>>0<=i>>>0){h=c&2;l=a+946304|0;f=1;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{while(1){c=f&65535;if(c>>>0>z[a+480190>>1]){break w}x[31609]=0;d=y[c+(e+320|0)|0];S(331,b|0,l+(c<<5)|0,d&63);g=x[31609];x[31609]=0;if((g|0)==1){break u}B:{C:{if(d<<24>>24<0){break C}x[31609]=0;d=R(332,b|0)|0;g=x[31609];x[31609]=0;D:{E:{F:{G:{H:{I:{J:{K:{if((g|0)==1){break K}c=D(c,104)+r|0;x[c+12>>2]=d<<1;x[31609]=0;d=R(332,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break J}if(d>>>0>=2){x[c+16>>2]=x[c+12>>2]+(d<<1);w[c+34>>1]=z[c+34>>1]|8}x[31609]=0;d=R(197,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break t}v[e+80|0]=d;v[e+180|0]=64;C=c,E=y[Qb(e+80|0,e+180|0)|0]<<2,w[C+30>>1]=E;x[31609]=0;d=R(197,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break K}v[c+37|0]=d<<4;fp(c);if(!x[c>>2]){break C}x[31609]=0;d=R(197,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break E}g=0;switch(d|0){case 4:case 5:break D;case 2:case 3:break G;case 1:break H;case 0:break I;default:break h}}a=N()|0;break c}a=N()|0;break c}if(h){d=Nb(e+80|0);i=x[b+8>>2];j=x[b>>2];k=x[c>>2];x[31609]=0;i=U(150,j|0,i|0,k|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break s}if(!i){break x}g=x[c>>2];x[31609]=0;S(333,b|0,d|0,g|0);g=x[31609];x[31609]=0;if((g|0)==1){break s}C=e,E=wb(x[d>>2]),x[C+180>>2]=E;i=wb(x[e+84>>2]);while(1){g=x[e+180>>2];if(Ib(g,i)){j=g;g=y[g|0];v[j|0]=g<<7|(g^-1)>>>1&127;we(e+180|0);continue}break}se(e+200|0,x[d>>2],x[e+84>>2]);g=Md(e+192|0);x[31609]=0;i=x[g+4>>2];x[e+16>>2]=x[g>>2];x[e+20>>2]=i;g=hg(327,e+212|0,x[e+200>>2],x[e+204>>2],e+16|0);i=x[31609];x[31609]=0;L:{if((i|0)!=1){i=Zc(e+180|0,16,1,0,16);x[31609]=0;U(215,i|0,c|0,g|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break L}ub(g);fc(d);break C}a=N()|0;break p}a=N()|0;ub(g);break p}c=x[c>>2];break F}d=Nb(e+80|0);i=x[c>>2];x[31609]=0;g=e+180|0;S(334,g|0,b|0,i|0);i=x[31609];x[31609]=0;M:{N:{O:{if((i|0)!=1){j=zn(d,g);fc(g);if(h){se(e+152|0,x[j>>2],x[e+84>>2]);i=Md(e+144|0);x[31609]=0;k=x[i+4>>2];x[e+24>>2]=x[i>>2];x[e+28>>2]=k;i=hg(327,e+160|0,x[e+152>>2],x[e+156>>2],e+24|0);k=x[31609];x[31609]=0;if((k|0)==1){break O}g=Zc(g,8,1,0,2);x[31609]=0;U(215,g|0,c|0,i|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break N}ub(i)}fc(j);break C}a=T(28816)|0;if((gb|0)!=($(28816)|0)){break M}Y(a|0)|0;g=0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)!=1){break v}a=N()|0;break M}a=N()|0;break M}a=N()|0;ub(i)}fc(d);break c}if(h){d=Zc(e+80|0,(d|0)==2?8:16,1,0,0);x[31609]=0;U(215,d|0,c|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break C}a=N()|0;break c}c=D(x[c>>2],d-1|0)}x[31609]=0;P(183,b|0,c|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break C}}a=N()|0;break c}i=Nb(e+80|0);g=x[c>>2];x[31609]=0;j=e+180|0;S(335,j|0,b|0,g|0);g=x[31609];x[31609]=0;P:{Q:{if((g|0)!=1){g=zn(i,j);fc(j);if(!h){break P}if((d|0)!=5){break Q}C=e,E=wb(x[g>>2]),x[C+180>>2]=E;k=wb(x[e+84>>2]);while(1){j=x[e+180>>2];if(!Ib(j,k)){break Q}m=j;j=y[j|0];v[m|0]=y[(j>>>7|0)+24753|0]^j;we(e+180|0);continue}}a=T(28816)|0;if((gb|0)!=($(28816)|0)){break y}Y(a|0)|0;g=0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)!=1){break B}a=N()|0;break y}se(e+112|0,x[g>>2],x[e+84>>2]);j=Md(e+104|0);x[31609]=0;k=x[j+4>>2];x[e+32>>2]=x[j>>2];x[e+36>>2]=k;j=hg(327,e+124|0,x[e+112>>2],x[e+116>>2],e+32|0);k=x[31609];x[31609]=0;if((k|0)==1){break A}d=(d|0)==5;d=Zc(e+180|0,d?16:8,1,0,d?16:1);x[31609]=0;U(215,d|0,c|0,j|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break z}ub(j)}fc(g)}f=f+1|0;continue}break}fc(i);break h}a=N()|0;break y}a=N()|0;ub(j)}fc(i);break c}fc(d);break h}d=0;v[e+182|0]=0;w[e+180>>1]=0;w[e+80>>1]=y[e+413|0]|y[e+414|0]<<8;v[e+82|0]=y[e+415|0];while(1){if((d|0)!=3){c=xb(e+80|0,d);C=xb(e+180|0,d),E=y[c|0],v[C|0]=E;d=d+1|0;continue}break}R:{S:{T:{U:{c=e+180|0;d=cg(c);if(d){c=Nb(c);x[31609]=0;b=U(326,b|0,c|0,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break r}if(!b){break S}se(e+72|0,x[c>>2],x[c+4>>2]);b=Md(e- -64|0);x[31609]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=hg(327,e+80|0,x[e+72>>2],x[e+76>>2],e+8|0);f=x[31609];x[31609]=0;if((f|0)==1){break U}x[31609]=0;V(336,a+1298332|0,b|0,d|0,1);d=x[31609];x[31609]=0;if((d|0)==1){break T}ub(b);fc(c)}x[31609]=0;W(337,e+52|0);b=x[31609];x[31609]=0;if((b|0)!=1){break R}a=N()|0;break c}a=N()|0;break q}a=N()|0;ub(b);break q}fc(c);g=0;break h}x[31609]=0;b=e+180|0;c=e+52|0;S(338,b|0,c|0,y[e+407|0]);d=x[31609];x[31609]=0;V:{W:{if((d|0)!=1){zb(a+1298344|0,b);tb(b);Eb(c);x[31609]=0;b=P(1,b|0,10112)|0;d=x[31609];x[31609]=0;if((d|0)==1){break W}zb(a+1298356|0,b);tb(b);x[31609]=0;b=P(1,c|0,5101)|0;c=x[31609];x[31609]=0;if((c|0)==1){break V}zb(a+1298368|0,b);tb(b);C=a,E=x[Fc(e+48|0,24)>>2],x[C+1298404>>2]=E;g=1;break h}a=N()|0;Eb(e+52|0);break c}a=N()|0;break c}a=N()|0;break c}fc(d);break h}a=N()|0;break c}a=N()|0;break c}a=N()|0;break p}a=N()|0}fc(c);break c}fc(d);break c}C=ac(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],i),E=i,w[C>>1]=E;X:{Y:{if(!t){break Y}x[31609]=0;s=i&65535;d=U(196,k|0,s|0,64)|0;f=x[31609];x[31609]=0;if((f|0)==1){break X}if(!d){break Y}f=z[a+480188>>1];j=0;while(1){d=f&65535;if(d>>>0<=j>>>0){break Y}d=ac(x[q>>2],D(d,i)+j|0);d=y[d|0]|y[d+1|0]<<8;Z:{if(d>>>0>=(y[e+411|0]|y[e+412|0]<<8)>>>0){break Z}g=0;u=d<<8;d=Wb(x[k>>2],i);d=md(x[d>>2],x[x[d+48>>2]+12>>2],0,j&65535);A=D(j,-6);while(1){if((g|0)==64){break Z}wr(e+212|0,x[e+240>>2],x[e+244>>2],g<<2|u,4);f=x[e+212>>2];h=xb(f,0);o=y[h|0]&63;v[d|0]=o?o+48|0:0;l=xb(f,1);v[d+1|0]=y[l|0]<<2&60|y[h|0]>>>6;m=y[l|0];h=xb(f,2);l=y[xb(f,3)|0];f=y[h|0];h=l<<4|f>>>4;w[e+80>>1]=h;B=m>>>6|0;m=f<<2&60;f=B|m;_:{if(!(y[xb(e+312|0,m>>>3|0)|0]>>>(f&7)&1)|!(f|h)){break _}v[d+5|0]=h;m=l>>>4|0;v[d+4|0]=m;$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{switch(f|0){case 0:case 1:case 2:case 32:case 33:case 34:Cf(d,f&15,h&255);if(!y[d+4|0]){break _}v[d+2|0]=f>>>0<32?3:4;break _;case 9:v[d+3|0]=10;v[d+5|0]=h>>>1;if(h>>>0<512){break _}v[d+2|0]=15;v[d+4|0]=l>>>5;break _;case 10:case 42:if(h>>>0>254){break ja}f=f&15;break;case 50:break aa;case 48:break ba;case 43:break ca;case 47:break da;case 17:case 18:case 26:case 27:break ea;case 22:case 25:case 28:case 29:case 30:break fa;case 16:case 19:case 20:case 21:case 23:case 31:break ga;case 13:break ha;case 11:case 15:break ia;case 3:case 4:case 5:case 6:case 7:case 12:break ka;default:break $}}Cf(d,f,h&255);break _}v[d+3|0]=19;v[d+5|0]=m|(f>>>0<32?16:32);if(l&15){v[d+2|0]=3;v[d+4|0]=(h&240)>>>4;break _}v[d+4|0]=h;v[d+2|0]=4;break _}v[d+3|0]=(f|0)==11?12:16;C=d,E=ew(h),v[C+5|0]=E;break _}v[d+3|0]=14;if((h&255)>>>0<64){break _}v[d+5|0]=0;break _}v[d+3|0]=19;v[d+5|0]=h&15|f<<4;break _}v[d+3|0]=19;w[e+160>>1]=15;C=d,E=y[Oc(e+80|0,e+160|0)|0]|f<<4,v[C+5|0]=E;break _}v[d+3|0]=19;if(h&255){v[d+5|0]=h&15|((f|0)==17?16:(f|0)==26?16:32);if(l>>>0<16){break _}v[d+2|0]=f>>>0>25?6:5;break _}v[d+5|0]=m|(f>>>0>25?-80:-96);break _}if(!h){break $}v[d+3|0]=17;x[e+160>>2]=8;x[e+124>>2]=h+4;C=d,E=Eh(x[Ye(e+160|0,e+124|0)>>2]/8|0),v[C+5|0]=E;break _}v[d+3|0]=14;l=d+A|0;o=z[a+480188>>1];f=0;while(1){if((f|0)==(o|0)){break _}h=l+D(f,6)|0;if(!y[h+3|0]){v[h+3|0]=12;C=h,E=ew(s),v[C+5|0]=E}f=f+1|0;continue}}v[d+3|0]=9;f=h&7;if(f){v[d+5|0]=y[f+24745|0];break _}f=h>>>4|0;if((f|0)==128){break $}v[d+5|0]=f;if(h>>>0<=2047){v[d+5|0]=f|128;break _}v[d+5|0]=f^-1;break _}v[d+5|0]=0;v[d+3|0]=0;if(!o){v[d|0]=255;break _}v[d+3|0]=25;break _}v[d+3|0]=0}g=g+1|0;f=z[a+480188>>1];d=D(f,6)+d|0;continue}}j=j+1|0;continue}}i=i+1|0;continue}break}a=N()|0;break c}a=N()|0;break b}}else{bE(a,d&65535);w[(f+(d<<5)|0)+4>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;g=z[a+480188>>1];continue}break}fc(d);g=0;break g}a=N()|0;break c}fc(n)}od(q)}fb=e+416|0;return g|0}a=N()|0;break c}a=N()|0;fc(d)}fc(n);break a}fc(d)}od(q);Q(a|0);p()}function o1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a:{n=ak(b,13930);if(!n){break a}o=a+900380|0;b:while(1){if(!Mb(x[b>>2],x[b+8>>2],6)){break a}f=Rg(b);if(!(!((f|0)==(Dn(13780)|0)|!(f&1616928864)|f&-2139062144)&(f|0)!=70791730)){Ih(b,4);break a}l=1;c=gh(b);while(1){e=l&65535;if(e>>>0>z[a+480192>>1]){continue b}e=x[(e<<2)+o>>2];if(e){c:{g=0;if((Dn(16790)|0)==(f|0)){Vb(b,c);break c}h=fb-48|0;fb=h;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{switch(f-1349079874|0){default:if((f|0)==1095062094){break t}if((f|0)==1095126087){break q}if((f|0)==1129524782){break z}if((f|0)==1145263150){break W}if((f|0)==1145979182){break V}if((f|0)==1179463214){break x}if((f|0)==1851469358){break D}if((f|0)==1179931728){break l}Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if((f|0)!=1196830254){if((f|0)==1229341486){break S}if((f|0)==1229345326){break R}if((f|0)==1264266798){break E}if((f|0)==1296182830){break Q}if((f|0)==1296248366){break O}if((f|0)==1297100334){break P}if((f|0)==1297110852){break o}if((f|0)==1298747438){break B}if((f|0)==1313692462){break F}if((f|0)==1313751342){break X}if((f|0)==1345203758){break ha}if((f|0)==1346711086){break j}if((f|0)==1346720334){break u}if((f|0)==1346722606){break H}if((f|0)==1346784327){break r}if((f|0)==1347175726){break ba}if((f|0)==1347179310){break ca}if((f|0)==1347437358){break M}if((f|0)==1347441454){break N}if((f|0)==1347443502){break K}if((f|0)==1347628590){break U}if((f|0)==1347633710){break aa}if((f|0)==1347634478){break $}if((f|0)==1347703884){break m}if((f|0)==1347831112){break w}if((f|0)==1347833672){break v}if((f|0)==1349076270){break i}if((f|0)==1349076315){break G}if((f|0)==1349078085){break Z}if((f|0)==1349078099){break _}if((f|0)==1349079131){break J}if((f|0)==1378758190){break n}if((f|0)==1381183022){break y}if((f|0)==1447374382){break k}if((f|0)==1447383630){break s}if((f|0)==1447385902){break I}if((f|0)==1447447623){break p}if((f|0)==1447839022){break fa}if((f|0)==1447842606){break ga}if((f|0)==1448106798){break L}if((f|0)==1448226350){break A}if((f|0)==1448291886){break T}if((f|0)==1448297006){break ea}if((f|0)==1448297774){break da}if((f|0)!=1682320942){if((f|0)==1718508334){break C}if((f|0)!=1179594286|c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Qw(b,c),x[q>>2]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+15|0]=r;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Qw(b,c),x[q+4>>2]=r;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Qw(b,c),x[q+8>>2]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+61|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+62|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+63|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+64|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+81|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+82|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+83|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+84|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+101|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+102|0]=r;break e;case 0:if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+103|0]=r;break e;case 3:break Y;case 1:case 2:break d}}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+104|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+16|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+17|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+18|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+19|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+20|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+21|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+22|0]=r;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=FF(b,c),w[q+28>>1]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+30|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+31|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=EF(b,c),v[q+26|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+27|0]=r;break e}d=h+8|0;he(d,b,c);j=hc(h+28|0,d);ub(d);i=Wh(e,0);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31609]=0;k=R(192,j|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break h}g=x[i>>2];q=yb(g,d),r=k,w[q>>1]=r;d=d+1|0;continue}}d=h+8|0;he(d,b,c);j=hc(h+28|0,d);ub(d);i=Wh(e,1);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31609]=0;k=R(192,j|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){g=x[i>>2];q=yb(g,d),r=k,w[q>>1]=r;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;he(d,b,c);j=hc(h+28|0,d);ub(d);i=Wh(e,2);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31609]=0;k=R(192,j|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){g=x[i>>2];q=yb(g,d),r=k,w[q>>1]=r;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;he(d,b,c);j=hc(h+28|0,d);ub(d);i=Wh(e,0);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31609]=0;k=R(193,j|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){g=x[i>>2];q=yb(g,d),r=k,v[q+2|0]=r;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;he(d,b,c);j=hc(h+28|0,d);ub(d);i=Wh(e,1);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31609]=0;k=R(193,j|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){g=x[i>>2];q=yb(g,d),r=k,v[q+2|0]=r;d=d+1|0;continue}break}d=N()|0;break g}d=h+8|0;he(d,b,c);j=hc(h+28|0,d);ub(d);i=Wh(e,2);g=x[i>>2];d=0;while(1){if(Sd(g,x[i+4>>2])>>>0<=d>>>0){ub(j);break e}x[31609]=0;k=R(193,j|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){g=x[i>>2];q=yb(g,d),r=k,v[q+2|0]=r;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>128){break d}g=e+108|0;d=h+8|0;he(d,b,c);j=hc(h+28|0,d);ub(d);d=0;while(1){if((d|0)==128){ub(j);break e}x[31609]=0;i=R(193,j|0)|0;k=x[31609];x[31609]=0;if((k|0)!=1){q=xb(g,d),r=i,v[q|0]=r;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>256){break d}g=e+236|0;d=h+8|0;he(d,b,c);j=hc(h+28|0,d);ub(d);d=0;while(1){if((d|0)==128){ub(j);break e}x[31609]=0;i=R(192,j|0)|0;k=x[31609];x[31609]=0;if((k|0)!=1){q=ac(g,d),r=i,w[q>>1]=r;d=d+1|0;continue}break}d=N()|0;break g}if(c>>>0>32){break d}i=e+492|0;d=h+8|0;he(d,b,c);j=hc(h+28|0,d);ub(d);g=Fb(d);d=0;while(1){if((c|0)==(d|0)){break f}x[31609]=0;k=R(194,j|0)|0;m=x[31609];x[31609]=0;ia:{if((m|0)==1){break ia}x[31609]=0;P(195,g|0,k|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break ia}d=d+1|0;continue}break}d=N()|0;tb(g);break g}if(c>>>0>32){break d}i=e+524|0;d=h+8|0;he(d,b,c);j=hc(h+28|0,d);ub(d);g=Fb(d);d=0;ja:{while(1){if((c|0)!=(d|0)){x[31609]=0;k=R(194,j|0)|0;m=x[31609];x[31609]=0;if((m|0)==1){break ja}x[31609]=0;P(195,g|0,k|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break ja}d=d+1|0;continue}break}Ac(i,g);tb(g);ub(j);break e}d=N()|0;tb(g);break g}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+34|0]=r;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=FF(b,c),w[q+12>>1]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+23|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+24|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+25|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+35|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+36|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+105|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+85|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+65|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+100|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+80|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Kd(b,c),v[q+60|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=EF(b,c),v[q+33|0]=r;break e}g=1;d=vp(b,c);if(!up(d)){break d}v[e+14|0]=d;break d}q=e,r=D(Ow(b,c),1e4)+(A[e+40>>2]%1e4|0)|0,x[q+40>>2]=r;break e}g=(Ow(b,c)>>>0)%1e4|0;d=x[e+40>>2];x[e+40>>2]=g+d-(d>>>0)%1e4;break e}x[h+28>>2]=240;q=h,r=vp(b,c),x[q+8>>2]=r;fh(e+48|0,x[Hb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;q=h,r=vp(b,c),x[q+8>>2]=r;fh(e+68|0,x[Hb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;q=h,r=vp(b,c),x[q+8>>2]=r;fh(e+88|0,x[Hb(h+28|0,h+8|0)>>2]);break e}d=N()|0}ub(j);Q(d|0);p()}Ac(i,g);tb(g);ub(j)}g=1}fb=h+48|0;if(!g){Vb(b,c);break c}if((Dn(16795)|0)==(f|0)){d=y[e+15|0];v[e+15|0]=0;v[e+60|0]=d>>>1&2|(d<<1&4|(y[e+60|0]&240|d&1));v[e+100|0]=d>>>5&4|(y[e+100|0]&224|d>>>6&1);v[e+80|0]=d>>>4&2|(d>>>2&4|(y[e+80|0]&240|d>>>3&1))}}}l=l+1|0;continue}}}return n|0}function Gd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(a>>>0<=244){e=x[31485];g=a>>>0<11?16:a+11&504;a=g>>>3|0;b=e>>>a|0;if(b&3){c=a+((b^-1)&1)|0;b=c<<3;a=b+125980|0;b=x[b+125988>>2];d=x[b+8>>2];k:{if((a|0)==(d|0)){m=125940,n=Dua(-2,c)&e,x[m>>2]=n;break k}x[d+12>>2]=a;x[a+8>>2]=d}a=b+8|0;c=c<<3;x[b+4>>2]=c|3;b=b+c|0;x[b+4>>2]=x[b+4>>2]|1;break a}i=x[31487];if(i>>>0>=g>>>0){break j}if(b){c=2<<a;a=zua((0-c|c)&b<<a);c=a<<3;b=c+125980|0;c=x[c+125988>>2];d=x[c+8>>2];l:{if((b|0)==(d|0)){e=Dua(-2,a)&e;x[31485]=e;break l}x[d+12>>2]=b;x[b+8>>2]=d}x[c+4>>2]=g|3;h=c+g|0;a=a<<3;f=a-g|0;x[h+4>>2]=f|1;x[a+c>>2]=f;if(i){a=(i&-8)+125980|0;d=x[31490];b=1<<(i>>>3);m:{if(!(b&e)){x[31485]=b|e;b=a;break m}b=x[a+8>>2]}x[a+8>>2]=d;x[b+12>>2]=d;x[d+12>>2]=a;x[d+8>>2]=b}a=c+8|0;x[31490]=h;x[31487]=f;break a}l=x[31486];if(!l){break j}c=x[(zua(l)<<2)+126244>>2];f=(x[c+4>>2]&-8)-g|0;b=c;while(1){n:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break n}}d=(x[a+4>>2]&-8)-g|0;b=d>>>0<f>>>0;f=b?d:f;c=b?a:c;b=a;continue}break}j=x[c+24>>2];a=x[c+12>>2];if((c|0)!=(a|0)){b=x[c+8>>2];x[b+12>>2]=a;x[a+8>>2]=b;break b}b=x[c+20>>2];if(b){d=c+20|0}else{b=x[c+16>>2];if(!b){break i}d=c+16|0}while(1){h=d;a=b;d=a+20|0;b=x[a+20>>2];if(b){continue}d=a+16|0;b=x[a+16>>2];if(b){continue}break}x[h>>2]=0;break b}g=-1;if(a>>>0>4294967231){break j}b=a+11|0;g=b&-8;i=x[31486];if(!i){break j}f=0-g|0;e=0;o:{if(g>>>0<256){break o}e=31;if(g>>>0>16777215){break o}a=G(b>>>8|0);e=((g>>>38-a&1)-(a<<1)|0)+62|0}b=x[(e<<2)+126244>>2];p:{q:{r:{if(!b){a=0;break r}a=0;c=g<<((e|0)!=31?25-(e>>>1|0)|0:0);while(1){s:{h=(x[b+4>>2]&-8)-g|0;if(h>>>0>=f>>>0){break s}d=b;f=h;if(f){break s}f=0;a=b;break q}h=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=h?(h|0)==(b|0)?a:h:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<e;a=(0-a|a)&i;if(!a){break j}a=x[(zua(a)<<2)+126244>>2]}if(!a){break p}}while(1){c=(x[a+4>>2]&-8)-g|0;b=c>>>0<f>>>0;f=b?c:f;d=b?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[31487]-g>>>0<=f>>>0){break j}h=x[d+24>>2];a=x[d+12>>2];if((d|0)!=(a|0)){b=x[d+8>>2];x[b+12>>2]=a;x[a+8>>2]=b;break c}b=x[d+20>>2];if(b){c=d+20|0}else{b=x[d+16>>2];if(!b){break h}c=d+16|0}while(1){e=c;a=b;c=a+20|0;b=x[a+20>>2];if(b){continue}c=a+16|0;b=x[a+16>>2];if(b){continue}break}x[e>>2]=0;break c}d=x[31487];if(d>>>0>=g>>>0){a=x[31490];b=d-g|0;t:{if(b>>>0>=16){c=a+g|0;x[c+4>>2]=b|1;x[a+d>>2]=b;x[a+4>>2]=g|3;break t}x[a+4>>2]=d|3;b=a+d|0;x[b+4>>2]=x[b+4>>2]|1;c=0;b=0}x[31487]=b;x[31490]=c;a=a+8|0;break a}c=x[31488];if(c>>>0>g>>>0){b=c-g|0;x[31488]=b;a=x[31491];c=a+g|0;x[31491]=c;x[c+4>>2]=b|1;x[a+4>>2]=g|3;a=a+8|0;break a}a=0;f=g+47|0;if(x[31603]){b=x[31605]}else{x[31606]=-1;x[31607]=-1;x[31604]=4096;x[31605]=4096;x[31603]=k+12&-16^1431655768;x[31608]=0;x[31596]=0;b=4096}e=f+b|0;h=0-b|0;b=e&h;if(b>>>0<=g>>>0){break a}i=x[31595];if(i){j=x[31593];d=j+b|0;if(d>>>0<=j>>>0|d>>>0>i>>>0){break a}}u:{if(!(y[126384]&4)){v:{w:{x:{y:{d=x[31491];if(d){a=126388;while(1){i=x[a>>2];if(i>>>0<=d>>>0&d>>>0<i+x[a+4>>2]>>>0){break y}a=x[a+8>>2];if(a){continue}break}}c=hp(0);if((c|0)==-1){break v}e=b;a=x[31604];d=a-1|0;if(d&c){e=(b-c|0)+(c+d&0-a)|0}if(e>>>0<=g>>>0){break v}d=x[31595];if(d){h=x[31593];a=h+e|0;if(a>>>0<=h>>>0|a>>>0>d>>>0){break v}}a=hp(e);if((c|0)!=(a|0)){break x}break u}e=h&e-c;c=hp(e);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break w}a=c}if((a|0)==-1){break v}if(g+48>>>0<=e>>>0){c=a;break u}c=x[31605];c=c+(f-e|0)&0-c;if((hp(c)|0)==-1){break v}e=c+e|0;c=a;break u}if((c|0)!=-1){break u}}x[31596]=x[31596]|4}c=hp(b);a=hp(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break e}e=a-c|0;if(e>>>0<=g+40>>>0){break e}}a=x[31593]+e|0;x[31593]=a;if(a>>>0>A[31594]){x[31594]=a}z:{f=x[31491];if(f){a=126388;while(1){b=x[a>>2];d=x[a+4>>2];if((b+d|0)==(c|0)){break z}a=x[a+8>>2];if(a){continue}break}break g}a=x[31489];if(!(a>>>0<=c>>>0?a:0)){x[31489]=c}a=0;x[31598]=e;x[31597]=c;x[31493]=-1;x[31494]=x[31603];x[31600]=0;while(1){b=a<<3;d=b+125980|0;x[b+125988>>2]=d;x[b+125992>>2]=d;a=a+1|0;if((a|0)!=32){continue}break}a=e-40|0;b=-8-c&7;d=a-b|0;x[31488]=d;b=b+c|0;x[31491]=b;x[b+4>>2]=d|1;x[(a+c|0)+4>>2]=40;x[31492]=x[31607];break f}if(x[a+12>>2]&8|(c>>>0<=f>>>0|b>>>0>f>>>0)){break g}x[a+4>>2]=d+e;a=-8-f&7;b=a+f|0;x[31491]=b;c=x[31488]+e|0;a=c-a|0;x[31488]=a;x[b+4>>2]=a|1;x[(c+f|0)+4>>2]=40;x[31492]=x[31607];break f}a=0;break b}a=0;break c}if(A[31489]>c>>>0){x[31489]=c}b=c+e|0;a=126388;A:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break A}break}if(!(y[a+12|0]&8)){break d}}a=126388;while(1){B:{b=x[a>>2];if(b>>>0<=f>>>0){d=b+x[a+4>>2]|0;if(d>>>0>f>>>0){break B}}a=x[a+8>>2];continue}break}a=e-40|0;b=-8-c&7;h=a-b|0;x[31488]=h;b=b+c|0;x[31491]=b;x[b+4>>2]=h|1;x[(a+c|0)+4>>2]=40;x[31492]=x[31607];a=(d+(39-d&7)|0)-47|0;b=a>>>0<f+16>>>0?f:a;x[b+4>>2]=27;a=x[31600];x[b+16>>2]=x[31599];x[b+20>>2]=a;a=x[31598];x[b+8>>2]=x[31597];x[b+12>>2]=a;x[31599]=b+8;x[31598]=e;x[31597]=c;x[31600]=0;a=b+24|0;while(1){x[a+4>>2]=7;c=a+8|0;a=a+4|0;if(c>>>0<d>>>0){continue}break}if((b|0)==(f|0)){break f}x[b+4>>2]=x[b+4>>2]&-2;c=b-f|0;x[f+4>>2]=c|1;x[b>>2]=c;C:{if(c>>>0<=255){a=(c&-8)+125980|0;b=x[31485];c=1<<(c>>>3);D:{if(!(b&c)){x[31485]=b|c;b=a;break D}b=x[a+8>>2]}x[a+8>>2]=f;x[b+12>>2]=f;d=8;c=12;break C}a=31;if(c>>>0<=16777215){a=G(c>>>8|0);a=((c>>>38-a&1)-(a<<1)|0)+62|0}x[f+28>>2]=a;x[f+16>>2]=0;x[f+20>>2]=0;b=(a<<2)+126244|0;E:{d=x[31486];e=1<<a;F:{if(!(d&e)){x[31486]=d|e;x[b>>2]=f;break F}a=c<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((c|0)==(x[b+4>>2]&-8)){break E}d=a>>>29|0;a=a<<1;e=(d&4)+b|0;d=x[e+16>>2];if(d){continue}break}x[e+16>>2]=f}x[f+24>>2]=b;b=f;a=b;d=12;c=8;break C}a=x[b+8>>2];x[a+12>>2]=f;x[b+8>>2]=f;x[f+8>>2]=a;a=0;d=12;c=24}x[d+f>>2]=b;x[c+f>>2]=a}a=x[31488];if(a>>>0<=g>>>0){break e}b=a-g|0;x[31488]=b;a=x[31491];c=a+g|0;x[31491]=c;x[c+4>>2]=b|1;x[a+4>>2]=g|3;a=a+8|0;break a}x[31484]=48;a=0;break a}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+e;j=(-8-c&7)+c|0;x[j+4>>2]=g|3;e=b+(-8-b&7)|0;f=g+j|0;i=e-f|0;G:{if(x[31491]==(e|0)){x[31491]=f;a=x[31488]+i|0;x[31488]=a;x[f+4>>2]=a|1;break G}if(x[31490]==(e|0)){x[31490]=f;a=x[31487]+i|0;x[31487]=a;x[f+4>>2]=a|1;x[a+f>>2]=a;break G}a=x[e+4>>2];if((a&3)==1){g=a&-8;c=x[e+12>>2];H:{if(a>>>0<=255){b=x[e+8>>2];if((b|0)==(c|0)){m=125940,n=x[31485]&Dua(-2,a>>>3|0),x[m>>2]=n;break H}x[b+12>>2]=c;x[c+8>>2]=b;break H}h=x[e+24>>2];I:{if((c|0)!=(e|0)){a=x[e+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break I}J:{a=x[e+20>>2];if(a){b=e+20|0}else{a=x[e+16>>2];if(!a){break J}b=e+16|0}while(1){d=b;c=a;b=a+20|0;a=x[a+20>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[d>>2]=0;break I}c=0}if(!h){break H}a=x[e+28>>2];b=(a<<2)+126244|0;K:{if(x[b>>2]==(e|0)){x[b>>2]=c;if(c){break K}m=125944,n=x[31486]&Dua(-2,a),x[m>>2]=n;break H}x[h+(x[h+16>>2]==(e|0)?16:20)>>2]=c;if(!c){break H}}x[c+24>>2]=h;a=x[e+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[e+20>>2];if(!a){break H}x[c+20>>2]=a;x[a+24>>2]=c}i=g+i|0;e=e+g|0;a=x[e+4>>2]}x[e+4>>2]=a&-2;x[f+4>>2]=i|1;x[f+i>>2]=i;if(i>>>0<=255){a=(i&-8)+125980|0;b=x[31485];c=1<<(i>>>3);L:{if(!(b&c)){x[31485]=b|c;b=a;break L}b=x[a+8>>2]}x[a+8>>2]=f;x[b+12>>2]=f;x[f+12>>2]=a;x[f+8>>2]=b;break G}c=31;if(i>>>0<=16777215){a=G(i>>>8|0);c=((i>>>38-a&1)-(a<<1)|0)+62|0}x[f+28>>2]=c;x[f+16>>2]=0;x[f+20>>2]=0;a=(c<<2)+126244|0;M:{b=x[31486];d=1<<c;N:{if(!(b&d)){x[31486]=b|d;x[a>>2]=f;break N}c=i<<((c|0)!=31?25-(c>>>1|0)|0:0);b=x[a>>2];while(1){a=b;if((x[a+4>>2]&-8)==(i|0)){break M}b=c>>>29|0;c=c<<1;d=(b&4)+a|0;b=x[d+16>>2];if(b){continue}break}x[d+16>>2]=f}x[f+24>>2]=a;x[f+12>>2]=f;x[f+8>>2]=f;break G}b=x[a+8>>2];x[b+12>>2]=f;x[a+8>>2]=f;x[f+24>>2]=0;x[f+12>>2]=a;x[f+8>>2]=b}a=j+8|0;break a}O:{if(!h){break O}b=x[d+28>>2];c=(b<<2)+126244|0;P:{if(x[c>>2]==(d|0)){x[c>>2]=a;if(a){break P}i=Dua(-2,b)&i;x[31486]=i;break O}x[h+(x[h+16>>2]==(d|0)?16:20)>>2]=a;if(!a){break O}}x[a+24>>2]=h;b=x[d+16>>2];if(b){x[a+16>>2]=b;x[b+24>>2]=a}b=x[d+20>>2];if(!b){break O}x[a+20>>2]=b;x[b+24>>2]=a}Q:{if(f>>>0<=15){a=f+g|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break Q}x[d+4>>2]=g|3;e=d+g|0;x[e+4>>2]=f|1;x[f+e>>2]=f;if(f>>>0<=255){a=(f&-8)+125980|0;b=x[31485];c=1<<(f>>>3);R:{if(!(b&c)){x[31485]=b|c;b=a;break R}b=x[a+8>>2]}x[a+8>>2]=e;x[b+12>>2]=e;x[e+12>>2]=a;x[e+8>>2]=b;break Q}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+126244|0;S:{c=1<<a;T:{if(!(c&i)){x[31486]=c|i;x[b>>2]=e;x[e+24>>2]=b;break T}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);b=x[b>>2];while(1){c=b;if((x[b+4>>2]&-8)==(f|0)){break S}h=a>>>29|0;a=a<<1;h=b+(h&4)|0;b=x[h+16>>2];if(b){continue}break}x[h+16>>2]=e;x[e+24>>2]=c}x[e+12>>2]=e;x[e+8>>2]=e;break Q}a=x[c+8>>2];x[a+12>>2]=e;x[c+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=c;x[e+8>>2]=a}a=d+8|0;break a}U:{if(!j){break U}b=x[c+28>>2];d=(b<<2)+126244|0;V:{if(x[d>>2]==(c|0)){x[d>>2]=a;if(a){break V}m=125944,n=Dua(-2,b)&l,x[m>>2]=n;break U}x[j+(x[j+16>>2]==(c|0)?16:20)>>2]=a;if(!a){break U}}x[a+24>>2]=j;b=x[c+16>>2];if(b){x[a+16>>2]=b;x[b+24>>2]=a}b=x[c+20>>2];if(!b){break U}x[a+20>>2]=b;x[b+24>>2]=a}W:{if(f>>>0<=15){a=f+g|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break W}x[c+4>>2]=g|3;h=c+g|0;x[h+4>>2]=f|1;x[f+h>>2]=f;if(i){a=(i&-8)+125980|0;d=x[31490];b=1<<(i>>>3);X:{if(!(b&e)){x[31485]=b|e;b=a;break X}b=x[a+8>>2]}x[a+8>>2]=d;x[b+12>>2]=d;x[d+12>>2]=a;x[d+8>>2]=b}x[31490]=h;x[31487]=f}a=c+8|0}fb=k+16|0;return a|0}function wua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=fb-272|0;fb=e;yc(b);a:{b:{c:{d:{if(Or(b,18456)){n=Fb(e+260|0);x[31609]=0;g=P(230,b|0,n|0)|0;d=x[31609];x[31609]=0;e:{if((d|0)!=1){if(!g){break e}x[31609]=0;i=e+253|0;g=P(245,b|0,i|0)|0;d=x[31609];x[31609]=0;f:{if((d|0)==1){break f}if(!g){break e}if(!z0(y[e+253|0],y[e+254|0])){break e}i=Bc(y0(i),hb);g=x[b+8>>2];d=x[b>>2];x[31609]=0;g=U(150,d|0,g|0,i|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break f}if(!g){break e}f=1;if((c|0)==64){break e}x[31609]=0;O(246,a|0,4096);d=x[31609];x[31609]=0;if((d|0)==1){break f}x[31609]=0;O(247,a+1298308|0,n|0);d=x[31609];x[31609]=0;if((d|0)==1){break f}d=y[e+255|0];w[a+480188>>1]=32;w[a+480192>>1]=d;Uh(a,1);x[31609]=0;f=P(1,e+240|0,9492)|0;d=x[31609];x[31609]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{if((d|0)!=1){zb(a+1298344|0,f);tb(f);x[31609]=0;f=P(1,e+228|0,7105)|0;d=x[31609];x[31609]=0;if((d|0)==1){break o}zb(a+1298356|0,f);tb(f);x[31609]=0;g=e+32|0;W(248,g|0);d=x[31609];x[31609]=0;if((d|0)==1){break n}v[e+204|0]=y[e+254|0];x[31609]=0;v[e|0]=y[e+253|0];f=e+216|0;O(249,f|0,e|0);d=x[31609];x[31609]=0;if((d|0)==1){break m}x[31609]=0;i=e+80|0;V(250,i|0,g|0,e+204|0,f|0);d=x[31609];x[31609]=0;if((d|0)==1){break l}zb(a+1298368|0,i);tb(i);tb(f);Eb(g);t=a,u=x[Fc(i,4)>>2],x[t+1298404>>2]=u;if(y[e+253|0]<2){break h}w[e+80>>1]=8192;x[31609]=0;f=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break j}w[e+32>>1]=f;t=a,u=D(z[qe(i,g)>>1],1e4)>>>8|0,x[t+480204>>2]=u;x[31609]=0;v[e+80|0]=1;f=R(197,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break i}v[e+32|0]=f;t=a,u=y[cf(i,g)|0],x[t+480196>>2]=u;x[31609]=0;P(183,b|0,3)|0;d=x[31609];x[31609]=0;if((d|0)!=1){x[31609]=0;f=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break g}}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break k}b=N()|0;tb(e+216|0)}Eb(e+32|0);break a}b=N()|0;break a}b=N()|0;break a}v[e+80|0]=32;x[31609]=0;f=R(197,b|0)|0;d=x[31609];x[31609]=0;p:{if((d|0)!=1){v[e+32|0]=f;t=a,u=D(y[cf(e+80|0,e+32|0)|0],1e4),x[t+480204>>2]=u;x[31609]=0;v[e+80|0]=1;f=R(197,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break p}v[e+32|0]=f;t=a,u=y[cf(e+80|0,e+32|0)|0],x[t+480196>>2]=u;x[31609]=0;f=R(197,b|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break g}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}x[a+480208>>2]=f>>>2&16|12;o=a+484380|0;s=a+946304|0;l=Nb(e+216|0);j=e+80|12;m=Nb(e+204|0);q=1;while(1){q:{r:{d=q&65535;if(d>>>0>z[a+480192>>1]){break r}x[31609]=0;h=U(251,a|0,d|0,0)|0;d=x[31609];x[31609]=0;s:{if((d|0)==1){break s}if(!h){break r}x[31609]=0;f=P(240,b|0,h+492|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break s}if(!f){break r}x[31609]=0;r=R(197,b|0)|0;d=x[31609];x[31609]=0;t:{u:{v:{if((d|0)!=1){d=e+80|0;Rb(d,0,120);if(!r){break q}w:{if(y[e+253|0]){x[31609]=0;f=P(252,b|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break v}if(!f){break q}if(y[e+253|0]){break w}}d=Zb(e+72|0,j,96);f=x[d>>2];d=x[d+4>>2];x[31609]=0;Yn(159,e+32|0,b,f,d);d=x[31609];x[31609]=0;if((d|0)==1){break u}if(!x[e+36>>2]){break q}}d=h+236|0;f=0;break t}b=N()|0;break b}b=N()|0;break b}b=N()|0;break b}while(1){if((f|0)!=120){t=ac(d,f),u=(y[(e+80|0)+f|0]+z[a+480190>>1]|0)+1|0,w[t>>1]=u;f=f+1|0;continue}break}x[31609]=0;i=h+48|0;S(253,e|0,i|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}x[31609]=0;g=h+68|0;S(253,e+16|0,g|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}x[31609]=0;f=h+88|0;S(253,e- -64|0,f|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}x[31609]=0;O(254,b|0,e+56|0);d=x[31609];x[31609]=0;if((d|0)==1){break d}x[h>>2]=(y[e+57|0]|y[e+58|0]<<8)&4095;d=y[e+57|0]|y[e+58|0]<<8;CE(y[e+59|0]|y[e+60|0]<<8,i,0);CE(y[e+59|0]|y[e+60|0]<<8,g,1);CE(y[e+59|0]|y[e+60|0]<<8,f,2);t=e,u=wb(x[h+48>>2]),x[t+32>>2]=u;f=d>>>12|0;d=wb(x[h+52>>2]);while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)- -64>>>0)/127;t=g,u=y[Qb(e+28|0,e+54|0)|0],v[t+2|0]=u;Xe(e+32|0);continue}else{t=e,u=wb(x[h+68>>2]),x[t+32>>2]=u;d=wb(x[h+72>>2])}break}while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)+128>>>0)/255;t=g,u=y[Qb(e+28|0,e+54|0)|0],v[t+2|0]=u;Xe(e+32|0);continue}break}t=e,u=wb(x[h+88>>2]),x[t+32>>2]=u;k=f&3;i=wb(x[h+92>>2]);while(1){f=x[e+32>>2];if(Ib(f,i)){g=v[f+2|0];d=g>>31^-1;g=g^-128;h=k&31;if((k&63)>>>0>=32){d=g<<h;h=0}else{d=(1<<h)-1&g>>>32-h|d<<h;h=g<<h}x:{if((d|0)>=-1&h>>>0>=4294967292|(d|0)>=0){g=h+4|0;d=(((g>>>0<4?d+1|0:d)&7)<<29|g>>>3)&536870911;g=0;break x}g=0-((h>>>0>3)+d|0)|0;d=3-h|0;g=((g&7)<<29|d>>>3)&536870911;d=0-g|0;g=0-((g|0)!=0)|0}t=f,u=Gc(d,g)^128,v[t+2|0]=u;Xe(e+32|0);continue}else{d=z[a+480190>>1]+1|0;w[e+54>>1]=d;f=0;h=d&65535;d=4e3-h|0;k=d>>>0<=4e3?d:0;y:{z:{A:{while(1){if((f|0)==(r|0)){break z}if((f|0)==(k|0)){x[31609]=0;P(183,b|0,20)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break z}b=N()|0;break b}x[31609]=0;i=f+h|0;P(240,b|0,s+(i<<5)|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break y}x[31609]=0;g=e+32|0;O(255,b|0,g|0);d=x[31609];x[31609]=0;B:{if((d|0)==1){break B}x[31609]=0;O(256,g|0,D(i,104)+o|0);d=x[31609];x[31609]=0;if((d|0)==1){break B}x[31609]=0;w[e+28>>1]=y[e+56|0]|f<<8&32512|((y[e+51|0]&3)!=0)<<15;O(257,m|0,e+28|0);d=x[31609];x[31609]=0;if((d|0)==1){break A}f=f+1|0;continue}break}b=N()|0;break b}b=N()|0;break b}x[31609]=0;O(257,l|0,e+54|0);d=x[31609];x[31609]=0;if((d|0)!=1){x[e+32>>2]=3999;x[e+28>>2]=r+z[a+480190>>1];t=a,u=x[Cd(e+32|0,e+28|0)>>2],w[t+480190>>1]=u;break q}b=N()|0;break b}b=N()|0;break b}}}b=N()|0;break b}g=Fb(e+80|0);x[31609]=0;f=P(230,b|0,g|0)|0;d=x[31609];x[31609]=0;C:{D:{E:{F:{G:{if((d|0)!=1){H:{if(f){x[31609]=0;f=e+32|0;S(258,f|0,21,g|0);d=x[31609];x[31609]=0;if((d|0)==1){break H}zb(a+1298320|0,f);tb(f)}tb(g);g=a+480280|0;f=0;I:{while(1){if((f|0)==32){x[31609]=0;f=P(259,b|0,e+16|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break E}if(!f){break F}g=x[e+16>>2];if(g>>>0<12){break G}f=x[b+8>>2];d=x[b>>2];x[31609]=0;f=U(150,d|0,f|0,g-11|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break E}if(f){break I}break G}d=g+(f<<5)|0;Ve(d);x[31609]=0;O(231,b|0,d+9|0);d=x[31609];x[31609]=0;if((d|0)!=1){f=f+1|0;continue}break}b=N()|0;break b}d=x[e+16>>2]-11|0;x[e+64>>2]=d;h=Nb(e+80|0);x[31609]=0;S(234,b|0,h|0,d|0);d=x[31609];x[31609]=0;J:{if((d|0)!=1){x[e+32>>2]=50529027;d=e+32|0;t=e,u=D(x[Hb(e- -64|0,d)>>2],85),x[t+56>>2]=u;j=Fb(d);x[e>>2]=x[e+20>>2];d=x[Hb(e+56|0,e)>>2];x[31609]=0;O(114,j|0,d|0);d=x[31609];x[31609]=0;K:{if((d|0)==1){break K}f=0;L:{while(1){d=x[e+64>>2];if(d>>>0<=f>>>0){break L}k=x[h>>2];g=v[xb(k,f)|0];i=d;d=f+1|0;if(!((g|0)!=-1|i-d>>>0<2)){i=v[xb(k,d)|0];g=y[xb(k,f+2|0)|0];d=x[vb(e+12|0,Df(j))>>2];x[31609]=0;V(237,j|0,d|0,g|0,i|0);d=x[31609];x[31609]=0;if((d|0)!=1){f=f+3|0;continue}break K}x[31609]=0;O(115,j|0,g|0);g=x[31609];x[31609]=0;f=d;if((g|0)!=1){continue}break}break K}x[31609]=0;S(235,e|0,21,j|0);d=x[31609];x[31609]=0;if((d|0)!=1){M:{i=zb(j,e);tb(e);g=Kb(i);f=y[i+11|0];d=x[i+4>>2];x[31609]=0;aa(236,a+1298332|0,g|0,_c(d,f)|0,74,0);d=x[31609];x[31609]=0;if((d|0)==1){break M}tb(i);fc(h);break G}}}b=N()|0;tb(j);break J}b=N()|0}fc(h);break b}}b=N()|0;tb(g);break b}f=y[a+484376|0];d=x[a+484360>>2];x[31609]=0;S(238,Xb(d,f)|0,b|0,y[e+258|0]|y[e+259|0]<<8);d=x[31609];x[31609]=0;if((d|0)==1){break E}i=c&1;if(i){x[31609]=0;O(223,a+484344|0,y[e+256|0]|y[e+257|0]<<8);d=x[31609];x[31609]=0;if((d|0)==1){break E}}k=a+484344|0;f=0;while(1){N:{if((y[e+256|0]|y[e+257|0]<<8)>>>0>f>>>0){g=x[b+8>>2];d=x[b>>2];x[31609]=0;g=U(150,d|0,g|0,4)|0;d=x[31609];x[31609]=0;if((d|0)==1){break C}if(g){break N}}if(!(c&2)){break F}f=0;while(1){c=z[a+480190>>1];if(f>>>0>=c>>>0){f=0;while(1){if(c>>>0<=f>>>0){break F}g=z[ac(x[m>>2],f)>>1];b=g&255;O:{if(!b){break O}d=x[l>>2];b=b-1&65535;if($c(d,x[l+4>>2])>>>0<=b>>>0){break O}b=z[ac(d,b)>>1]+(g>>>8&127)&65535;if(b>>>0>c>>>0){break O}i=D(b,104)+o|0;c=x[i>>2];if(!le(c,x[i+20>>2])){break O}b=z[i+34>>1];g=D(f,104)+o|0;d=g+104|0;x[d>>2]=c;w[g+138>>1]=z[g+138>>1]&65534|b&1;if(!Gh(d)){break O}zc(x[d+20>>2],x[i+20>>2],Qk(x[i>>2],z[i+34>>1]))}f=f+1|0;c=z[a+480190>>1];continue}}c=z[ac(x[m>>2],f)>>1];if(c&255){f=f+1|0;continue}f=f+1|0;d=D(f,104)+o|0;c=Zc(e+80|0,w[d+34>>1]&1?16:8,1,0,c<<16>>16<0?6:0);x[31609]=0;U(215,c|0,d|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){continue}break}b=N()|0;break b}x[31609]=0;g=R(151,b|0)|0;d=x[31609];x[31609]=0;P:{Q:{R:{S:{if((d|0)!=1){x[31609]=0;h=e+32|0;S(185,h|0,b|0,g|0);d=x[31609];x[31609]=0;if((d|0)==1){break S}j=hc(e+80|0,h);ub(h);if(!i){break Q}x[31609]=0;g=R(197,j|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break P}x[31609]=0;P(183,j|0,1)|0;d=x[31609];x[31609]=0;if((d|0)==1){break P}x[31609]=0;g=U(196,k|0,f&65535,g+1|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break P}if(!g){break Q}x[31609]=0;g=P(232,j|0,h|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break D}if(!g){break R}d=x[k>>2];x[31609]=0;O(233,Wb(d,f)|0,h|0);d=x[31609];x[31609]=0;if((d|0)!=1){break R}break D}b=N()|0;break b}b=N()|0;break b}d=x[k>>2];x[31609]=0;S(239,Wb(d,f)|0,1,j|0);d=x[31609];x[31609]=0;if((d|0)==1){break D}}ub(j);f=f+1|0;continue}break}break D}od(m);od(l);f=1;break e}b=N()|0;break b}b=N()|0;ub(j);break b}b=N()|0;break b}q=q+1|0;continue}}b=N()|0;break a}b=N()|0;break a}tb(n)}fb=e+272|0;return f|0}b=N()|0;break b}b=N()|0}od(m);od(l)}tb(n);Q(b|0);p()}function qK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=0,H=E(0),I=0;e=fb-144|0;fb=e;d=Rb(e,0,144);x[d+76>>2]=-1;x[d+44>>2]=a;x[d+32>>2]=1251;x[d+84>>2]=a;e=b;u=c;a=0;j=fb-304|0;fb=j;a:{b:{if(!x[d+4>>2]){At(d);if(!x[d+4>>2]){break b}}c=y[e|0];if(!c){break a}c:{d:{e:{f:{g:{while(1){h:{b=c&255;i:{if(fl(b)){while(1){c=e;e=e+1|0;if(fl(y[c+1|0])){continue}break}Bi(d,0,0);while(1){b=x[d+4>>2];j:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break j}b=td(d)}if(fl(b)){continue}break}e=x[d+4>>2];b=x[d+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){e=e-1|0;x[d+4>>2]=e}b=e-x[d+44>>2]|0;e=b;i=o+x[d+124>>2]|0;f=b>>31;b=l+x[d+120>>2]|0;i=f+(b>>>0<l>>>0?i+1|0:i)|0;l=b+e|0;o=l>>>0<b>>>0?i+1|0:i;break i}k:{l:{m:{if((b|0)==37){b=y[e+1|0];if((b|0)==42){break m}if((b|0)!=37){break l}}Bi(d,0,0);n:{if(y[e|0]==37){while(1){b=x[d+4>>2];o:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;c=y[b|0];break o}c=td(d)}if(fl(c)){continue}break}e=e+1|0;break n}b=x[d+4>>2];if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;c=y[b|0];break n}c=td(d)}if(y[e|0]!=(c|0)){a=x[d+116>>2];if((a|0)>0){a=1}else{a=(a|0)>=0}if(a){x[d+4>>2]=x[d+4>>2]-1}if((c|0)>=0|t){break a}break b}b=x[d+4>>2]-x[d+44>>2]|0;f=b;g=b>>31;b=o+x[d+124>>2]|0;c=l+x[d+120>>2]|0;h=(c>>>0<l>>>0?b+1|0:b)+g|0;l=c+f|0;o=l>>>0<c>>>0?h+1|0:h;c=e;break i}k=0;c=e+2|0;break k}b=b-48|0;if(!(y[e+2|0]!=36|b>>>0>9)){c=fb-16|0;x[c+12>>2]=u;b=b>>>0>1?((b<<2)+u|0)-4|0:u;x[c+8>>2]=b+4;k=x[b>>2];c=e+3|0;break k}k=x[u>>2];u=u+4|0;c=e+1|0}q=0;g=0;e=y[c|0];if(e-48>>>0<=9){while(1){g=(D(g,10)+e|0)-48|0;e=y[c+1|0];c=c+1|0;if(e-48>>>0<10){continue}break}}if((e|0)==109){n=0;q=(k|0)!=0;e=y[c+1|0];a=0;c=c+1|0}f=c;c=f+1|0;b=3;h=q;p:{q:{switch((e&255)-65|0){case 39:b=y[f+1|0]==104;c=b?f+2|0:c;b=b?-2:-1;break p;case 43:b=y[f+1|0]==108;c=b?f+2|0:c;b=b?3:1;break p;case 51:case 57:b=1;break p;case 11:b=2;break p;case 41:break p;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break q;default:break d}}b=0;c=f}f=b;b=y[c|0];e=(b&47)==3;z=e?1:f;p=e?b|32:b;r:{if((p|0)==91){break r}s:{if((p|0)!=110){if((p|0)!=99){break s}g=(g|0)<=1?1:g;break r}xI(k,z,l,o);break i}Bi(d,0,0);while(1){b=x[d+4>>2];t:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break t}b=td(d)}if(fl(b)){continue}break}e=x[d+4>>2];b=x[d+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){e=e-1|0;x[d+4>>2]=e}b=e-x[d+44>>2]|0;e=b;i=o+x[d+124>>2]|0;f=b>>31;b=l+x[d+120>>2]|0;o=f+(b>>>0<l>>>0?i+1|0:i)|0;l=b+e|0;o=l>>>0<b>>>0?o+1|0:o}r=g;m=g>>31;Bi(d,g,m);b=x[d+4>>2];u:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;break u}if((td(d)|0)<0){break e}}b=x[d+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){x[d+4>>2]=x[d+4>>2]-1}e=16;v:{w:{x:{y:{z:{switch(p-88|0){default:b=p-65|0;if(b>>>0>6|!(1<<b&113)){break v}case 9:case 13:case 14:case 15:wI(j+8|0,d,z,0);b=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]!=(0-b|0)|x[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break x}break f;case 3:case 11:case 27:if((p|16)==115){Rb(j+32|0,-1,257);v[j+32|0]=0;if((p|0)!=115){break w}v[j+65|0]=0;v[j+46|0]=0;w[j+42>>1]=0;w[j+44>>1]=0;break w}e=y[c+1|0];f=(e|0)==94;Rb(j+32|0,f,257);v[j+32|0]=0;b=f?c+2|0:c+1|0;A:{B:{C:{c=y[(f?2:1)+c|0];if((c|0)!=45){if((c|0)==93){break C}h=(e|0)!=94;break A}h=(e|0)!=94;v[j+78|0]=h;break B}h=(e|0)!=94;v[j+126|0]=h}b=b+1|0}c=b;while(1){b=y[c|0];D:{if((b|0)!=45){if(!b){break e}if((b|0)==93){break w}break D}b=45;f=y[c+1|0];if(!f|(f|0)==93){break D}i=c+1|0;e=y[c-1|0];E:{if(f>>>0<=e>>>0){b=f;break E}while(1){e=e+1|0;v[e+(j+32|0)|0]=h;b=y[i|0];if(e>>>0<b>>>0){continue}break}}c=i}v[(b+j|0)+33|0]=h;c=c+1|0;continue};case 23:e=8;break y;case 12:case 29:e=10;break y;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break v;case 0:case 24:case 32:break y;case 17:break z}}e=0}f=0;i=0;g=0;h=0;r=0;A=fb-16|0;fb=A;F:{if((e|0)==1){x[31484]=28;break F}while(1){b=x[d+4>>2];G:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break G}b=td(d)}if(fl(b)){continue}break}H:{I:{switch(b-43|0){case 0:case 2:break I;default:break H}}r=(b|0)==45?-1:0;b=x[d+4>>2];if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break H}b=td(d)}J:{K:{L:{M:{if(!((e|0)!=0&(e|0)!=16|(b|0)!=48)){b=x[d+4>>2];N:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break N}b=td(d)}if((b&-33)==88){e=16;b=x[d+4>>2];O:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break O}b=td(d)}if(y[b+104561|0]<16){break L}b=x[d+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){x[d+4>>2]=x[d+4>>2]-1}Bi(d,0,0);break F}if(e){break M}e=8;break L}e=e?e:10;if(e>>>0>y[b+104561|0]){break M}b=x[d+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){x[d+4>>2]=x[d+4>>2]-1}Bi(d,0,0);x[31484]=28;break F}if((e|0)!=10){break L}g=b-48|0;if(g>>>0<=9){b=0;while(1){b=D(b,10)+g|0;f=b>>>0<429496729;e=x[d+4>>2];P:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break P}e=td(d)}g=e-48|0;if(f&g>>>0<=9){continue}break}f=b}if(g>>>0>9){break J}e=Aua(f,0,10,0);m=hb;while(1){i=m;f=e+g|0;i=f>>>0<g>>>0?i+1|0:i;e=(i|0)==429496729&f>>>0<2576980378|i>>>0<429496729;b=x[d+4>>2];Q:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break Q}b=td(d)}h=b-48|0;if(!(e&h>>>0<=9)){e=10;if(h>>>0<=9){break K}break J}e=Aua(f,i,10,0);m=hb;g=h;if((m|0)==-1&(g^-1)>>>0>=e>>>0|(m|0)!=-1){continue}break}e=10;break K}if(e-1&e){h=y[b+104561|0];if(h>>>0<e>>>0){while(1){g=D(e,g)+h|0;f=g>>>0<119304647;b=x[d+4>>2];R:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break R}b=td(d)}h=y[b+104561|0];if(f&h>>>0<e>>>0){continue}break}f=g}if(e>>>0<=h>>>0){break K}while(1){g=Aua(f,i,e,0);m=hb;h=h&255;if((m|0)==-1&(h^-1)>>>0<g>>>0){break K}i=m;f=g+h|0;i=f>>>0<h>>>0?i+1|0:i;b=x[d+4>>2];S:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break S}b=td(d)}h=y[b+104561|0];if(e>>>0<=h>>>0){break K}Mf(A,e,0,0,0,f,i,0,0);if(!(x[A+8>>2]|x[A+12>>2])){continue}break}break K}m=v[(D(e,23)>>>5&7)+104817|0];g=y[b+104561|0];if(g>>>0<e>>>0){while(1){h=h<<m|g;f=h>>>0<134217728;b=x[d+4>>2];T:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break T}b=td(d)}g=y[b+104561|0];if(f&g>>>0<e>>>0){continue}break}f=h}if(e>>>0<=g>>>0){break K}s=m&31;if((m&63)>>>0>=32){h=0;s=-1>>>s|0}else{h=-1>>>s|0;s=h|(1<<s)-1<<32-s}if(!h&f>>>0>s>>>0){break K}while(1){F=g&255;g=f;b=m&31;if((m&63)>>>0>=32){i=f<<b;b=0}else{i=(1<<b)-1&g>>>32-b|i<<b;b=g<<b}f=F|b;b=x[d+4>>2];U:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break U}b=td(d)}g=y[b+104561|0];if(e>>>0<=g>>>0){break K}if((i|0)==(h|0)&f>>>0<=s>>>0|i>>>0<h>>>0){continue}break}}if(y[b+104561|0]>=e>>>0){break J}while(1){b=x[d+4>>2];V:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break V}b=td(d)}if(y[b+104561|0]<e>>>0){continue}break}x[31484]=68;f=-1;i=-1;r=0}b=x[d+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){x[d+4>>2]=x[d+4>>2]-1}b=f^r;f=b-r|0;e=r>>31;i=(e^i)-((b>>>0<r>>>0)+e|0)|0}fb=A+16|0;b=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]==(0-b|0)&x[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break f}if(!(!k|(p|0)!=112)){x[k>>2]=f;break v}xI(k,z,f,i);break v}if(!k){break v}b=x[j+16>>2];f=x[j+20>>2];e=x[j+8>>2];g=x[j+12>>2];W:{switch(z|0){case 0:G=k,H=XG(e,g,b,f),B[G>>2]=H;break v;case 1:G=k,I=Fx(e,g,b,f),C[G>>3]=I;break v;case 2:break W;default:break v}}x[k>>2]=e;x[k+4>>2]=g;x[k+8>>2]=b;x[k+12>>2]=f;break v}i=(p|0)!=99;b=i?31:g+1|0;X:{if((z|0)==1){g=k;if(q){g=Gd(b<<2);if(!g){break g}}x[j+296>>2]=0;x[j+300>>2]=0;e=0;while(1){a=g;Y:{while(1){f=x[d+4>>2];Z:{if((f|0)!=x[d+104>>2]){x[d+4>>2]=f+1;f=y[f|0];break Z}f=td(d)}if(!y[(f+j|0)+33|0]){break Y}v[j+27|0]=f;f=fq(j+28|0,j+27|0,1,j+296|0);if((f|0)==-2){continue}if((f|0)==-1){n=0;break e}if(a){x[(e<<2)+a>>2]=x[j+28>>2];e=e+1|0}if(!q|(b|0)!=(e|0)){continue}break}h=1;n=0;e=b;b=b<<1|1;g=Vv(a,b<<2);if(g){continue}break d}break}n=0;b=a;f=j+296|0;if(f){f=x[f>>2]}else{f=0}if(f){break e}break X}if(q){e=0;g=Gd(b);if(!g){break g}while(1){a=g;while(1){f=x[d+4>>2];_:{if((f|0)!=x[d+104>>2]){x[d+4>>2]=f+1;f=y[f|0];break _}f=td(d)}if(!y[(f+j|0)+33|0]){b=0;n=a;break X}v[a+e|0]=f;e=e+1|0;if((e|0)!=(b|0)){continue}break}h=1;e=b;b=b<<1|1;g=Vv(a,b);if(g){continue}break}n=a;a=0;break d}e=0;if(k){while(1){a=x[d+4>>2];$:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break $}a=td(d)}if(y[(a+j|0)+33|0]){v[e+k|0]=a;e=e+1|0;continue}else{b=0;a=k;n=a;break X}}}while(1){a=x[d+4>>2];aa:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break aa}a=td(d)}if(y[(a+j|0)+33|0]){continue}break}a=0;n=0;b=0}g=x[d+4>>2];f=x[d+116>>2];if((f|0)>0){f=1}else{f=(f|0)>=0}if(f){g=g-1|0;x[d+4>>2]=g}g=g-x[d+44>>2]|0;f=g+x[d+120>>2]|0;h=x[d+124>>2]+(g>>31)|0;h=f>>>0<g>>>0?h+1|0:h;if(!(h|f)|!(i|(f|0)==(r|0)&(h|0)==(m|0))){break h}if(q){x[k>>2]=a}ba:{if((p|0)==99){break ba}if(b){x[(e<<2)+b>>2]=0}if(!n){n=0;break ba}v[e+n|0]=0}a=b}b=x[d+4>>2]-x[d+44>>2]|0;f=b;g=b>>31;b=o+x[d+124>>2]|0;e=l+x[d+120>>2]|0;i=(e>>>0<l>>>0?b+1|0:b)+g|0;l=e+f|0;o=l>>>0<e>>>0?i+1|0:i;t=((k|0)!=0)+t|0}e=c+1|0;c=y[c+1|0];if(c){continue}break a}break}a=b;break f}h=1;n=0;a=0;break d}h=q;break c}h=q}t=t?t:-1}if(!h){break a}Db(n);Db(a);break a}t=-1}fb=j+304|0;fb=d+144|0;return t}function joa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=fb-192|0;fb=j;if(!qv(a)){e=j+40|0;aW(e,a);f=j+168|0;bf(f,e,128,2);e=j+180|0;Cc(e,f);Ac(b+492|0,e);tb(e)}w[c+34>>1]=z[c+34>>1]&65489;o=j+180|0;g=fb-32|0;fb=g;a:{b:{switch(y[a+128|0]-4|0){default:x[g+28>>2]=0;qn(o,0,g+28|0);break a;case 0:case 4:break b}}v[g+28|0]=y[a+129|0];v[g+24|0]=100;k=g+24|0;e=y[Qb(g+28|0,k)|0];v[g+24|0]=y[a+130|0];v[g+20|0]=100;l=g+20|0;m=y[Qb(k,l)|0];x[g+28>>2]=m;c:{if(y[a+140|0]&16){i=Bb(y[a+150|0]|y[a+151|0]<<8);h=Bb(y[a+152|0]|y[a+153|0]<<8);f=x[c>>2];s=+(f>>>0)/6553600;e=vr(s*+((i|e<<16)>>>0));x[g+24>>2]=f-e;t=g,u=vr(s*+((h|m<<16)>>>0)),x[t+20>>2]=u;t=g,u=x[Hb(k,l)>>2],x[t+28>>2]=u;break c}i=x[c>>2];l=x[c+20>>2];if(!le(i,l)){break c}f=i>>>7|0;e=D(f,(e<<7>>>0)/100|0);x[g+24>>2]=i-e;x[g+20>>2]=D(f,(m<<7>>>0)/100|0);f=x[Hb(g+24|0,g+20|0)>>2];h=z[c+34>>1];i=D(_d(h),i);d:{if(h&1){cc(g+12|0,l,i);l=x[g+12>>2];i=_d(z[c+34>>1]);h=l+(D(i,e+f|0)<<1)|0;m=w[l+(D(e,i)<<1)>>1];l=0-i<<1;while(1){e:{f:{if(f){i=w[h>>1]-m|0;k=i>>31;if((i^k)-k>>>0>=1536){break f}}else{f=0}break e}f=f-1|0;h=h+l|0;continue}break}break d}cc(g+4|0,l,i);l=x[g+4>>2];i=_d(z[c+34>>1]);m=0-i|0;h=l+D(i,e+f|0)|0;l=v[l+D(e,i)|0];while(1){g:{h:{if(f){i=v[h|0]-l|0;k=i>>31;if((i^k)-k>>>0>=6){break h}}else{f=0}break g}f=f-1|0;h=h+m|0;continue}break}}x[g+28>>2]=f}qn(o,e,g+28|0)}fb=g+32|0;r=gc(o);if(!(!x[r>>2]|y[a+128|0]!=4)){w[c+34>>1]=z[c+34>>1]|2;f=x[j+180>>2];x[c+4>>2]=f;x[c+8>>2]=f+x[r>>2]}f=j;e=y[a+134|0];if((e-1&255)>>>0<=198){v[f+40|0]=e;v[f+168|0]=100;e=(y[Qb(f+40|0,f+168|0)|0]<<7>>>0)/100|0}else{e=128}v[f+39|0]=e;v[j+40|0]=64;e=j+39|0;f=j+40|0;t=c,u=y[cf(e,f)|0]>>>1|0,w[t+32>>1]=u;v[j+40|0]=64;t=b,u=y[Qb(e,f)|0],x[t+4>>2]=u;x[c+24>>2]=40460;_l(c,+v[a+139|0]/12+ +(0-y[a+143|0]|0)+ +v[a+138|0]/1536);v[b+34|0]=y[a+142|0]&2?2:1;if(y[a+142|0]&2){ck(b,127,1);bk(b,0,1)}i:{if(!le(x[c>>2],x[c+20>>2])){break i}b=y[a+140|0];if(b&1){b=x[c>>2];g=x[c+20>>2];j:{if(!le(b,g)|b>>>0<2){break j}k:{l:{switch(Zk(z[c+34>>1])-1|0){case 3:e=b>>>1|0;b=g+(b<<2)|0;f=0;while(1){if((e|0)!=(f|0)){Tb(g+(f<<2)|0,b+((f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:e=b>>>1|0;b=g+(b<<1)|0;f=0;while(1){if((e|0)!=(f|0)){DR(g+(f<<1)|0,b+((f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}e=b+g|0;b=b>>>1|0;f=0;while(1){if((b|0)!=(f|0)){rg(f+g|0,e+(f^-1)|0);f=f+1|0;continue}break}}Ij(c,d)}b=y[a+140|0]}if(b&4){m:{f=x[c>>2];g=x[c+20>>2];if(!le(f,g)){break m}b=z[c+34>>1];f=D(_d(b),f);n:{o:{switch(Jn(b)-1|0){case 1:e=0;while(1){if((e|0)!=(f|0)){b=g+(e<<1)|0;w[b>>1]=z[b>>1]^-1;e=e+1|0;continue}break};break n;case 0:break o;default:break m}}e=0;while(1){if((e|0)!=(f|0)){b=e+g|0;v[b|0]=y[b|0]^-1;e=e+1|0;continue}break}}Ij(c,d)}}p=y[a+170|0]!=2|y[a+171|0]>100?p:y[a+172|0]<101;b=z[c+34>>1];if(!(!(p|y[a+160|0]!=0|y[a+141|0])|b&1)){f=pv(x[c>>2],_d(b)<<1&254);if(!f){break i}b=f;h=x[c>>2];e=z[c+34>>1];g=D(_d(e),h);k=x[c+20>>2];e=Qk(h,e);i=fb-16|0;fb=i;x[i+12>>2]=g;xc(i+12|0,e);h=x[i+12>>2];while(1){if(h){w[b>>1]=v[k|0]<<8;k=k+1|0;b=b+2|0;h=h-1|0;continue}break}fb=i+16|0;w[c+34>>1]=z[c+34>>1]|1;_V(c,f,x[c>>2],d);b=z[c+34>>1]}f=x[c>>2];e=x[c+20>>2];p:{if(v[a+141|0]>=0){break p}cc(j+40|0,e,D(_d(b),f));q:while(1){if((0-v[a+141|0]|0)<=(q|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1];break p}b=x[j+40>>2];f=w[b>>1];t=j,u=wb(b),x[t+168>>2]=u;b=fn(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,b)){f=rd(w[e>>1]-rd(f,1)|0,1);w[e>>1]=f;ge(j+168|0);continue}else{q=q+1|0;continue q}}}}if(p){cc(j+40|0,e,D(_d(b),f));h=x[j+44>>2];b=(h|0)/2|0;e=b;f=e>>31;b=y[a+172|0];i=y[a+171|0];g=b-i|0;k=0-(b>>>0<i>>>0)<<24|g>>>8;b=g<<24;e=b+e|0;f=f+k|0;b=Gc(Bua(e,b>>>0>e>>>0?f+1|0:f,h,h>>31),hb);t=j,u=wb(x[j+40>>2]),x[t+168>>2]=u;g=b;l=b>>31;b=i<<24;f=b>>31;i=fn(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,i)){h=w[e>>1];h=Aua(b,f,h,h>>31);k=hb;h=h+838860800|0;k=h>>>0<838860800?k+1|0:k;t=e,u=Gc(Bua(h,k,1677721600,0),hb),w[t>>1]=u;f=f+l|0;b=b+g|0;f=b>>>0<g>>>0?f+1|0:f;ge(j+168|0);continue}break}f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1]}if(y[a+160|0]){cc(j+168|0,e,D(_d(b),f));m=y[a+163|0];l=y[a+162|0];f=0;k=0;if(y[a+161|0]>=2){i=x[j+172>>2];b=(i|0)/2|0;h=b;g=b>>31;b=y[a+164|0];e=0-(b>>>0<l>>>0)|0;b=b-l|0;k=e<<23|b>>>9;b=b<<23;e=b+h|0;k=g+k|0;n=Gc(Bua(e,b>>>0>e>>>0?k+1|0:k,i,i>>31),hb);i=x[j+172>>2];b=(i|0)/2|0;h=b;g=b>>31;b=y[a+165|0];e=0-(b>>>0<m>>>0)|0;b=b-m|0;k=e<<23|b>>>9;b=b<<23;e=b+h|0;g=g+k|0;k=Gc(Bua(e,b>>>0>e>>>0?g+1|0:g,i,i>>31),hb)}e=m<<23;q=l<<23;g=y[a+160|0];b=wb(x[j+168>>2]);x[j+32>>2]=b;i=(j+40|0)+((g&2)<<2)|0;h=fn(x[j+168>>2],x[j+172>>2]);p=0;while(1){if(Ib(b,h)){g=(w[b>>1]>>1)-p|0;x[j+48>>2]=g;m=g;g=(q|0)/8388608|0;f=rd(D(m,g),8)+f|0;x[j+44>>2]=f;g=rd(D(f,g),6)+p|0;p=rd(rd(D(g,(e|0)/8388608|0),6)+g|0,2);x[j+40>>2]=p;t=b,u=gd(x[i>>2]),w[t>>1]=u;e=e+k|0;q=n+q|0;b=x[ge(j+32|0)>>2];continue}else{f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1]}break}}r:{if(v[a+141|0]<=0){break r}cc(j+40|0,e,D(_d(b),f));q=0;s:while(1){if(v[a+141|0]<=(q|0)){f=x[c>>2];e=x[c+20>>2];b=z[c+34>>1];break r}b=x[j+40>>2];f=w[b>>1];t=j,u=wb(b),x[t+168>>2]=u;b=fn(x[j+40>>2],x[j+44>>2]);while(1){e=x[j+168>>2];if(Ib(e,b)){f=((w[e>>1]<<1)+f|0)/3|0;w[e>>1]=f;ge(j+168|0);continue}else{q=q+1|0;continue s}}}}f=D(_d(b),f);t:{if(b&1){cc(j+24|0,e,f);m=x[j+28>>2];b=fb-16|0;fb=b;k=x[j+24>>2];e=wb(k);q=fn(k,m);p=fb-16|0;fb=p;v[p+14|0]=0;o=fb-16|0;fb=o;x[o+12>>2]=e;Zb(o+4|0,p+15|0,p+14|0);l=b+8|0;f=o+12|0;h=qn(l,e,f);u:{if(mc(e,q)){break u}n=ge(f);g=x[n>>2];if(mc(g,q)){break u}e=x[h>>2];f=Rl(g,e);x[(f?0:4)+h>>2]=g;f=f?g:e;i=h+4|0;while(1){g=ge(n);e=x[g>>2];if(!Ib(e,q)){break u}g=x[ge(g)>>2];if(mc(g,q)){if(!Rl(e,f)){h=i;if(Rl(e,x[i>>2])){break u}}x[h>>2]=e;break u}v:{if(Rl(g,e)){if(Rl(g,f)){x[h>>2]=g;f=g}if(Rl(e,x[i>>2])){continue}break v}if(Rl(e,f)){x[h>>2]=e;f=e}e=g;if(Rl(e,x[i>>2])){continue}}x[i>>2]=e;continue}}fb=o+16|0;fb=p+16|0;x[b+4>>2]=0-w[x[b+8>>2]>>1];t=b,u=w[x[gc(l)>>2]>>1],x[t>>2]=u;w:{g=x[Ye(b+4|0,b)>>2];if((g|0)>32766|!g){break w}e=wb(k);x[b+4>>2]=e;f=fn(k,m);while(1){if(!Ib(e,f)){break w}w[e>>1]=(D(w[e>>1],32767)|0)/(g|0);e=x[ge(b+4|0)>>2];continue}}break t}cc(j+16|0,e,f);m=x[j+20>>2];b=fb-16|0;fb=b;k=x[j+16>>2];e=wb(k);q=Yj(k,m);p=fb-16|0;fb=p;v[p+14|0]=0;o=fb-16|0;fb=o;x[o+12>>2]=e;Zb(o+4|0,p+15|0,p+14|0);l=b+8|0;f=o+12|0;h=qn(l,e,f);x:{if(mc(e,q)){break x}n=we(f);g=x[n>>2];if(mc(g,q)){break x}e=x[h>>2];f=Sl(g,e);x[(f?0:4)+h>>2]=g;f=f?g:e;i=h+4|0;while(1){g=we(n);e=x[g>>2];if(!Ib(e,q)){break x}g=x[we(g)>>2];if(mc(g,q)){if(!Sl(e,f)){h=i;if(Sl(e,x[i>>2])){break x}}x[h>>2]=e;break x}y:{if(Sl(g,e)){if(Sl(g,f)){x[h>>2]=g;f=g}if(Sl(e,x[i>>2])){continue}break y}if(Sl(e,f)){x[h>>2]=e;f=e}e=g;if(Sl(e,x[i>>2])){continue}}x[i>>2]=e;continue}}fb=o+16|0;fb=p+16|0;x[b+4>>2]=0-v[x[b+8>>2]];t=b,u=v[x[gc(l)>>2]],x[t>>2]=u;z:{g=x[Ye(b+4|0,b)>>2];if((g|0)>126|!g){break z}e=wb(k);x[b+4>>2]=e;f=Yj(k,m);while(1){if(!Ib(e,f)){break z}v[e|0]=(D(v[e|0],127)|0)/(g|0);e=x[we(b+4|0)>>2];continue}}}fb=b+16|0;A:{if((y[a+134|0]-101&255)>>>0>98){break A}b=z[c+34>>1];f=D(x[c>>2],_d(b));e=x[c+20>>2];if(b&1){x[j+8>>2]=e;x[j+12>>2]=(e+(f<<1)|0)-e>>1;g=x[j+12>>2];f=y[a+134|0];h=fb-16|0;fb=h;b=x[j+8>>2];e=wb(b);x[h+12>>2]=e;n=(3276800-(f<<14)|0)/100|0;f=0-n|0;i=32768-n|0;b=fn(b,g);while(1){if(Ib(e,b)){g=w[e>>1];B:{if((g|0)>(n|0)){m=i+((D(n,g-n|0)|0)/(i|0)|0)|0;break B}m=((D(n,g+n|0)|0)/(i|0)|0)-i|0;if((f|0)>(g|0)){break B}m=(D(g,i)|0)/(n|0)|0}t=e,u=gd(m),w[t>>1]=u;e=x[ge(h+12|0)>>2];continue}break}fb=h+16|0;break A}b=wl(j,e,e+f|0);h=x[b>>2];g=x[b+4>>2];b=y[a+134|0];i=fb-16|0;fb=i;e=wb(h);x[i+12>>2]=e;l=(3276800-(b<<14)|0)/100|0;f=0-l|0;n=32768-l|0;b=Yj(h,g);while(1){if(Ib(e,b)){g=v[e|0]<<8;C:{if((g|0)>(l|0)){h=n+((D(l,g-l|0)|0)/(n|0)|0)|0;break C}h=((D(l,g+l|0)|0)/(n|0)|0)-n|0;if((f|0)>(g|0)){break C}h=(D(g,n)|0)/(l|0)|0}t=e,u=cY((h|0)/256|0),v[t|0]=u;e=x[we(i+12|0)>>2];continue}break}fb=i+16|0}ZV(c);if(y[a+128|0]!=8){break i}f=y[a+131|0];if(!f){break i}b=x[r>>2];if(!b){break i}t=yb(c+68|0,0),u=x[j+180>>2]+D(b,f+1|0)|0,x[t>>2]=u;h=x[j+180>>2];x[c+12>>2]=h;x[c+16>>2]=h+x[r>>2];e=x[r>>2];g=y[a+131|0];if(e>>>0>268435456/(g>>>0)>>>0){break i}b=x[c>>2];f=D(e,g);if(b>>>0>268435456-f>>>0){break i}k=b+f|0;o=Zk(z[c+34>>1]);b=pv(k,o);if(!b){break i}l=h+D(e,g+1|0)|0;x[c>>2]=k;n=x[c+20>>2];i=x[r>>2];h=x[j+180>>2];g=D(o,i+h|0);m=zc(b,n,g);e=D(i,o);f=n+D(h,o)|0;a=y[a+131|0];b=0;while(1){if((a|0)==(b|0)){zc(m+D(l,o)|0,g+n|0,D(o,k-l|0));_V(c,m,k,d)}else{b=b+1|0;zc(m+D(o,h+D(i,b)|0)|0,f,e);continue}break}}fb=j+192|0}function Aja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;d=fb-720|0;fb=d;yc(b);a:{b:{c:{d:{if(!vi(b,d+712|0)){break d}if(!qR(x[d+712>>2],x[d+716>>2])){break d}if(!Pr(b,d+708|0)){break d}f=x[d+708>>2];if(!pR(f)){break d}if((f|0)==1179012417){f=0}else{if((f|0)!=538987841){break d}f=1}e=f?2:1;g=f?1414090313:1313423693;o=He(d+688|0,b);k=Nb(d+676|0);e:{f:{g:{h:{i:{j:{k:{if((c|0)==64){x[31609]=0;b=d+112|0;V(894,b|0,o|0,e|0,g|0);e=x[31609];x[31609]=0;if((e|0)!=1){break k}a=N()|0;break a}x[31609]=0;b=d+112|0;S(895,b|0,o|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break j}}Cv(k,b);ke(b);x[31609]=0;b=d+656|0;S(896,b|0,k|0,g|0);e=x[31609];x[31609]=0;if((e|0)!=1){x[31609]=0;g=R(172,x[d+656>>2])|0;e=x[31609];x[31609]=0;if((e|0)==1){break i}e=0;if(!g){break e}x[31609]=0;i=d+583|0;b=P(897,b|0,i|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break i}if(!b){break e}b=y[d+648|0];if(!b){break e}x[31609]=0;e=U(150,x[d+656>>2],x[d+664>>2],b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break i}if(!((c|0)!=64&e)){break e}x[31609]=0;O(246,a|0,8388608);b=x[31609];x[31609]=0;if((b|0)==1){break i}x[a+480208>>2]=y[d+647|0]<<4&16^28;w[d+112>>1]=y[d+648|0];w[d+464>>1]=127;b=d+112|0;e=d+464|0;r=a,s=z[Oc(b,e)>>1],w[r+480188>>1]=s;x[a+480196>>2]=y[d+649|0];x[a+480204>>2]=D(y[d+650|0],1e4);x[a+480200>>2]=y[d+655|0]<<1;x[31609]=0;O(130,a+1298344|0,(f?16971:17005)|0);g=x[31609];x[31609]=0;if((g|0)==1){break i}x[31609]=0;g=P(1,d+568|0,13334)|0;m=x[31609];x[31609]=0;if((m|0)==1){break g}zb(a+1298356|0,g);tb(g);r=a,s=x[Fc(b,4)>>2],x[r+1298404>>2]=s;KC(e,2,i);x[31609]=0;O(218,b|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break h}zb(a+1298308|0,b);i=a+480280|0;tb(b);b=0;while(1){l:{m:{n:{if(z[a+480188>>1]<=b>>>0){b=wb(x[k>>2]);g=wb(x[k+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=b;while(1){o:{if(!Ib(b,g)){break o}if(u$(1380209231,x[b>>2],x[b+4>>2])){break o}b=x[dm(e+12|0)>>2];continue}break}fb=e+16|0;if(Ib(b,wb(x[k+4>>2]))){break n}break f}g=i+(b<<5)|0;Ve(g);x[31609]=0;e=R(197,d+656|0)|0;m=x[31609];x[31609]=0;p:{q:{if((m|0)!=1){if(!f){break p}if(e>>>0<129){break q}break m}a=N()|0;break b}w[g+4>>1]=e<<1;break l}if(e<<24>>24<0){break m}x[d+112>>2]=e<<2;x[d+464>>2]=256;r=g,s=x[Cd(d+112|0,d+464|0)>>2],w[r+4>>1]=s;break l}x[31609]=0;b=d+112|0;S(896,b|0,k|0,1380209231);e=x[31609];x[31609]=0;r:{if((e|0)!=1){x[31609]=0;e=R(197,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break r}g=y[a+484376|0];i=x[a+484360>>2];x[31609]=0;aa(348,Xb(i,g)|0,b|0,e+1&255,255,254);e=x[31609];x[31609]=0;if((e|0)==1){break r}ub(b);break f}a=N()|0;break b}a=N()|0;ub(d+112|0);break b}x[g>>2]=1024}b=b+1|0;continue}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}s:{if(!(c&1)){break s}w[d+48>>1]=0;x[31609]=0;S(898,d+528|0,k|0,1414807888);b=x[31609];x[31609]=0;if((b|0)==1){break c}b=x[d+532>>2];e=x[d+528>>2];x[31609]=0;i=a+484344|0;O(223,i|0,Sf(e,b)&65535);b=x[31609];x[31609]=0;t:{if((b|0)!=1){r=d,s=wb(x[d+528>>2]),x[r+76>>2]=s;m=wb(x[d+532>>2]);u:{v:{w:{x:{y:{while(1){b=x[d+76>>2];if(!Ib(b,m)){b=0;break u}b=He(d+112|0,b);x[31609]=0;e=R(197,b|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){x[31609]=0;w[d+452>>1]=e;e=R(151,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break y}x[31609]=0;g=d+464|0;S(185,g|0,b|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break x}e=hc(d+548|0,g);x[31609]=0;n=x[e+12>>2];x[d+8>>2]=x[e+8>>2];x[d+12>>2]=n;x[d+16>>2]=x[e+16>>2];n=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=n;V(899,d|0,z[d+452>>1],f|0,a|0);e=x[31609];x[31609]=0;if((e|0)==1){break w}ub(g);r=d,s=z[qe(d+48|0,d+452|0)>>1],w[r+48>>1]=s;ub(b);Qf(d+76|0);continue}break}a=N()|0;break v}a=N()|0;break v}a=N()|0;break v}a=N()|0;ub(d+464|0)}ub(b);break t}while(1){e=b&65535;if(e>>>0>=z[d+48>>1]){Rc(d+528|0);break s}z:{if(!Je(x[a+484344>>2],x[a+484348>>2],e)){x[31609]=0;U(196,i|0,e|0,64)|0;e=x[31609];x[31609]=0;if((e|0)==1){break z}}b=b+1|0;continue}break}a=N()|0;break t}a=N()|0}Rc(d+528|0);break b}A:{B:{C:{if(!f){x[31609]=0;S(898,d+76|0,k|0,1414745673);b=x[31609];x[31609]=0;if((b|0)==1){break B}r=d,s=wb(x[d+76>>2]),x[r+100>>2]=s;g=c&2;i=a+484380|0;m=a+946304|0;n=d+472|0;q=wb(x[d+80>>2]);while(1){b=x[d+100>>2];if(!Ib(b,q)){Rc(d+76|0);break A}c=He(d+528|0,b);x[31609]=0;e=d+112|0;b=P(900,c|0,e|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){D:{if(!b){break D}b=y[d+113|0];if((b|0)==255){break D}x[31609]=0;f=U(251,a|0,b+1|0,0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break C}if(!f){break D}j=z[a+480190>>1];b=0;x[31609]=0;S(901,e|0,f|0,j|0);f=x[31609];x[31609]=0;if((f|0)==1){break C}while(1){if(y[d+142|0]<=b>>>0){break D}E:{if(!oi(z[a+480190>>1])){break E}x[31609]=0;e=d+464|0;f=P(902,c|0,e|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break C}if(!f){break E}j=z[a+480190>>1]+1|0;w[a+480190>>1]=j;if(x[d+464>>2]!=1347240275){break E}h=d+452|0;Vi(h,2,n);x[31609]=0;f=d+48|0;O(218,f|0,h|0);h=x[31609];x[31609]=0;F:{if((h|0)!=1){j=j&65535;Ac(m+(j<<5)|0,f);tb(f);x[31609]=0;h=e;e=i+D(j,104)|0;S(903,h|0,d+112|0,e|0);j=x[31609];x[31609]=0;if((j|0)==1){break C}if(!g){break F}oR(f,z[d+502>>1]);x[31609]=0;U(215,f|0,e|0,c|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){break E}break C}break C}f=z[e+34>>1];e=x[e>>2];x[31609]=0;P(183,c|0,Qk(e,f)|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break C}}b=b+1|0;continue}}ub(c);Qf(d+100|0);continue}break}break C}x[31609]=0;S(898,d+452|0,k|0,1179011410);b=x[31609];x[31609]=0;if((b|0)!=1){r=d,s=wb(x[d+452>>2]),x[r+448>>2]=s;g=c&2;i=a+484380|0;m=a+946304|0;n=d+468|0;q=wb(x[d+456>>2]);G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{while(1){b=x[d+448>>2];if(!Ib(b,q)){Rc(d+452|0);break A}c=He(d+528|0,b);x[31609]=0;b=R(151,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break P}Q:{R:{if((b|0)!=538986817){break R}x[31609]=0;b=P(904,c|0,d+440|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break O}if(!(x[d+440>>2]==1414745673&b)){break R}x[31609]=0;f=d+112|0;b=P(905,c|0,f|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break N}if(!b){break R}b=y[d+117|0];if((b|0)==255){break R}x[31609]=0;b=U(251,a|0,b+1|0,0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break M}if(!b){break R}e=z[a+480190>>1];x[31609]=0;S(906,f|0,b|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break M}x[31609]=0;b=d+464|0;S(895,b|0,c|0,2);f=x[31609];x[31609]=0;if((f|0)==1){break Q}x[31609]=0;S(898,d+100|0,b|0,1179011410);f=x[31609];x[31609]=0;if((f|0)==1){break L}ke(b);r=d,s=wb(x[d+100>>2]),x[r+96>>2]=s;j=wb(x[d+104>>2]);S:{T:{while(1){b=x[d+96>>2];if(!Ib(b,j)){break S}b=He(d+76|0,b);x[31609]=0;f=R(151,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break K}U:{V:{if((f|0)!=538989377){break V}f=z[a+480190>>1];if(!oi(f)){break V}e=y[d+436|0]|y[d+437|0]<<8;h=e-1|0;v[d+436|0]=h;v[d+437|0]=h>>>8;if(!e){ub(b);break S}h=f+1|0;w[a+480190>>1]=h;x[31609]=0;f=P(904,b|0,d+68|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break J}if(!(x[d+68>>2]==1347240275&f)){break T}x[31609]=0;e=d+464|0;S(185,e|0,b|0,x[d+72>>2]);f=x[31609];x[31609]=0;W:{if((f|0)!=1){f=hc(d+48|0,e);ub(e);x[31609]=0;e=P(907,f|0,e|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break U}if(e){break W}ub(f);ub(b);break S}a=N()|0;break H}l=d+24|0;Ue(l,2,n);x[31609]=0;e=d+36|0;O(218,e|0,l|0);l=x[31609];x[31609]=0;if((l|0)==1){break I}h=h&65535;Ac(m+(h<<5)|0,e);tb(e);x[31609]=0;h=i+D(h,104)|0;S(908,d+464|0,d+112|0,h|0);l=x[31609];x[31609]=0;if((l|0)==1){break U}X:{if(!g){break X}x[31609]=0;P(149,f|0,x[d+464>>2]+4|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break U}oR(e,z[d+504>>1]);x[31609]=0;U(215,e|0,h|0,f|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break X}break I}ub(f)}ub(b);Qf(d+96|0);continue}break}break I}ub(b)}Rc(d+100|0)}ub(c);Qf(d+448|0);continue}break}a=N()|0;break G}a=N()|0;break G}a=N()|0;break G}a=N()|0;break G}a=N()|0;break G}a=N()|0;ke(d+464|0);break G}a=N()|0;break H}a=N()|0;break H}a=N()|0;ub(f)}ub(b);Rc(d+100|0)}ub(c);Rc(d+452|0);break b}a=N()|0;break b}a=N()|0;ub(c);Rc(d+76|0);break b}a=N()|0;break b}e=1}ub(d+656|0);ke(k);ub(o)}fb=d+720|0;return e|0}a=N()|0}ub(d+656|0)}ke(k);ub(o);Q(a|0);p()}function p2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0;e=fb-1456|0;fb=e;yc(b);Lp(a);a:{b:{c:{d=e+1432|0;if(!ps(b,d)){break c}if(!IG(d)){break c}if(!c){i=1;break c}if(!wm(x[b>>2],y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))){break c}if(!wm(x[b>>2],(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+((y[e+1444|0]|y[e+1445|0]<<8)<<2)|0)){break c}tx(a);w=e,B=sx(),x[w+68>>2]=B;c=e+68|0;rx(cj(x[a+4>>2])+32|0,c);os(c);l=x[cj(x[a+4>>2])+32>>2];x[e+1428>>2]=y[e+1446|0]|y[e+1447|0]<<8|(y[e+1448|0]<<16|y[e+1449|0]<<24);w=e,B=Lh(x[b>>2]),x[w+1168>>2]=B;x[e+1136>>2]=214748364;d=e+1168|0;w=e,B=D(x[Hb(d,e+1136|0)>>2],20),x[w+68>>2]=B;to(l,x[Hb(e+1428|0,c)>>2]);Rb(d,0,256);s=Nb(e+1156|0);while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{i=(y[e+1444|0]|y[e+1445|0]<<8)>>>0<=t>>>0;if(!i){x[31609]=0;c=P(149,b|0,(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+(t<<2)|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break r}if(!c){break h}c=x[b+8>>2];d=x[b>>2];x[31609]=0;c=U(150,d|0,c|0,4)|0;d=x[31609];x[31609]=0;if((d|0)==1){break r}if(!c){break h}x[31609]=0;c=R(151,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break q}x[31609]=0;d=P(149,b|0,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break q}if(!d){break h}x[31609]=0;d=P(152,b|0,e+1136|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break p}if(!d){break h}x[31609]=0;d=U(153,b|0,s|0,y[e+1148|0]|y[e+1149|0]<<8)|0;f=x[31609];x[31609]=0;if((f|0)==1){break p}if(!d){break h}f=x[s>>2];h=x[b>>2];x[31609]=0;d=y[e+1148|0]|y[e+1149|0]<<8;h=R(154,h|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break o}n=h;h=c+20|0;if(n>>>0<=h+(d<<3)>>>0){break h}c=d?f:0;f=y[e+1148|0]|y[e+1149|0]<<8;j=h+(f<<3)|0;d=0;h=y[e+1150|0]|y[e+1151|0]<<8;if(!(h&1)){while(1){if((f&65535)>>>0<=d>>>0){break d}if(!c){break h}f=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);h=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31609]=0;f=ba(155,h|0,f|0,l|0,x[e+1428>>2])|0;h=x[31609];x[31609]=0;s:{if((h|0)==1){break s}if(!f){break h}x[31609]=0;f=P(149,b|0,j|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break s}if(!f){break h}f=Zb(e+1128|0,xb(x[l>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24));h=x[f>>2];f=x[f+4>>2];x[31609]=0;Yn(156,e+68|0,b,h,f);f=x[31609];x[31609]=0;if((f|0)==1){break n}if(x[e+72>>2]!=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))){break h}d=d+1|0;c=c+8|0;f=y[e+1148|0]|y[e+1149|0]<<8;continue}break}i=N()|0;break a}t:{if(h&4){if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31609]=0;d=ba(155,f|0,d|0,l|0,x[e+1428>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break m}if(!d){break h}o=xb(x[l>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));m=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!m){break h}x[31609]=0;h=y[e+1154|0]|y[e+1155|0]<<8;d=P(149,b|0,j+(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break l}if(!d){break h}d=x[b+8>>2];f=x[b>>2];x[31609]=0;d=U(150,f|0,d|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break l}if(!d){break h}x[31609]=0;d=e+48|0;S(157,d|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);f=x[31609];x[31609]=0;if((f|0)==1){break b}k=ns(e+68|0,d);ub(d);r=0;j=0;while(1){f=0;u:{while(1){if((j&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}x[31609]=0;d=P(158,k|0,h+1|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break u}g=h&15;q=z[(g<<1)+24384>>1];v:{w:{if(q>>>0>d>>>0){break w}x[31609]=0;g=y[g+24432|0];n=P(158,k|0,g|0)|0;u=x[31609];x[31609]=0;if((u|0)==1){break u}d=n+(d-q<<g)|0;if((d|0)!=(h|0)){h=d&15;break v}x[31609]=0;d=P(158,k|0,4)|0;g=x[31609];x[31609]=0;if((g|0)==1){break u}if((d|0)==15){x[31609]=0;g=P(158,k|0,1)|0;d=x[31609];x[31609]=0;if((d|0)==1){break u}d=65535;if(!g){break w}break e}d=d+65520|0;if(d>>>0>65535){break v}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;n=f+o|0;g=y[e+1150|0]|y[e+1151|0]<<8;x:{if(g&2){r=d+r|0;d=r;break x}d=g&512?d:d^32768}q=d>>>8|0;g=g&1024;v[n+1|0]=g?d:q;v[n|0]=g?q:d;f=f+2|0}if(f>>>0<m>>>0){continue}break}j=j+1|0;if(j>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}d=(j<<3)+c|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);o=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31609]=0;f=ba(155,f|0,o|0,l|0,x[e+1428>>2])|0;o=x[31609];x[31609]=0;if((o|0)==1){break u}if(!f){break t}m=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!m){break t}o=xb(x[l>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}i=T(28816)|0;if((gb|0)==($(28816)|0)){Y(i|0)|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;if((c|0)!=1){break e}i=N()|0}ub(k);break a}if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31609]=0;d=ba(155,f|0,d|0,l|0,x[e+1428>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break k}if(!d){break h}r=xb(x[l>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));if((y[e+1152|0]|y[e+1153|0]<<8)>>>0>256){break h}m=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);h=y[e+1154|0]|y[e+1155|0]<<8;x[31609]=0;d=P(149,b|0,j|0)|0;f=x[31609];x[31609]=0;y:{z:{if((f|0)!=1){if(!d){break h}d=Zb(e+40|0,e+1168|0,y[e+1152|0]|y[e+1153|0]<<8);f=x[d>>2];d=x[d+4>>2];x[31609]=0;Yn(159,e+68|0,b,f,d);d=x[31609];x[31609]=0;if((d|0)==1){break z}d=y[e+1152|0]|y[e+1153|0]<<8;if(d>>>0>A[e+72>>2]){break h}f=x[b+8>>2];j=x[b>>2];x[31609]=0;d=U(150,j|0,f|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-d|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){break y}}i=N()|0;break a}i=N()|0;break a}if(!d){break h}x[31609]=0;d=e+48|0;S(157,d|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);f=x[31609];x[31609]=0;if((f|0)==1){break f}k=ns(e+68|0,d);ub(d);j=0;o=0;while(1){f=0;A:{while(1){if((j&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}x[31609]=0;d=P(158,k|0,h+1|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break A}g=h&7;q=y[g+24416|0];B:{C:{if(q>>>0>d>>>0){break C}x[31609]=0;g=y[g+24424|0];n=P(158,k|0,g|0)|0;u=x[31609];x[31609]=0;if((u|0)==1){break A}d=n+(d-q<<g)|0;if((d|0)!=(h|0)){h=d&7;break B}x[31609]=0;d=P(158,k|0,3)|0;g=x[31609];x[31609]=0;if((g|0)==1){break A}if((d|0)==7){x[31609]=0;g=P(158,k|0,1)|0;d=x[31609];x[31609]=0;if((d|0)==1){break A}d=255;if(!g){break C}break g}d=d+248|0;if(d>>>0>255){break B}}d=y[(e+1168|0)+d|0];g=d+o|0;n=d;d=(y[e+1150|0]|y[e+1151|0]<<8)&2;v[f+r|0]=d?g:n;o=d?g:o;f=f+1|0}if(f>>>0<m>>>0){continue}break}j=j+1|0;if(j>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}d=(j<<3)+c|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);m=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31609]=0;f=ba(155,f|0,m|0,l|0,x[e+1428>>2])|0;m=x[31609];x[31609]=0;if((m|0)==1){break A}if(!f){break j}m=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);r=xb(x[l>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}i=T(28816)|0;if((gb|0)==($(28816)|0)){Y(i|0)|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;if((c|0)!=1){break g}i=N()|0}ub(k);break a}ub(k);break h}se(e+24|0,x[l>>2],x[l+4>>2]);lf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Md(e+16|0);x[31609]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;b=hg(160,e+68|0,x[e+32>>2],x[e+36>>2],e+8|0);c=x[31609];x[31609]=0;if((c|0)==1){break i}kd(cj(x[a+4>>2])+12|0,b);ub(b);break h}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}i=N()|0;break a}ub(k);break h}i=N()|0;break a}Ce(s);break c}ub(k);break d}i=N()|0;break a}ub(k)}t=t+1|0;continue}}fb=e+1456|0;return i|0}i=N()|0}Ce(s);Q(i|0);p()}function f1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;e=fb-208|0;fb=e;yc(b);d=e+204|0;a:{if(!Pr(b,d)){break a}x[e+184>>2]=0;x[e+188>>2]=0;x[e+176>>2]=0;x[e+180>>2]=0;x[e+168>>2]=0;x[e+172>>2]=0;x[e+160>>2]=0;x[e+164>>2]=0;b:{c:{if(!dF(d)){break c}if(!Mb(x[b>>2],x[b+8>>2],32)){break c}Gw(b,e+160|0);break b}q=1;if(!cF(e+204|0)){break a}}i=e+155|0;f=bF(y[e+207|0]);d=fb-32|0;fb=d;x[d+28>>2]=f;x[d+8>>2]=5;g=x[b>>2];h=x[b+8>>2];f=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(g,h,f)){f=jf(b)}n=d+8|0;_j(n,i);o=Zb(d+16|0,x[d+8>>2],f);g=x[o>>2];kc(d,x[b>>2],x[b+8>>2],g,x[o+4>>2]);_j(n,i);Rb(x[d+8>>2]+f|0,0,5-f|0);Vb(b,x[d+28>>2]);fb=d+32|0;if(!f){break a}if(!aF(i,y[e+207|0])){break a}j=1;if((c|0)==64){break a}j=e+207|0;Dd(a,2048);eg(a);d:{e:{f:{g:{h:{i:{j:{k:{if(q){d=fb-16|0;fb=d;f=e+4|0;i=uc(d+4|0,3893);Uc(f,i);tb(i);fb=d+16|0;x[31609]=0;d=e+72|0;S(209,d|0,f|0,j|0);j=x[31609];x[31609]=0;if((j|0)==1){break j}zb(a+1298344|0,d);tb(d);Eb(f);f=uc(d,11160);zb(a+1298356|0,f);break k}f=e+4|0;Ue(f,2,e+160|0);d=e+72|0;Cc(d,f);zb(a+1298308|0,d);tb(d);i=fb-16|0;fb=i;n=uc(i+4|0,3944);Uc(f,n);tb(n);fb=i+16|0;x[31609]=0;S(209,d|0,f|0,j|0);j=x[31609];x[31609]=0;if((j|0)==1){break i}zb(a+1298344|0,d);tb(d);Eb(f);f=uc(d,11164);zb(a+1298356|0,f)}tb(f);A=a,B=x[Fc(e+72|0,4)>>2],x[A+1298404>>2]=B;w[a+480188>>1]=y[e+159|0];w[a+480190>>1]=y[e+155|0];l:{f=y[e+207|0];if(f>>>0>8){break l}w[a+480188>>1]=4;j=a+480280|0;d=0;while(1){if((d|0)==4){break l}w[(j+(d<<5)|0)+4>>1]=d&1?192:64;d=d+1|0;continue}}m:{if(f>>>0>=11){j=(f|0)==11?16:32;f=a+480280|0;d=0;while(1){if((d|0)==(j|0)){break m}i=Pw(b);n:{if((i|0)==100){x[f+(d<<5)>>2]=256;break n}x[e+72>>2]=(i<<1)+128;x[e+4>>2]=0;x[e+140>>2]=256;A=f+(d<<5)|0,B=x[Zj(e+72|0,e+4|0,e+140|0)>>2],w[A+4>>1]=B}d=d+1|0;continue}}if(f>>>0<9){break m}Vb(b,16);f=a+480280|0;d=0;while(1){if((d|0)==16){break m}w[(f+(d<<5)|0)+4>>1]=d&1?192:64;d=d+1|0;continue}}o:{if(y[e+207|0]>=13){d=e+72|0;Mw(d,b);f=Jc(d);d=y[e+72|0];if(d>>>0<=31){v[e+72|0]=125;d=125}x[a+480204>>2]=D(d,1e4);x[a+480196>>2]=y[f|0];break o}x[a+480196>>2]=6;x[a+480204>>2]=125e4}vg(Xb(x[a+484360>>2],y[a+484376|0]),y[e+156|0]);n=Nb(e+140|0);d=x[b+8>>2];f=y[e+207|0]>13;if(!f){break h}x[31609]=0;O(210,n|0,y[e+156|0]);j=x[31609];x[31609]=0;if((j|0)!=1){break h}d=N()|0;break g}d=N()|0;Eb(e+4|0);break f}d=N()|0;Eb(e+4|0);break f}t=d+(f<<1)|0;d=0;p:{q:{while(1){if(y[e+156|0]<=d>>>0){f=0;if(y[e+207|0]!=10){break p}o=x[b+8>>2];d=1;while(1){f=z[a+480190>>1]>=(d&65535)>>>0;if(!f){break q}x[31609]=0;j=P(211,b|0,e+72|0)|0;i=x[31609];x[31609]=0;if((i|0)!=1){if(j){j=0;r:{if(y[e+155|0]<(y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24))>>>0|y[e+72|0]>1){break r}i=y[e+122|0]|y[e+123|0]<<8|(y[e+124|0]<<16|y[e+125|0]<<24);if(i>>>0>1048576|y[e+128|0]>64|i>>>0<(y[e+129|0]|y[e+130|0]<<8|(y[e+131|0]<<16|y[e+132|0]<<24))>>>0){break r}j=i>>>0>=(y[e+133|0]|y[e+134|0]<<8|(y[e+135|0]<<16|y[e+136|0]<<24))>>>0}if(!j){break q}}d=d+1|0;continue}break}d=N()|0;break g}A=ac(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],d),B=d,w[A>>1]=B;s:{if(y[e+207|0]>=14){x[31609]=0;f=R(189,b|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break s}A=ac(x[n>>2],d),B=f,w[A>>1]=B}f=z[a+480188>>1];x[31609]=0;P(183,b|0,f<<1)|0;f=x[31609];x[31609]=0;if((f|0)==1){break s}d=d+1|0;continue}break}d=N()|0;break g}x[31609]=0;P(149,b|0,o|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break p}d=N()|0;break g}d=z[a+480190>>1];x[31609]=0;x[e+72>>2]=0;o=U(212,e+60|0,d|0,e+72|0)|0;d=x[31609];x[31609]=0;t:{u:{v:{w:{if((d|0)!=1){m=f?59:65;i=a+946304|0;l=a+484380|0;g=e+73|0;j=1;x:{while(1){d=j&65535;if(d>>>0>z[a+480190>>1]){i=Nb(e+48|0);x[31609]=0;j=U(213,b|0,i|0,y[e+157|0]|y[e+158|0]<<8)|0;d=x[31609];x[31609]=0;y:{if((d|0)!=1){if(!j){break d}d=0;f=0;g=x[i>>2];if(!mc(g,x[i+4>>2])){f=wb(g);m=wb(x[i+4>>2]);g=fb-16|0;fb=g;z:{if(!Ib(f,m)){break z}x[g+12>>2]=f;while(1){h=x[ge(g+12|0)>>2];if(!Ib(h,m)){break z}f=Yk(y[f|0]|y[f+1|0]<<8,y[h|0]|y[h+1|0]<<8)?h:f;continue}}fb=g+16|0;f=y[f|0]|y[f+1|0]<<8}x[31609]=0;h=P(214,e+24|0,f|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break y}A:{while(1){if((d|0)==(f|0)){if(!(c&2)){break w}k=Zc(e+4|0,8,1,0,q?2:1);d=z[a+480190>>1];m=1;B:{C:{D:while(1){s=m&65535;if(s>>>0>(d&65535)>>>0){break w}d=x[b+8>>2];g=x[b>>2];x[31609]=0;d=U(150,g|0,d|0,1)|0;g=x[31609];x[31609]=0;if((g|0)==1){break B}if(!d){break w}u=x[b+8>>2];g=0;E:while(1){d=z[a+480190>>1];if(g>>>0>=d>>>0){m=m+1|0;continue D}if(x[yb(x[o>>2],g)>>2]!=(s|0)){g=g+1|0;continue}x[31609]=0;P(149,b|0,u|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){x[31609]=0;g=g+1|0;d=l+D(g,104)|0;U(215,k|0,d|0,b|0)|0;r=x[31609];x[31609]=0;if((r|0)==1){break C}if(!q){continue}cc(e+72|0,x[d+20>>2],x[d>>2]);A=e,B=wb(x[e+72>>2]),x[A>>2]=B;r=Yj(x[e+72>>2],x[e+76>>2]);while(1){d=x[e>>2];if(!Ib(d,r)){continue E}v[d|0]=y[d|0]^128;we(e);continue}}break}break}d=N()|0;break v}d=N()|0;break v}d=N()|0;break v}x[31609]=0;g=R(189,b|0)|0;m=x[31609];x[31609]=0;F:{if((m|0)==1){break F}x[31609]=0;P(183,b|0,1)|0;m=x[31609];x[31609]=0;if((m|0)==1){break F}if(g){x[31609]=0;m=e+4|0;S(185,m|0,b|0,D(g,3)+(y[e+207|0]==1?3:0)|0);g=x[31609];x[31609]=0;if((g|0)==1){break A}g=hc(e+72|0,m);kd(ch(x[h>>2],d),g);ub(g);ub(m)}d=d+1|0;continue}break}d=N()|0;break v}d=N()|0;break v}d=N()|0;break u}d=N()|0;break u}G:{H:{if(y[e+207|0]<=9){x[31609]=0;h=e+72|0;O(216,b|0,h|0);k=x[31609];x[31609]=0;I:{J:{if((k|0)==1){break J}x[31609]=0;O(217,h|0,l+D(d,104)|0);h=x[31609];x[31609]=0;if((h|0)==1){break J}k=e+48|0;Ue(k,2,g);x[31609]=0;h=e+4|0;O(218,h|0,k|0);k=x[31609];x[31609]=0;if((k|0)==1){break I}Ac(i+(d<<5)|0,h);tb(h);A=yb(x[o>>2],d-1|0),B=y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24),x[A>>2]=B;break H}d=N()|0;break t}d=N()|0;break t}if(q){x[31609]=0;h=e+72|0;O(219,b|0,h|0);k=x[31609];x[31609]=0;K:{L:{if((k|0)==1){break L}x[31609]=0;O(220,h|0,l+D(d,104)|0);h=x[31609];x[31609]=0;if((h|0)==1){break L}x[31609]=0;h=P(36,e+36|0,22292)|0;k=x[31609];x[31609]=0;if((k|0)==1){break K}Ac(i+(d<<5)|0,h);tb(h);A=yb(x[o>>2],d-1|0),B=y[e+74|0]|y[e+75|0]<<8|(y[e+76|0]<<16|y[e+77|0]<<24),x[A>>2]=B;break H}d=N()|0;break t}d=N()|0;break t}x[31609]=0;h=e+72|0;S(221,b|0,h|0,m|0);k=x[31609];x[31609]=0;if((k|0)==1){break G}x[31609]=0;S(222,h|0,l+D(d,104)|0,f|0);h=x[31609];x[31609]=0;if((h|0)==1){break G}k=e+48|0;Ue(k,2,g);x[31609]=0;h=e+4|0;O(218,h|0,k|0);k=x[31609];x[31609]=0;if((k|0)==1){break x}Ac(i+(d<<5)|0,h);tb(h);A=yb(x[o>>2],d-1|0),B=y[e+118|0]|y[e+119|0]<<8|(y[e+120|0]<<16|y[e+121|0]<<24),x[A>>2]=B}j=j+1|0;continue}break}d=N()|0;break t}d=N()|0;break t}d=N()|0;break g}if(!(c&1)){break e}x[31609]=0;q=a+484344|0;O(223,q|0,y[e+156|0]);c=x[31609];x[31609]=0;M:{if((c|0)!=1){c=0;while(1){N:{if(y[e+156|0]<=c>>>0){break e}d=64;g=x[n>>2];if($c(g,x[n+4>>2])>>>0>c>>>0){d=z[ac(g,c)>>1]}x[31609]=0;d=U(196,q|0,c&65535,d&65535)|0;g=x[31609];x[31609]=0;if((g|0)==1){break M}O:{if(d){d=z[a+480188>>1];x[31609]=0;P(149,b|0,D(((y[e+207|0]>13)<<1)+(d<<1)|0,c)+t|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break M}g=Nb(e+72|0);d=z[a+480188>>1];x[31609]=0;l=U(213,b|0,g|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break O}d=0;P:{if(!l){break P}while(1){if(z[a+480188>>1]<=d>>>0){break P}Q:{l=ac(x[g>>2],d);l=(y[l|0]|y[l+1|0]<<8)-1|0;if((l&65535)>>>0>=(y[e+157|0]|y[e+158|0]<<8)>>>0){break Q}l=ac(x[i>>2],l);l=(y[l|0]|y[l+1|0]<<8)-1&65535;if(l>>>0>=f>>>0){break Q}m=x[q>>2];k=x[h>>2];x[31609]=0;S(224,Wb(m,c)|0,d&65535,ch(k,l)|0);l=x[31609];x[31609]=0;if((l|0)!=1){break Q}break N}d=d+1|0;continue}}od(g)}c=c+1|0;continue}}break}d=N()|0;od(g);break v}d=N()|0;break v}d=N()|0}Rc(h)}od(i)}wc(o)}od(n)}Q(d|0);p()}Rc(h)}od(i);wc(o);od(n)}fb=e+208|0;return j|0}function Wpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0;e=fb-368|0;fb=e;a:{if(!dd(b,1080)){break a}f=e+364|0;if(!kr(b,f)){break a}k=$X(e+344|0);if(!_X(f,k)){break a}d=z[k+10>>1];if(!d|d>>>0>127){break a}R=1;if((c|0)==64){break a}T=1;Dd(a,1);h=z[k+10>>1];w[a+480188>>1]=h;s=y[k+14|0];V=y[k+13|0];g=y[k+12|0];if(!oe(f,25274)){T=oe(f,25279)}if(y[k+15|0]){Lb(a+1074312|0,5,1);h=z[a+480188>>1]}d=e+364|0;E=oe(d,16780);m=1;if(!oe(d,17542)){m=oe(d,13702)}B=a+480188|0;F=(h&65535)==8&(V|0)!=0;dd(b,0);d=y[k+16|0];j=fb-16|0;fb=j;b:{i=e+324|0;if(!lx(b,i)|!d){break b}jx(j+8|0,i);d=0;while(1){if(d>>>0>=20){break b}f=x[j+8>>2];rg(xb(f,d),xb(f,d|1));d=d+2|0;continue}}fb=j+16|0;d=e+312|0;bf(d,i,20,3);f=e+180|0;Cc(f,d);zb(a+1298308|0,f);tb(f);w[a+480190>>1]=31;t=a+946304|0;Z=a+484380|0;j=(g|0)!=0;h=1;f=0;d=E;while(1){if((h|0)==32){R=A[k+4>>2]>=f>>>0;if(!R){break a}}else{g=y[k+16|0];n=fb-16|0;fb=n;c:{o=e+180|0;if(!TX(b,o)|!g){break c}Gv(n+8|0,o);g=0;while(1){if(g>>>0>=30){break c}i=x[n+8>>2];rg(xb(i,g),xb(i,g|1));g=g+2|0;continue}}fb=n+16|0;g=D(h,104)+Z|0;i=XC(o,g,t+(h<<5)|0,z[B>>1]==4);n=x[g>>2];d:{if(m){v[g+37|0]=0-(y[e+204|0]<<3);break d}j=n>>>0<65536&j;r=n>>>0>65535|r}o=Bb(y[e+202|0]|y[e+203|0]<<8);e:{if(o){_=!Bb(y[e+208|0]|y[e+209|0]<<8)|_;break e}$=y[e+205|0]==64|$}g=d&1;d=0;f:{if(!g){break f}u=(o<<1)+u|0;g=y[e+204|0];d=!g;if(g|!o){break f}d=y[e+205|0]==64}f=f+i|0;l=l+n|0;h=h+1|0;continue}break}g=y[k+16|0];i=fb-16|0;fb=i;g:{f=e+180|0;if(!RC(b,f)|!g){break g}WC(i+8|0,f);f=0;while(1){if(f>>>0>=130){break g}g=x[i+8>>2];rg(xb(g,f),xb(g,f|1));f=f+2|0;continue}}fb=i+16|0;dd(b,z[k+8>>1]);f=y[e+181|0];g=128;ow(Xb(x[a+484360>>2],y[a+484376|0]),e+182|0,128);o=!f&d;t=o?u:0;i=y[e+180|0];h:{if(i>>>0>=129){d=y[a+484376|0];f=x[a+484360>>2];break h}d=y[a+484376|0];f=x[a+484360>>2];if(i){g=i;break h}i=x[Xb(f,d)>>2];h=128;while(1){g=h;if(g>>>0<2){g=1;break h}h=g-1|0;if(!z[ac(i,h)>>1]){continue}break}}n=YX(b,Xb(f,d),g&65535,l,B,t,0);J=1;i:{if(!(o&z[B>>1]==8)){J=(s|0)!=0;break i}x[k>>2]=11279}j:{if(!F){break j}d=Xb(x[a+484360>>2],y[a+484376|0]);ca=e,da=wb(x[d>>2]),x[ca+312>>2]=da;d=wb(x[d+4>>2]);while(1){f=x[e+312>>2];if(!Ib(f,d)){break j}w[f>>1]=z[f>>1]>>>1;ge(e+312|0);continue}}$e(Xb(x[a+484360>>2],y[a+484376|0]),y[e+181|0]);d=y[e+181|0];o=g-1|0;k:{if(d>>>0<=(o&65535)>>>0){h=z[B>>1];if((d|0)!=120|(h|0)!=4){break k}}$e(Xb(x[a+484360>>2],y[a+484376|0]),0);h=z[a+480188>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;u=0;x[a+480208>>2]=0;ca=a,da=Yb(256/((h&65535)>>>0)|0,32,128),x[ca+480228>>2]=da;Uh(a,0);v[e+179|0]=0;l:{if(j&1){G=1;i=1;break l}G=1;m=0;j=0;l=E;m:while(1){g=j&65535;if(g>>>0<n>>>0){t=0;h=0;while(1)if((h|0)==256){j=j+1|0;continue m}else{f=Ng(e+312|0);XX(e+160|0,b,!g&y[k+16|0]!=0);d=x[e+160>>2];x[e+172>>2]=d;x[e+64>>2]=d;d=e+92|0;ep(d,e- -64|0,f);d=Jc(d);i=OD(y[f|0]);n:{o:{p:{q:{s=y[e+92|0];if((s-7&255)>>>0<3){l=0;break q}f=y[d|0];if(!((s|0)!=14|f>>>0<=1)){l=0;break p}if(!((s|0)!=15|(f&255)>>>0<=31)){l=0;break n}l=i?l:0;if((s|0)!=13){break q}t=t+1|0;l=(t&65535)>>>0<=1?l:0;break n}if((s|0)==8){break o}if((s|0)!=14){break n}f=y[d|0]}if((f&240)!=128){break n}v[e+80|0]=f<<4;ca=e,da=y[cf(e+179|0,e+80|0)|0],v[ca+179|0]=da;break n}ca=e,da=y[cf(e+179|0,d)|0],v[ca+179|0]=da;d=v[d|0];if((d|0)>=0){u=1;break n}m=(d|0)!=-92&d>>>0>4294967183|m}G=i&G;h=h+1|0;continue}}break}d=u^-1;u=0;u=(d|m)&1?u:y[e+179|0]>47;i=l&1}dd(b,z[k+8>>1]);d=z[a+480188>>1];H=a+484344|0;W=n+F&65535;Tf(H,W);n=F?4:d;I=a+1074312|0;t=c&1;m=0;j=0;l=r;r:{s:{t:{u:{while(1){if((m|0)==(W|0)){break t}v:{if(F){f=(m&65534)>>>1|0;d=m&1;if(!d){if(!Pg(H,f,64)){break t}}h=Wb(x[H>>2],f);d=d<<2;break v}if(!Pg(H,m&65535,64)){break t}h=Wb(x[H>>2],m);d=0}f=0;X=md(x[h>>2],x[x[h+48>>2]+12>>2],0,d);if(!t){K=0;break s}d=z[B>>1];v[e+92|0]=0;f=e+92|0;L=kw(e+312|0,d,f);d=z[B>>1];x[31609]=0;v[e+92|0]=0;M=U(600,e+160|0,d|0,f|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){Y=0;w:{x:while(1){y:{if((Y|0)==64){break w}h=0;f=0;s=0;while(1){if((h|0)==(n|0)){Y=Y+1|0;l=f&s|l;X=D(z[B>>1],6)+X|0;continue x}d=y[k+16|0];x[31609]=0;S(601,e+92|0,b|0,!m&(d|0)!=0);d=x[31609];x[31609]=0;if((d|0)!=1){d=x[e+92>>2];x[e+156>>2]=d;x[e+60>>2]=d;g=e+80|0;q=D(h,6)+X|0;ep(g,e+60|0,q);d=y[e+80|0];O=Jc(g);g=y[O|0];if(d|g){z:{if(!(!V|(d&255)!=14)){d=0;v[O|0]=0;v[e+80|0]=0;g=y[O|0];break z}if(!V|(d&255)!=15|(g&255)>>>0<32){break z}g=31;v[O|0]=31;d=y[e+80|0]}Cf(q,d&255,g&255)}d=1;A:{B:{C:{D:{E:{g=y[q+3|0];switch(g-14|0){case 2:break A;case 0:break D;case 3:break E;default:break C}}j=y[q+5|0]<100|j;s=1;break B}if(!i){break B}v[q+5|0]=0;break B}if((g|0)==9&u){d=y[q+5|0];if((d|0)==164){v[q+5|0]=145;v[q+3|0]=20;break B}ca=q,da=Eh(d<<1),v[ca+5|0]=da;break B}if((g|0)!=19){break B}d=y[q+5|0];if(d>>>0>15){break B}d=!(d&1);g=(d^aa)&1;aa=g?d:aa;K=g+K|0}d=f}F:{if(!y[q|0]){g=y[q+1|0];if(!g|F){break F}f=y[xb(x[L>>2],h)|0];if(!f|(f|0)==(g|0)){break F}f=xb(x[M>>2],h);g=y[f|0]+1|0;v[f|0]=g;if((g&255)>>>0<4){break F}x[31609]=0;U(266,I|0,85,1)|0;f=x[31609];x[31609]=0;if((f|0)!=1){break F}break y}ca=xb(x[M>>2],h),da=0,v[ca|0]=da}f=y[q+1|0];if(f){ca=xb(x[L>>2],h),da=f,v[ca|0]=da}h=h+1|0;f=d;continue}break}}break}d=N()|0;fc(M);break u}fc(M);fc(L);m=m+1|0;continue}break}d=N()|0}fc(L);break r}f=j;r=l}G:{H:{I:{g=G^1;if((g|_)&1){break I}d=e+364|0;J:{if(oe(d,16780)){break J}if(oe(d,17547)){break J}if(!oe(d,13697)){break I}}x[a+480208>>2]=x[a+480208>>2]|2162688;d=Lb(Lb(Lb(I,85,1),91,1),92,1);K:{if(y[e+179|0]>47){break K}d=Lb(d,84,1);if(y[e+181|0]==127){break K}Lb(d,83,1)}if(!((K|0)>6|J)){break H}break G}if(!(G&1)){if(!(y[e+181|0]==127&(o&65535)>>>0<129&E)){break G}x[k>>2]=8494;break G}if((K|0)>6|J){break G}}x[a+480208>>2]=x[a+480208>>2]|8388608}if((E|J)==1){Lb(I,89,1)}if(T){Lb(I,84,1)}l=0;L:{if(!(c&2)){break L}dd(b,z[k+8>>1]+(D(n,W)<<8)|0);i=(g|E^1|$)&1;h=1;while(1){if((h|0)==32){break L}j=D(h,104)+Z|0;d=x[j>>2];if(d){g=2;if(!T){c=WX(b,13945);g=c?10:0;l=c|l;d=x[j>>2]}g=Zc(e+312|0,8,1,0,g);c=AD(g,d)+x[b+8>>2]|0;if(!i){ca=j,da=x[bd(j,j+8|0)>>2],x[ca>>2]=da}dg(g,j,b);dd(b,c)}h=h+1|0;continue}}M:{N:{if(!E){if(!((oe(e+364|0,17547)&f^-1|r)&1)){break N}break M}if((f^-1|r)&1){break M}}c=VX(e+128|0,0);b=x[c+20>>2];x[e+48>>2]=x[c+16>>2];x[e+52>>2]=b;b=x[c+12>>2];x[e+40>>2]=x[c+8>>2];x[e+44>>2]=b;b=x[c+4>>2];x[e+32>>2]=x[c>>2];x[e+36>>2]=b;d=e+312|0;Fv(d,a,0,e+32|0);ba=C[x[e+312>>2]>>3];Qi(d);if(!(ba>=480)){break M}c=Lb(I,5,1);f=UX(e+104|0,ba);b=x[f+20>>2];x[e+24>>2]=x[f+16>>2];x[e+28>>2]=b;b=x[f+12>>2];x[e+16>>2]=x[f+8>>2];x[e+20>>2]=b;b=x[f+4>>2];x[e+8>>2]=x[f>>2];x[e+12>>2]=b;Fv(d,a,0,e+8|0);b=y[x[e+312>>2]+26|0];Qi(d);if(b){bg(c,5);break M}x[k>>2]=17114}f=e+364|0;d=f;r=gc(d);c=d;while(1){if((d|0)!=(r|0)){b=y[d|0];v[c|0]=b>>>0<=32?32:b;c=c+1|0;d=d+1|0;continue}break}d=e+92|0;gg(d,16867);x[31609]=0;r=U(44,e+68|0,f|0,r|0)|0;b=x[31609];x[31609]=0;O:{P:{Q:{R:{S:{if((b|0)!=1){x[31609]=0;c=e+80|0;S(602,c|0,1,r|0);b=x[31609];x[31609]=0;if((b|0)==1){break S}x[31609]=0;f=e+312|0;S(139,f|0,d|0,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break R}zb(a+1298344|0,f);tb(f);tb(c);tb(r);Eb(d);b=uc(f,12402);zb(a+1298356|0,b);tb(b);b=x[k>>2];if(b){Zh(a+1298368|0,b)}b=e+312|0;ca=a,da=x[Fc(b,28)>>2],x[ca+1298404>>2]=da;if(!(l&1)){break a}b=uc(b,17166);x[31609]=0;P(74,a+1298368|0,b|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break O}tb(b);break a}d=N()|0;break P}d=N()|0;break Q}d=N()|0;tb(e+80|0)}tb(r)}Eb(e+92|0);break r}d=N()|0;tb(b)}Q(d|0);p()}fb=e+368|0;return R|0}function Cta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=fb+-64|0;fb=e;yc(a);a:{b:{if(b>>>0<=2){H=e,I=Zd(a),v[H+56|0]=I;Vb(a,2);b=gh(a);v[e+58|0]=b;v[e+59|0]=b>>>8;b=Rg(a);v[e+60|0]=b;v[e+61|0]=b>>>8;v[e+62|0]=b>>>16;v[e+63|0]=b>>>24;break b}jp(a,e+56|0);if(b>>>0>5){break a}}v[e+57|0]=0}c:{t=d+484344|0;F=Ld(y[e+58|0]|y[e+59|0]<<8,1,1024);q=jE(t,F);if((q|0)==65535){break c}b=Wb(x[d+484344>>2],q);h=md(x[b>>2],x[x[b+48>>2]+12>>2],0,0);f=z[d+480188>>1];w[e+12>>1]=f-1;w[e+44>>1]=y[e+56|0];G=z[Oc(e+12|0,e+44|0)>>1];g=G+1|0;b=g&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){v[c+13|0]=y[e+57|0]>>>4;b=y[c+12|0];v[e+12|0]=0;b=(b|0)!=0;B=kw(e+44|0,g,e+12|0);d:while(1){if((l|0)==(F|0)){fc(B);break c}e:{f:{g=xb(x[B>>2],0);f=y[g|0];g:{if(!f){x[31609]=0;g=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}h=g<<24>>24;if((h|0)<0){x[31609]=0;g=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}H=xb(x[B>>2],0),I=g,v[H|0]=I}v[e+12|0]=0;h:{i:{g=h&63;if(!g){break i}x[31609]=0;k=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break h}v[e+12|0]=k;j:{k:{switch(g-1|0){case 0:v[c+12|0]=0;v[e+40|0]=1;H=c,I=y[cf(e+40|0,e+12|0)|0],v[H+14|0]=I;v[c+15|0]=0;break j;case 1:if(!k){break i}v[c+15|0]=k;v[c+12|0]=1;b=y[c+13|0];if(!b){break j}v[c+14|0]=D(D(b,k),15);break j;case 2:v[c+13|0]=k>>>4;if(k>>>0>=16){b=y[c+12|0];k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b){break g}break f}k=0;v[c+12|0]=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b&1){break g}break f;case 3:u=0;x[e+40>>2]=0;x[e+36>>2]=0;if(b&1){break g}break f;case 5:if(!k){break i}b=(y[c+12|0]?15:14)+c|0;f=y[b|0];v[b|0]=f>>>0>=256-k>>>0?-1:f+k|0;break j;case 6:break k;default:break i}}if(!k){break i}b=(y[c+12|0]?15:14)+c|0;f=y[b|0];v[b|0]=f>>>0<=k+1>>>0?1:f-k|0}k=0;x[e+40>>2]=0;x[e+36>>2]=0;break g}k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(b&1){break g}break f}break e}v[g|0]=f-1;k=0;x[e+40>>2]=0;x[e+36>>2]=0;u=0;if(!(b&1)){break f}}f=y[c+13|0];b=y[c+12|0];if(b){u=0;if(!f){break f}}l:{if(b){x[e+12>>2]=1;x[e+32>>2]=D(f,y[c+15|0])<<1;f=x[Ye(e+12|0,e+32|0)>>2];break l}f=D(y[c+14|0],30)+30|0}b=255;g=0;s=0;while(1){m:{if(b){h=D(b,f);s=(h|0)/48|0;if(h-1536>>>0>=10752){break m}g=b}x[e+36>>2]=s;x[e+40>>2]=g;Ge(e+36|0,32,255);u=1;x[e+12>>2]=1;H=c,I=x[Ye(e+12|0,e+40|0)>>2],v[H+16|0]=I;break f}b=b-1|0;continue}}C=l-1|0;E=1;b=Wb(x[t>>2],q);b=md(x[b>>2],x[x[b+48>>2]+12>>2],l,1);while(1){i=E&65535;if(i>>>0>G>>>0){if(u){b=e+12|0;Ae(Wb(x[t>>2],q),Vh(ip(We(Oe(b,17,y[e+36|0]),l),0)));Ae(Wb(x[t>>2],q),Vh(We(Oe(b,16,y[e+40|0]),l)))}if(k>>>0>=16){Ae(Wb(x[t>>2],q),C$(We(Oe(e+12|0,20,k>>>4|224),l)))}b=k&15;if(b){Ae(Wb(x[t>>2],q),C$(We(Oe(e+12|0,20,Ld((D(b,y[c+16|0])>>>0)/15&255,1,15)|96),l)))}l=l+1|0;b=0;continue d}n:{o:{p:{q:{g=xb(x[B>>2],i);f=y[g|0];if(!f){x[31609]=0;g=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}h=g<<24>>24;if((h|0)<0){x[31609]=0;g=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}H=xb(x[B>>2],i),I=g,v[H|0]=I}s=1;m=h&255;if(m&64){x[31609]=0;g=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}v[b+1|0]=g;s=!g}if(!(m&32)){g=y[b|0];break q}x[31609]=0;g=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}v[b|0]=g;if((g-1&255)>>>0<=107){g=iE(g+24&255);v[b|0]=g;H=Yc(x[c>>2],i),I=g,v[H+1|0]=I;break q}if((g+127&255)>>>0<=107){f=iE((g&127)+24|0);H=Yc(x[c>>2],i),I=f,v[H|0]=I;v[b|0]=0;break p}if((g|0)!=255){break q}v[b|0]=254;break o}v[g|0]=f-1;break n}if(g&255){break o}}if(!y[b+1|0]){break o}f=y[Yc(x[c>>2],i)+1|0];v[b+1|0]=0;v[b|0]=f}if(Tc(y[b|0])){H=Yc(x[c>>2],i),I=0,v[H+5|0]=I}v[e+31|0]=0;v[e+30|0]=0;if(m&16){v[b+2|0]=1;x[31609]=0;g=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}v[b+4|0]=g+2>>>2}g=0;r=0;A=0;r:{if(!(m&8)){break r}x[31609]=0;h=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}x[31609]=0;A=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}s:{switch(h-1|0){case 0:v[b|0]=254;break r;case 1:v[b|0]=255;break r;case 2:f=Yc(x[c>>2],i);v[b|0]=y[f+1|0];v[f+5|0]=0;break r;case 3:f=jw(A,y[c+16|0]);A=f?f|-48:0;r=f?20:0;if(y[b|0]){break r}f=Yc(x[c>>2],i);v[b|0]=y[f+1|0];v[f+5|0]=0;break r;case 4:v[e+12|0]=1;H=e,I=jw(A,y[c+16|0]),v[H+32|0]=I;A=y[cf(e+12|0,e+32|0)|0];H=Yc(x[c>>2],i),I=0,v[H+5|0]=I;r=15;break r;case 5:case 6:case 7:case 8:r=x[c>>2];t:{if(!l){break t}if((h|0)==y[Yc(r,i)+4|0]){break t}f=Ae(Wb(x[t>>2],q),An(ip(We(Oe(e+12|0,20,(h+122|160)&255),C),i)));r=x[c>>2];if(!f){break t}H=Yc(r,i),I=h,v[H+4|0]=I}f=Yc(r,i);if(!y[b|0]){v[b|0]=y[f+1|0]}v[f+5|0]=0;r=10;break r;case 9:break s;default:break r}}f=Yc(x[c>>2],i);h=y[f+5|0];v[f+5|0]=h^1;A=h?-98:-97;r=20}u:{v:{w:{if(!(m&4)){break w}x[31609]=0;n=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}x[31609]=0;j=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}v[e+31|0]=j;h=1;g=1;x:{switch(n-1|0){case 0:hE(e+12|0,j<<24>>24<<3,128);f=y[b|0];if(Tc(f)){H=b,I=iw(f+x[e+12>>2]|0),v[H|0]=I}v[e+31|0]=y[e+16|0]^128;g=35;break w;case 1:f=jw(j,y[c+16|0]);v[e+31|0]=f;if(!f){break v}v[e+31|0]=f|208;g=20;break u;case 3:case 4:H=e,I=B$(j,y[c+16|0],1),v[H+31|0]=I;g=(n|0)==4?2:3;break u;case 5:if(!y[b|0]){H=b,I=y[Yc(x[c>>2],i)|0],v[H|0]=I}H=e,I=B$(j,y[c+16|0],0),v[H+31|0]=I;g=4;break u;case 6:H=b,I=iw(j+25|0),v[H|0]=I;v[e+31|0]=255;g=4;break u;case 7:case 8:case 9:y:{if(!l){break y}if((n|0)==y[Yc(x[c>>2],i)+2|0]){break y}if(!Ae(Wb(x[t>>2],q),An(ip(We(Oe(e+12|0,20,(n-8|48)&255),C),i)))){break y}H=Yc(x[c>>2],i),I=n,v[H+2|0]=I}H=e,I=gE(j,y[c+16|0]),v[H+31|0]=I;g=5;break u;case 10:H=e,I=A$(j,y[c+16|0]),v[H+31|0]=I;g=18;break u;case 11:f=jw(j,y[c+16|0]);v[e+31|0]=f;if(f){v[e+31|0]=f|192;g=20;break u}v[b|0]=254;break v;case 2:break u;default:break x}}g=0}h=0;break u}g=0}o=0;f=1;z:{if(m&2){x[31609]=0;m=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}x[31609]=0;n=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}v[e+30|0]=n;o=9;f=0;j=0;A:{switch(m-1|0){case 0:case 1:j=1;H=e,I=z$(n,y[c+16|0],(m|0)==1),v[H+30|0]=I;o=11;break z;case 2:H=e,I=A$(n,y[c+16|0]),v[H+30|0]=I;j=1;o=18;break z;case 3:case 4:case 5:B:{if(!l){break B}if((m|0)==y[Yc(x[c>>2],i)+3|0]){break B}if(!Ae(Wb(x[t>>2],q),An(ip(We(Oe(e+12|0,20,(m-4|64)&255),C),i)))){break B}H=Yc(x[c>>2],i),I=m,v[H+3|0]=I}H=e,I=gE(n,y[c+16|0]),v[H+30|0]=I;j=1;o=8;break z;case 7:case 8:H=e,I=z$(n,y[c+16|0],(m|0)==8),v[H+30|0]=I;j=1;o=29;break z;case 9:H=e,I=gE(n,y[c+16|0]),v[H+30|0]=I;j=1;o=27;break z;case 6:break z;default:break A}}o=0;f=1}j=0}if(h){y$(b,l,z[d+480188>>1],g,e+31|0)}if(j){y$(b,l,z[d+480188>>1],o,e+30|0)}C:{D:{E:{F:{G:{if(!s){break G}if(!Tc(y[b|0])){break G}if(!g){break F}if(!f|(g|0)==4){break G}v[e+30|0]=255;o=4}j=b+2|0;if(y[b+2|0]!=1){break C}if(g){break E}v[e+31|0]=y[b+4|0];g=13;break D}v[e+31|0]=255;j=b+2|0;g=4;if(y[b+2|0]!=1){break C}}if(o){break C}v[e+30|0]=y[b+4|0];o=13}v[j|0]=0}h=Ng(e+12|0);em(e+32|0,h,g,y[e+31|0],o,y[e+30|0]);H:{if(y[j|0]){break H}f=y[e+14|0];if(!f){break H}v[b+2|0]=f;v[b+4|0]=y[e+16|0]}s=y[e+15|0];I:{if(r){em(e+32|0,h,s&255,y[e+17|0],r,A&255);J:{if(y[j|0]){break J}f=y[e+14|0];if(!f){break J}v[b+2|0]=f;v[b+4|0]=y[e+16|0]}s=y[e+15|0];break I}if(!(s&255)){break n}}v[b+3|0]=s;v[b+5|0]=y[e+17|0]}b=b+6|0;E=E+1|0;continue}}break}a=N()|0;fc(B);Q(a|0);p()}else{v[h+D(b,6)|0]=254;b=b+1|0;continue}}fb=e- -64|0;return q|0}function yS(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=fb-336|0;fb=k;m=h;n=i&65535;o=d;p=e&65535;s=(e^i)&-2147483648;y=i>>>16&32767;u=e>>>16&32767;a:{b:{if(y-32767>>>0>4294934529&u-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){r=d;s=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){r=h;s=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;s=2147450880;break a}s=s|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));r=b?0:r;s=b?2147450880:s;b=0;c=0;break a}if(!(f|h|(e|g))){s=s|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){d=!(o|p);i=d;j=d?b:o;d=d<<6;i=G(i?c:p);d=d+((i|0)==32?G(j)+32|0:i)|0;$f(k+320|0,b,c,o,p,d-15|0);q=16-d|0;o=x[k+328>>2];p=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|m);h=d;i=d?f:m;d=d<<6;h=G(h?g:n);d=d+((h|0)==32?G(i)+32|0:h)|0;$f(k+304|0,f,g,m,n,d-15|0);q=(d+q|0)-16|0;m=x[k+312>>2];n=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=n|65536;z=e;B=m;d=m;j=e<<15|d>>>17;e=d<<15|g>>>17;d=e;i=0-d|0;h=j;j=1963258675-(j+((d|0)!=0)|0)|0;Mf(k+288|0,d,h,0,0,i,j,0,0);d=x[k+296>>2];Mf(k+272|0,0-d|0,0-(x[k+300>>2]+((d|0)!=0)|0)|0,0,0,i,j,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;Mf(k+256|0,i,d,0,0,e,h,0,0);j=x[k+264>>2];Mf(k+240|0,i,d,0,0,0-j|0,0-(x[k+268>>2]+((j|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;Mf(k+224|0,j,d,0,0,e,h,0,0);i=x[k+232>>2];Mf(k+208|0,j,d,0,0,0-i|0,0-(x[k+236>>2]+((i|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;Mf(k+192|0,i,d,0,0,e,h,0,0);j=x[k+200>>2];Mf(k+176|0,i,d,0,0,0-j|0,0-(x[k+204>>2]+((j|0)!=0)|0)|0,0,0);i=e;e=x[k+184>>2];d=h;m=e<<1|x[k+180>>2]>>>31;h=m-1|0;e=(x[k+188>>2]<<1|e>>>31)-!m|0;Mf(k+160|0,i,d,0,0,h,e,0,0);d=h;Mf(k+144|0,f<<15,g<<15|f>>>17,0,0,d,e,0,0);v=k+112|0;C=x[k+168>>2];h=x[k+172>>2];m=x[k+160>>2];i=x[k+152>>2];l=m+i|0;n=x[k+164>>2];j=n+x[k+156>>2]|0;j=i>>>0>l>>>0?j+1|0:j;i=j;j=(n|0)==(j|0)&l>>>0<m>>>0|j>>>0<n>>>0;n=j+C|0;j=j>>>0>n>>>0?h+1|0:h;m=!i&l>>>0>1|(i|0)!=0;h=n+m|0;j=m>>>0>h>>>0?j+1|0:j;Mf(v,d,e,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);Mf(k+128|0,1-l|0,0-((l>>>0>1)+i|0)|0,0,0,d,e,0,0);M=(u-y|0)+q|0;e=x[k+116>>2];u=e;d=x[k+112>>2];j=e<<1|d>>>31;i=d<<1;n=j;d=j;h=x[k+140>>2];w=h;e=x[k+136>>2];j=h<<1|e>>>31;l=e<<1|x[k+132>>2]>>>31;h=l+i|0;d=d+j|0;d=h>>>0<l>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;t=d;v=d;l=0;j=p|65536;N=j;O=o;d=o;j=j<<1|d>>>31;Q=d<<1;R=j;H=j;d=Aua(t,l,j,0);j=hb;D=d;E=j;J=b<<1;d=c<<1|b>>>31;y=d;C=d;j=0;q=j;m=h-13927|0;t=(e|0)==(t|0)&m>>>0<h>>>0|e>>>0>t>>>0;e=(e|0)==(n|0)&h>>>0<i>>>0|e>>>0<n>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;d=d<<1|u>>>31;l=w>>>31|0;d=l+d|0;j=h;j=d>>>0<l>>>0?j+1|0:j;h=d;d=d+e|0;j=h>>>0>d>>>0?j+1|0:j;e=d;d=d+t|0;l=e>>>0>d>>>0?j+1|0:j;e=d-1|0;F=l-!d|0;w=0;i=Aua(C,q,F,w);d=i+D|0;h=hb+E|0;h=d>>>0<i>>>0?h+1|0:h;n=(E|0)==(h|0)&d>>>0<D>>>0|h>>>0<E>>>0;D=e;P=c>>>31|0;I=P|o<<1;t=0;e=Aua(e,0,I,t);o=e+d|0;j=hb+h|0;l=0;j=e>>>0>o>>>0?j+1|0:j;p=j;d=(j|0)==(h|0)&d>>>0>o>>>0|h>>>0>j>>>0;e=d;d=d+n|0;l=e>>>0>d>>>0?1:l;e=Aua(H,q,F,w);d=e+d|0;j=hb+l|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=Aua(H,q,D,t);l=hb;h=e;e=Aua(I,t,F,w);i=h+e|0;j=hb+l|0;j=e>>>0>i>>>0?j+1|0:j;e=j;j=(l|0)==(j|0)&h>>>0>i>>>0|j>>>0<l>>>0;l=n+e|0;d=d+j|0;d=l>>>0<e>>>0?d+1|0:d;n=l;l=d;e=0;d=e+o|0;j=i+p|0;j=d>>>0<e>>>0?j+1|0:j;e=j;h=(j|0)==(p|0)&d>>>0<o>>>0|j>>>0<p>>>0;j=l;i=h;h=h+n|0;j=i>>>0>h>>>0?j+1|0:j;u=h;l=j;o=d;E=m;d=Aua(m,0,I,t);i=hb;h=d;m=Aua(v,r,C,r);d=d+m|0;j=hb+i|0;j=d>>>0<m>>>0?j+1|0:j;m=(i|0)==(j|0)&d>>>0<h>>>0|i>>>0>j>>>0;h=j;K=J&-2;i=Aua(D,t,K,0);p=i+d|0;j=hb+j|0;j=i>>>0>p>>>0?j+1|0:j;i=j;d=(j|0)==(h|0)&d>>>0>p>>>0|h>>>0>j>>>0;h=0;j=d+m|0;d=(j>>>0<d>>>0?1:h)+e|0;n=j+o|0;d=n>>>0<j>>>0?d+1|0:d;j=l;m=d;d=(d|0)==(e|0)&n>>>0<o>>>0|d>>>0<e>>>0;e=d;d=d+u|0;j=e>>>0>d>>>0?j+1|0:j;S=d;u=j;d=Aua(H,q,E,r);L=hb;H=d;e=Aua(F,w,K,r);d=d+e|0;j=hb+L|0;j=d>>>0<e>>>0?j+1|0:j;o=d;l=Aua(v,r,I,t);e=d+l|0;h=j;d=j+hb|0;d=e>>>0<l>>>0?d+1|0:d;q=e;j=Aua(C,r,D,t);e=e+j|0;l=hb+d|0;l=e>>>0<j>>>0?l+1|0:l;F=(d|0)==(l|0)&e>>>0<q>>>0|d>>>0>l>>>0;j=(h|0)==(L|0)&o>>>0<H>>>0|h>>>0<L>>>0;d=(d|0)==(h|0)&o>>>0>q>>>0|d>>>0<h>>>0;d=d+j|0;d=d+F|0;h=l;q=h+n|0;j=(d|w)+m|0;j=h>>>0>q>>>0?j+1|0:j;o=j;d=(m|0)==(j|0)&n>>>0>q>>>0|j>>>0<m>>>0;j=u;h=d;d=d+S|0;j=h>>>0>d>>>0?j+1|0:j;w=d;m=j;d=Aua(v,r,K,r);v=hb;n=d;h=Aua(C,r,E,r);d=d+h|0;j=hb+v|0;j=d>>>0<h>>>0?j+1|0:j;u=0;h=(j|0)==(v|0)&d>>>0<n>>>0|j>>>0<v>>>0;n=j;d=j+p|0;j=(h|u)+i|0;j=d>>>0<n>>>0?j+1|0:j;i=(i|0)==(j|0)&d>>>0<p>>>0|i>>>0>j>>>0;h=j;j=e;p=0;e=p+d|0;l=h+j|0;j=0;l=e>>>0<p>>>0?l+1|0:l;d=(h|0)==(l|0)&d>>>0>e>>>0|h>>>0>l>>>0;e=d;d=d+i|0;j=(e>>>0>d>>>0?1:j)+o|0;l=m;e=d;d=d+q|0;j=e>>>0>d>>>0?j+1|0:j;e=j;h=(o|0)==(j|0)&d>>>0<q>>>0|j>>>0<o>>>0;i=h;h=h+w|0;l=i>>>0>h>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){O=Q|P;N=t|R;Mf(k+80|0,d,j,h,l,f,g,B,z);l=x[k+84>>2];q=l;j=b<<17;o=0;p=x[k+88>>2];c=o-p|0;b=x[k+80>>2];l=(l|b)!=0;m=c-l|0;n=(j-(x[k+92>>2]+(o>>>0<p>>>0)|0)|0)-(c>>>0<l>>>0)|0;p=0-(((b|0)!=0)+q|0)|0;q=M+16382|0;o=0-b|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;Mf(k+96|0,d,e,h,i,f,g,B,z);m=x[k+100>>2];y=m;n=0;q=x[k+104>>2];o=n-q|0;l=x[k+96>>2];p=(m|l)!=0;m=o-p|0;n=((b<<16)-(x[k+108>>2]+(n>>>0<q>>>0)|0)|0)-(o>>>0<p>>>0)|0;p=0-(((l|0)!=0)+y|0)|0;J=b;y=c;q=M+16383|0;o=0-l|0}if((q|0)>=32767){s=s|2147418112;b=0;c=0;break a}d:{if((q|0)>0){b=m<<1|p>>>31;c=n<<1|m>>>31;m=h;n=i&65535|q<<16;l=p<<1|o>>>31;h=o<<1;break d}if((q|0)<=-113){b=0;c=0;break a}cn(k- -64|0,d,e,h,i,1-q|0);$f(k+48|0,J,y,O,N,q+112|0);d=x[k+64>>2];e=x[k+68>>2];m=x[k+72>>2];n=x[k+76>>2];Mf(k+32|0,f,g,B,z,d,e,m,n);b=x[k+40>>2];c=x[k+56>>2];i=x[k+36>>2];p=b<<1|i>>>31;l=c-p|0;p=x[k+60>>2]-((x[k+44>>2]<<1|b>>>31)+(c>>>0<p>>>0)|0)|0;c=x[k+52>>2];q=c;b=x[k+32>>2];h=i<<1|b>>>31;o=b<<1;b=o;j=x[k+48>>2];c=(c|0)==(h|0)&b>>>0>j>>>0|c>>>0<h>>>0;b=l-c|0;c=p-(c>>>0>l>>>0)|0;l=q-((j>>>0<o>>>0)+h|0)|0;h=j-o|0}Mf(k+16|0,f,g,B,z,3,0,0,0);Mf(k,f,g,B,z,5,0,0,0);o=d;p=d&1;i=p;d=h+i|0;j=0;h=j+l|0;h=d>>>0<i>>>0?h+1|0:h;i=d;g=(g|0)==(h|0)&d>>>0>f>>>0|g>>>0<h>>>0;l=c;d=(h|0)==(j|0)&d>>>0<p>>>0|h>>>0<j>>>0;f=b+d|0;l=d>>>0>f>>>0?l+1|0:l;j=e;b=(l|0)==(z|0);b=b&(f|0)==(B|0)?g:b&f>>>0>B>>>0|l>>>0>z>>>0;c=b;b=b+o|0;j=c>>>0>b>>>0?j+1|0:j;c=j;d=(e|0)==(j|0)&b>>>0<o>>>0|e>>>0>j>>>0;j=n;e=d;d=d+m|0;j=e>>>0>d>>>0?j+1|0:j;g=d;e=x[k+20>>2];m=(e|0)==(h|0)&A[k+16>>2]<i>>>0|e>>>0<h>>>0;e=x[k+28>>2];d=x[k+24>>2];e=j>>>0<2147418112&((d|0)==(f|0)&(e|0)==(l|0)?m:(e|0)==(l|0)&d>>>0<f>>>0|e>>>0<l>>>0);d=c;m=e;e=b+e|0;d=m>>>0>e>>>0?d+1|0:d;b=(c|0)==(d|0)&b>>>0>e>>>0|c>>>0>d>>>0;c=b;b=b+g|0;j=c>>>0>b>>>0?j+1|0:j;g=b;c=x[k+4>>2];h=(c|0)==(h|0)&A[k>>2]<i>>>0|c>>>0<h>>>0;c=x[k+12>>2];b=x[k+8>>2];b=j>>>0<2147418112&((b|0)==(f|0)&(c|0)==(l|0)?h:(c|0)==(l|0)&b>>>0<f>>>0|c>>>0<l>>>0);c=b;b=b+e|0;l=c>>>0>b>>>0?d+1|0:d;c=l;e=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;d=j;f=e;e=e+g|0;d=f>>>0>e>>>0?d+1|0:d;r=e|r;s=d|s}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=r;x[a+12>>2]=s;fb=k+336|0}function OO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-32|0;fb=f;d=Dc(f+20|0,11616);e=oh(c,d);tb(d);a:{b:{c:{d:{e:{if(e){ro(a,x[b+24>>2]+1298356|0);break e}d=Dc(f+20|0,11021);e=oh(c,d);tb(d);if(e){ro(a,x[b+24>>2]+1298344|0);break e}d=Dc(f+20|0,11446);e=oh(c,d);tb(d);if(e){ro(a,x[b+24>>2]+1298392|0);break e}d=Dc(f+20|0,11013);e=oh(c,d);tb(d);if(e){ro(a,x[b+24>>2]+1298380|0);break e}d=f+20|0;e=Dc(d,8243);g=oh(c,e);tb(e);if(g){e=x[x[b+24>>2]+480184>>2];c=0;f:{g:{while(1){b=c;if((b|0)==48){break g}c=b+12|0;if((e|0)!=x[b+30992>>2]){continue}break}c=fb-32|0;fb=c;e=c+8|0;Yw(e,x[b+31e3>>2]);x[31609]=0;b=c+20|0;S(123,b|0,0,e|0);g=x[31609];x[31609]=0;h:{i:{j:{if((g|0)!=1){x[31609]=0;O(12,d|0,b|0);g=x[31609];x[31609]=0;if((g|0)==1){break j}Ub(b);tb(e);fb=c+32|0;break h}a=N()|0;break i}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}break f}Fb(d)}x[31609]=0;O(1059,a|0,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break d}tb(d);break e}g=f+20|0;d=Dc(g,10998);e=oh(c,d);tb(d);if(e){l=x[x[b+24>>2]+480184>>2];c=fb-48|0;fb=c;h=og(c+36|0);d=Fb(g);b=0;while(1){if((b|0)!=48){if(x[b+30992>>2]==(l|0)){x[31609]=0;e=P(1,c+24|0,x[b+30996>>2])|0;i=x[31609];x[31609]=0;k:{l:{m:{n:{o:{p:{if((i|0)!=1){x[31609]=0;S(888,c+16|0,h|0,e|0);i=x[31609];x[31609]=0;if((i|0)==1){break n}if(!y[c+20|0]){break k}if(!Ad(x[d+4>>2],y[d+11|0])){x[31609]=0;i=P(1,c+4|0,18410)|0;k=x[31609];x[31609]=0;if((k|0)==1){break p}x[31609]=0;P(74,d|0,i|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break o}tb(i)}x[31609]=0;P(74,d|0,e|0)|0;i=x[31609];x[31609]=0;if((i|0)!=1){break k}b=N()|0;break m}b=N()|0;break l}b=N()|0;break m}b=N()|0;tb(i);break m}b=N()|0}tb(e)}tb(d);yR(h);Q(b|0);p()}tb(e)}b=b+12|0;continue}break}yR(h);fb=c+48|0;x[31609]=0;O(1059,a|0,g|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(g);break e}c=N()|0;tb(f+20|0);break a}d=Dc(f+20|0,8309);e=oh(c,d);tb(d);if(e){ro(a,x[b+24>>2]+1298368|0);break e}d=Dc(f+20|0,5620);e=oh(c,d);tb(d);if(e){ro(a,x[b+24>>2]+1298320|0);break e}d=f+20|0;e=Dc(d,12020);g=oh(c,e);tb(e);if(g){jg(d,x[b+24>>2]+1298308|0);b=x[b+24>>2];x[31609]=0;S(1053,a|0,b|0,d|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(d);break e}c=N()|0;tb(f+20|0);break a}d=Dc(f+20|0,11389);e=oh(c,d);tb(d);if(e){d=_L(x[b+24>>2]);c=x[d+4>>2];q:{if(!mc(x[d>>2],c)){e=gw(c);d=fb-32|0;fb=d;x[d+8>>2]=0;x[d+12>>2]=0;x[d+16>>2]=0;x[d>>2]=0;x[d+4>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;c=fb-48|0;fb=c;HF(c+24|0,e,e+4|0,e+8|0,e+12|0,e+16|0,e+24|0);HF(c,d,d+4|0,d+8|0,d+12|0,d+16|0,d+24|0);e=x[c+28>>2];g=x[c+4>>2];fb=c+48|0;fb=d+32|0;if(x[e>>2]==x[g>>2]&x[x[c+24>>2]>>2]==x[x[c>>2]>>2]&x[x[c+32>>2]>>2]==x[x[c+8>>2]>>2]&x[x[c+36>>2]>>2]==x[x[c+12>>2]>>2]&x[x[c+40>>2]>>2]==x[x[c+16>>2]>>2]){e=x[c+44>>2];g=x[c+20>>2];c=x[e>>2]==x[g>>2]&x[e+4>>2]==x[g+4>>2]}else{c=0}if(!c){break q}}Fb(a);break e}g=f+20|0;b=x[b+24>>2];e=gw(x[_L(b)+4>>2]);h=x[b+1298408>>2];d=fb-512|0;fb=d;i=x[e+32>>2];r:{if(i){b=-1;j=Fe(+(i>>>0)/18.2);c=2147483647;s:{if(j>=0x8000000000000000){break s}b=0;c=-2147483648;if(j<=-0x8000000000000000){break s}if(F(j)<0x8000000000000000){b=~~j>>>0;if(F(j)>=1){c=~~(j>0?H(J(j*2.3283064365386963e-10),4294967295):K((j-+(~~j>>>0>>>0))*2.3283064365386963e-10))>>>0}else{c=0}break s}c=-2147483648}if((h|0)==1){h=x[e+28>>2];x[d+184>>2]=x[e+24>>2];x[d+188>>2]=h;h=x[e+20>>2];x[d+176>>2]=x[e+16>>2];x[d+180>>2]=h;h=x[e+12>>2];x[d+168>>2]=x[e+8>>2];x[d+172>>2]=h;h=x[e+4>>2];x[d+160>>2]=x[e>>2];x[d+164>>2]=h;Hu(d+480|0,d+160|0);e=x[d+508>>2];x[d+152>>2]=x[d+504>>2];x[d+156>>2]=e;e=x[d+500>>2];x[d+144>>2]=x[d+496>>2];x[d+148>>2]=e;e=x[d+492>>2];x[d+136>>2]=x[d+488>>2];x[d+140>>2]=e;e=x[d+484>>2];x[d+128>>2]=x[d+480>>2];x[d+132>>2]=e;e=d+448|0;h=_A(xS(d+128|0),hb);c=c+hb|0;i=b;b=b+h|0;c=i>>>0>b>>>0?c+1|0:c;vS(e,wS(b,c),hb);b=x[d+476>>2];x[d+120>>2]=x[d+472>>2];x[d+124>>2]=b;b=x[d+468>>2];x[d+112>>2]=x[d+464>>2];x[d+116>>2]=b;b=x[d+460>>2];x[d+104>>2]=x[d+456>>2];x[d+108>>2]=b;b=x[d+452>>2];x[d+96>>2]=x[d+448>>2];x[d+100>>2]=b;CN(g,d+96|0);break r}h=x[e+28>>2];x[d+312>>2]=x[e+24>>2];x[d+316>>2]=h;h=x[e+20>>2];x[d+304>>2]=x[e+16>>2];x[d+308>>2]=h;h=x[e+12>>2];x[d+296>>2]=x[e+8>>2];x[d+300>>2]=h;h=x[e+4>>2];x[d+288>>2]=x[e>>2];x[d+292>>2]=h;Hu(d+416|0,d+288|0);e=x[d+444>>2];x[d+280>>2]=x[d+440>>2];x[d+284>>2]=e;e=x[d+436>>2];x[d+272>>2]=x[d+432>>2];x[d+276>>2]=e;e=x[d+428>>2];x[d+264>>2]=x[d+424>>2];x[d+268>>2]=e;e=x[d+420>>2];x[d+256>>2]=x[d+416>>2];x[d+260>>2]=e;e=d+352|0;h=_A(xS(d+256|0),hb);c=c+hb|0;i=b;b=b+h|0;c=i>>>0>b>>>0?c+1|0:c;vS(e,wS(b,c),hb);b=x[d+380>>2];x[d+248>>2]=x[d+376>>2];x[d+252>>2]=b;b=x[d+372>>2];x[d+240>>2]=x[d+368>>2];x[d+244>>2]=b;b=x[d+364>>2];x[d+232>>2]=x[d+360>>2];x[d+236>>2]=b;b=x[d+356>>2];x[d+224>>2]=x[d+352>>2];x[d+228>>2]=b;Hu(d+384|0,d+224|0);b=x[d+412>>2];x[d+216>>2]=x[d+408>>2];x[d+220>>2]=b;b=x[d+404>>2];x[d+208>>2]=x[d+400>>2];x[d+212>>2]=b;b=x[d+396>>2];x[d+200>>2]=x[d+392>>2];x[d+204>>2]=b;b=x[d+388>>2];x[d+192>>2]=x[d+384>>2];x[d+196>>2]=b;FO(g,d+192|0);break r}if((h|0)==1){b=x[e+28>>2];x[d+56>>2]=x[e+24>>2];x[d+60>>2]=b;b=x[e+20>>2];x[d+48>>2]=x[e+16>>2];x[d+52>>2]=b;b=x[e+12>>2];x[d+40>>2]=x[e+8>>2];x[d+44>>2]=b;b=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=b;Hu(d+320|0,d+32|0);b=x[d+348>>2];x[d+24>>2]=x[d+344>>2];x[d+28>>2]=b;b=x[d+340>>2];x[d+16>>2]=x[d+336>>2];x[d+20>>2]=b;b=x[d+332>>2];x[d+8>>2]=x[d+328>>2];x[d+12>>2]=b;b=x[d+324>>2];x[d>>2]=x[d+320>>2];x[d+4>>2]=b;CN(g,d);break r}b=x[e+28>>2];x[d+88>>2]=x[e+24>>2];x[d+92>>2]=b;b=x[e+20>>2];x[d+80>>2]=x[e+16>>2];x[d+84>>2]=b;b=x[e+12>>2];x[d+72>>2]=x[e+8>>2];x[d+76>>2]=b;b=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=b;FO(g,d- -64|0)}fb=d+512|0;x[31609]=0;O(1059,a|0,g|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(g);break e}c=N()|0;tb(f+20|0);break a}d=f+20|0;e=Dc(d,12289);g=oh(c,e);tb(e);if(g){jV(d,x[b+24>>2]+1298332|0);t:{if(!Ad(x[f+24>>2],y[f+31|0])){break t}c=x[x[b+24>>2]+480180>>2];u:{v:{if((c|0)==33554432){break v}e=1;if((c|0)==32){break u}if((c|0)==16384){break v}if((c|0)==16777216){break u}}e=2}if((e|0)!=2){x[31609]=0;c=f+8|0;O(1060,c|0,b|0);e=x[31609];x[31609]=0;if((e|0)!=1){zb(d,c);tb(c);break t}break b}x[31609]=0;c=f+8|0;O(1061,c|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break b}d=zb(f+20|0,c);tb(c);if(!Ad(x[f+24>>2],y[f+31|0])){break t}x[31609]=0;O(1060,c|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break b}zb(d,c);tb(c)}b=x[b+24>>2];x[31609]=0;c=a;a=f+20|0;S(1053,c|0,b|0,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){tb(a);break e}break b}d=f+20|0;e=Dc(d,5472);g=oh(c,e);tb(e);if(g){jV(d,x[b+24>>2]+1298332|0);b=x[b+24>>2];x[31609]=0;S(1053,a|0,b|0,d|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(d);break e}c=N()|0;tb(f+20|0);break a}i=c;c=Dc(f+20|0,7335);d=oh(i,c);tb(c);if(d){a=Fb(a);c=wb(x[b+68>>2]);x[f+20>>2]=c;d=wb(x[b+72>>2]);b=1;while(1){if(!Ib(c,d)){break e}if(!(b&1)){x[31609]=0;P(985,a|0,22267)|0;b=x[31609];x[31609]=0;if((b|0)==1){break c}}x[31609]=0;P(838,a|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break c}c=x[xm(f+20|0)>>2];b=0;continue}}Dc(a,22292)}fb=f+32|0;return}c=N()|0;tb(f+20|0);break a}c=N()|0;tb(a);break a}c=N()|0;tb(f+20|0)}Q(c|0);p()}function vpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0;d=fb-1328|0;fb=d;yc(b);e=fb-16|0;fb=e;i=d+220|0;vX(e+8|0,i);h=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);f=x[e+4>>2];if((f|0)==(h|0)){Vb(b,x[e+12>>2])}fb=e+16|0;a:{if((f|0)!=(h|0)){break a}if(!xX(i)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(wX(y[d+1324|0]|y[d+1325|0]<<8|(y[d+1326|0]<<16|y[d+1327|0]<<24)),hb))){break a}n=1;if((c|0)==64){break a}yc(b);b=He(d+220|0,b);x[31609]=0;e=d+208|0;O(642,e|0,b|0);h=x[31609];x[31609]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((h|0)!=1){ub(b);x[31609]=0;S(643,d+196|0,e|0,1196314451);b=x[31609];x[31609]=0;if((b|0)==1){break i}n=0;x[31609]=0;S(643,d+184|0,e|0,1280331091);b=x[31609];x[31609]=0;if((b|0)==1){break h}if(mc(x[d+196>>2],x[d+200>>2])){break b}if(!mc(x[d+184>>2],x[d+188>>2])){break g}break b}c=N()|0;ub(b);break d}c=N()|0;break e}c=N()|0;break f}x[31609]=0;O(246,a|0,1);b=x[31609];x[31609]=0;j:{if((b|0)!=1){eg(a);x[a+480188>>2]=4;x[a+480208>>2]=25231360;F=d,G=wb(x[d+184>>2]),x[F+52>>2]=G;i=c&2;o=a+946304|0;q=a+484380|0;f=wb(x[d+188>>2]);k:{l:{while(1){e=x[d+52>>2];if(!Ib(e,f)){break l}b=z[a+480190>>1];if(!oi(b)){break l}b=b+1|0;w[a+480190>>1]=b;x[31609]=0;b=D(b&65535,104)+q|0;O(279,b|0,1);h=x[31609];x[31609]=0;m:{n:{if((h|0)!=1){x[31609]=0;h=d+220|0;k=P(644,e|0,h|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break n}if(!k){break c}if(Ev(h)){break m}break c}c=N()|0;break j}c=N()|0;break j}x[31609]=0;h=P(36,d+172|0,d+220|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break k}Ac((z[a+480190>>1]<<5)+o|0,h);tb(h);h=y[d+256|0]|y[d+257|0]<<8|(y[d+258|0]<<16|y[d+259|0]<<24);x[b+8>>2]=h;x[b>>2]=h;x[b+4>>2]=y[d+252|0]|y[d+253|0]<<8|(y[d+254|0]<<16|y[d+255|0]<<24);w[b+34>>1]=z[b+34>>1]|2;w[b+30>>1]=255;o:{if(i){h=Zc(d+24|0,8,1,0,0);x[31609]=0;U(215,h|0,b|0,e|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break o}}Qf(d+52|0);continue}break}c=N()|0;break j}F=d,G=wb(x[d+196>>2]),x[F+168>>2]=G;r=a+484344|0;s=c&1;t=a+484360|0;B=d+252|0;C=wb(x[d+200>>2]);c=1;n=1;while(1){p:{q:{r:{s:{t:{u:{v:{b=x[d+168>>2];if(!Ib(b,C)){break v}if(!(c&1)){x[31609]=0;c=R(274,t|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break u}if(!c){break v}}Nc(Xb(x[a+484360>>2],y[a+484376|0]));x[31609]=0;e=d+220|0;c=P(645,b|0,e|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break t}if(!(!(y[d+1306|0]|y[d+1307|0]<<8)&c)|(y[d+1308|0]|y[d+1309|0]<<8|(y[d+1310|0]<<16|y[d+1311|0]<<24))-5>>>0<4294967292){break c}h=y[a+484376|0];i=x[a+484360>>2];x[31609]=0;c=d+156|0;O(646,c|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break t}pp(Xb(i,h),c);tb(c);w:{if(s){x[31609]=0;S(185,d+52|0,b|0,y[d+1316|0]|y[d+1317|0]<<8|(y[d+1318|0]<<16|y[d+1319|0]<<24));b=x[31609];x[31609]=0;if((b|0)!=1){break w}c=N()|0;break j}x[31609]=0;b=R(168,d+116|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break s}uG(d+52|0,b)}b=d+52|0;k=hc(d+136|0,b);ub(b);if(!s){ub(d+116|0)}Rb(d+52|0,0,64);l=1;x:{y:{z:{while(1){if((l|0)==32){break z}b=(D(l,34)+B|0)-34|0;En(d+8|0,b);A:{B:{if(Lj(y[x[d+8>>2]])){break B}c=y[b+32|0];if(c>>>0>15){break y}e=y[b+33|0];if(e>>>0>64){break y}if(!Ev(b)){break y}h=e<<2;i=c<<4;c=0;b=1;while(1){f=b&65535;e=z[a+480190>>1];if(f>>>0<=e>>>0){x[31609]=0;m=d+24|0;S(647,m|0,x[d+8>>2],x[d+12>>2]);e=x[31609];x[31609]=0;if((e|0)==1){break A}e=fb-32|0;fb=e;fe(e+24|0,m);sX(e+16|0,(f<<5)+o|0);g=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=g;g=Ic(x[e+24>>2],x[e+28>>2],e+8|0);fb=e+32|0;tb(m);C:{if(g^1){break C}F=ac(d+52|0,l),G=b,w[F>>1]=G;e=D(f,104)+q|0;f=z[e+30>>1];if((f|0)!=255){c=b;if(y[e+37|0]!=(i&255)|(f|0)!=(h|0)){break C}}w[e+30>>1]=h;v[e+37|0]=i;break B}b=b+1|0;continue}break}c=c&65535;if(!c){break B}if(!oi(e)){break B}b=e+1|0;w[a+480190>>1]=b;F=ac(d+52|0,l),G=b,w[F>>1]=G;b=D(z[a+480190>>1],104)+q|0;nn(b);e=D(c,104)+q|0;b=Xo(b,e);w[b+30>>1]=h;v[b+37|0]=i;nY(b,e);c=(c<<5)+o|0;e=x[c+4>>2];b=(z[a+480190>>1]<<5)+o|0;x[b>>2]=x[c>>2];x[b+4>>2]=e;e=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=e;e=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=e;e=x[c+12>>2];x[b+8>>2]=x[c+8>>2];x[b+12>>2]=e}l=l+1|0;continue}break}break r}i=0;x[d+48>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;e=64;h=65535;E=y[d+1308|0]|y[d+1309|0]<<8;m=0;D:while(1){E:{if(m){break E}b=x[k>>2];x[31609]=0;b=U(150,b|0,x[d+144>>2],1)|0;c=x[31609];x[31609]=0;if((c|0)==1){break x}if(b){break E}c=h;b=e;break q}b=e+1|0;F:{if(e>>>0<63){e=b;break F}x[31609]=0;h=P(367,r|0,64)|0;c=x[31609];x[31609]=0;if((c|0)==1){break x}c=65535;if((h|0)==65535){break q}b=y[a+484376|0];c=x[a+484360>>2];e=0;x[31609]=0;O(537,Xb(c,b)|0,h|0);b=x[31609];x[31609]=0;if((b|0)==1){break x}}b=0;c=Wb(x[r>>2],h&65535);c=md(x[c>>2],x[x[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(E|0)){continue D}f=(d+24|0)+D(b,7)|0;g=y[f+6|0];G:{if(g){v[f+6|0]=g-1;g=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=g;v[c+5|0]=g>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;m=m-1|0;break G}g=x[k>>2];x[31609]=0;g=U(150,g|0,x[d+144>>2],1)|0;j=x[31609];x[31609]=0;if((j|0)==1){break r}if(!g){break G}if(x[d+144>>2]==(y[d+1312|0]|y[d+1313|0]<<8|(y[d+1314|0]<<16|y[d+1315|0]<<24))){i=Xb(x[a+484360>>2],y[a+484376|0]);$e(i,mE(x[i>>2],x[i+4>>2]));i=e}x[31609]=0;g=R(197,k|0)|0;j=x[31609];x[31609]=0;H:{if((j|0)!=1){g=g<<24>>24;if((g|0)>=0){break H}g=g&127;v[f+6|0]=g;j=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=j;v[c+5|0]=j>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;m=g+m|0;break G}break r}if((g-1&255)>>>0<=35){v[c|0]=g+48}x[31609]=0;g=R(197,k|0)|0;j=x[31609];x[31609]=0;I:{J:{if((j|0)!=1){g=g<<24>>24;F=c,G=y[ac(d+52|0,g&31)|0],v[F+1|0]=G;if((g|0)>=0){break J}v[c+3|0]=y[f+3|0];v[c+5|0]=y[f+5|0];break I}break r}x[31609]=0;j=d+8|0;O(198,j|0,k|0);g=x[31609];x[31609]=0;K:{if((g|0)!=1){g=y[d+8|0];if(g>>>0>19){break I}u=g<<1;A=y[u+25328|0];v[c+3|0]=A;j=y[Jc(j)|0];v[c+5|0]=j;if((A|0)!=16|j>>>0<32){break K}v[c+3|0]=17;break I}break r}if(819137>>>g&1){break I}v[c+5|0]=y[u+25329|0]|j&15}g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=g;v[f+1|0]=g>>>8;v[f+2|0]=g>>>16;v[f+3|0]=g>>>24;g=y[c+4|0]|y[c+5|0]<<8;v[f+4|0]=g;v[f+5|0]=g>>>8}c=c+6|0;b=b+1|0;continue}}}n=0;break p}break r}Vj(t,0);x[31609]=0;b=P(1,d+220|0,6467)|0;c=x[31609];x[31609]=0;L:{if((c|0)!=1){zb(a+1298344|0,b);tb(b);x[31609]=0;b=P(1,d+52|0,6804)|0;c=x[31609];x[31609]=0;if((c|0)==1){break L}zb(a+1298356|0,b);tb(b);F=a,G=x[Fc(d+24|0,4)>>2],x[F+1298404>>2]=G;n=1;break b}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;ub(k);break j}c=c&65535;if(!((i|0)!=0|b>>>0<63)|(c|0)==65535){break p}Ae(Wb(x[r>>2],c),Vh(We(Oe(d+8|0,14,i&255),b)))}ub(k);if((l|0)!=32){break b}Qf(d+168|0);c=0;continue}}c=N()|0;break j}c=N()|0}Rc(d+184|0)}Rc(d+196|0)}ke(d+208|0)}Q(c|0);p()}n=0}Rc(d+184|0);Rc(d+196|0);ke(d+208|0)}fb=d+1328|0;return n|0}function coa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;h=fb-256|0;fb=h;e=fb-112|0;fb=e;f=He(h+76|0,c);x[31609]=0;o=R(168,f+20|0)|0;c=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){x[31609]=0;r=R(168,f+40|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break B}x[31609]=0;s=R(168,f+60|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break A}x[31609]=0;i=R(168,f+80|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break z}x[31609]=0;q=R(168,f+100|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break y}x[31609]=0;m=R(168,f+120|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break x}j=Nb(f+140|0);yc(f);x[f+172>>2]=1873739776;w[f+176>>1]=0;x[31609]=0;d=P(806,f|0,e+100|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break w}if(!d){break n}d=x[e+100>>2];if((d|0)!=1414744396&(d|0)!=1179011410){break n}c=x[e+108>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}v[f+176|0]=(d|0)==1414744396;x[31609]=0;g=e+88|0;S(807,g|0,f|0,2);c=x[31609];x[31609]=0;if((c|0)==1){break v}k=x[e+88>>2];C:{if(Hr(k,x[e+92>>2])>>>0<4){break C}l=e+36|0;c=xA(k,1);d=x[c>>2];c=x[c+4>>2];qi(l,d,c);if(x[e+36>>2]!=1635017060){break C}qi(e+60|0,d,c);if(!(v[e+64|0]&1)){break C}c=xA(k,2);qi(e+16|0,x[c>>2],x[c+4>>2]);if(y[e+20|0]|y[e+21|0]<<8|(y[e+22|0]<<16|y[e+23|0]<<24)){break C}c=xA(k,3);qi(e+80|0,x[c>>2],x[c+4>>2]);if(x[e+80>>2]){break C}x[31609]=0;P(149,f|0,12)|0;c=x[31609];x[31609]=0;if((c|0)==1){break u}x[31609]=0;S(807,l|0,f|0,1);c=x[31609];x[31609]=0;if((c|0)==1){break t}Cv(g,l);ke(l)}x[31609]=0;g=e+60|0;S(808,g|0,e+88|0,544501094);c=x[31609];x[31609]=0;if((c|0)==1){break s}x[31609]=0;d=P(809,g|0,f+156|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break k}if(!d){break o}d=z[f+156>>1];if((d|0)!=1){break q}x[31609]=0;d=R(202,g|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break r}break k}d=N()|0;break b}d=N()|0;break c}d=N()|0;break d}d=N()|0;break e}d=N()|0;break f}d=N()|0;break g}d=N()|0;break h}d=N()|0;break h}d=N()|0;break i}d=N()|0;break i}d=N()|0;break i}if((d|0)==4){x[31609]=0;g=R(192,e+60|0)|0;c=x[31609];x[31609]=0;D:{if((c|0)!=1){x[31609]=0;d=R(192,e+60|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break D}if((g|0)!=2|(d|0)!=1){break p}v[f+177|0]=1;break p}d=N()|0;break j}d=N()|0;break j}d=z[f+156>>1]}if((d&65535)!=65534){break p}x[31609]=0;d=P(810,e+60|0,e+36|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break l}if(!d){break o}c=y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24);x[e+8>>2]=y[e+52|0]|y[e+53|0]<<8|(y[e+54|0]<<16|y[e+55|0]<<24);x[e+12>>2]=c;c=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);x[e>>2]=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[e+4>>2]=c;c=e+16|0;x[c>>2]=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);w[c+4>>1]=y[e+4|0]|y[e+5|0]<<8;w[c+6>>1]=y[e+6|0]|y[e+7|0]<<8;t=c,u=pA(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24),y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24)),x[t+8>>2]=u;x[c+12>>2]=hb;w[f+172>>1]=x[c>>2]}x[31609]=0;k=e+36|0;g=e+88|0;S(808,k|0,g|0,1635017060);c=x[31609];x[31609]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){l=kd(o,k);ub(k);c=x[l>>2];x[31609]=0;d=R(172,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break k}if(!d){x[31609]=0;S(808,k|0,g|0,544039792);c=x[31609];x[31609]=0;if((c|0)==1){break J}kd(l,k);ub(k)}x[31609]=0;g=e+36|0;S(808,g|0,e+88|0,1952670054);c=x[31609];x[31609]=0;if((c|0)==1){break I}x[31609]=0;d=R(151,g|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break H}x[f+152>>2]=d;ub(g);if(x[f+152>>2]?z[f+156>>1]==17:0){break E}g=z[f+158>>1];d=tR(g,z[f+170>>1]);if(!d){break E}c=z[f+168>>1];if(c){if((c>>>0)/(g>>>0)>>>0<d<<1>>>0){break G}}c=x[l>>2];x[31609]=0;d=R(154,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break k}c=tR(z[f+158>>1],z[f+170>>1]);break F}d=N()|0;break j}d=N()|0;break j}d=N()|0;break j}d=N()|0;ub(e+36|0);break j}c=x[l>>2];x[31609]=0;d=R(154,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break k}c=z[f+168>>1]}x[f+152>>2]=(d>>>0)/((c&65535)>>>0)}x[31609]=0;g=e+88|0;d=P(811,f|0,g|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break k}w[f+174>>1]=d;x[31609]=0;O(812,f|0,g|0);c=x[31609];x[31609]=0;if((c|0)==1){break k}x[31609]=0;d=e+36|0;S(808,d|0,g|0,1886221175);c=x[31609];x[31609]=0;if((c|0)==1){break m}kd(q,d);ub(d)}ub(e+60|0);ke(e+88|0)}fb=e+112|0;break a}d=N()|0;break j}d=N()|0;break j}d=N()|0}ub(e+60|0)}ke(e+88|0)}ke(j);ub(m)}ub(q)}ub(i)}ub(s)}ub(r)}ub(o)}ub(f);Q(d|0);p()}c=x[f+20>>2];x[31609]=0;d=R(744,c|0)|0;c=x[31609];x[31609]=0;K:{L:{if((c|0)!=1){M:{if(!d|(z[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=z[f+170>>1];P:{if(!c){if((Ck(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Ck(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}d=Ck(f);c=28576;while(1){Q:{R:{if((c|0)!=28600){if((d|0)!=x[c>>2]){break R}}else{c=28600}break Q}c=c+4|0;continue}break}if((c|0)==28600){break M}Vu(a,b);x[31609]=0;g=P(36,h- -64|0,22292)|0;c=x[31609];x[31609]=0;S:{T:{U:{V:{W:{if((c|0)!=1){d=Ac(((b<<5)+a|0)+946304|0,g);tb(g);x[31609]=0;i=(D(b,104)+a|0)+484380|0;O(279,i|0,0);c=x[31609];x[31609]=0;if((c|0)==1){break W}x[i>>2]=x[f+152>>2];x[i+24>>2]=x[f+160>>2];c=x[a+1298404>>2];x[31609]=0;V(745,f|0,i|0,c|0,d|0);c=x[31609];x[31609]=0;if((c|0)==1){break W}He(h+44|0,f+20|0);d=z[f+158>>1];j=Zc(h+40|0,8,d>>>0>1?2:1,0,0);c=Ck(f);if((c|0)!=17|d>>>0>2){break U}xc(i,268435456);w[i+34>>1]=z[i+34>>1]&65470|((d|0)==2)<<6|1;if(Gh(i)){break V}break S}n=N()|0;break K}n=N()|0;break K}j=x[i>>2];g=x[i+20>>2];m=He(h+20|0,h+44|0);d=z[f+158>>1];c=z[f+168>>1];x[31609]=0;b=x[m+12>>2];x[h+8>>2]=x[m+8>>2];x[h+12>>2]=b;x[h+16>>2]=x[m+16>>2];b=x[m+4>>2];x[h>>2]=x[m>>2];x[h+4>>2]=b;aa(746,g|0,j|0,h|0,c|0,d|0);b=x[31609];x[31609]=0;if((b|0)==1){break L}Ij(i,a);break T}if((c|0)==85){x[31609]=0;c=U(574,a|0,b|0,h+44|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(AV(z[f+156>>1])){break Z}_:{if(!Id(y[f+177|0])){break _}if((Ck(f)|0)!=1|z[f+170>>1]!=32|z[f+168>>1]!=d<<2){break _}hd(j,32);b=12;break Y}if((Ck(f)|0)!=1|z[f+170>>1]!=24|z[f+168>>1]!=d<<2){break Z}hd(j,32);b=13;break Y}if((Ck(f)&65534)!=6){break X}hd(j,16);b=(Ck(f)|0)==6?17:16}wg(j,b);x[31609]=0;U(215,j|0,i|0,h+44|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break T}break L}d=z[f+170>>1];c=d-1|0;b=c&-8;g=b&31;if((b&63)>>>0>=32){b=1074268168>>>g|0}else{b=((1<<g)-1&1074268168)<<32-g|538447880>>>g}hd(j,(c>>>0>=64?8:b)&120);if(d>>>0<9){wg(j,1)}if((Ck(f)|0)==3){wg(j,3)}x[31609]=0;U(215,j|0,i|0,h+44|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break L}}eC(i,x[a+480180>>2]);Ij(i,a);n=1}ub(h+44|0)}zV(f);fb=h+256|0;return n|0}n=N()|0;break K}n=N()|0;ub(h+44|0)}zV(f);Q(n|0);p()}function qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=E(0),z=E(0),A=0,C=0,D=0,F=E(0),G=E(0),H=0,I=E(0);a:{if(!y[a+5046|0]){break a}g=B[a+4268>>2];PP(a);if(B[a+4268>>2]==g){break a}Tz(a)}b:{if(!y[a+5045|0]){break b}if(!ti(a+44|0)){break b}n=x[a+44>>2];q=Hc(n,0);r=Hc(n,1);n=x[a+56>>2];l=Hc(n,0);m=Hc(n,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[l>>2]=B[a+5036>>2];B[m>>2]=B[a+5040>>2];v[a+5044|0]=0;r=r+4|0;q=q+4|0;m=m+4|0;l=l+4|0;p=d-1|0;break c}p=d}s=p;t=a+4888|0;u=a+4864|0;d:{while(1){if(!s){break d}g=B[q>>2];g=E(E(E(B[a+5008>>2]-g)*B[a+4276>>2])+g);B[a+5008>>2]=g;H=Pc(x[a+4864>>2],x[a+4868>>2],x[a+4880>>2]),I=g,B[H>>2]=I;g=B[r>>2];g=E(E(E(B[a+5012>>2]-g)*B[a+4276>>2])+g);B[a+5012>>2]=g;H=Pc(x[a+4888>>2],x[a+4892>>2],x[a+4904>>2]),I=g,B[H>>2]=I;g=E(E(E(E(E(ii(u,x[a+4356>>2])*E(.6800000071525574))+E(ii(u,x[a+4360>>2])*E(-.5)))-E(ii(u,x[a+4364>>2])*E(.6200000047683716)))+E(ii(u,x[a+4368>>2])*E(-.5)))-E(ii(u,x[a+4372>>2])*E(.6200000047683716)));if(v[a+4264|0]&1){e=g;g=E(B[Pc(x[a+4816>>2],x[a+4820>>2],x[a+4836>>2])>>2]+E(e*E(.6180340051651001)));H=Pc(x[a+4816>>2],x[a+4820>>2],x[a+4832>>2]),I=E(e-E(g*E(.6180340051651001))),B[H>>2]=I}w=B[a+4280>>2];H=a,I=E(ii(u,x[a+4352>>2])+B[a+5020>>2]),B[H+5020>>2]=I;e=E(ii(t,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=e;f=B[a+5020>>2];h=E(E(E(B[a+4980>>2]-B[Pc(x[a+4624>>2],x[a+4628>>2],x[a+4644>>2])>>2])*B[a+4444>>2])+B[Pc(x[a+4624>>2],x[a+4628>>2],x[a+4644>>2])>>2]);B[a+4980>>2]=h;k=E(h*B[a+4440>>2]);j=E(e*E(.7070000171661377));i=E(f*E(-.7070000171661377));f=E(j+i);h=B[a+4272>>2];e=E(k+E(f*h));H=Pc(x[a+4624>>2],x[a+4628>>2],x[a+4640>>2]),I=E(f-E(h*e)),B[H>>2]=I;f=E(E(E(B[a+4976>>2]-B[Pc(x[a+4600>>2],x[a+4604>>2],x[a+4620>>2])>>2])*B[a+4436>>2])+B[Pc(x[a+4600>>2],x[a+4604>>2],x[a+4620>>2])>>2]);B[a+4976>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4432>>2])+E(e*h));H=Pc(x[a+4600>>2],x[a+4604>>2],x[a+4616>>2]),I=E(e-E(h*f)),B[H>>2]=I;z=E(E(e*E(-.15000000596046448))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){e=E(E(E(B[a+4972>>2]-B[Pc(x[a+4576>>2],x[a+4580>>2],x[a+4596>>2])>>2])*B[a+4428>>2])+B[Pc(x[a+4576>>2],x[a+4580>>2],x[a+4596>>2])>>2]);B[a+4972>>2]=e;h=B[a+4272>>2];e=E(E(e*B[a+4424>>2])+E(f*h));H=Pc(x[a+4576>>2],x[a+4580>>2],x[a+4592>>2]),I=E(f-E(h*e)),B[H>>2]=I;f=E(E(E(B[a+4968>>2]-B[Pc(x[a+4552>>2],x[a+4556>>2],x[a+4572>>2])>>2])*B[a+4420>>2])+B[Pc(x[a+4552>>2],x[a+4556>>2],x[a+4572>>2])>>2]);B[a+4968>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4416>>2])+E(e*h));H=Pc(x[a+4552>>2],x[a+4556>>2],x[a+4568>>2]),I=E(e-E(h*f)),B[H>>2]=I;z=E(E(E(e*E(.3499999940395355))+z)+E(f*E(-.3799999952316284)))}H=Pc(x[a+4912>>2],x[a+4916>>2],x[a+4928>>2]),I=f,B[H>>2]=I;e=E(B[Pc(x[a+4912>>2],x[a+4916>>2],x[a+4932>>2])>>2]*B[a+4496>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-e)*B[a+4500>>2])+e;e=E(E(E(B[a+4964>>2]-B[Pc(x[a+4528>>2],x[a+4532>>2],x[a+4548>>2])>>2])*B[a+4412>>2])+B[Pc(x[a+4528>>2],x[a+4532>>2],x[a+4548>>2])>>2]);B[a+4964>>2]=e;f=B[a+5028>>2];k=B[a+4272>>2];h=E(E(f*k)+E(e*B[a+4408>>2]));H=Pc(x[a+4528>>2],x[a+4532>>2],x[a+4544>>2]),I=E(f-E(k*h)),B[H>>2]=I;e=E(E(E(B[a+4960>>2]-B[Pc(x[a+4504>>2],x[a+4508>>2],x[a+4524>>2])>>2])*B[a+4404>>2])+B[Pc(x[a+4504>>2],x[a+4508>>2],x[a+4524>>2])>>2]);B[a+4960>>2]=e;f=E(e*B[a+4400>>2]);e=B[a+4272>>2];k=E(f+E(h*e));H=Pc(x[a+4504>>2],x[a+4508>>2],x[a+4520>>2]),I=E(h-E(e*k)),B[H>>2]=I;B[a+5020>>2]=k;e=E(E(E(E(E(ii(t,x[a+4380>>2])*E(.7070000171661377))+E(ii(t,x[a+4384>>2])*E(-.6000000238418579)))-E(ii(t,x[a+4388>>2])*E(.5)))+E(ii(t,x[a+4392>>2])*E(-.6000000238418579)))-E(ii(t,x[a+4396>>2])*E(.5)));if(v[a+4264|0]&1){f=e;e=E(B[Pc(x[a+4840>>2],x[a+4844>>2],x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));H=Pc(x[a+4840>>2],x[a+4844>>2],x[a+4856>>2]),I=E(f-E(e*E(.6180340051651001))),B[H>>2]=I}F=B[a+4280>>2];f=E(E(E(B[a+5004>>2]-B[Pc(x[a+4768>>2],x[a+4772>>2],x[a+4788>>2])>>2])*B[a+4492>>2])+B[Pc(x[a+4768>>2],x[a+4772>>2],x[a+4788>>2])>>2]);B[a+5004>>2]=f;G=E(f*B[a+4488>>2]);f=E(i-j);i=B[a+4272>>2];j=E(G+E(f*i));H=Pc(x[a+4768>>2],x[a+4772>>2],x[a+4784>>2]),I=E(f-E(i*j)),B[H>>2]=I;f=E(E(E(B[a+5e3>>2]-B[Pc(x[a+4744>>2],x[a+4748>>2],x[a+4764>>2])>>2])*B[a+4484>>2])+B[Pc(x[a+4744>>2],x[a+4748>>2],x[a+4764>>2])>>2]);B[a+5e3>>2]=f;i=B[a+4272>>2];f=E(E(f*B[a+4480>>2])+E(j*i));H=Pc(x[a+4744>>2],x[a+4748>>2],x[a+4760>>2]),I=E(j-E(i*f)),B[H>>2]=I;j=E(E(E(h*E(.3799999952316284))+E(j*E(-.15000000596046448)))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){h=E(E(E(B[a+4996>>2]-B[Pc(x[a+4720>>2],x[a+4724>>2],x[a+4740>>2])>>2])*B[a+4476>>2])+B[Pc(x[a+4720>>2],x[a+4724>>2],x[a+4740>>2])>>2]);B[a+4996>>2]=h;i=B[a+4272>>2];h=E(E(h*B[a+4472>>2])+E(f*i));H=Pc(x[a+4720>>2],x[a+4724>>2],x[a+4736>>2]),I=E(f-E(i*h)),B[H>>2]=I;f=E(E(E(B[a+4992>>2]-B[Pc(x[a+4696>>2],x[a+4700>>2],x[a+4716>>2])>>2])*B[a+4468>>2])+B[Pc(x[a+4696>>2],x[a+4700>>2],x[a+4716>>2])>>2]);B[a+4992>>2]=f;i=B[a+4272>>2];f=E(E(f*B[a+4464>>2])+E(h*i));H=Pc(x[a+4696>>2],x[a+4700>>2],x[a+4712>>2]),I=E(h-E(i*f)),B[H>>2]=I;j=E(E(E(h*E(.3499999940395355))+j)+E(f*E(-.3799999952316284)))}n=r+4|0;p=q+4|0;h=E(g*w);z=E(z-E(k*E(.3799999952316284)));k=E(e*F);H=Pc(x[a+4936>>2],x[a+4940>>2],x[a+4952>>2]),I=f,B[H>>2]=I;g=E(B[Pc(x[a+4936>>2],x[a+4940>>2],x[a+4956>>2])>>2]*B[a+4496>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-g)*B[a+4500>>2])+g;g=E(E(E(B[a+4988>>2]-B[Pc(x[a+4672>>2],x[a+4676>>2],x[a+4692>>2])>>2])*B[a+4460>>2])+B[Pc(x[a+4672>>2],x[a+4676>>2],x[a+4692>>2])>>2]);B[a+4988>>2]=g;e=B[a+5032>>2];f=B[a+4272>>2];g=E(E(e*f)+E(g*B[a+4456>>2]));H=Pc(x[a+4672>>2],x[a+4676>>2],x[a+4688>>2]),I=E(e-E(f*g)),B[H>>2]=I;f=B[a+4284>>2];e=E(E(E(B[a+4984>>2]-B[Pc(x[a+4648>>2],x[a+4652>>2],x[a+4668>>2])>>2])*B[a+4452>>2])+B[Pc(x[a+4648>>2],x[a+4652>>2],x[a+4668>>2])>>2]);B[a+4984>>2]=e;w=B[a+4272>>2];e=E(E(e*B[a+4448>>2])+E(g*w));H=Pc(x[a+4648>>2],x[a+4652>>2],x[a+4664>>2]),I=E(g-E(w*e)),B[H>>2]=I;B[a+5024>>2]=e;e=E(-e);w=B[a+4288>>2];D=4504;e:{f:{while(1){if((D|0)==4960){g:{e=E(k+E(E(E(e*E(.3799999952316284))+j)*w));g=E(h+E(E(E(g*E(.3799999952316284))+z)*f));if(!(y[a+4264|0]&2)){break g}break f}}else{o=a+D|0;A=x[o+16>>2];C=A-1|0;x[o+16>>2]=C;if((A|0)<=0){x[o+16>>2]=C+x[o+12>>2]}C=x[o+20>>2];A=C-1|0;x[o+20>>2]=A;if((C|0)<=0){x[o+20>>2]=A+x[o+12>>2]}D=D+24|0;continue}break}B[l>>2]=E(g+B[a+5036>>2])*E(.5);B[m>>2]=E(e+B[a+5040>>2])*E(.5);B[a+5040>>2]=e;B[a+5036>>2]=g;if((s|0)==1){break e}s=s-1|0;m=m+4|0;l=l+4|0;n=r+8|0;p=q+8|0}q=p;r=n;B[l>>2]=g;B[m>>2]=e;s=s-1|0;m=m+4|0;l=l+4|0;continue}break}v[a+5044|0]=1}p=a;a=x[a+56>>2];Ii(p,b,c,Hc(a,0),Hc(a,1),d)}}function Gta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-272|0;fb=e;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{h=e+206|0;m:{if(!E$(b,h)){break m}if(!F$(h)){break m}d=1;if((c|0)==64){break m}Dd(a,131072);d=fb-16|0;fb=d;h=e+120|0;f=uc(d+4|0,3910);Uc(h,f);tb(f);fb=d+16|0;x[31609]=0;d=e+160|0;S(209,d|0,h|0,e+210|0);f=x[31609];x[31609]=0;n:{o:{p:{if((f|0)!=1){zb(a+1298344|0,d);tb(d);Eb(h);f=uc(d,11160);zb(a+1298356|0,f);tb(f);o=a,q=x[Fc(d,4)>>2],x[o+1298404>>2]=q;xE(h,3,e+219|0);Cc(d,h);zb(a+1298308|0,d);tb(d);pi(h,3,e+249|0);Er(d,4,h);zb(a+1298320|0,d);tb(d);d=kp(d);o=d,q=Ld(y[e+269|0],1,31),x[o+8>>2]=q;o=d,q=Ld(y[e+270|0],1,12),x[o+4>>2]=q;x[d>>2]=y[e+271|0]+1900;h=a+1298412|0;Nc(h);nE(h,d);m=e+128|0;h=Nb(e+148|0);q:{r:{s:{while(1){d=x[b+8>>2];f=x[b>>2];x[31609]=0;d=U(150,f|0,d|0,8)|0;f=x[31609];x[31609]=0;t:{u:{v:{w:{x:{if((f|0)!=1){if(!d){break q}x[31609]=0;O(310,b|0,e- -64|0);d=x[31609];x[31609]=0;if((d|0)==1){break x}d=x[e+68>>2];y:{g=y[e+210|0];switch(g-3|0){case 1:break w;case 0:break y;default:break v}}f=2;if(x[e+64>>2]!=1431389523){break u}break t}b=N()|0;break b}b=N()|0;break b}f=4;if(x[e+64>>2]!=1431389523){break u}break t}f=0;if(g>>>0>7){break t}}d=x[e+64>>2]==1146113363?-1:d;f=0}g=x[e+68>>2];x[e+120>>2]=x[e+64>>2];x[e+124>>2]=g;x[31609]=0;g=e+100|0;S(185,g|0,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break s}hc(m,g);x[31609]=0;d=e+120|0;O(311,h|0,d|0);i=x[31609];x[31609]=0;if((i|0)==1){break r}Hd(d);ub(g);x[31609]=0;P(183,b|0,f|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){continue}break}b=N()|0;break b}b=N()|0;break b}b=N()|0;Hd(e+120|0);ub(e+100|0);break b}x[31609]=0;m=R(168,e+120|0)|0;b=x[31609];x[31609]=0;z:{A:{B:{if((b|0)!=1){x[31609]=0;d=e+100|0;S(312,d|0,h|0,1431389523);b=x[31609];x[31609]=0;if((b|0)==1){break B}b=kd(m,d);ub(d);w[e+98>>1]=0;w[e+96>>1]=65534;if(y[e+210|0]<3){break z}x[31609]=0;d=R(189,b|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){break A}break d}b=N()|0;break b}b=N()|0;break c}w[e+98>>1]=d;if(y[e+210|0]<4){break z}x[31609]=0;d=R(189,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}w[e+96>>1]=y[e+210|0]==4?d?d:-2:d}d=y[a+484376|0];f=x[a+484360>>2];x[31609]=0;g=R(202,b|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break d}x[31609]=0;S(238,Xb(f,d)|0,b|0,g>>>1|0);d=x[31609];x[31609]=0;if((d|0)==1){break d}d=Xb(x[a+484360>>2],y[a+484376|0]);d=mE(x[d>>2],x[d+4>>2]);Hf(e+98|0,d);Hf(e+96|0,d);x[31609]=0;d=e+100|0;S(312,d|0,h|0,1414807888);f=x[31609];x[31609]=0;if((f|0)==1){break e}b=kd(b,d);ub(d);d=x[b>>2];x[31609]=0;d=R(172,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}if(!(c&1)|d^1){break n}x[31609]=0;O(313,b|0,e+8|0);d=x[31609];x[31609]=0;if((d|0)==1){break f}o=a,q=Ld(y[e+10|0],1,32)+1|0,w[o+480188>>1]=q;x[31609]=0;d=P(214,e+84|0,z[e+8>>1])|0;f=x[31609];x[31609]=0;if((f|0)==1){break g}o=e,q=wb(x[d>>2]),x[o+44>>2]=q;i=wb(x[d+4>>2]);C:{D:{E:{while(1){k=x[e+44>>2];if(!Ib(k,i)){f=z[a+480188>>1];x[31609]=0;f=P(314,e+100|0,f|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){break C}b=N()|0;break o}x[31609]=0;f=y[e+210|0]<3?9:8;P(183,b|0,f-4|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){x[31609]=0;l=R(151,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break E}Ih(b,f);x[31609]=0;g=e- -64|0;S(185,g|0,b|0,f+l|0);f=x[31609];x[31609]=0;if((f|0)==1){break D}f=hc(e+100|0,g);kd(k,f);ub(f);ub(g);Qf(e+44|0);continue}break}b=N()|0;break o}b=N()|0;break o}b=N()|0;break o}g=Xb(x[a+484360>>2],y[a+484376|0]);g=cm(x[g>>2],x[g+4>>2]);x[31609]=0;l=a+484344|0;O(223,l|0,g|0);g=x[31609];x[31609]=0;if((g|0)!=1){g=Xb(x[a+484360>>2],y[a+484376|0]);o=e,q=wb(x[g>>2]),x[o+64>>2]=q;i=wb(x[g+4>>2]);while(1){g=x[e+64>>2];if(!Ib(g,i)){g=Xb(x[a+484360>>2],y[a+484376|0]);i=z[e+96>>1];F:{if(!Wi(g,i)){break F}k=x[g>>2];j=z[e+98>>1];if(!j){if(mE(k,x[g+4>>2])>>>0<=i>>>0){break F}}g=Wb(x[l>>2],z[ac(k,i)>>1]);Ae(g,An(We(Oe(e- -64|0,12,j&255),x[g+12>>2]-1|0)))}Mk(f);Rc(d);break n}k=x[d>>2];n=Sf(k,x[d+4>>2]);j=z[g>>1];if(n>>>0>j>>>0){x[31609]=0;k=ba(315,ch(k,j)|0,y[e+210|0],f|0,a|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break p}w[g>>1]=k}ge(e- -64|0);continue}}break p}b=N()|0;Eb(e+120|0);break a}b=N()|0;Mk(f)}Rc(d);break c}x[31609]=0;d=e- -64|0;S(312,d|0,h|0,1196641603);f=x[31609];x[31609]=0;if((f|0)==1){break k}b=kd(b,d);ub(d);d=x[b>>2];x[31609]=0;d=R(172,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}if(d){x[31609]=0;P(183,b|0,1)|0;d=x[31609];x[31609]=0;if((d|0)==1){break d}x[31609]=0;d=R(202,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}x[31609]=0;aa(316,a+1298332|0,b|0,d|0,40,0);d=x[31609];x[31609]=0;if((d|0)==1){break d}}x[31609]=0;S(312,e- -64|0,h|0,1146113363);d=x[31609];x[31609]=0;if((d|0)==1){break h}x[31609]=0;d=e+44|0;S(312,d|0,h|0,1229999443);f=x[31609];x[31609]=0;if((f|0)==1){break l}b=kd(b,d);ub(d);x[31609]=0;d=R(197,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}w[a+480190>>1]=d;i=a+484380|0;k=a+946304|0;l=!(c&2);f=1;G:{while(1){H:{c=f&65535;if(c>>>0>(d&65535)>>>0){break G}d=30;I:{J:{K:{if(y[e+210|0]>=2){x[31609]=0;d=R(197,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break K}}x[31609]=0;S(317,b|0,k+(c<<5)|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break K}x[31609]=0;d=e+28|0;O(318,b|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break J}x[31609]=0;g=i+D(c,104)|0;O(319,d|0,g|0);c=x[31609];x[31609]=0;if((c|0)==1){break J}d=y[e+210|0];if(d>>>0>=8){x[31609]=0;O(320,b|0,g+43|0);c=x[31609];x[31609]=0;if((c|0)==1){break J}d=y[e+210|0]}x[31609]=0;P(183,b|0,((d&255)>>>0>1?6:2)|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break J}x[31609]=0;c=e- -64|0;d=R(151,c|0)|0;j=x[31609];x[31609]=0;if((j|0)!=1){x[31609]=0;S(185,e+8|0,c|0,d|0);c=x[31609];x[31609]=0;if((c|0)!=1){break I}}b=N()|0;break i}b=N()|0;break i}b=N()|0;break i}d=e+8|0;c=hc(e+44|0,d);ub(d);j=x[c>>2];x[31609]=0;j=R(172,j|0)|0;n=x[31609];x[31609]=0;if((n|0)!=1){L:{if(l|j^1){break L}d=Zc(d,w[g+34>>1]&1?16:8,1,0,(y[e+43|0]&12)==4?7:0);x[31609]=0;U(215,d|0,g|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break L}break H}ub(c);f=f+1|0;d=z[a+480190>>1];continue}}break}b=N()|0;ub(c);break i}eg(a);x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;x[31609]=0;d=1;U(266,a+1074312|0,114,1)|0;a=x[31609];x[31609]=0;if((a|0)==1){break j}ub(e- -64|0);ub(b);ke(h)}fb=e+272|0;return d|0}b=N()|0;break i}b=N()|0;break c}b=N()|0}ub(e- -64|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}ub(m)}ke(h)}Q(b|0);p()}function jpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;d=fb-288|0;fb=d;yc(b);a:{b:{c:{e=d+192|0;d:{if(!Dv(b,e)){break d}if(!mX(e)){break d}if(!Mb(x[b>>2],x[b+8>>2],Bc(lX(e),hb))){break d}o=1;if((c|0)==64){break d}o=0;if(!dd(b,y[d+196|0])){break d}Dd(a,268435456);eg(a);x[a+480208>>2]=4;Lb(a+1074312|0,114,1);e=d+84|0;i=uc(e,15411);zb(a+1298344|0,i);tb(i);i=uc(e,10298);zb(a+1298356|0,i);tb(i);E=a,F=x[Fc(e,4)>>2],x[E+1298404>>2]=F;i=d+16|0;bf(i,d+198|0,48,3);Cc(e,i);zb(a+1298308|0,e);tb(e);e=y[d+246|0];w[a+480188>>1]=e+1;x[a+480228>>2]=y[d+249|0];x[a+480204>>2]=D(y[d+250|0],1e4);x[a+480196>>2]=y[d+251|0];i=a+480280|0;h=d+252|0;while(1){if((f|0)==(e|0)){e:{w[a+480190>>1]=y[d+284|0];f=y[d+286|0]|y[d+287|0]<<8;i=fb-16|0;fb=i;e=d+180|0;x[e>>2]=0;x[e+4>>2]=0;tc(e+8|0);Rd(i+8|0,x[vb(i+4|0,e)>>2]);f:{g:{if(f){x[31609]=0;O(662,e|0,f|0);h=x[31609];x[31609]=0;if((h|0)==1){break g}oD(e,f)}f=i+8|0;Qd(f);bh(f);fb=i+16|0;break f}a=N()|0;bh(i+8|0);Q(a|0);p()}x[31609]=0;i=e;S(657,b|0,e|0,y[d+286|0]|y[d+287|0]<<8);e=x[31609];x[31609]=0;if((e|0)==1){break b}u=Nb(d+168|0);q=Nb(d+156|0);x[31609]=0;U(420,b|0,u|0,y[d+285|0])|0;e=x[31609];x[31609]=0;if((e|0)==1){break c}x[31609]=0;U(420,b|0,q|0,y[d+284|0])|0;e=x[31609];x[31609]=0;if((e|0)==1){break c}o=c&2;r=a+946304|0;s=a+484380|0;m=d+122|0;t=d+90|0;e=0;h:{while(1){f=e;if(e>>>0>=y[d+284|0]){o=1;if(!(c&1)){break e}x[d+68>>2]=0;Nc(Xb(x[a+484360>>2],y[a+484376|0]));E=d,F=wb(x[i>>2]),x[E+64>>2]=F;r=a+484344|0;A=wb(x[i+4>>2]);break h}x[31609]=0;e=f+1|0;h=s+D(e,104)|0;O(279,h|0,0);g=x[31609];x[31609]=0;i:{if((g|0)!=1){g=yb(x[q>>2],f);g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);if(!g){continue}x[31609]=0;g=P(149,b|0,g|0)|0;j=x[31609];x[31609]=0;j:{if((j|0)==1){break j}if(!g){continue}x[31609]=0;g=P(658,b|0,d+84|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break j}if(!g){continue}j=d+72|0;Ue(j,2,t);x[31609]=0;g=d+16|0;O(218,g|0,j|0);l=x[31609];x[31609]=0;if((l|0)==1){break c}Ac(r+(e<<5)|0,g);tb(g);Lk(j,2,m);x[31609]=0;O(218,g|0,j|0);j=x[31609];x[31609]=0;if((j|0)==1){break c}Be(h+43|0,g);tb(g);g=y[d+134|0];if(g>>>0<=15){w[h+28>>1]=D(g,17)&255;w[h+34>>1]=z[h+34>>1]|32}v[d+16|0]=y[d+135|0];v[d+72|0]=64;E=h,F=y[Qb(d+16|0,d+72|0)|0],w[E+32>>1]=F;x[h+24>>2]=y[d+137|0]|y[d+138|0]<<8;g=y[d+143|0]|y[d+144|0]<<8|(y[d+145|0]<<16|y[d+146|0]<<24);x[h+4>>2]=g;j=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[h+8>>2]=j;l=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[h>>2]=l;k=y[d+136|0];if(k&1){j=j>>>1|0;x[h+8>>2]=j;g=g>>>1|0;x[h+4>>2]=g;x[h>>2]=l>>>1}k:{if(g>>>0>=j>>>0){break k}g=z[h+34>>1];w[h+34>>1]=g|2;if(!(k&2)){break k}w[h+34>>1]=g|6}Uk(h);if(!o){continue}f=yb(x[q>>2],f);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[31609]=0;P(149,b|0,f+y[d+88|0]|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){break i}}break c}break c}f=Zc(d+16|0,v[d+136|0]&1?16:8,1,0,1);x[31609]=0;U(215,f|0,h|0,b|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){continue}break}break c}while(1){j=x[d+64>>2];if(!Ib(j,A)){f=y[a+484376|0];h=x[a+484360>>2];l:{b=x[d+68>>2];c=b&63;m:{if(!c){break m}e=Xb(h,f);b=b>>>6&65535;if(!Wi(e,b)){break m}b=z[ac(x[e>>2],b)>>1];e=x[r>>2];x[31609]=0;O(659,Wb(e,b)|0,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break l}f=y[a+484376|0];h=x[a+484360>>2]}a=Xb(h,f);f=wb(x[a>>2]);x[d+84>>2]=f;a=wb(x[a+4>>2]);e=65535;while(1){if(!Ib(f,a)){break e}if(z[f>>1]==65535){n:{if((e&65535)!=65535){break n}x[31609]=0;e=P(367,r|0,64)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break n}break c}w[f>>1]=e}f=x[ge(d+84|0)>>2];continue}}break c}o:{c=y[j+3|0];if(y[j+2|0]>y[d+246|0]|c>>>0>=y[d+285|0]){break o}c=yb(x[u>>2],c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31609]=0;c=P(149,b|0,c|0)|0;e=x[31609];x[31609]=0;p:{if((e|0)!=1){if(!c){break o}x[31609]=0;O(660,b|0,d+84|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}f=y[d+88|0];if(!f){break o}c=y[j|0]|y[j+1|0]<<8;v[d+16|0]=y[d+89|0];v[d+72|0]=y[d+246|0]-y[j+2|0];s=y[Qb(d+16|0,d+72|0)|0];x[d+60>>2]=c+f;E=d,F=x[bd(d+68|0,d+60|0)>>2],x[E+68>>2]=F;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;e=c&63;m=c>>>6|0;t=0;while(1){if((f&255)>>>0<=t>>>0){break o}f=Xb(x[a+484360>>2],y[a+484376|0]);g=e>>>0>63;m=g+m|0;c=m&65535;if($c(x[f>>2],x[f+4>>2])>>>0<=c>>>0){x[31609]=0;O(330,f|0,m+1&65535);f=x[31609];x[31609]=0;if((f|0)==1){break p}x[31609]=0;h=P(367,r|0,64)|0;f=x[31609];x[31609]=0;if((f|0)==1){break p}f=Xb(x[a+484360>>2],y[a+484376|0]);E=ac(x[f>>2],c),F=h,w[E>>1]=F}k=x[a+484344>>2];n=x[a+484348>>2];l=z[ac(x[f>>2],c)>>1];if(!Je(k,n,l)){break o}h=0;c=Wb(k,l);k=g?0:e;f=md(x[c>>2],x[x[c+48>>2]+12>>2],k,y[j+2|0]);q:{while(1){if((h|0)==(s|0)){c=y[d+89|0];if(c>>>0<=s>>>0){break q}x[31609]=0;P(183,b|0,D(c-s|0,5)|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break q}break c}x[31609]=0;c=d+72|0;O(661,c|0,b|0);e=x[31609];x[31609]=0;if((e|0)!=1){g=Jc(c);B=_e(c);n=Yi(c);C=gc(c);e=0;c=y[d+72|0];if((c-1&255)>>>0<=142){e=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[(d+16|0)+h|0]=e}v[f|0]=e;c=y[g|0];v[f+2|0]=1;v[f+1|0]=c;c=y[B|0];r:{if((c|0)!=255){v[f+4|0]=c;break r}v[f+2|0]=0}c=y[n|0];s:{if(c>>>0>22){break s}v[f+3|0]=y[c+25376|0];g=y[C|0];v[f+5|0]=g;c=f+5|0;t:{switch(y[n|0]-4|0){case 3:v[c|0]=g&3|64;break s;case 4:v[c|0]=g&3|48;break s;case 7:e=x[i>>2];if(oc(e,x[i+4>>2])>>>0<=g>>>0){break s}n=c;c=yb(e,g);c=y[c|0]|y[c+1|0]<<8;v[n|0]=c>>>6;e=Wb(x[a+484344>>2],l);e=md(x[e>>2],x[x[e+48>>2]+12>>2],k,z[a+480188>>1]-1&65535);v[e+5|0]=c&63;v[e+3|0]=14;break s;case 8:e=c;c=x[d+60>>2];v[e|0]=c>>>6;e=Wb(x[a+484344>>2],l);e=md(x[e>>2],x[x[e+48>>2]+12>>2],k,z[a+480188>>1]-1&65535);v[e+5|0]=c&63;v[e+3|0]=14;break s;case 10:v[c|0]=g&15|128;break s;case 12:v[d+15|0]=15;E=c,F=y[Qb(c,d+15|0)|0]|208,v[E|0]=F;break s;case 13:v[d+15|0]=15;E=c,F=y[Qb(c,d+15|0)|0]|192,v[E|0]=F;break s;case 14:v[d+15|0]=15;E=c,F=y[Qb(c,d+15|0)|0]|224,v[E|0]=F;break s;case 0:case 16:case 17:if(!(g&15)){break s}e=g&240;if(!e|(e|0)==240){break s}v[c|0]=g|15;break s;case 9:case 18:break t;default:break s}}if(e&255){break s}v[f|0]=y[(d+16|0)+h|0]}f=f+6|0;h=h+1|0;continue}break}break c}e=k+1|0;t=t+1|0;f=y[d+88|0];continue}}break c}break c}Xe(d- -64|0);continue}}}else{w[(i+(f<<5)|0)+4>>1]=D(y[f+h|0],17);f=f+1|0;continue}break}wc(q);wc(u);wc(i)}fb=d+288|0;return o|0}f=N()|0;wc(q);wc(u);break a}f=N()|0}wc(i);Q(f|0);p()}function YL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;i=fb-208|0;fb=i;a:{b:{if(g){rf(i+196|0,f,32);x[31609]=0;U(542,i+184|0,f|0,32)|0;h=x[31609];x[31609]=0;if((h|0)!=1){break b}f=N()|0;break a}Fb(i+196|0);Fb(i+184|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(Vt(c)){h=x[b+24>>2];j=x[h+484344>>2];if(Je(j,x[h+484348>>2],c&65535)){break j}}x[31609]=0;S(1211,a|0,i+196|0,i+184|0);a=x[31609];x[31609]=0;if((a|0)!=1){break i}f=N()|0;break c}c=Wb(j,c);if(!(!((e|0)<0|x[c+12>>2]<=(d|0)|(d|0)<0)&z[h+480188>>1]>e>>>0)){x[31609]=0;S(1211,a|0,i+196|0,i+184|0);a=x[31609];x[31609]=0;if((a|0)!=1){break i}f=N()|0;break c}c=md(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);sf(i+196|0);sf(i+184|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=y[c|0];if(!Tc(d)){if(!Fl(d)){break A}}e=y[c+1|0];h=x[b+24>>2];x[31609]=0;j=i+160|0;V(1212,j|0,h|0,d|0,e|0);d=x[31609];x[31609]=0;e=1;if((d|0)==1){break y}x[31609]=0;O(1059,i+172|0,j|0);d=x[31609];x[31609]=0;if((d|0)!=1){break z}f=N()|0;break v}e=0;x[31609]=0;P(36,i+172|0,16800)|0;d=x[31609];x[31609]=0;if((d|0)==1){break x}}x[31609]=0;h=i+172|0;d=P(838,i+196|0,h|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break w}tb(h);if(e){tb(i+160|0)}e=9984;h=y[c|0];if(!Tc(h)){e=Fl(h)?10294:16800}x[31609]=0;h=P(36,i+172|0,e|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break u}x[31609]=0;e=P(838,i+184|0,h|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break t}tb(h);if(f-6>>>0>4294967290){break l}x[31609]=0;h=P(36,i+148|0,18454)|0;j=x[31609];x[31609]=0;if((j|0)==1){break s}x[31609]=0;j=P(838,d|0,h|0)|0;m=x[31609];x[31609]=0;if((m|0)==1){break r}tb(h);x[31609]=0;h=P(36,i+136|0,18454)|0;m=x[31609];x[31609]=0;if((m|0)==1){break q}x[31609]=0;m=P(838,e|0,h|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break p}tb(h);h=c+1|0;B:{if(y[c+1|0]){x[31609]=0;O(559,i+124|0,h|0);k=x[31609];x[31609]=0;if((k|0)!=1){break B}break d}x[31609]=0;P(36,i+124|0,16805)|0;k=x[31609];x[31609]=0;if((k|0)==1){break d}}x[31609]=0;k=j;j=i+124|0;k=P(838,k|0,j|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break o}tb(j);h=y[h|0];x[31609]=0;h=P(36,j|0,(h?10817:16805)|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break n}x[31609]=0;m=P(838,m|0,h|0)|0;j=x[31609];x[31609]=0;if((j|0)!=1){break m}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;tb(i+172|0);if(!e){break c}}tb(i+160|0);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;tb(i+124|0);break c}f=N()|0;break c}tb(h);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{j=Wg(y[c|0]);O:{if(j){x[31609]=0;l=P(36,i+100|0,18454)|0;h=x[31609];x[31609]=0;if((h|0)==1){break N}h=y[c+4|0];n=y[c+2|0];x[31609]=0;o=i,q=Cj(n,h)&255,x[o+76>>2]=q;n=i+88|0;O(558,n|0,i+76|0);h=x[31609];x[31609]=0;if((h|0)==1){break M}h=0;x[31609]=0;S(1015,i+112|0,l|0,n|0);l=x[31609];x[31609]=0;if((l|0)!=1){break O}f=N()|0;break G}h=y[c+2|0];if(h){h=lR(x[x[x[b+24>>2]+8>>2]+88>>2],h);x[31609]=0;h=U(542,i+100|0,1,h|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break E}x[31609]=0;l=i+88|0;O(559,l|0,c+4|0);n=x[31609];x[31609]=0;if((n|0)==1){break L}x[31609]=0;S(1015,i+112|0,h|0,l|0);l=x[31609];x[31609]=0;h=1;if((l|0)!=1){break O}f=N()|0;break J}h=0;x[31609]=0;P(36,i+112|0,16804)|0;l=x[31609];x[31609]=0;if((l|0)==1){break e}}x[31609]=0;l=k;k=i+112|0;l=P(838,l|0,k|0)|0;n=x[31609];x[31609]=0;if((n|0)==1){break K}tb(k);if(h){tb(i+88|0);tb(i+100|0)}if(j){tb(i+88|0);tb(i+100|0)}h=5488;if(!Wg(y[c|0])){h=y[c+2|0]?5484:16804}x[31609]=0;h=P(36,i+112|0,h|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break D}x[31609]=0;j=P(838,m|0,h|0)|0;m=x[31609];x[31609]=0;if((m|0)!=1){break C}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break F}f=N()|0;break I}f=N()|0;tb(i+112|0);if(!h){break H}}tb(i+88|0)}tb(i+100|0)}if(!j){break c}}tb(i+88|0)}tb(i+100|0);break c}f=N()|0;break c}f=N()|0;break c}tb(h);if(f-13>>>0>4294967283){break l}x[31609]=0;h=P(36,i+76|0,18454)|0;m=x[31609];x[31609]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((m|0)!=1){x[31609]=0;m=P(838,l|0,h|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break Z}tb(h);x[31609]=0;h=P(36,i- -64|0,18454)|0;k=x[31609];x[31609]=0;if((k|0)==1){break Y}x[31609]=0;j=P(838,j|0,h|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break X}tb(h);h=y[c+3|0];_:{if(Wg(y[c|0])){k=y[c+5|0];b=0;x[31609]=0;o=i,q=Cj(h,k)&4095,x[o+16>>2]=q;O(1213,i+52|0,i+16|0);h=x[31609];x[31609]=0;if((h|0)!=1){break _}f=N()|0;break c}if(h){b=kR(x[x[x[b+24>>2]+8>>2]+84>>2],h);x[31609]=0;b=U(542,i+40|0,1,b|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break W}x[31609]=0;h=i+28|0;O(559,h|0,c+5|0);k=x[31609];x[31609]=0;if((k|0)==1){break V}x[31609]=0;S(1015,i+52|0,b|0,h|0);h=x[31609];x[31609]=0;b=1;if((h|0)!=1){break _}f=N()|0;break S}b=0;x[31609]=0;P(36,i+52|0,16800)|0;h=x[31609];x[31609]=0;if((h|0)==1){break U}}x[31609]=0;h=i+52|0;P(838,m|0,h|0)|0;m=x[31609];x[31609]=0;if((m|0)==1){break T}tb(h);if(b){tb(i+28|0);tb(i+40|0)}b=11177;if(!Wg(y[c|0])){b=y[c+3|0]?11177:16800}x[31609]=0;b=P(36,i+52|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break Q}x[31609]=0;P(838,j|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break P}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break R}f=N()|0;break c}f=N()|0;tb(i+52|0);if(!b){break c}}tb(i+28|0)}tb(i+40|0);break c}f=N()|0;break c}tb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=_c(x[d+4>>2],y[d+11|0]);da:{if(b>>>0>f>>>0){x[31609]=0;b=i+16|0;V(121,b|0,d|0,0,f|0);c=x[31609];x[31609]=0;if((c|0)!=1){zb(d,b);tb(b);break da}f=N()|0;break c}if(!g){break da}x[31609]=0;b=U(542,i+16|0,f-b|0,32)|0;c=x[31609];x[31609]=0;if((c|0)==1){break ca}x[31609]=0;P(838,d|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break ba}tb(b)}b=_c(x[e+4>>2],y[e+11|0]);if(b>>>0<=f>>>0){break $}x[31609]=0;b=i+4|0;V(121,b|0,e|0,0,f|0);c=x[31609];x[31609]=0;if((c|0)==1){break aa}zb(e,b);tb(b);break k}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}if(!g){break k}x[31609]=0;b=U(542,i+4|0,f-b|0,32)|0;c=x[31609];x[31609]=0;if((c|0)==1){break h}x[31609]=0;P(838,e|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break g}tb(b)}x[31609]=0;S(1211,a|0,d|0,e|0);a=x[31609];x[31609]=0;if((a|0)==1){break f}}tb(i+184|0);tb(i+196|0);fb=i+208|0;return}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0}tb(i+184|0)}tb(i+196|0);Q(f|0);p()}function Psa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=fb-256|0;fb=e;yc(b);f=fb-16|0;fb=f;g=e+99|0;q_(f+8|0,g);i=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);h=x[f+4>>2];if((h|0)==(i|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(i|0)==(h|0);if(!f){p_(g)}a:{if(!f){break a}if(!r_(g)){break a}d=1;if((c|0)==64){break a}Dd(a,x[((y[e+215|0]|y[e+216|0]<<8)<<2)+24784>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;d=e+36|0;f=uc(d,13187);zb(a+1298344|0,f);tb(f);f=uc(d,10329);zb(a+1298356|0,f);tb(f);g=fb-16|0;fb=g;f=e+4|0;i=uc(g+4|0,4389);Uc(f,i);tb(i);fb=g+16|0;x[31609]=0;V(229,d|0,f|0,y[e+178|0],e+175|0);g=x[31609];x[31609]=0;b:{if((g|0)!=1){zb(a+1298368|0,d);tb(d);Eb(f);Zh(a+1298392|0,((y[e+215|0]|y[e+216|0]<<8)<<2)+24832|0);Zh(a+1298380|0,x[((y[e+215|0]|y[e+216|0]<<8)<<2)+24880>>2]);t=a,u=x[Fc(d,4)>>2],x[t+1298404>>2]=u;Ue(f,2,e+103|0);Cc(d,f);zb(a+1298308|0,d);tb(d);Ue(f,2,e+135|0);Cc(d,f);c:{if(!Nd(d,9766)){x[31609]=0;S(258,f|0,4,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}zb(a+1298320|0,f);tb(f)}tb(e+36|0);w[a+480188>>1]=32;i=a+480280|0;h=e+180|0;f=0;d:{while(1){if((f|0)!=32){d=i+(f<<5)|0;Ve(d);g=y[f+h|0];e:{if(g>>>0<=15){x[e+36>>2]=(g<<4|8)&248;x[e+4>>2]=256;t=d,u=x[Cd(e+36|0,e+4|0)>>2],w[t+4>>1]=u;break e}if((g|0)!=16){if((g|0)!=255){break e}w[a+480188>>1]=f;break d}x[d>>2]=256;w[d+4>>1]=128}f=f+1|0;continue}break}f=z[a+480188>>1]}d=0;if(!(f&65535)){break a}x[e+36>>2]=y[e+212|0]<<2;x[e+4>>2]=256;t=a,u=x[Hb(e+36|0,e+4|0)>>2],x[t+480200>>2]=u;x[a+480196>>2]=y[e+213|0];x[a+480204>>2]=D(y[e+214|0],1e4);if(dd(b,y[e+217|0]|y[e+218|0]<<8|(y[e+219|0]<<16|y[e+220|0]<<24))){$j(Xb(x[a+484360>>2],y[a+484376|0]),b,y[e+221|0]+1|0,255,254)}if(!dd(b,y[e+227|0]|y[e+228|0]<<8|(y[e+229|0]<<16|y[e+230|0]<<24))){break a}f=y[e+235|0]+1|0;w[a+480190>>1]=f;l=a+946304|0;k=a+484380|0;m=e+68|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(f&65535)>>>0){break g}d=fb-16|0;fb=d;g=e+36|0;cc(d+8|0,g,62);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(f|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(h|0);if(!d){Rb(g,0,62)}if(!d){break g}f=0;d=k+D(j,104)|0;nd(d,0);h=e+24|0;Ue(h,2,g);g=e+4|0;Cc(g,h);Ac(l+(j<<5)|0,g);tb(g);Lk(h,2,m);Cc(g,h);Be(d+43|0,g);tb(g);g=y[e+94|0]|y[e+95|0]<<8;x[d+24>>2]=g;if(!xn(x[a+480180>>2])){break f}while(1){if((f|0)==16){break f}if((g|0)==z[(f<<1)+24928>>1]){v[d+37|0]=f<<4;break f}else{f=f+1|0;continue}}}h:{if(!(c&2)){break h}if(!dd(b,y[e+231|0]|y[e+232|0]<<8|(y[e+233|0]<<16|y[e+234|0]<<24))){break h}f=1;while(1){d=f&65535;if(d>>>0>z[a+480190>>1]){break h}d=k+D(d,104)|0;dg(Zc(e+36|0,w[d+34>>1]&1?16:8,1,0,1),d,b);f=f+1|0;continue}}o=a+484344|0;Tf(o,y[e+226|0]+1|0);k=PD(tr(a));dd(b,y[e+222|0]|y[e+223|0]<<8|(y[e+224|0]<<16|y[e+225|0]<<24));s=c&1;h=0;l=1;i:{j:{k:{while(1){if(y[e+226|0]<h>>>0){if(!(z[a+480188>>1]==4&l)|x[a+480180>>2]!=1){break k}c=x[a+480208>>2]|8454144;break j}l:{d=gh(b);if(d>>>0>=3){c=e+4|0;he(c,b,d-2|0);i=hc(e+36|0,c);ub(c);m:{if(!s){break m}c=x[i>>2];x[31609]=0;c=R(172,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break l}if(!c){break m}x[31609]=0;c=U(196,o|0,h&65535,64)|0;d=x[31609];x[31609]=0;if((d|0)==1){break l}j=0;if(!c){break m}while(1){if((j|0)==64){break m}c=Wb(x[o>>2],h);af(e+4|0,x[c>>2],x[x[c+48>>2]+12>>2],j);n:{o:while(1){x[31609]=0;c=R(197,i|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=z[a+480188>>1]){break n}f=Yc(x[e+4>>2],d);if(c&32){x[31609]=0;d=e+24|0;O(198,d|0,i|0);g=x[31609];x[31609]=0;if((g|0)==1){break i}g=Jc(d);d=y[e+24|0];if(d){d=(d&127)-1|0;v[e+24|0]=d;d=(D((d&240)>>>4|0,12)+(d&15)|0)+13|0;v[f|0]=d;l=OD(d)&l}v[f+1|0]=y[g|0]}if(!(c&64)){continue}v[f+2|0]=0;v[f+3|0]=0;m=f+5|0;while(1){c=x[i>>2];x[31609]=0;c=U(150,c|0,x[e+44>>2],2)|0;d=x[31609];x[31609]=0;if((d|0)==1){break i}if(!c){continue o}q=y[f+5|0];c=y[f+3|0];x[31609]=0;d=e+24|0;O(198,d|0,i|0);g=x[31609];x[31609]=0;if((g|0)!=1){g=y[Jc(d)|0];v[f+5|0]=g;r=y[e+24|0];d=y[(r&31)+24960|0];v[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(g>>>0<224){break p}n=223;if(x[a+480180>>2]!=1){break s}break p;case 11:v[e+3|0]=64;d=y[Qb(m,e+3|0)|0];v[m|0]=d;if(!$v(x[k+88>>2],1)){break p}v[f+4|0]=d;v[f+2|0]=1;v[f+5|0]=q;v[f+3|0]=c;d=c;break r;case 17:u:{switch(((g&240)>>>4|0)-8|0){case 0:v[f+3|0]=2;v[f+5|0]=g&15|224;break p;case 1:v[f+3|0]=3;v[f+5|0]=g&15|224;break p;default:break u}}if(Ui(x[k+84>>2],19)){break p}Lr(f);d=y[f+3|0];break r;case 13:c=x[k+84>>2];if(Ui(c,15)){break p}if(!Ui(c,19)){break p}v[f+3|0]=19;v[f+5|0]=g&15|144;break p;case 18:n=145;if((g|0)==1){break s}if((g&240)==128){if(Ui(x[k+84>>2],20)){break q}v[f+3|0]=19;break p}v[f+3|0]=0;break p;case 4:case 5:break t;default:break r}}n=g&240;if(!n){break p}}v[m|0]=n}if((d&255)!=20){break p}}d=y[f+5|0];if(y[f+2|0]|(d&240)!=128){break p}v[f+2|0]=2;v[f+5|0]=q;v[f+3|0]=c;v[f+4|0]=((d<<6&960|8)>>>0)/15}if(!(r&32)){continue o}continue}break}break}break i}j=j+1|0;continue}}ub(i)}h=h+1|0;continue}break}break i}c=x[a+480208>>2]&-8454145}x[a+480208>>2]=c;d=1;if(!(y[e+240|0]|y[e+241|0]<<8|(y[e+242|0]<<16|y[e+243|0]<<24))){break a}if(!dd(b,y[e+236|0]|y[e+237|0]<<8|(y[e+238|0]<<16|y[e+239|0]<<24))){break a}cE(a+1298332|0,b,y[e+240|0]|y[e+241|0]<<8|(y[e+242|0]<<16|y[e+243|0]<<24),4);break a}f=N()|0;ub(i);break b}w[d+32>>1]=64;g=y[e+81|0]|y[e+82|0]<<8|(y[e+83|0]<<16|y[e+84|0]<<24);x[d>>2]=g;f=y[e+93|0];if(f&2){x[d>>2]=g>>>1;w[d+34>>1]=z[d+34>>1]|1}x[d+4>>2]=y[e+85|0]|y[e+86|0]<<8|(y[e+87|0]<<16|y[e+88|0]<<24);x[d+8>>2]=(y[e+89|0]|y[e+90|0]<<8|(y[e+91|0]<<16|y[e+92|0]<<24))-1;if(f&1){w[d+34>>1]=z[d+34>>1]|2}v:{w:{if(!(f&4)){break w}g=y[e+96|0];if((g|0)==255){break w}v[e+4|0]=g;v[e+24|0]=64;t=d,u=y[Qb(e+4|0,e+24|0)|0]<<2,w[t+30>>1]=u;break v}w[d+34>>1]=z[d+34>>1]|32768}x:{if(f&8){h=z[d+34>>1]|32;w[d+34>>1]=h;f=y[e+97|0];if(f>>>0<=15){x[e+24>>2]=256;x[e+4>>2]=(f<<4|8)&248;g=x[Cd(e+4|0,e+24|0)>>2]}else{g=128}w[d+28>>1]=g;w[d+34>>1]=h&65279|((f|0)==16)<<8;break x}w[d+28>>1]=128}i=i+1|0;f=z[a+480190>>1];continue}}f=N()|0;tb(e+36|0);break b}f=N()|0;Eb(e+4|0)}Q(f|0);p()}fb=e+256|0;return d|0}function n7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(fi(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+72>>2]=1274;b=l+72|0;t=De(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);q=Fb(l+60|0);n=Fb(l+48|0);o=Fb(l+36|0);s=Fb(l+24|0);b=x[d>>2];x[31609]=0;ka(1284,c|0,b|0,l+92|0,l+88|0,l+84|0,u|0,q|0,n|0,o|0,l+20|0);b=x[31609];x[31609]=0;if((b|0)!=1){x[j>>2]=x[i>>2];z=e&512;w=x[l+20>>2];e=0;while(1){c:{d:{e:{f:{g:{if((e|0)==4){break g}x[31609]=0;b=P(1257,a|0,l+524|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(b){break g}h:{i:{j:{k:{l:{switch(y[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31609]=0;b=R(1258,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=U(1285,h|0,1,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(b){x[31609]=0;O(1286,l+12|0,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){x[31609]=0;O(35,s|0,x[l+12>>2]);b=x[31609];x[31609]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((e|0)==3){break c}}while(1){x[31609]=0;b=P(1257,a|0,l+524|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[31609]=0;b=R(1258,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=U(1285,h|0,1,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(!b){break c}x[31609]=0;O(1286,l+12|0,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){x[31609]=0;O(35,s|0,x[l+12>>2]);b=x[31609];x[31609]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Cb(x[n+4>>2],y[n+11|0])){break m}b=x[a>>2];x[31609]=0;b=R(1258,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(x[Wd(n,0)>>2]!=(b|0)){break m}x[31609]=0;R(1260,a|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}v[g|0]=0;r=Cb(x[n+4>>2],y[n+11|0])>>>0>1?n:r;break c}n:{o:{k=x[o+4>>2];b=y[o+11|0];if(Cb(k,b)){b=x[a>>2];x[31609]=0;b=R(1258,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(x[Wd(o,0)>>2]==(b|0)){break o}k=x[o+4>>2];b=y[o+11|0]}c=Cb(x[n+4>>2],y[n+11|0]);if(!c){break n}if(!Cb(k,b)){break n}x[f>>2]=x[f>>2]|4;a=0;break d}x[31609]=0;R(1260,a|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}v[g|0]=1;r=Cb(x[o+4>>2],y[o+11|0])>>>0>1?o:r;break c}b=Cb(k,b);if(!(b|c)){break c}v[g|0]=!b;break c}if(!((e|0)==2&y[l+95|0]!=0|(e>>>0<2|r|z))){r=0;break c}b=vb(l+12|0,zd(q));p:{if(!e|y[(e+l|0)+91|0]>1){break p}q:{while(1){c=nl(q);d=x[b>>2];if(!Ib(d,c)){break q}c=x[d>>2];x[31609]=0;c=U(1285,h|0,1,c|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){if(!c){break q}Xe(b);continue}break}break a}c=zd(q);c=Lv(x[b>>2],c);if(Cb(x[s+4>>2],y[s+11|0])>>>0>=c>>>0){c=Ek(nl(s),0-c|0);d=nl(s);if(!jd(c,zd(q),d-c&-4)){break p}}C=b,D=x[vb(l+8|0,zd(q))>>2],x[C>>2]=D}x[l+8>>2]=x[b>>2];r:{while(1){b=nl(q);if(!Ib(x[l+8>>2],b)){break r}x[31609]=0;b=P(1257,a|0,l+524|0)|0;c=x[31609];x[31609]=0;s:{if((c|0)==1){break s}if(b){break r}b=x[a>>2];x[31609]=0;b=R(1258,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break s}if(x[x[l+8>>2]>>2]!=(b|0)){break r}x[31609]=0;R(1260,a|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}Xe(l+8|0);continue}break}break a}if(!z){break c}b=nl(q);if(!Ib(x[l+8>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;A=x[l+84>>2];c=m;t:{while(1){u:{x[31609]=0;d=P(1257,a|0,l+524|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break u}if(d){break t}d=x[a>>2];x[31609]=0;k=R(1258,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}x[31609]=0;d=U(1285,h|0,64,k|0)|0;B=x[31609];x[31609]=0;if((B|0)==1){break a}v:{if(d){d=x[j>>2];if((d|0)==x[l+520>>2]){x[31609]=0;S(1287,i|0,j|0,l+520|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+4;x[d>>2]=k;b=b+1|0;break v}if(!Cb(x[u+4>>2],y[u+11|0])|!b|(k|0)!=(A|0)){break t}if(x[l+96>>2]==(m|0)){x[31609]=0;S(1280,t|0,l+100|0,l+96|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c;b=0}x[31609]=0;R(1260,a|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){continue}}break}break a}if(!b|x[t>>2]==(c|0)){break f}if(x[l+96>>2]==(c|0)){x[31609]=0;S(1280,t|0,l+100|0,l+96|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}c=x[l+100>>2]}m=c+4|0;x[l+100>>2]=m;x[c>>2]=b;break e}x[l+20>>2]=w;w:{if(!r){break w}k=1;while(1){if(Cb(x[r+4>>2],y[r+11|0])>>>0<=k>>>0){break w}x[31609]=0;b=P(1257,a|0,l+524|0)|0;c=x[31609];x[31609]=0;x:{if((c|0)==1){break x}y:{if(!b){b=x[a>>2];x[31609]=0;b=R(1258,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break x}if(x[Wd(r,k)>>2]==(b|0)){break y}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31609]=0;R(1260,a|0)|0;b=x[31609];x[31609]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+12>>2]=0;Vf(u,b,m,l+12|0);if(x[l+12>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=c}z:{if((w|0)<=0){break z}x[31609]=0;b=P(1257,a|0,l+524|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}A:{if(!b){b=x[a>>2];x[31609]=0;b=R(1258,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(x[l+88>>2]==(b|0)){break A}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31609]=0;b=R(1260,a|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break z}x[31609]=0;c=P(1257,b|0,l+524|0)|0;d=x[31609];x[31609]=0;B:{if((d|0)==1){break B}C:{if(!c){c=x[b>>2];x[31609]=0;c=R(1258,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break B}x[31609]=0;c=U(1285,h|0,64,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break B}if(c){break C}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31609]=0;S(1287,i|0,j|0,l+520|0);c=x[31609];x[31609]=0;if((c|0)==1){break B}}c=x[b>>2];x[31609]=0;c=R(1258,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break B}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=c;x[31609]=0;R(1260,b|0)|0;c=x[31609];x[31609]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}Ub(s);Ub(o);Ub(n);Ub(q);tb(u);Lc(t);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;Ub(s);Ub(o);Ub(n);Ub(q);tb(u);Lc(t);Q(a|0);p()}function fT(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,C=E(0),F=E(0),G=0,H=0,I=E(0),J=0;k=fb-48|0;fb=k;Jk(b+223848|0,Pj(e,Fi(e,So(e),0))+1|0);se(k+40|0,x[b+223848>>2],x[b+223852>>2]);Zb(k+32|0,e,Pj(e,Fi(e,So(e),0)));u=x[k+32>>2];q=x[k+36>>2];h=fb-16|0;fb=h;s=a+906300|0;m=a+1074312|0;e=D(c,872)+b|0;C=E(y[e+1466|0]);F=E(f>>>0);i=e+616|0;o=x[e+1272>>2];p=1;l=255;while(1){if((n|0)!=(q|0)&A[k+44>>2]>j>>>0){g=y[xb(u,n)|0];e=g-48|0;a:{b:{if((e&255)>>>0<=9){break b}if((g-65&255)>>>0<=5){e=g-55|0;break b}c:{d:{e:{switch(g-97|0){case 2:f:{e=om(a,b,c,3,0)-1|0;if((e&255)>>>0>249){break f}e=x[$d(s,e)>>2];if(!e){break f}e=hB(e,45896,42952);if(!e){break f}e=ib[x[x[e>>2]+192>>2]](e,i,c)|0;g=(e|0)!=255;e=g?e:0;if(g|!o){break b}break c}if(o){break c}e=0;break b;case 21:g:{if(!Ob(m,28)){e=0;if(!Ob(m,1)){break g}}e=w[i+776>>1]}g=D(x[i+752>>2],x[i+748>>2]);e=D(x[a+1074456>>2],e+x[i+688>>2]|0);e=Yb((Gc(Bua(Aua(g,g>>31,e,e>>31),hb,1048576,0),hb)|0)/2|0,1,127);break d;case 20:e=D(x[i+752>>2],x[i+748>>2]);g=e;t=e>>31;e=D(x[a+1074456>>2],x[i+720>>2]);e=Yb((Gc(Bua(Aua(g,t,e,e>>31),hb,67108864,0),hb)|0)/2|0,1,127);break d;case 23:x[h>>2]=x[i+692>>2]/2;x[h+12>>2]=127;e=x[Cd(h,h+12|0)>>2];break d;case 24:x[h>>2]=x[i+684>>2]/2;x[h+12>>2]=127;e=x[Cd(h,h+12|0)>>2];break d;case 0:e=0;if(!o){break d}g=z[o+28>>1];if(!g){break d}e=g-1>>>7&127;break d;case 1:e=0;if(!o){break d}g=z[o+28>>1];if(!g){break d}e=g-1&127;break d;case 14:e=x[i+664>>2]>>>8|0;break d;case 7:e=(z[a+480188>>1]<=c>>>0?y[i+786|0]-1|0:c)&127;break d;case 12:e=y[i+88|0]>>>7|0;break d;case 15:e=0;if(!o){break d}g=y[o+30|0];if(!g){break d}e=g-1&127;break d;case 25:h:{if(!d|v[i+850|0]<0){break h}i:{if(j>>>0<3){break i}e=x[k+40>>2];if(y[xb(e,j-3|0)|0]!=240){break i}if(y[xb(e,j-2|0)|0]>239){break h}}r=Fq(b,C,F);j:{if(r<E(4294967296)&r>=E(0)){e=~~r>>>0;break j}e=0}v[i+850|0]=e;l=128;break d}l=(l&255)==255?f:l;e=f;break d;case 18:k:{if(!j){e=0;break k}g=x[k+40>>2];e=j;while(1){e=e-1|0;t=xb(g,e);if(!e){break k}if(y[t|0]!=240){continue}break}}if(j-e>>>0<5){break a}t=x[k+40>>2];if(y[xb(t,e)|0]!=240){break a}e=e+5|0;g=0;while(1){if((e|0)!=(j|0)){g=y[xb(t,e)|0]+g|0;e=e+1|0;continue}break};e=0-g&127;break d;case 13:break e;default:break a}}e=y[i+799|0];e=Tc(e)?e-1|0:0}g=p^-1;p=1;j=(g&1)+j|0;G=xb(x[k+40>>2],j),H=e,v[G|0]=H;j=j+1|0;break a}e=z[i+786>>1];g=y[o+31|0];e=(e?e-1|0:c)&15;l:{if((g|0)==17){break l}e=Jj(g)?g-1&15:0}}g=xb(x[k+40>>2],j);v[g|0]=(p&1?0:y[g|0]<<4)|e;p=p^1;j=(p&1)+j|0}n=n+1|0;continue}else{if(l<<24>>24>=0){v[i+850|0]=l}cc(h,x[k+40>>2],((p^-1)&1)+j|0);e=x[h+4>>2];x[k+40>>2]=x[h>>2];x[k+44>>2]=e;fb=h+16|0}break}o=x[k+44>>2];j=0;m:while(1){p=0;while(1){l=p&255;e=j;n:{o:{p:{q:{while(1){if(A[k+44>>2]<=e>>>0){break n}f=x[k+40>>2];i=xb(f,e);h=y[i|0];if((h|0)==240){if(o-e>>>0>=4){j=4;if((y[xb(f,e+1|0)|0]&254)==240){break o}}j=e;r:{while(1){j=j+1|0;if(o>>>0<=j>>>0){break r}if(y[xb(f,j)|0]!=247){continue}break}j=(j-e|0)+1|0;if(j){break o}}G=xb(f,o),H=247,v[G|0]=H;o=o+1|0;j=o-e|0;break p}if(h<<24>>24<0){break q}if(l){e=e-1|0;G=xb(f,e),H=p,v[G|0]=H;continue}break}j=j+1|0;continue m}G=k,H=oV(h),x[G+20>>2]=H;x[k+28>>2]=o-e;j=x[Hb(k+20|0,k+28|0)>>2]}if(!j){break n}f=x[k+40>>2];i=xb(f,e)}u=y[i|0];wr(k+20|0,f,x[k+44>>2],e,j);f=Zb(k+12|0,x[k+20>>2],x[k+24>>2]);i=x[f+4>>2];x[k>>2]=x[f>>2];x[k+4>>2]=i;i=fb-32|0;fb=i;m=x[k+4>>2];s:{if(!m){break s}l=Id(y[b+223884|0]);t:{g=x[k>>2];q=xb(g,0);f=y[q|0]-250|0;if(f>>>0>5|!(1<<f&37)){break t}h=b+616|0;n=z[a+480188>>1];f=0;while(1){if((f|0)==(n|0)){break t}s=h+D(f,872)|0;v[s+837|0]=127;v[s+838|0]=0;f=f+1|0;continue}}f=(D(c,872)+b|0)+616|0;u:{if((m|0)!=4|y[q|0]!=240){break u}n=y[xb(g,1)|0];if((n&254)!=240){break u}m=xb(g,2);q=y[xb(g,3)|0];h=q<<24>>24;s=(n|0)!=241&(h|0)>=0;g=y[m|0];if(!(!s|g)){if(d){h=Bh(Fq(b,E(y[f+837|0]),E((h&255)>>>0)))}v[f+796|0]=0;v[f+837|0]=h;h=Kq(a,f,!(x[f+88>>2]&32768),256);if((h|0)<0|!(y[f+89|0]&2)){break s}f=x[a+1298300>>2];if(l|Ed(f)^1){break s}Pq(f,c,h>>>2&255,1);break s}m=g<<24>>24;if(s&(m|0)==1){if(d){h=Bh(Fq(b,E(y[f+838|0]),E((h&255)>>>0)))}v[f+795|0]=0;v[f+838|0]=h;Kq(a,f,!(x[f+88>>2]&32768),256);break s}if(!((n|0)==241|(m|0)!=2)){if(h>>>0>31){break s}v[f+845|0]=(h&240)>>>4;Kq(a,f,!(x[f+88>>2]&32768),256);break s}if(!((n|0)==241|(m|0)!=3)){f=om(a,b,c,3,0)-1|0;if((h|0)<0|(f&255)>>>0>249){break s}v[i+24|0]=f;h=$d(a+906300|0,f&255);f=x[h>>2];if(!f){break s}r=E(E(127-q|0)/E(127));if(l){l=0;h=fb-16|0;fb=h;G=h,H=Qj(i+24|0),x[G+4>>2]=H;f=fb-16|0;fb=f;n=b+223860|0;m=gB(n,f+12|0,y[i+24|0]);g=x[m>>2];if(!g){l=fb-16|0;fb=l;g=gc(n);q=Dh(f,Ec(24),Og(l+8|0,g));g=x[q>>2];s=y[x[h+4>>2]];x[g+20>>2]=0;v[g+16|0]=s;G=gc(q),H=1,v[G+4|0]=H;fb=l+16|0;$g(n,x[f+12>>2],m,x[f>>2]);g=ne(f);Ik(f);l=1}_g(h+8|0,x[vb(f,g)>>2],l);fb=f+16|0;f=ud(x[h+8>>2]);fb=h+16|0;B[f+4>>2]=r;break s}if(!d){Iu(x[f+20>>2],r);break s}Iu(x[f+20>>2],Fq(b,B[h+144>>2],r));break s}f=(m|0)>=0;m=(n|0)!=241;if(f&m){break s}n=om(a,b,c,3,0)-1|0;if((h|0)<0|(n&255)>>>0>249){break s}f=x[$d(a+906300|0,n&255)>>2];if(!f){break s}g=m?g&127:g+128|0;r=E(E((h&255)>>>0)/E(127));if(l){G=vT(b+223872|0,NS(i+24|0,n,g)),I=r,B[G>>2]=I;break s}h=x[f>>2];if(!d){ib[x[h+44>>2]](f,g,r);break s}H=f,J=g,I=Fq(b,E(ib[x[h+48>>2]](f,g)),r),G=x[x[f>>2]+44>>2],ib[G](H|0,J|0,E(I));break s}if(l){break s}l=z[a+480188>>1];v:{if(l>>>0>c>>>0){h=c+1|0;break v}h=z[f+786>>1];if(!h){break s}}if(y[f+91|0]&2|l>>>0<(h&65535)>>>0){break s}f=om(a,b,c,3,0)-1|0;if(f>>>0>249){break s}f=x[$d(a+906300|0,f)>>2];if(!f){break s}h=y[q|0];if((h|0)==240){lf(i+16|0,x[k>>2],x[k+4>>2]);h=x[x[f>>2]+72>>2];l=x[i+20>>2];x[i>>2]=x[i+16>>2];x[i+4>>2]=l;ib[h|0](f,i)|0;break s}G=i,J=oV(h),x[G+24>>2]=J;x[i+12>>2]=m;h=i+24|0;l=x[Hb(h,i+12|0)>>2];x[i+24>>2]=0;zc(h,g,l);ib[x[x[f>>2]+68>>2]](f,x[i+24>>2])|0}fb=i+32|0;p=u>>>0<240?u:p;j=e+j|0;continue}break}break}fb=k+48|0}function Toa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=fb-272|0;fb=e;yc(b);d=fb-16|0;fb=d;g=e+126|0;XW(d+8|0,g);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(f|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(h|0);if(!d){WW(g)}a:{b:{c:{d:{if(!d){break d}if(!YW(g)){break d}k=1;if((c|0)==64){break d}Dd(a,4194304);d=e+40|0;g=uc(d,17073);zb(a+1298344|0,g);tb(g);g=uc(d,10153);zb(a+1298356|0,g);tb(g);q=a,r=x[Fc(d,4)>>2],x[q+1298404>>2]=r;q=a,r=Ld(y[e+204|0]|y[e+205|0]<<8,y[e+206|0]|y[e+207|0]<<8,127),w[q+480188>>1]=r;g=y[e+195|0];x[a+480228>>2]=(g|0)==255?48:g;x[a+480196>>2]=y[e+193|0];x[a+480204>>2]=D(y[e+194|0],1e4);g=e+104|0;bf(g,e+130|0,59,3);Cc(d,g);zb(a+1298308|0,d);tb(d);d=y[e+208|0]|y[e+209|0]<<8|(y[e+210|0]<<16|y[e+211|0]<<24);e:{if(d>>>0<5){break e}if(!dd(b,d-4|0)){break e}if(!ak(b,14294)){break e}$j(Xb(x[a+484360>>2],y[a+484376|0]),b,y[e+198|0]|y[e+199|0]<<8,65535,65535)}f:{d=y[e+212|0]|y[e+213|0]<<8|(y[e+214|0]<<16|y[e+215|0]<<24);if(d>>>0<5){break f}if(!dd(b,d-4|0)){break f}if(!ak(b,13904)){break f}g=a+480280|0;d=0;while(1){if((d|0)==32){break f}f=g+(d<<5)|0;Ve(f);q=f,r=((((Zd(b)^-1)&15)<<8|8)>>>0)/15|0,w[q+4>>1]=r;d=d+1|0;continue}}d=y[e+220|0]|y[e+221|0]<<8|(y[e+222|0]<<16|y[e+223|0]<<24);g:{if(d>>>0<5){break g}if(!dd(b,d-4|0)){break g}if(!ak(b,14189)){break g}d=e+40|0;he(d,b,(y[e+202|0]|y[e+203|0]<<8)<<6);m=c&2;l=a+946304|0;k=a+480190|0;j=a+484380|0;g=hc(e+104|0,d);ub(d);n=e+53|0;d=0;h:{while(1){if((d&65535)>>>0>=(y[e+202|0]|y[e+203|0]<<8)>>>0){break h}x[31609]=0;h=e+40|0;f=P(689,g|0,h|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}if(!f){break h}f=y[e+85|0]|y[e+86|0]<<8;w[e+38>>1]=f;i:{j:{if((f-1&65535)>>>0>3998){break j}f=j+D(f,104)|0;if(le(x[f>>2],x[f+20>>2])){break j}q=k,r=z[qe(k,e+38|0)>>1],w[q>>1]=r;x[31609]=0;O(690,h|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break i}h=e+12|0;c_(h,1,n);x[31609]=0;f=e+24|0;O(218,f|0,h|0);h=x[31609];x[31609]=0;if((h|0)==1){break b}Ac((z[e+38>>1]<<5)+l|0,f);tb(f);if(!m){break j}x[31609]=0;P(149,b|0,y[e+77|0]|y[e+78|0]<<8|(y[e+79|0]<<16|y[e+80|0]<<24))|0;h=x[31609];x[31609]=0;if((h|0)==1){break i}i=1;h=y[e+87|0];o=Zc(f,h&4?16:8,1,0,0);k:{l:{if(h&8){break l}i=2;if(h&16){break l}if(h&103){break k}}wg(o,i)}x[31609]=0;U(215,f|0,j+D(z[e+38>>1],104)|0,b|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){break j}break b}d=d+1|0;continue}break}break b}ub(g)}k=1;if(!(c&1)){break d}m:{c=y[e+216|0]|y[e+217|0]<<8|(y[e+218|0]<<16|y[e+219|0]<<24);if(c>>>0<5){break m}if(!dd(b,c-4|0)){break m}if(!ak(b,13775)){break m}j=a+484344|0;Tf(j,y[e+200|0]|y[e+201|0]<<8);f=0;while(1){if((y[e+200|0]|y[e+201|0]<<8)>>>0<=f>>>0){break m}if(!Pr(b,e+24|0)){break m}n:{d=z[e+24>>1];if(d>>>0>3){c=e+104|0;he(c,b,(d+15&131056)-4|0);g=hc(e+40|0,c);ub(c);x[31609]=0;c=U(196,j|0,f&65535,y[e+26|0])|0;d=x[31609];x[31609]=0;if((d|0)==1){break n}h=0;o:{if(!c){break o}p:while(1){m=h&255;while(1){q:{c=x[g>>2];x[31609]=0;d=U(150,c|0,x[e+48>>2],1)|0;c=x[31609];x[31609]=0;r:{if((c|0)!=1){c=y[e+26|0];if(!(d&c>>>0>m>>>0)){break q}x[31609]=0;c=R(197,g|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}d=c<<24>>24;if(d){break r}h=h+1|0;continue p}break c}c=x[a+484344>>2];w[e+104>>1]=d&31;w[e+12>>1]=z[a+480188>>1]-1;c=Wb(c,f);i=e+104|0;c=md(x[c>>2],x[x[c+48>>2]+12>>2],h,z[Oc(i,e+12|0)>>1]);if((d|0)<0){x[31609]=0;O(198,i|0,g|0);l=x[31609];x[31609]=0;if((l|0)==1){break c}v[c|0]=y[e+104|0]+36;q=c,r=y[Jc(i)|0],v[q+1|0]=r}d=d&255;if(d&64){v[c+2|0]=1;x[31609]=0;i=R(197,g|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break c}v[e+104|0]=i;v[e+12|0]=64;q=c,r=y[Qb(e+104|0,e+12|0)|0],v[q+4|0]=r}if(!(d&32)){continue}x[31609]=0;d=e+104|0;O(198,d|0,g|0);i=x[31609];x[31609]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((i|0)!=1){d=y[Jc(d)|0];v[c+5|0]=d;X:{switch(y[e+104|0]-1|0){case 71:break t;case 70:break u;case 69:break v;case 60:break w;case 59:break x;case 52:break y;case 51:break z;case 50:break A;case 49:break B;case 42:break C;case 41:break D;case 40:break E;case 39:break F;case 30:break G;case 29:break H;case 22:break I;case 21:break J;case 20:break K;case 19:break L;case 16:break M;case 15:break N;case 14:break O;case 13:break P;case 12:break Q;case 11:break R;case 10:break S;case 9:break T;case 3:break U;case 2:break V;case 1:break W;case 0:break X;default:break s}}v[c+3|0]=11;v[c+5|0]=d<<4|15;continue}break c}v[c+3|0]=11;v[c+5|0]=d<<4;continue}v[c+3|0]=11;v[c+5|0]=d|240;continue}v[c+3|0]=11;v[c+5|0]=d&15;continue}v[c+3|0]=2;v[c+5|0]=d|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=d|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=d|16;continue}v[c+3|0]=6;v[c+5|0]=d<<4;continue}v[c+3|0]=6;v[c+5|0]=d&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=d|48;continue}v[c+3|0]=7;v[c+5|0]=d<<4;continue}v[c+3|0]=7;v[c+5|0]=d&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=d|64;continue}v[c+3|0]=10;x[31609]=0;d=R(197,g|0)|0;i=x[31609];x[31609]=0;if((i|0)!=1){v[c+5|0]=d;x[31609]=0;P(183,g|0,1)|0;c=x[31609];x[31609]=0;if((c|0)!=1){continue}}break c}v[c+3|0]=15;v[c+5|0]=d&15;continue}v[c+3|0]=20;v[c+5|0]=d|192;continue}v[c+3|0]=20;v[c+5|0]=d|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=d|176;continue}v[c+3|0]=20;v[c+5|0]=d|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=d&15|32;continue}v[c+3|0]=20;v[c+5|0]=d&15|128;continue}v[c+3|0]=0;continue}break}break}if((c|0)==64){break o}Ae(Wb(x[j>>2],f),Vh(We(Oe(e+104|0,14,0),c-1|0)))}ub(g)}f=f+1|0;continue}break}break c}c=y[e+224|0]|y[e+225|0]<<8|(y[e+226|0]<<16|y[e+227|0]<<24);if(!c){break d}dd(b,c);cE(a+1298332|0,b,gh(b),4)}fb=e+272|0;return k|0}a=N()|0;break a}a=N()|0}ub(g);Q(a|0);p()}function dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=fb-48|0;fb=j;d=x[b>>2];x[31609]=0;e=R(172,d|0)|0;d=x[31609];x[31609]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(e){d=0;g=Nb(j+36|0);g:{h:{i:{if(c&16){break i}x[31609]=0;f=(c|0)!=64;h=U(862,g|0,b|0,f|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break e}e=2;j:{if(h){break j}x[31609]=0;h=U(863,g|0,b|0,f|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break e}e=3;if(h){break j}x[31609]=0;h=U(864,g|0,b|0,f|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break e}e=4;if(h){break j}h=0;x[31609]=0;i=U(865,g|0,b|0,f|0)|0;f=x[31609];x[31609]=0;e=1;if((f|0)==1){break e}if(!i){break i}}if((c|0)==64){e=1;break h}h=x[g>>2];if(!mc(h,x[g+4>>2])){ax(b,h+12|0)}h=e}if(c&32){e=0;break h}k:{while(1){e=d;if((d|0)!=576){f=x[d+29896>>2];i=(f>>1)+a|0;d=x[d+29892>>2];d=f&1?x[x[i>>2]+d>>2]:d;x[31609]=0;f=U(d|0,i|0,b|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}d=e+12|0;if(!f){continue}break k}break}x[a+480180>>2]=0;x[a+480184>>2]=0}if((c|0)==64){e=(e|0)!=576;d=0;break h}if(!(x[a+480184>>2]|!h)){x[a+480184>>2]=h}x[31609]=0;d=1;O(801,a+1298264|0,1);h=x[31609];x[31609]=0;e=1;if((h|0)==1){break g}}_R(g);if(d){break f}break a}break c}x[31609]=0;O(246,a|0,0);d=x[31609];x[31609]=0;if((d|0)==1){break d}x[31609]=0;O(801,a+1298264|0,1);d=x[31609];x[31609]=0;if((d|0)==1){break d}x[a+1298408>>2]=0;x[a+1074304>>2]=20054022}h=a+1074992|0;d=a+480280|0;e=0;while(1){if((e|0)==127){h=a+484380|0;d=1;while(1){e=d&65535;if(e>>>0>z[a+480190>>1]){f=a+900380|0;d=0;e=0;l:{while(1){h=e&65535;if(h>>>0>z[a+480192>>1]){m:{w[a+480192>>1]=d;d=a+480204|0;if(A[a+480204>>2]>=1e4){break m}x[d>>2]=125e4;break l}}else{g=x[f+(h<<2)>>2];if(g){h=x[a+480180>>2];xc(g,65536);xc(g+4|0,64);xc(g+8|0,256);Hf(g+28|0,16384);Of(g+30|0,128);Of(g+31|0,17);if(y[g+16|0]>=4){v[g+16|0]=0}if(y[g+17|0]>=5){v[g+17|0]=0}if(y[g+18|0]>=3){v[g+18|0]=0}Of(g+19|0,64);Of(g+20|0,100);i=224;d=v[g+26|0];n:{if((d|0)>=-32){i=32;if((d|0)<33){break n}}v[g+26|0]=i}Of(g+23|0,64);Of(g+24|0,64);gC(g+48|0,64);gC(g+68|0,64);gC(g+88|0,(h|0)==4096?255:64);h=g+108|0;i=0;while(1){o:{if((i|0)==128){if(!up(y[g+14|0])){v[g+14|0]=5}if(y[g+34|0]>=251){v[g+34|0]=0}break o}d=xb(h,i);if((y[d|0]-121&255)>>>0<=135){v[d|0]=i+1}i=i+1|0;continue}break}d=e}e=e+1|0;continue}break}xc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}h=a+480216|0;e=a+480220|0;d=x[a+480216>>2];if(!(d|y[a+480224|0]!=2)){x[h>>2]=1;d=1}if(A[a+480220>>2]<d>>>0){x[e>>2]=d}xc(h,65536);xc(e,65536);xc(a+480200|0,256);p:{if(!mc(x[a+480248>>2],x[a+480252>>2])){d=x[h>>2];x[31609]=0;O(866,a+480248|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break p}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];d=x[a+480220>>2];x[a+1074408>>2]=x[a+480216>>2];x[a+1074412>>2]=d;x[a+1074456>>2]=x[a+480200>>2];sB(a+1074376|0);w[a+1074446>>1]=0;w[a+1074448>>1]=0;w[a+1074450>>1]=0;w[a+1074452>>1]=65535;x[a+1074392>>2]=-2;x[a+1074384>>2]=0;x[a+1074388>>2]=0;x[a+1074380>>2]=0;x[a+1074424>>2]=0;x[a+1074428>>2]=0;x[a+1074432>>2]=0;x[a+1074396>>2]=0;x[a+1074400>>2]=0;if(xn(x[a+480180>>2])){x[31609]=0;P(267,a+1074312|0,7)|0;d=x[31609];x[31609]=0;if((d|0)==1){break p}}w[a+480276>>1]=0;Cq(a);l=j,m=wb(x[a+484360>>2]),x[l+36>>2]=m;e=wb(x[a+484364>>2]);q:{while(1){r:{h=x[j+36>>2];if(!Ib(h,e)){if(x[a+480180>>2]){break r}e=0;break a}x[31609]=0;W(867,h|0);d=x[31609];x[31609]=0;if((d|0)==1){break q}if($c(x[h>>2],x[h+4>>2])>>>0<=z[h+28>>1]){$e(h,0)}Zq(j+36|0);continue}break}Bu(a+8|0,tr(a));if(x[a+1074308>>2]){x[31609]=0;W(868,a|0);d=x[31609];x[31609]=0;if((d|0)==1){break p}}g=Nb(j+36|0);s:{t:{if((c&12)!=12){break t}h=a+906300|0;e=0;u:{v:{w:{x:{y:{z:{while(1){if((e|0)==250){break t}A:{k=$d(h,e);B:{if(!Mi(x[k+16>>2],x[k+20>>2])){break B}x[31609]=0;O(869,k|0,a|0);c=x[31609];x[31609]=0;C:{if((c|0)!=1){f=x[k>>2];if(!f){break C}d=x[k+148>>2];c=x[x[f>>2]+56>>2];x[31609]=0;O(c|0,f|0,d|0);c=x[31609];x[31609]=0;if((c|0)!=1){break B}}a=N()|0;break s}i=wb(x[g>>2]);c=wb(x[g+4>>2]);f=fb-16|0;fb=f;x[f+12>>2]=i;while(1){D:{if(!Ib(i,c)){break D}d=x[i>>2];if((y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))==(y[k+20|0]|y[k+21|0]<<8|(y[k+22|0]<<16|y[k+23|0]<<24))){d=(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))==(y[k+16|0]|y[k+17|0]<<8|(y[k+18|0]<<16|y[k+19|0]<<24))}else{d=0}if(d){break D}i=x[Xe(f+12|0)>>2];continue}break}fb=f+16|0;if(Ib(i,wb(x[g+4>>2]))){break B}x[31609]=0;x[j+24>>2]=k+16;f=j+24|0;O(870,g|0,f|0);c=x[31609];x[31609]=0;if((c|0)==1){break A}x[31609]=0;d=P(1,j+12|0,18339)|0;c=x[31609];x[31609]=0;if((c|0)==1){break z}x[31609]=0;O(871,j|0,k|0);c=x[31609];x[31609]=0;if((c|0)==1){break y}x[31609]=0;S(2,f|0,d|0,j|0);c=x[31609];x[31609]=0;if((c|0)==1){break x}c=x[a+1298472>>2];x[31609]=0;S(385,c|0,2,f|0);c=x[31609];x[31609]=0;if((c|0)==1){break w}tb(f);tb(j);tb(d)}e=e+1|0;continue}break}a=N()|0;break s}a=N()|0;break s}a=N()|0;break u}a=N()|0;break v}a=N()|0;tb(j+24|0)}tb(j)}tb(d);break s}c=y[a+1074368|0];x[31609]=0;O(872,a|0,c|0);a=x[31609];x[31609]=0;e=1;if((a|0)!=1){wc(g);break a}a=N()|0}wc(g);break b}a=N()|0;break b}a=N()|0;break b}f=h+D(e,104)|0;E:{if(le(x[f>>2],x[f+20>>2])){Ij(f,a);break E}e=z[f+34>>1];if(e&16384){break E}x[f>>2]=0;x[f+4>>2]=0;x[f+16>>2]=0;x[f+8>>2]=0;x[f+12>>2]=0;w[f+34>>1]=e&49121}if(z[f+32>>1]>=65){w[f+32>>1]=64}F:{G:{if(!(y[f+35|0]&2)){break G}if(!Fj(x[a+1298300>>2])){break G}x[31609]=0;W(873,a|0);e=x[31609];x[31609]=0;if((e|0)==1){break F}}d=d+1|0;continue}break}a=N()|0;break b}f=d+(e<<5)|0;Hf(f+6|0,64);if(z[f+4>>1]>=257){w[f+4>>1]=128}if(y[f+8|0]>=251){v[f+8|0]=0}Qo(h+D(e,872)|0,a,e&65535,67108864);e=e+1|0;continue}}break c}a=N()|0;break b}a=N()|0;_R(g)}ub(b);Q(a|0);p()}ub(b);fb=j+48|0;return e|0}function u7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(th(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+76>>2]=1274;b=l+76|0;t=De(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);q=Fb(l- -64|0);n=Fb(l+52|0);o=Fb(l+40|0);s=Fb(l+28|0);b=x[d>>2];x[31609]=0;ka(1277,c|0,b|0,l+92|0,l+91|0,l+90|0,u|0,q|0,n|0,o|0,l+24|0);b=x[31609];x[31609]=0;if((b|0)!=1){x[j>>2]=x[i>>2];z=e&512;w=x[l+24>>2];A=y[l+95|0];B=y[l+91|0];C=y[l+90|0];d=m;e=0;while(1){c:{d:{e:{f:{if((e|0)==4){break f}x[31609]=0;b=P(1241,a|0,l+524|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(y[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31609]=0;b=R(1242,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(Jf(x[h+8>>2],1,b)){x[31609]=0;O(1278,l+16|0,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){x[31609]=0;O(115,s|0,v[l+16|0]);b=x[31609];x[31609]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break c}}while(1){x[31609]=0;b=P(1241,a|0,l+524|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[31609]=0;b=R(1242,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(!Jf(x[h+8>>2],1,b)){break c}x[31609]=0;O(1278,l+16|0,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){x[31609]=0;O(115,s|0,v[l+16|0]);b=x[31609];x[31609]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Cb(x[n+4>>2],y[n+11|0])){break l}b=x[a>>2];x[31609]=0;b=R(1242,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(y[ec(n,0)|0]!=(b&255)){break l}x[31609]=0;R(1244,a|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}v[g|0]=0;r=Cb(x[n+4>>2],y[n+11|0])>>>0>1?n:r;break c}m:{n:{k=x[o+4>>2];b=y[o+11|0];if(Cb(k,b)){b=x[a>>2];x[31609]=0;b=R(1242,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if(y[ec(o,0)|0]==(b&255)){break n}k=x[o+4>>2];b=y[o+11|0]}c=Cb(x[n+4>>2],y[n+11|0]);if(!c){break m}if(!Cb(k,b)){break m}x[f>>2]=x[f>>2]|4;a=0;break d}x[31609]=0;R(1244,a|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}v[g|0]=1;r=Cb(x[o+4>>2],y[o+11|0])>>>0>1?o:r;break c}b=Cb(k,b);if(!(b|c)){break c}v[g|0]=!b;break c}if(!(e>>>0<2|r|((e|0)==2&(A|0)!=0|z))){r=0;break c}b=vb(l+16|0,zd(q));o:{if(!e|y[(e+l|0)+91|0]>1){break o}while(1){p:{c=Df(q);k=x[b>>2];if(!Ib(k,c)){break p}if(!Jf(x[h+8>>2],1,v[k|0])){break p}we(b);continue}break}c=zd(q);c=zk(x[b>>2],c);if(Cb(x[s+4>>2],y[s+11|0])>>>0>=c>>>0){if(p0(aD(Df(s),c),Df(s),zd(q))){break o}}D=b,E=x[vb(l+12|0,zd(q))>>2],x[D>>2]=E}x[l+12>>2]=x[b>>2];q:{while(1){b=Df(q);if(!Ib(x[l+12>>2],b)){break q}x[31609]=0;b=P(1241,a|0,l+524|0)|0;c=x[31609];x[31609]=0;r:{if((c|0)==1){break r}if(b){break q}b=x[a>>2];x[31609]=0;b=R(1242,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break r}if(y[x[l+12>>2]]!=(b&255)){break q}x[31609]=0;R(1244,a|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}we(l+12|0);continue}break}break a}if(!z){break c}b=Df(q);if(!Ib(x[l+12>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}s:{while(1){t:{x[31609]=0;c=P(1241,a|0,l+524|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break t}if(c){break s}c=x[a>>2];x[31609]=0;k=R(1242,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}u:{if(Jf(x[h+8>>2],64,k)){c=x[j>>2];if((c|0)==x[l+520>>2]){x[31609]=0;S(1279,i|0,j|0,l+520|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}c=x[j>>2]}x[j>>2]=c+1;v[c|0]=k;b=b+1|0;break u}if(!Cb(x[u+4>>2],y[u+11|0])|!b|(k&255)!=(C|0)){break s}if(x[l+96>>2]==(d|0)){x[31609]=0;S(1280,t|0,l+100|0,l+96|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}d=x[l+100>>2]}m=d+4|0;x[l+100>>2]=m;x[d>>2]=b;d=m;b=0}x[31609]=0;R(1244,a|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){continue}}break}break a}if(!(!b|x[t>>2]==(m|0))){if(x[l+96>>2]==(m|0)){x[31609]=0;S(1280,t|0,l+100|0,l+96|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c}if((w|0)<=0){break e}x[31609]=0;b=P(1241,a|0,l+524|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}v:{if(!b){b=x[a>>2];x[31609]=0;b=R(1242,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}if((b&255)==(B|0)){break v}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31609]=0;b=R(1244,a|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break e}x[31609]=0;c=P(1241,b|0,l+524|0)|0;d=x[31609];x[31609]=0;w:{if((d|0)==1){break w}x:{if(!c){c=x[b>>2];x[31609]=0;c=R(1242,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break w}if(Jf(x[h+8>>2],64,c)){break x}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31609]=0;S(1279,i|0,j|0,l+520|0);c=x[31609];x[31609]=0;if((c|0)==1){break w}}c=x[b>>2];x[31609]=0;c=R(1242,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break w}d=x[j>>2];x[j>>2]=d+1;v[d|0]=c;x[31609]=0;R(1244,b|0)|0;c=x[31609];x[31609]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}x[l+24>>2]=w;y:{if(!r){break y}k=1;while(1){if(Cb(x[r+4>>2],y[r+11|0])>>>0<=k>>>0){break y}x[31609]=0;b=P(1241,a|0,l+524|0)|0;c=x[31609];x[31609]=0;z:{if((c|0)==1){break z}A:{if(!b){b=x[a>>2];x[31609]=0;b=R(1242,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break z}if(y[ec(r,k)|0]==(b&255)){break A}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31609]=0;R(1244,a|0)|0;b=x[31609];x[31609]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+16>>2]=0;Vf(u,b,m,l+16|0);if(x[l+16>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}d=m;if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}tb(s);tb(o);tb(n);tb(q);tb(u);Lc(t);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;tb(s);tb(o);tb(n);tb(q);tb(u);Lc(t);Q(a|0);p()}function Su(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=fb-16|0;fb=n;x[n+12>>2]=c;a:{if((c|0)<=0){break a}i=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{j=x[b+656>>2];k:{if(!(!j|x[a+480180>>2]!=16777216)){l=x[j+44>>2]!=0;break k}if(!j){break j}}if((c|0)>128){break i}m=c-1|0;h=z[ac(j+236|0,m)>>1];l:{if((h-1&65535)>>>0<=3998){i=(D(h,104)+a|0)+484380|0;break l}if(!Ob(a+1074312|0,43)){break l}if(!Bj(x[b+656>>2])){break a}}m=y[xb(j+108|0,m)|0];x[n+12>>2]=m;if(m>>>0<=120){break h}c=m;break i}m=c;h=0;if(c>>>0<121){break g}}m:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){Fo(a,b);if(d){break m}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]&4)|!y[b+789|0]){break m}x[b+88>>2]=x[b+88>>2]&-6145;break m}if(!z[a+480192>>1]){break m}x[b+88>>2]=x[b+88>>2]|4096}n:{if((c|0)!=254){break n}c=x[b+88>>2];if(!(!(c&512)|x[a+480180>>2]!=2)){x[b+88>>2]=c|2048;break n}x[b+88>>2]=c|2101248;o:{if(x[a+480180>>2]&16777248){if(!z[a+480192>>1]){break o}if(Ob(a+1074312|0,50)){break o}}x[b+688>>2]=0}if(Ob(a+1074312|0,50)){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}if(!Ob(a+1074312|0,20)){break a}v[b+797|0]=0;v[b+802|0]=0;break a}h=0;if(!l){break g}if(d){h=y[b+797|0];if(h){break f}}x[b+708>>2]=0;h=1}if(d){break e}if(!(!(x[a+480180>>2]&1048588)|!i)){w[b+770>>1]=v[i+36|0];w[b+772>>1]=v[i+37|0];break d}if(i){break d}i=0;p=1;break c}h=D((x[x[j+44>>2]+36>>2]<<16>>16)+1|0,(m<<16>>16)-(h<<16>>16)|0)-x[b+852>>2]|0;x[b+708>>2]=h;x[b+852>>2]=0-h;h=1}p=!i;l=1;if(Mi(x[b+8>>2],x[b+12>>2])){break b}p:{l=a+1074312|0;if(!Ob(l,54)){break p}if(Bj(x[b+656>>2])){if(!Ob(l,117)){break p}}x[b+700>>2]=0;break a}l=(Ob(l,39)^-1)&d;break b}if(!Ob(a+1074312|0,24)){break c}x[b+704>>2]=x[i+24>>2]}l=0}q:{if(xn(x[a+480180>>2])){x[n+12>>2]=w[b+770>>1]+m;Ge(n+12|0,12,131);break q}AX(n+12|0)}k=a+1074312|0;r:{if(Ob(k,34)){d=iE(c);break r}d=x[n+12>>2]}v[b+797|0]=d;v[b+851|0]=y[b+851|0]&183|64;if(!(x[a+480180>>2]&16777250?0:l)){v[b+803|0]=0}o=zh(a,x[n+12>>2],w[b+772>>1],x[b+704>>2]);v[b+831|0]=0;if(Ob(k,48)){aT(a,b,j,i)}s:{if(!Ob(k,115)|!j){break s}d=y[j+26|0];if(!d){break s}if(!z[b+784>>1]){w[b+784>>1]=z[b+692>>1]+1}$S(b+692|0,c,d,y[j+27|0])}t:{if(l|e^1){break t}x[b+776>>2]=0;x[b+780>>2]=0;if(!j){break t}if(Ob(k,29)){v[b+798|0]=y[j+16|0]}if(!(y[j+60|0]&8)){Aj(b+724|0)}if(!(y[j+80|0]&8)){Aj(b+732|0)}if(!(y[j+100|0]&8)){Aj(b+740|0)}if(y[j+20|0]){c=((D(Pu(Eo(a)),y[j+20|0])<<16>>16)/64|0)+1<<16>>16;u:{if(Ob(k,28)){d=x[b+752>>2];break u}d=(x[b+688>>2]+1|0)/2|0}w[b+776>>1]=(D(d,c)|0)/199}v:{if(!y[j+19|0]){break v}r=b,s=(D(Pu(Eo(a)),y[j+19|0])<<16>>16)/32|0,w[r+778>>1]=s;if(Ob(k,28)|z[b+784>>1]){break v}w[b+784>>1]=z[b+692>>1]+1}m=y[j+23|0];if(m){d=Pu(Eo(a));c=y[b+837|0];v[b+796|0]=c+1;w[b+780>>1]=(D((D(m,d+1|0)<<16>>16)/128<<16>>16,c)+1|0)/128}m=y[j+24|0];if(!m){break t}d=Pu(Eo(a));c=y[b+838|0];v[b+795|0]=c+1;w[b+782>>1]=(D(c,(D(m,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(p){break a}w:{x:{if(!o){d=0;break x}if(!(l&x[b+700>>2]!=0)){x[b+700>>2]=o}y:{z:{if(!h){if(!l){if(Ob(k,69)){break z}if(Ob(k,46)|x[a+480180>>2]==1){break z}}x[b+708>>2]=o;v[b+851|0]=y[b+851|0]&239}if(!l){break z}if(x[b+76>>2]|y[a+480180|0]&2){break y}}x[b+104>>2]=i;c=x[i>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;A:{B:{C:{if(!(y[a+480210|0]&32)){if(!Ob(k,96)|y[b+789|0]){break B}q=x[b>>2];c=x[b+76>>2];break C}if(y[b+789|0]){break B}}x[n+8>>2]=c-1;c=x[Hb(b+660|0,n+8|0)>>2];x[b>>2]=q;x[b+4>>2]=c;break A}x[b+660>>2]=0}c=z[i+34>>1];h=c&1023;d=h|x[b+88>>2]&-525056;x[b+88>>2]=d;D:{E:{if(c&8){x[b+80>>2]=x[i+12>>2];c=x[i+16>>2];x[b+88>>2]=(h&16?d|4:d&-524311)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break E}break D}if(!(h&2)){break D}x[b+80>>2]=x[i+4>>2];c=x[i+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break D}}x[b+76>>2]=c}F:{if(!(r=0,s=Ob(k,83),t=x[b+80>>2],t?r:s)){c=x[b+76>>2];break F}c=x[i>>2];x[b+84>>2]=c;x[b+76>>2]=c}d=x[b+88>>2];if(!(!(d&128)|!c)){x[b+4>>2]=c-1;x[b+88>>2]=d|128}G:{if(y[b+822|0]>3){break G}c=Ob(k,21);h=x[a+480180>>2];H:{I:{if(!(c|!(h&16777248))){d=16;if(y[a+480208|0]&4){break I}break H}d=32;if((h|0)==16){break H}}if(h&67633152){break G}d=0}v[b+819|0]=d}if(Ob(k,21)|y[b+825|0]>3){break y}v[b+820|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}d=0;if(!l){break x}d=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break x}c=1;if(!(y[a+480208|0]&8)){break w}c=1;if(!y[b+789|0]){break w}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){Ym(b);if(!Ob(k,21)){v[b+818|0]=0;x[b+756>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}J:{if(!d){i=y[b+789|0];break J}i=y[b+789|0];if(!(y[a+480208|0]&8)){break J}c=1;if(!(i&255)){break w}}if(!(i&255?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}c=d}K:{if(!(!c|!Ob(k,40)|(y[b+789|0]?y[a+480208|0]&8:0))){d=x[b+88>>2]&-4194305;break K}d=x[b+88>>2]&-4196353}x[b+88>>2]=d;L:{if(c){break L}w[b+842>>1]=65535;v[b+851|0]=y[b+851|0]|2;x[b+88>>2]=d&-6324225|2097152;M:{if(Ob(k,23)){break M}if(Ob(k,22)){break M}if(Ob(k,52)){break M}if(Ob(k,71)){break M}v[b+839|0]=0;v[b+808|0]=0}if(e){v[b+818|0]=0;x[b+756>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;if(!(y[b+89|0]&2)){break L}if(!Ed(x[a+1298300>>2])|(g|0)==65535){break L}if(Ob(k,111)){yk(x[a+1298300>>2],g);break L}if(!Ob(k,110)){break L}SB(x[a+1298300>>2],g,0,1,0)}d=x[b+88>>2];N:{O:{P:{if(f){x[b+88>>2]=d&-1025;break P}if(!(d&1024)){break P}if(y[a+24618|0]&16){break O}}a=x[b+104>>2];if(!(!a|!(y[a+35|0]&4)|f)){break O}a=x[b+656>>2];if(!a|(!(y[a+15|0]&2)|f)){break N}}x[b+700>>2]=0}if(c){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}fb=n+16|0}function A5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=xd(a,c);x[e>>2]=95212;f=EJ(e+8|0);x[31609]=0;b=P(71,e+152|0,b|0)|0;a=x[31609];x[31609]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31609]=0;a=ca(104)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}a=x[a>>2];c=0;x[31609]=0;a=P(1329,f|0,a+8|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break e}while(1){f:{d=x[a>>2];if(oc(d,x[e+12>>2])>>>0<=c>>>0){x[31609]=0;c=R(852,12)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break f}break e}d=x[yb(d,c)>>2];if(d){pm(d)}c=c+1|0;continue}break}x[31609]=0;a=U(1330,c|0,b|0,0)|0;d=x[31609];x[31609]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((d|0)!=1){x[31609]=0;O(1331,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,12)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=U(1332,c|0,b|0,0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break t}x[31609]=0;O(1333,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,20)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=U(1334,c|0,b|0,0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break s}x[31609]=0;O(1335,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,12)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=U(1336,c|0,b|0,0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break r}x[31609]=0;O(1337,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=R(852,8)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}a=xd(a,0);x[a>>2]=97156;x[a>>2]=102768;x[31609]=0;O(1338,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,12)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=P(1339,c|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break q}x[31609]=0;O(1340,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=R(852,8)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}a=xd(a,0);x[a>>2]=97304;x[a>>2]=102976;x[31609]=0;O(1341,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=R(852,8)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}a=xd(a,0);x[a>>2]=97536;x[a>>2]=103080;x[31609]=0;O(1342,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=R(852,8)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}a=xd(a,0);x[a>>2]=97420;x[a>>2]=103184;x[31609]=0;O(1343,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=R(852,8)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}a=xd(a,0);x[a>>2]=97652;x[a>>2]=103288;x[31609]=0;O(1344,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,24)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=U(1345,c|0,b|0,0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break p}x[31609]=0;O(1346,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,28)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=U(1347,c|0,b|0,0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break o}x[31609]=0;O(1348,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,72)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=P(1349,c|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break n}x[31609]=0;O(1350,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,72)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=P(1351,c|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break m}x[31609]=0;O(1352,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,76)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=P(1353,c|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break l}x[31609]=0;O(1354,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,76)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=P(1355,c|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break k}x[31609]=0;O(1356,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,544)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=P(1357,c|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break j}x[31609]=0;O(1358,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,544)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=P(1359,c|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break i}x[31609]=0;O(1360,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,12)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=P(1361,c|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break h}x[31609]=0;O(1362,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;c=R(852,12)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=P(1363,c|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break g}x[31609]=0;O(1364,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=R(852,8)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}a=mJ(a,0);x[a>>2]=102616;x[31609]=0;O(1365,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=R(852,8)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}a=lJ(a,0);x[a>>2]=102692;x[31609]=0;O(1366,e|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}return e|0}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=T(0)|0;Db(c);break d}a=N()|0;break c}a=T(0)|0}Y(a|0)|0;c=0;while(1){a=x[f>>2];if(oc(a,x[e+12>>2])>>>0<=c>>>0){x[31609]=0;X(84);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;if((c|0)==1){break b}tb(b);break c}a=x[yb(a,c)>>2];if(a){um(a)}c=c+1|0;continue}}oy(f);Q(a|0);p()}T(0)|0;Sb()}p()}function boa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-176|0;fb=d;yc(c);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!gp(c,d+164|0)|(y[d+164|0]|y[d+165|0]<<8|(y[d+166|0]<<16|y[d+167|0]<<24))!=1297239878){break l}f=y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24);if((f|0)!=1179011393&(f|0)!=1128679745){break l}e=fb-32|0;fb=e;h=d+152|0;f=Nb(h);m:{n:{o:{p:{q:{while(1){g=x[c+8>>2];i=x[c>>2];x[31609]=0;g=U(150,i|0,g|0,8)|0;i=x[31609];x[31609]=0;if((i|0)==1){break o}if(!g){break p}x[31609]=0;g=e+4|0;O(825,g|0,c|0);i=x[31609];x[31609]=0;if((i|0)!=1){x[31609]=0;O(826,f|0,g|0);i=x[31609];x[31609]=0;if((i|0)==1){break q}Hd(g);continue}break}a=N()|0;break n}a=N()|0;Hd(e+4|0);break n}fb=e+32|0;break m}a=N()|0}ke(f);Q(a|0);p()}x[31609]=0;e=d+132|0;S(747,e|0,h|0,1129270605);c=x[31609];x[31609]=0;if((c|0)==1){break f}x[31609]=0;c=P(748,e|0,d+114|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break i}r:{if(!c){break r}if(!$b(z[d+116>>1]|z[d+118>>1]<<16)){break r}if((Bb(z[d+114>>1])-3&65535)>>>0<65534){break r}if((Bb(z[d+120>>1])-65&65535)>>>0<65472){break r}v[d+110|0]=78;v[d+111|0]=79;v[d+112|0]=78;v[d+113|0]=69;c=1;if((y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24))==1128679745){x[31609]=0;c=P(628,e|0,d+110|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break h}if(!c){break r}c=(y[d+110|0]|y[d+111|0]<<8|(y[d+112|0]<<16|y[d+113|0]<<24))!=1936684916}x[31609]=0;e=d+88|0;S(747,e|0,d+152|0,1397968452);f=x[31609];x[31609]=0;s:{t:{u:{if((f|0)!=1){x[31609]=0;l=P(749,e|0,d+80|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break j}if(!l){break s}f=(Bb(z[d+120>>1])-1|0)/8|0;g=f<<3;e=g&31;h=d+76|0;if((g&63)>>>0>=32){e=1074268168>>>e|0}else{e=((1<<e)-1&1074268168)<<32-e|538447880>>>e}h=Zc(h,(f>>>0>=8?8:e)&120,(Bb(z[d+114>>1])|0)==2?2:1,c,0);c=y[d+110|0]|y[d+111|0]<<8|(y[d+112|0]<<16|y[d+113|0]<<24);if(!((c|0)==842230886|(c|0)==842222662|(c|0)==875981926)){if((c|0)!=875973702){break u}}wg(h,3);break t}c=N()|0;break b}c=y[d+110|0]|y[d+111|0]<<8|(y[d+112|0]<<16|y[d+113|0]<<24);if(!((c|0)!=2002873441&(c|0)!=1463897153)){wg(h,17);hd(h,16);break t}c=y[d+110|0]|y[d+111|0]<<8|(y[d+112|0]<<16|y[d+113|0]<<24);if(!((c|0)!=2002873461&(c|0)!=1463897173)){wg(h,16);hd(h,16);break t}if((y[d+110|0]|y[d+111|0]<<8|(y[d+112|0]<<16|y[d+113|0]<<24))!=544694642){break t}wg(h,1)}c=x[d+80>>2];x[31609]=0;c=U(150,x[d+88>>2],x[d+96>>2],$b(c)|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break d}if(c){c=x[d+80>>2];x[31609]=0;P(183,d+88|0,$b(c)|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}}Vu(a,b);x[31609]=0;g=(D(b,104)+a|0)+484380|0;O(279,g|0,0);c=x[31609];x[31609]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)==1){break E}n=g,o=$b(z[d+116>>1]|z[d+118>>1]<<16),x[n>>2]=o;c=y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24);f=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);i=30-y[d+123|0]|0;e=0;while(1){c=f;if(i&255){f=c>>>1|0;i=i-1|0;e=c;continue}break}x[g+24>>2]=c+(e&1);x[31609]=0;U(215,h|0,g|0,d+88|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break E}x[31609]=0;e=d+56|0;f=d+152|0;S(747,e|0,f|0,1296126539);c=x[31609];x[31609]=0;if((c|0)==1){break D}x[31609]=0;c=R(172,x[d+56>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break C}if(!c){break v}x[31609]=0;c=d+16|0;S(747,c|0,f|0,1229869908);f=x[31609];x[31609]=0;if((f|0)==1){break B}x[31609]=0;f=P(750,c|0,d+36|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break A}ub(c);if(!f){break v}x[31609]=0;f=R(273,e|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break z}e=Nb(c);x[31609]=0;O(751,e|0,f|0);c=x[31609];x[31609]=0;if((c|0)==1){break x}c=0;while(1){if((c|0)==(f|0)){break y}x[31609]=0;h=d+56|0;i=d+4|0;j=P(752,h|0,i|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break x}if(!j){break y}x[31609]=0;O(753,e|0,i|0);i=x[31609];x[31609]=0;if((i|0)==1){break x}x[31609]=0;P(183,h|0,y[d+10|0]|1)|0;h=x[31609];x[31609]=0;if((h|0)==1){break x}c=c+1|0;continue}}c=N()|0;break c}c=N()|0;break c}c=N()|0;break e}c=N()|0;break e}c=N()|0;ub(d+16|0);break e}c=N()|0;break e}c=Bb(y[d+44|0]|y[d+45|0]<<8);if(c){w[g+34>>1]=z[g+34>>1]&65511|((c|0)==2)<<4|8}c=Bb(y[d+50|0]|y[d+51|0]<<8);if(c){w[g+34>>1]=z[g+34>>1]&65529|((c|0)==2?4:2)|2}n=d,o=wb(x[e>>2]),x[n+4>>2]=o;h=wb(x[e+4>>2]);i=y[d+46|0]|y[d+47|0]<<8;j=y[d+48|0]|y[d+49|0]<<8;k=y[d+52|0]|y[d+53|0]<<8;m=y[d+54|0]|y[d+55|0]<<8;while(1){c=x[d+4>>2];if(!Ib(c,h)){break w}f=Bb(y[c|0]|y[c+1|0]<<8);if((f|0)==(Bb(i)|0)){n=g,o=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[n+12>>2]=o;f=Bb(y[c|0]|y[c+1|0]<<8)}if((Bb(j)|0)==(f|0)){n=g,o=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[n+16>>2]=o;f=Bb(y[c|0]|y[c+1|0]<<8)}if((Bb(k)|0)==(f|0)){n=g,o=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[n+4>>2]=o;f=Bb(y[c|0]|y[c+1|0]<<8)}if((f|0)==(Bb(m)|0)){n=g,o=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[n+8>>2]=o}x[d+4>>2]=x[d+4>>2]+7;continue}}c=N()|0;JT(e);break e}Uk(g);JT(e)}x[31609]=0;c=d+16|0;S(747,c|0,d+152|0,1312902469);e=x[31609];x[31609]=0;if((e|0)==1){break g}x[31609]=0;e=R(172,x[d+16>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break k}F:{if(e){x[31609]=0;e=R(154,x[d+16>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break k}x[31609]=0;S(317,c|0,((b<<5)+a|0)+946304|0,e|0);b=x[31609];x[31609]=0;if((b|0)!=1){break F}break k}x[31609]=0;c=P(36,d+4|0,22292)|0;e=x[31609];x[31609]=0;if((e|0)==1){break k}Ac(((b<<5)+a|0)+946304|0,c);tb(c)}eC(g,x[a+480180>>2]);Ij(g,a);ub(d+16|0);ub(d+56|0)}ub(d+88|0)}ub(d+132|0);ke(d+152|0)}fb=d+176|0;return l|0}c=N()|0;ub(d+16|0);break e}c=N()|0;break c}c=N()|0;break b}c=N()|0;break b}c=N()|0;break e}c=N()|0;break a}ub(d+56|0);break c}c=N()|0}ub(d+88|0)}ub(d+132|0)}ke(d+152|0);Q(c|0);p()}function z9(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0;p=fb-560|0;fb=p;x[p+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){w=1;B=5296;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){w=1;B=5299;break a}w=e&1;B=w?5302:5297;E=!w}b:{if((g&2146435072)==2146435072){g=w+3|0;Wf(a,32,c,g,e&-65537);Kf(a,B,w);d=f&32;Kf(a,b!=b?d?9994:13909:d?11148:14227,3);Wf(a,32,c,g,e^8192);n=(c|0)<(g|0)?g:c;break b}z=p+16|0;c:{d:{e:{b=pL(b,p+44|0);b=b+b;if(b!=0){g=x[p+44>>2];x[p+44>>2]=g-1;A=f|32;if((A|0)!=97){break e}break c}A=f|32;if((A|0)==97){break c}k=x[p+44>>2];m=(d|0)<0?6:d;break d}k=g-29|0;x[p+44>>2]=k;b=b*268435456;m=(d|0)<0?6:d}s=(p+48|0)+((k|0)>=0?288:0)|0;h=s;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((k|0)<=0){d=k;g=h;i=s;break f}i=s;d=k;while(1){l=(d|0)>=29?29:d;g=h-4|0;g:{if(i>>>0>g>>>0){break g}q=0;while(1){d=x[g>>2];n=l&31;C=q;if((l&63)>>>0>=32){q=d<<n;d=0}else{q=(1<<n)-1&d>>>32-n;d=d<<n}n=C+d|0;q=q+r|0;q=Cua(n,d>>>0>n>>>0?q+1|0:q,1e9,0);d=Aua(q,hb,-1e9,0)+n|0;x[g>>2]=d;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!q){break g}i=i-4|0;x[i>>2]=q}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[p+44>>2]-l|0;x[p+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){u=((m+25>>>0)/9|0)+1|0;r=(A|0)==102;while(1){d=0-d|0;n=(d|0)>=9?9:d;h:{if(g>>>0<=i>>>0){h=!x[i>>2]<<2;break h}q=1e9>>>n|0;l=-1<<n^-1;d=0;h=i;while(1){C=d;d=x[h>>2];x[h>>2]=C+(d>>>n|0);d=D(q,d&l);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=!x[i>>2]<<2;if(!d){break h}x[g>>2]=d;g=g+4|0}d=n+x[p+44>>2]|0;x[p+44>>2]=d;i=h+i|0;h=r?s:i;g=g-h>>2>(u|0)?h+(u<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=i>>>0){break i}d=D(s-i>>2,9);h=10;l=x[i>>2];if(l>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(l>>>0>=h>>>0){continue}break}}h=(m-((A|0)!=102?d:0)|0)-((A|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-s>>2,9)-9|0)){q=h+9216|0;l=(q|0)/9|0;u=((p+48|0)+((k|0)<0?4:292)|0)+(l<<2)|0;k=u-4096|0;h=10;n=q+D(l,-9)|0;if((n|0)<=7){while(1){h=D(h,10);n=n+1|0;if((n|0)!=8){continue}break}}r=x[k>>2];q=(r>>>0)/(h>>>0)|0;n=D(q,h);l=u-4092|0;j:{if((n|0)==(r|0)&(l|0)==(g|0)){break j}r=r-n|0;k:{if(!(q&1)){b=9007199254740992;if(!(v[u-4100|0]&1)|((h|0)!=1e9|i>>>0>=k>>>0)){break k}}b=9007199254740994}t=(g|0)==(l|0)?1:1.5;l=h>>>1|0;t=l>>>0>r>>>0?.5:(l|0)==(r|0)?t:1.5;if(!(y[B|0]!=45|E)){t=-t;b=-b}x[k>>2]=n;if(b+t==b){break j}d=h+n|0;x[k>>2]=d;if(d>>>0>=1e9){while(1){x[k>>2]=0;k=k-4|0;if(k>>>0<i>>>0){i=i-4|0;x[i>>2]=0}d=x[k>>2]+1|0;x[k>>2]=d;if(d>>>0>999999999){continue}break}}d=D(s-i>>2,9);h=10;l=x[i>>2];if(l>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(l>>>0>=h>>>0){continue}break}}h=k+4|0;g=g>>>0>h>>>0?h:g}while(1){l=g;q=g>>>0<=i>>>0;if(!q){g=g-4|0;if(!x[g>>2]){continue}}break}l:{if((A|0)!=103){k=e&8;break l}h=m?m:1;g=(h|0)>(d|0)&(d|0)>-5;m=(g?d^-1:-1)+h|0;f=(g?-1:-2)+f|0;k=e&8;if(k){break l}g=-9;m:{if(q){break m}k=x[l-4>>2];if(!k){break m}n=10;g=0;if((k>>>0)%10|0){break m}while(1){h=g;g=g+1|0;n=D(n,10);if(!((k>>>0)%(n>>>0)|0)){continue}break}g=h^-1}h=D(l-s>>2,9);if((f&-33)==70){k=0;g=(g+h|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}k=0;g=((d+h|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}n=-1;q=k|m;if(((q?2147483645:2147483646)|0)<(m|0)){break b}r=(((q|0)!=0)+m|0)+1|0;h=f&-33;n:{if((h|0)==70){if((r^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=lo((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}u=g-2|0;v[u|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-u|0;if((g|0)>(r^2147483647)){break b}}d=g+r|0;if((d|0)>(w^2147483647)){break b}r=d+w|0;Wf(a,32,c,r,e);Kf(a,B,w);Wf(a,48,c,r,e^65536);o:{p:{q:{if((h|0)==70){f=p+16|0;d=f|8;k=f|9;h=i>>>0>s>>>0?s:i;i=h;while(1){g=lo(x[i>>2],0,k);r:{if((h|0)!=(i|0)){if(p+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(p+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(k|0)){break r}v[p+24|0]=48;g=d}Kf(a,g,k-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}if(q){Kf(a,16806,1)}if((m|0)<=0|i>>>0>=l>>>0){break q}while(1){g=lo(x[i>>2],0,k);if(g>>>0>p+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(p+16>>>0<g>>>0){continue}break}}Kf(a,g,(m|0)>=9?9:m);g=m-9|0;i=i+4|0;if(l>>>0<=i>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}s=i>>>0<l>>>0?l:i+4|0;f=p+16|0;d=f|8;l=f|9;h=i;while(1){g=lo(x[h>>2],0,l);if((l|0)==(g|0)){v[p+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(p+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(p+16>>>0<g>>>0){continue}break}break t}Kf(a,g,1);g=g+1|0;if(!(k|m)){break t}Kf(a,16806,1)}f=l-g|0;Kf(a,g,(f|0)<(m|0)?f:m);m=m-f|0;h=h+4|0;if(s>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}Wf(a,48,m+18|0,18,0);Kf(a,u,z-u|0);break o}g=m}Wf(a,48,g+9|0,9,0)}Wf(a,32,c,r,e^8192);n=(c|0)<(r|0)?r:c;break b}k=(f<<26>>31&9)+B|0;u:{if(d>>>0>11){break u}g=12-d|0;t=16;while(1){t=t*16;g=g-1|0;if(g){continue}break}if(y[k|0]==45){b=-(t+(-b-t));break u}b=b+t-t}s=w|2;i=f&32;h=x[p+44>>2];g=h>>31;g=lo((g^h)-g|0,0,z);if((z|0)==(g|0)){v[p+15|0]=48;g=p+15|0}m=g-2|0;v[m|0]=f+15;v[g-1|0]=(h|0)<0?45:43;g=e&8;h=p+16|0;while(1){f=h;if(F(b)<2147483648){l=~~b}else{l=-2147483648}v[h|0]=i|y[l+93232|0];b=(b-+(l|0))*16;h=f+1|0;if(!(!(g|(d|0)>0)&b==0|(h-(p+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}n=-1;g=z-m|0;f=g+s|0;if((2147483645-f|0)<(d|0)){break b}l=f;f=p+16|0;i=h-f|0;d=d?(i-2|0)<(d|0)?d+2|0:i:i;h=l+d|0;Wf(a,32,c,h,e);Kf(a,k,s);Wf(a,48,c,h,e^65536);Kf(a,f,i);Wf(a,48,d-i|0,0,0);Kf(a,m,g);Wf(a,32,c,h,e^8192);n=(c|0)<(h|0)?h:c}fb=p+560|0;return n|0}function Isa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;v[j+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}v[b+5|0]=d;v[j+8|0]=15;l=j+127|0;p=j+8|0;k=p;o=y[Qb(l,k)|0];v[j+8|0]=14;l=y[Qb(l,k)|0];x[j+8>>2]=d+31>>>5;x[j+120>>2]=14;r=j+120|0;n=x[Cd(k,r)>>2];x[j+8>>2]=d+127>>>7;x[j+120>>2]=14;q=c&15;k=q<<8|d;p=Cd(p,r);b:{switch((c>>>4|0)-2|0){case 0:v[b+2|0]=1;x[j+8>>2]=k>>>2;x[j+120>>2]=64;s=b,t=x[Cd(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 1:v[b+2|0]=1;if(!k){v[b+4|0]=0;break a}s=j,t=MD(k)>>>2|0,x[s+8>>2]=t;x[j+120>>2]=64;s=b,t=x[Cd(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 2:v[b+3|0]=9;v[b+5|0]=k>>>4;break a;case 3:v[b+3|0]=23;v[b+5|0]=k+1>>>5;break a;case 4:v[b+3|0]=23;if(k){a=Eh(MD(k)>>>5|0)}else{a=0}v[b+5|0]=a;break a;case 5:v[b+5|0]=q;v[b+3|0]=15;break a;case 6:v[b+3|0]=15;if((e|0)>=0){if(y[b+2|0]){break a}v[b+2|0]=2;s=b,t=Gc(((q<<6|7)>>>0)/15|0,0),v[s+4|0]=t;break a}v[b+2|0]=1;v[b+5|0]=q;v[b+4|0]=d+3>>>2;break a;case 7:v[b+3|0]=10;c:{if((e|0)>5){break c}if(!k){v[b+5|0]=1;break a}c=rr(a,f,g);if(!c){break c}a=ni(a,c);c=z[a+34>>1];if(c&1){k=k>>>1|0;x[j+120>>2]=k}if(!(c&2)){break c}c=x[a>>2];if(c>>>0>=k<<8>>>0){break c}x[j+120>>2]=x[a+4>>2]+8>>>8;xc(j+120|0,c-1>>>8|0);k=x[j+120>>2]}v[b+5|0]=k;if(y[b+2|0]|k>>>0<256){break a}v[b+2|0]=15;x[j+116>>2]=k>>>8;_v(j+8|0);x[j+112>>2]=9;s=b,t=x[Hb(j+116|0,j+112|0)>>2],v[s+4|0]=t;break a;default:break b}}k=x[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:Cf(b,c,d);f:{switch(y[b+3|0]-16|0){case 1:x[h>>2]=D(y[b+5|0],1e4);break a;case 0:break f;default:break a}}a=y[b+5|0];if(!a){break a}x[i>>2]=a;break a;case 4:v[b+3|0]=4;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=8;break a;case 5:v[b+3|0]=5;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=11;break a;case 7:if(!Tc(y[b|0])|!d){break a}v[b+3|0]=35;v[b+5|0]=(d>>>1&120|128)-(d<<3&120);if(z[a+480192>>1]){break a}w[j+8>>1]=255;c=z[Oc(a+480190|0,j+8|0)>>1];w[a+480192>>1]=c;e=a+946304|0;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=DE(a,d,d);if(c){v[c+33|0]=2;d=e+(d<<5)|0;f=x[d+4>>2];x[c+492>>2]=x[d>>2];x[c+496>>2]=f;f=x[d+12>>2];x[c+500>>2]=x[d+8>>2];x[c+504>>2]=f;f=x[d+20>>2];x[c+508>>2]=x[d+16>>2];x[c+512>>2]=f;f=x[d+28>>2];x[c+516>>2]=x[d+24>>2];x[c+520>>2]=f;ck(c,127,1);bk(c,0,1)}b=b+1|0;c=z[a+480192>>1];continue};case 8:v[b+3|0]=19;v[b+5|0]=o|208;break a;case 9:v[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|64;break a;case 12:v[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|112;break a;case 15:v[b+3|0]=1;break a;case 16:case 17:v[b+3|0]=19;v[b+5|0]=l|c<<4;break a;case 18:v[b+3|0]=15;break a;case 19:v[b+3|0]=11;v[b+5|0]=l<<4;break a;case 20:v[b+5|0]=l;v[b+3|0]=11;break a;case 23:v[b+3|0]=6;v[b+5|0]=l<<4;break a;case 24:v[b+5|0]=l;v[b+3|0]=6;break a;case 27:v[b+3|0]=7;v[b+5|0]=l<<4;break a;case 28:break e;default:break a}}v[b+5|0]=l;v[b+3|0]=7;break a;case 0:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4;break a;case 1:if(!d){break a}v[b+5|0]=n;v[b+3|0]=24;break a;case 4:v[b+3|0]=11;v[b+5|0]=l<<4|15;break a;case 5:v[b+3|0]=11;v[b+5|0]=l|240;break a;case 6:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n|240;break a;case 8:if(!d){break a}v[b+3|0]=16;x[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=x[h>>2];if(a>>>0<1e4){break a}v[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,t=Zl(245850/(m+m)),v[s+5|0]=t;break a;case 10:v[b+3|0]=19;v[b+5|0]=o|224;break a;case 12:v[b+3|0]=28;v[b+5|0]=o|16;break a;case 13:v[b+3|0]=28;v[b+5|0]=o|32;break a;case 14:v[b+3|0]=29;v[b+5|0]=l<<3&240;break a;case 15:v[b+3|0]=29;v[b+5|0]=(l&254)>>>1;break a;case 16:v[b+3|0]=18;break a;case 17:v[b+3|0]=19;v[b+5|0]=o|176;break a;case 18:case 19:v[b+3|0]=20;v[b+5|0]=d?120:119;break a;case 20:v[b+3|0]=20;v[b+5|0]=d?125:123;break a;case 21:v[b+3|0]=20;v[b+5|0]=d?122:121;break a;case 22:v[b+3|0]=20;v[b+5|0]=d?126:123;break a;case 26:v[b+3|0]=10;v[b+5|0]=d+15>>>4;break a;case 27:v[b+5|0]=1;v[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=x[h>>2];if(o>>>0<1e4){break a}l=x[i>>2];if(!l){break a}i=rr(a,f,g);if(!i){break a}k=ni(a,i);n=z[k+34>>1];g:{if(!(n&2)){i=x[k>>2];break g}i=x[k+8>>2]-((e|0)<6?x[k+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=x[k+24>>2];if(!n){break a}h:{if(z[a+480192>>1]<g>>>0){break h}a=x[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(y[xb(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=Ai(m/12+(a?(e|0)<6?+v[k+37|0]/-1536:-0:-0))*+(n>>>0);if(a){v[b+3|0]=17;a=Zl(m*.5*(+(D(d,l)>>>0)*2.5)/+(i>>>0));v[b+5|0]=a;x[h>>2]=D(a,1e4);break a}m=Zv(rM(+(i>>>0)/m/(+(D(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=Tc(y[b|0]);v[b|0]=a;m=(m-J(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}v[b+5|0]=a;if((a|0)!=128){v[b+3|0]=35}if(c){break a}if(!y[b+2|0]){v[b+4|0]=9;v[b+2|0]=11;break a}v[b+5|0]=255;v[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}v[b+3|0]=20;v[b+5|0]=a-99;break a;case 34:v[b+3|0]=21;v[b+5|0]=d<<2;break a;case 35:v[b+3|0]=21;s=b,t=Eh(MD(d<<4)>>>6|0),v[s+5|0]=t;break a;case 36:case 38:v[b+3|0]=22;v[b+5|0]=k<<4;break a;case 37:case 39:v[b+5|0]=k;v[b+3|0]=22;break a;case 40:v[b+3|0]=22;v[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}v[b+3|0]=22;v[b+5|0]=l|240}fb=j+128|0}function Lo(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;h=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:h;r=x[b+752>>2];a:{j=y[b+802|0];b:{if(!j){if(Ob(a+1074312|0,11)){break b}}g=a+484380|0;c:{d:{if(!h){break d}if(!Tc(j)){break d}e:{j=j-1|0;k=ac(h+236|0,j);if(z[k>>1]){break e}if(!Ob(a+1074312|0,43)){break e}if(Jj(y[h+31|0])){break e}x[b+656>>2]=h;return}if(y[xb(h+108|0,j)|0]>120){break b}j=z[k>>1];k=(j-1&65535)>>>0<3999?g+D(j,104)|0:0;break c}if(!z[a+480192>>1]){k=g+D(c,104)|0;break c}if(j>>>0>250){break b}if(!Ob(a+1074312|0,43)){break c}if(h){if(Jj(y[h+31|0])){break c}}v[b+803|0]=0;x[b+656>>2]=0;return}j=x[b+104>>2];m=(j|0)!=0&(j|0)!=(k|0);i=x[b+656>>2];p=!h|x[a+480180>>2]!=16777216?p:x[h+44>>2]!=0;n=d^1;g=(i|0)!=(h|0);if((n|g|m)==1){w[b+774>>1]=0}l=!m;if(!(l|(g|!(d&p)))){break b}f:{if(l|n){break f}q=a+1074312|0;if(!(!Ob(q,32)|!(y[a+480208|0]&8))){k=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:k}j=x[a+480180>>2];g:{h:{i:{j:{if(!g){if((h|0)!=0&(j&1048580)!=0|(j|0)==268435456){break h}if((j|0)!=1){break i}break j}if((j|0)==1){break j}if((j|0)==268435456){break h}break i}if(Mi(x[b+8>>2],x[b+12>>2])){break h}}if(!Ob(q,79)){break g}if(!Mi(x[b+8>>2],x[b+12>>2])){break g}}o=1}if(!Ob(q,119)|z[a+480192>>1]){break f}v[b+851|0]=y[b+851|0]|2}k:{if(!x[b+16>>2]|(l|(g|!z[a+480192>>1]))){break k}if(!Ob(a+1074312|0,87)){break k}o=Tc(y[b+788|0])^1|o}l=(i|0)!=(h|0);l:{if(Mi(x[b+8>>2],x[b+12>>2])|!(x[a+480180>>2]&16777248)){break l}if(h){if(Jj(y[h+31|0])){break l}}l=1}m:{n:{if(!d|(l|m)!=1){break n}if(!Ob(a+1074312|0,61)){break n}g=x[b+104>>2];i=x[b+656>>2];j=0;if(g|i){break m}}x[b+656>>2]=h;g=k;i=h;j=l}o:{p:{q:{r:{if(!e){break r}s:{if(y[a+480180|0]&3){if(g){if(le(x[g>>2],x[g+20>>2])){break s}}if(!Bj(i)){break r}}if(!g){break q}}if(w[g+34>>1]<0){break r}x[b+688>>2]=z[g+30>>1]}h=(g|0)!=0;if(!(m&o)|!g){break o}if(Ob(a+1074312|0,85)){w[b+772>>1]=v[g+37|0]}h=1;if(x[a+480180>>2]!=2){break o}if(!le(x[g>>2],x[g+20>>2])){break o}l=704;k=x[g+24>>2];break p}l=688;if(!i){h=0;k=0;break p}h=0;k=0;if(!y[i+34|0]){break p}k=x[b+688>>2];if(i){k=x[i+4>>2]<<2}}x[b+l>>2]=k}if(o){break b}v[b+803|0]=0;t:{if(!i){break t}if(s=(B=Ob(a+1074312|0,29),C=1,E=g,E?B:C),t=0,u=!y[i+34|0]&(j^-1),u?s:t){break t}v[b+798|0]=y[i+16|0]}k=64;x[b+752>>2]=64;if(g){k=z[g+32>>1];x[b+752>>2]=k}if(i){x[b+752>>2]=D(x[i+4>>2],k)>>>6}u:{if(!(x[a+480180>>2]&1048580?e:1)){break u}if(Ob(a+1074312|0,48)){break u}aT(a,b,i,g)}v:{w:{x:{if(!f){break x}y:{z:{A:{B:{C:{D:{E:{F:{f=a+1074312|0;if(Ob(f,19)){if(!x[b+76>>2]){e=1;break E}if(!(!c|n)){e=(y[a+480208|0]&8)>>>3|0;if(e){break E}break F}e=0;if(c){break F}break E}G:{c=x[a+480180>>2]&17301536;e=1;H:{if(!d|!c){break H}c=1;e=1;if(y[a+480208|0]&8){break H}e=1;if(!x[b+76>>2]){break H}if(!(y[b+89|0]&16)){break G}e=!x[b+696>>2]}if(j|(!i|!c)){break C}if(!e){break y}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break B}break D}if((j|!i)!=1){break y}break z}if(d){break E}if(!(y[b+89|0]&24)){e=0;break E}e=(y[a+480208|0]&4)>>>2|0}if(j|!x[b+696>>2]){break C}if(!e){break z}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(!i){break A}if(c&2048){break B}}if(!(y[i+60|0]&8)){Aj(b+724|0)}if(!(y[i+80|0]&8)){Aj(b+732|0)}if(y[i+100|0]&8){break A}Aj(b+740|0);break A}if(!e){break z}x[b+88>>2]=x[b+88>>2]|2097152;if(!i){break A}}Ym(b)}if(Ob(f,21)){break x}v[b+818|0]=0;x[b+756>>2]=0;break x}if(!i){break w}}if(v[i+60|0]&1){break x}if(Ob(f,32)){Aj(b+724|0);break x}Ym(b)}c=0;if(g){break v}if(!i){break a}c=1;if(Jj(y[i+31|0])){break v}break a}c=0;if(!g){break a}}I:{if(!(!d|(h^1|x[b+104>>2]!=(g|0)))){e=x[a+480180>>2];if(x[b+76>>2]?e&16777250:0){break b}J:{K:{if((e|0)!=4){break K}if(!Ob(a+1074312|0,40)|y[b+789|0]){break K}e=x[b+88>>2];break J}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break I}x[b+88>>2]=x[b+88>>2]&-6145;e=a+1074312|0;L:{M:{if(!Ob(e,18)){h=-640;if(j|(x[a+480180>>2]&16777248|x[b+104>>2]!=(g|0))){break M}break L}h=-640;if((j^-1)&x[b+104>>2]==(g|0)){break L}}h=-768}x[b+88>>2]=x[b+88>>2]&h;if(!i){break I}v[b+730|0]=y[i+60|0];v[b+738|0]=y[i+80|0];f=y[i+100|0];v[b+746|0]=f;N:{if((f&17)!=17){break N}if(Ob(e,36)|y[b+837|0]){break N}v[b+837|0]=127}e=y[i+21|0];if(vd(e)){s=b,t=Hh(e),v[s+837|0]=t}e=y[i+22|0];if(!vd(e)){break I}s=b,t=Hh(e),v[s+838|0]=t}if(c){x[b+76>>2]=0;x[b+104>>2]=0;return}O:{if(x[b+76>>2]|!d){break O}c=a+1074312|0;if(!Ob(c,54)){if(!Ob(c,39)){break O}}x[b+8>>2]=0;x[b+12>>2]=0}P:{if(y[b+788|0]!=255){break P}if(!Ob(a+1074312|0,100)|!(y[a+480208|0]>>>2&m)){break P}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+752>>2]=r;x[b+688>>2]=z[g+30>>1];if(!(y[g+34|0]&32)){break b}Sq(b,z[g+28>>1],a);return}x[b+104>>2]=g;x[b+76>>2]=x[g>>2];x[b+80>>2]=x[g+4>>2];x[b+84>>2]=x[g+8>>2];c=a+1074312|0;if(!(!Ob(c,83)|x[b+80>>2])){x[b+84>>2]=x[g>>2]}x[b+88>>2]=x[b+88>>2]|z[g+34>>1]&1023;if(Ob(c,21)){v[b+818|0]=0;x[b+756>>2]=0}Q:{R:{if(p){x[b+704>>2]=x[g+24>>2];v[b+851|0]=y[b+851|0]|64;d=0;break R}if(!(m|n)){d=x[a+480180>>2];if(d&5){break Q}}x[b+704>>2]=x[g+24>>2];d=v[g+37|0]}w[b+772>>1]=d;d=x[a+480180>>2]}if(xn(d)){d=v[g+36|0]}else{d=0}w[b+770>>1]=d;if(!(Ob(c,69)|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+852>>2]=0;h=x[b+88>>2];if(h&8){x[b+80>>2]=x[g+12>>2];x[b+84>>2]=x[g+16>>2];h=h>>>2&4|h|2;x[b+88>>2]=h}c=x[b+76>>2];S:{if(!(h&2)){break S}d=x[b+84>>2];if(d>>>0>=c>>>0){break S}x[b+76>>2]=d;c=d}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<c>>>0){break b}x[b>>2]=0;x[b+4>>2]=0}return}x[b+752>>2]=0;x[b+104>>2]=0}
function Doa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;d=fb-224|0;fb=d;yc(b);f=d+160|0;a:{if(!yr(b,f)){break a}if(!zW(f)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(yW(f),hb))){break a}e=1;if((c|0)==64){break a}Dd(a,256);h=d+148|0;pi(h,2,f);e=d+56|0;Cc(e,h);zb(a+1298308|0,e);tb(e);f=y[d+210|0]|y[d+211|0]<<8;x[a+480260>>2]=64;x[a+480264>>2]=32767;w[a+480188>>1]=4;w[a+480190>>1]=f;Lb(a+1074312|0,107,1);f=y[d+203|0];f=f?f:96;h=AC(f);x[a+480196>>2]=f>>>4;x[a+480204>>2]=h;v[d+56|0]=64;r=a,s=y[Qb(d+202|0,e)|0]<<2,x[r+480200>>2]=s;f=a+480280|0;e=0;b:{c:{d:{e:{f:{g:{while(1){if((e|0)==4){h:{h=Nb(d+148|0);m=Nb(d+136|0);x[31609]=0;P(149,b|0,(y[d+192|0]|y[d+193|0]<<8)<<4)|0;e=x[31609];x[31609]=0;i:{if((e|0)==1){break i}x[31609]=0;U(213,b|0,h|0,y[d+208|0]|y[d+209|0]<<8)|0;e=x[31609];x[31609]=0;if((e|0)==1){break i}x[31609]=0;P(149,b|0,(y[d+194|0]|y[d+195|0]<<8)<<4)|0;e=x[31609];x[31609]=0;if((e|0)==1){break i}x[31609]=0;U(213,b|0,m|0,y[d+210|0]|y[d+211|0]<<8)|0;e=x[31609];x[31609]=0;if((e|0)==1){break i}x[31609]=0;P(149,b|0,((y[d+196|0]|y[d+197|0]<<8)<<4)+32|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break i}e=y[a+484376|0];f=x[a+484360>>2];x[31609]=0;O(330,Xb(f,e)|0,y[d+212|0]|y[d+213|0]<<8);e=x[31609];x[31609]=0;if((e|0)==1){break i}e=Xb(x[a+484360>>2],y[a+484376|0]);r=d,s=wb(x[e>>2]),x[r+56>>2]=s;e=wb(x[e+4>>2]);j:{while(1){f=x[d+56>>2];if(!Ib(f,e)){e=0;if(!BW(Xb(x[a+484360>>2],y[a+484376|0]))){break b}j=c&2;n=a+946304|0;o=a+484380|0;k=d+57|0;e=1;break j}x[31609]=0;g=R(197,b|0)|0;i=x[31609];x[31609]=0;k:{if((i|0)==1){break k}w[f>>1]=g;x[31609]=0;P(183,b|0,4)|0;f=x[31609];x[31609]=0;if((f|0)==1){break k}ge(d+56|0);continue}break}b=N()|0;break c}l:{m:{n:{o:{while(1){g=e&65535;if(g>>>0>(y[d+210|0]|y[d+211|0]<<8)>>>0){break l}f=ac(x[m>>2],g-1|0);f=y[f|0]|y[f+1|0]<<8;x[31609]=0;f=P(149,b|0,f<<4)|0;i=x[31609];x[31609]=0;p:{if((i|0)!=1){if(f){break p}e=0;break b}b=N()|0;break c}x[31609]=0;i=d+56|0;P(698,b|0,i|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break o}x[31609]=0;l=o+D(g,104)|0;S(699,i|0,l|0,0);f=x[31609];x[31609]=0;if((f|0)==1){break o}q=d+28|0;Lk(q,2,k);x[31609]=0;f=d+40|0;O(218,f|0,q|0);q=x[31609];x[31609]=0;if((q|0)==1){break n}Ac(n+(g<<5)|0,f);tb(f);q:{r:{if(!j|!(y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24))){break r}g=NW(i);x[31609]=0;g=P(149,b|0,g|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break m}if(!g){break r}MW(f,y[d+86|0],y[d+87|0],1);x[31609]=0;U(215,f|0,l|0,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break q}}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}v[d+27|0]=1;n=0;e=x[h>>2];s:{if(mc(e,x[h+4>>2])|(y[d+188|0]|y[d+189|0]<<8)==26){break s}f=y[e|0]|y[e+1|0]<<8;e=0;x[31609]=0;f=P(149,b|0,f<<4)|0;g=x[31609];x[31609]=0;if((g|0)==1){break h}if(!f){break b}x[31609]=0;e=R(189,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break h}if((y[d+188|0]|y[d+189|0]<<8)!=(e|0)){break s}v[d+27|0]=0;n=1}o=c&1;if(o){x[31609]=0;O(223,a+484344|0,y[d+208|0]|y[d+209|0]<<8);c=x[31609];x[31609]=0;if((c|0)==1){break h}}i=a+484344|0;f=0;while(1){t:{if(!o|(y[d+208|0]|y[d+209|0]<<8)>>>0<=f>>>0){break t}x[31609]=0;c=U(196,i|0,f&65535,64)|0;e=x[31609];x[31609]=0;if((e|0)==1){break g}if(!c){break t}c=ac(x[h>>2],f);c=y[c|0]|y[c+1|0]<<8;x[31609]=0;c=P(149,b|0,c<<4)|0;e=x[31609];x[31609]=0;if((e|0)==1){break g}e=0;if(!c){break b}if(n){x[31609]=0;c=R(189,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}w[d+12>>1]=65535;x[d+28>>2]=63;c=Wb(x[i>>2],f);af(d+40|0,x[c>>2],x[x[c+48>>2]+12>>2],0);u:while(1){c=e;while(1){if(c>>>0<=63){x[31609]=0;e=R(197,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break f}j=e<<24>>24;if(!j){e=64;if((c|0)==63){continue u}e=Wb(x[i>>2],f);g=x[e>>2];j=x[x[e+48>>2]+12>>2];e=c+1|0;af(d+56|0,g,j,e);c=x[d+60>>2];x[d+40>>2]=x[d+56>>2];x[d+44>>2]=c;continue u}e=Ng(d+56|0);g=j&31;if(g>>>0<z[a+480188>>1]){e=Yc(x[d+40>>2],g)}k=j&255;if(k&32){x[31609]=0;g=d+25|0;O(198,g|0,b|0);l=x[31609];x[31609]=0;v:{w:{x:{if((l|0)!=1){l=Jc(g);g=y[d+25|0];if(g>>>0>239){break x}g=LW((D(g>>>4|0,12)+(g&15)|0)+37|0);break w}b=N()|0;break c}y:{switch(g-254|0){case 0:break w;case 1:break y;default:break v}}g=0}v[e|0]=g}v[e+1|0]=y[l|0]}if(k&64){x[31609]=0;g=R(197,b|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break e}v[d+25|0]=g;v[e+2|0]=1;v[d+24|0]=64;r=e,s=y[Qb(d+25|0,d+24|0)|0],v[r+4|0]=s}if((j|0)>=0){continue}x[31609]=0;g=d+25|0;O(198,g|0,b|0);j=x[31609];x[31609]=0;if((j|0)==1){break d}r=e,s=y[Jc(g)|0],v[r+5|0]=s;AW(e,y[d+25|0],c,255,d+12|0,d+28|0);continue}break}break}c=z[d+12>>1];if((c|0)!=65535){Ae(Wb(x[i>>2],f),An(We(Oe(d+56|0,12,c&255),x[d+28>>2])))}f=f+1|0;continue}break}x[31609]=0;b=P(1,d+56|0,6088)|0;c=x[31609];x[31609]=0;z:{A:{B:{if((c|0)!=1){zb(a+1298344|0,b);tb(b);x[31609]=0;b=P(1,d+40|0,5274)|0;c=x[31609];x[31609]=0;if((c|0)==1){break B}zb(a+1298356|0,b);tb(b);b=d+28|0;r=a,s=x[Fc(b,4)>>2],x[r+1298404>>2]=s;x[31609]=0;c=d+12|0;O(701,c|0,4405);e=x[31609];x[31609]=0;if((e|0)==1){break A}x[31609]=0;S(209,b|0,c|0,d+27|0);e=x[31609];x[31609]=0;if((e|0)==1){break z}zb(a+1298368|0,b);tb(b);Eb(c);e=1;break b}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;Eb(d+12|0);break c}b=N()|0;break c}}else{h=f+(e<<5)|0;Ve(h);w[h+4>>1]=e&1?64:192;e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}od(m);od(h);Q(b|0);p()}od(m);od(h)}fb=d+224|0;return e|0}function Tpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0;d=fb-1824|0;fb=d;yc(b);e=fb-16|0;fb=e;f=d+1224|0;QX(e+8|0,f);j=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);k=x[e+4>>2];if((k|0)==(j|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(j|0)==(k|0);if(!e){PX(f)}a:{if(!e){break a}if(!SX(f)){break a}if(!VC(b,16,0)){break a}e=d+1240|0;x[d+1216>>2]=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=y[d+1228|0]|y[d+1229|0]<<8|(y[d+1230|0]<<16|y[d+1231|0]<<24);x[d+1200>>2]=y[d+1224|0]|y[d+1225|0]<<8|(y[d+1226|0]<<16|y[d+1227|0]<<24);x[d+1204>>2]=e;e=d+1232|0;f=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);e=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);x[d+1208>>2]=f;x[d+1212>>2]=e;Dd(a,1);Lb(Lb(bg(a+1074312|0,83),84,1),85,1);w[a+480188>>1]=4;x[d+1196>>2]=0;w[a+480190>>1]=15;dd(b,20);k=a+946304|0;s=a+484380|0;m=a+480188|0;g=1;j=1;b:{while(1){c:{if((g|0)==16){e=d+1064|0;if(!RC(b,e)){MC(e)}ow(Xb(x[a+484360>>2],y[a+484376|0]),d+1066|0,128);m=YX(b,Xb(x[a+484360>>2],y[a+484376|0]),y[d+1064|0],i,m,0,1);if(!(y[d+1065|0]|m>>>0>1)){g=0;if(!y[d+1064|0]){break a}}e=(m<<10)+i|0;x[d+1060>>2]=e;x[d+24>>2]=65536;g=0;if(!Mb(x[b>>2],x[b+8>>2],e-x[Hb(d+1060|0,d+24|0)>>2]|0)){break a}g=1;if((c|0)==64){break a}g=y[d+1065|0];if(!g){v[d+1065|0]=120;g=120}if(jd(d+1200|0,15025,6)){break c}v[d+1065|0]=120;x[a+480204>>2]=125e4;break b}e=d+24|0;OC(b,e);h=e;e=D(g,104)+s|0;f=k+(g<<5)|0;XC(h,e,f,1);l=x[e>>2];d:{if(!y[xb(f,0)|0]){break d}e:{if(jd(f,16808,3)){if(jd(f,16812,3)){break e}}if(y[xb(f,5)|0]==58){break d}}j=0}f=Bb(y[d+52|0]|y[d+53|0]<<8);if(f>>>0>=2){h=Bb(y[d+50|0]|y[d+51|0]<<8);x[e+4>>2]=h;x[e+8>>2]=h+(f<<1);Uk(e)}f:{if(Bb(y[d+46|0]|y[d+47|0]<<8)>>>0<=4999){if(Bb(y[d+50|0]|y[d+51|0]<<8)>>>0<1e4){break f}}x[d+1064>>2]=5;u=d,z=x[Ye(d+1196|0,d+1064|0)>>2],x[u+1196>>2]=z}i=i+l|0;g=g+1|0;continue}break}x[a+480204>>2]=125e4;if((g|0)==120){break b}u=a,z=Te(1773447.5/(+(240-g|0)*122)*1e4),x[u+480204>>2]=z;if(x[d+1196>>2]>=2){x[d+24>>2]=j&1?4:5;u=d,z=x[Ye(d+1196|0,d+24|0)>>2],x[u+1196>>2]=z;break b}x[d+24>>2]=j&1?1:2;u=d,z=x[Ye(d+1196|0,d+24|0)>>2],x[u+1196>>2]=z}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;f=d+1048|0;pi(f,3,d+1200|0);e=d+24|0;Cc(e,f);zb(a+1298308|0,e);tb(e);Uh(a,0);f=j&1;r=x[b+8>>2];while(1){g:{if(m>>>0>(n&65535)>>>0){e=Xb(x[a+484360>>2],y[a+484376|0]);e=Ib(NC(wb(x[e>>2]),wb(x[e+4>>2]),n),wb(x[e+4>>2]));g=d+24|0;NX(b,g);h:{if(e){p=TC(g,0)+p|0;if(p>>>0>512){break h}}j=0;e=x[d+1196>>2];i=0;k=0;i:while(1){if((k|0)==64){break g}g=0;t=Yd(d+24|0,k);while(1)if((g|0)==4){k=k+1|0;continue i}else{h=yb(t,g);o=y[xb(h,2)|0]&15;l=y[xb(h,3)|0];j:{if(!(!(i&255)|(y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24)))){i=i+1|0;if((i&255)>>>0<33){break j}e=6;x[d+1196>>2]=6;break j}i=0}k:{l:{m:{n:{switch(o-1|0){case 0:case 1:if((e|0)==1&l>>>0>=32){break l}h=(o|0)!=1;if(!(h|!l|l>>>0>2)){x[d+1048>>2]=2;e=x[Ye(d+1196|0,d+1048|0)>>2];break m}if(h|(l|0)!=55&(l|0)!=71){break k}if((e|0)<=2){break l}break k;case 10:e=6;break m;case 11:case 12:case 13:x[d+1048>>2]=2;e=x[Ye(d+1196|0,d+1048|0)>>2];x[d+1196>>2]=e;if((o|0)!=13){break k}j=((k|l)!=0)+j|0;i=1;break k;case 14:break n;default:break k}}x[d+1048>>2]=3;e=x[Ye(d+1196|0,d+1048|0)>>2]}x[d+1196>>2]=e;break k}x[d+1196>>2]=f;e=f}g=g+1|0;continue}}}g=0;break a}if(!(x[d+1196>>2]!=6|m+32>>>0>=q>>>0)){x[d+1196>>2]=5}dd(b,r);o=c&1;if(o){Tf(a+484344|0,m)}n=a+484344|0;j=0;while(1)if((j|0)==(m|0)){g=22292;e=x[d+1196>>2];if(e>>>0<7){g=x[(e<<2)+25292>>2]}e=d+24|0;f=uc(e,8304);zb(a+1298344|0,f);tb(f);f=uc(e,10801);zb(a+1298356|0,f);tb(f);Zh(a+1298368|0,g);u=a,z=x[Fc(e,28)>>2],x[u+1298404>>2]=z;g=1;if(!(c&2)){break a}while(1)if((g|0)==16){g=1;break a}else{a=D(g,104)+s|0;Vb(b,x[a+4>>2]);c=x[a+4>>2];x[a+4>>2]=0;x[a>>2]=x[a>>2]-c;x[a+8>>2]=x[a+8>>2]-c;c=d+24|0;Zc(c,8,1,1,0);dg(c,a,b);g=g+1|0;continue}}else{NX(b,d+24|0);o:{if(!o){break o}if(!Pg(n,j&65535,64)){break o}k=0;x[d+20>>2]=0;p:while(1){if((k|0)==64){break o}e=Wb(x[n>>2],j);af(d+1048|0,x[e>>2],x[x[e+48>>2]+12>>2],k);g=0;q=Yd(d+24|0,k);while(1)if((g|0)==4){k=k+1|0;continue p}else{e=Yc(x[d+1048>>2],g);f=yb(q,g);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[d+8>>2]=f;x[d+12>>2]=f;f=d+18|0;ep(f,d+8|0,e);l=(d+20|0)+g|0;i=y[d+18|0];f=Jc(f);h=y[f|0];q:{r:{if(!((i|0)!=14?h:0)){v[l|0]=0;if(i|h){break r}break q}h=y[l|0];if(!h){break r}p=h;r=h>>>4|0;h=h>>>0<16;v[e+4|0]=h?p:r;v[e+2|0]=h?4:3}s:{t:{u:{v:{w:{switch(i-12|0){case 1:i=x[d+1196>>2];if((i|0)!=6){v[d+18|0]=10;break u}v[f|0]=0;break v;case 0:v[f|0]=y[f|0]&127;break v;case 2:i=y[f|0];if(i>>>0<=1){h=14;if(x[d+1196>>2]>3){break t}}v[d+18|0]=10;v[l|0]=y[f|0];break v;case 3:break w;default:break v}}v[f|0]=y[f|0]&15}i=x[d+1196>>2]}if((i|0)<2){break s}i=y[f|0];h=y[d+18|0]}Cf(e,h,i&255);break q}f=y[f|0];v[e+5|0]=f;x:{y:{z:{switch(y[d+18|0]){case 0:if(f>>>0>2){break y}break;case 2:break x;case 1:break y;default:break z}}v[e+3|0]=0;break q}v[e+3|0]=1;break q}i=f&15;if(i){v[e+5|0]=i;v[e+3|0]=2;break q}if(!f){break q}v[e+3|0]=3;v[e+5|0]=(f&240)>>>4}g=g+1|0;continue}}}j=j+1|0;continue}}if((j-1&255)>>>0<2){x[d+1196>>2]=6}n=n+1|0;q=(j&255)+q|0;continue}}fb=d+1824|0;return g|0}function isa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;d=fb-1344|0;fb=d;yc(b);f=fb-16|0;fb=f;e=d+768|0;MZ(f+8|0,e);l=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);h=x[f+4>>2];if((h|0)==(l|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(h|0)==(l|0);if(!f){LZ(e)}a:{b:{c:{if(!f){break c}if(!OZ(e)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(NZ(y[d+802|0]|y[d+803|0]<<8,y[d+804|0]|y[d+805|0]<<8),hb))){break c}t=1;if((c|0)==64){break c}l=a+480280|0;h=d+832|0;s=tc(d+764|0);f=0;while(1){t=(j|0)==32;if(!t){e=l+(j<<5)|0;Ve(e);g=h+(j<<4)|0;w[e+4>>1]=((y[g+14|0]<<8&65280)>>>0)/255;n=d+496|0;Lk(n,1,g);k=d+108|0;Cc(k,n);gm(e+9|0,k);tb(k);d:{e:{switch(y[g+15|0]){case 0:i=f+1|0;break d;case 1:x[e>>2]=1024;i=j+1|0;break d;case 2:break e;default:break c}}x[e>>2]=1024;e=d+108|0;Qc(e,s,j);bp(e)}f=f+1|0;j=j+1|0;continue}break}Dd(a,33554432);w[a+480188>>1]=i&255;f=d+108|0;e=uc(f,6808);zb(a+1298344|0,e);tb(e);e=uc(f,11156);zb(a+1298356|0,e);tb(e);B=a,C=x[Fc(f,4)>>2],x[B+1298404>>2]=C;f:{if(y[d+847|0]){break f}j=1;f=1;while(1){if((j|0)==16){while(1){if((f|0)==16){break f}e=l+(f<<5)|0;x[e>>2]=x[e>>2]&-1025;f=f+1|0;continue}}e=j<<4;j=j+1|0;if(y[(e+h|0)+15|0]==1){continue}break}}f=d+496|0;Ue(f,1,d+768|0);e=d+108|0;Cc(e,f);zb(a+1298308|0,e);tb(e);x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+806|0]|y[d+807|0]<<8)<<4&16;x[a+480196>>2]=y[d+816|0];x[a+480204>>2]=D(y[d+817|0],1e4);x[a+480200>>2]=y[d+818|0]<<2;x[a+480228>>2]=y[d+819|0];e=y[d+804|0]|y[d+805|0]<<8;w[a+480190>>1]=0;w[a+480192>>1]=e;Hw(b,f);Qr(Xb(x[a+484360>>2],y[a+484376|0]),f,y[d+800|0]|y[d+801|0]<<8,65535,255);q=c&1;if(q){Tf(a+484344|0,y[d+802|0]|y[d+803|0]<<8)}n=a+484344|0;l=0;g:{while(1){if((y[d+802|0]|y[d+803|0]<<8)>>>0<=l>>>0){k=c&2;s=a+946304|0;n=a+484380|0;f=1;l=0;h:while(1){if(z[a+480192>>1]<=(l&65535)>>>0){break c}l=l+1|0;c=DE(a,l&65535,0);h=!c;e=fb-16|0;fb=e;j=d+108|0;cc(e+8|0,j,384);i=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);g=x[e+4>>2];if((g|0)==(i|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(i|0);if(!e){Rb(j,0,384)}if(!e|h){continue}h=f&65535;i=fb-32|0;fb=i;g=i+8|0;Ue(g,1,j);e=i+20|0;Cc(e,g);Ac(c+492|0,e);tb(e);i:{if(!(y[j+378|0]|y[j+379|0]<<8)){break i}g=c+236|0;m=j+32|0;e=0;while(1){x[i+20>>2]=120;x[i+8>>2]=116;if(A[Hb(i+20|0,i+8|0)>>2]<=e>>>0){break i}B=ac(g,e+12|0),C=h+y[e+m|0]|0,w[B>>1]=C;e=e+1|0;continue}}e=y[j+376|0]|y[j+377|0]<<8;v[c+33|0]=1;x[c>>2]=e;FD(j,c+48|0,0);FD(j,c+68|0,1);FD(j,c+88|0,2);e=y[c+100|0];if(e&1){v[c+100|0]=e|16}if(!(x[c>>2]|v[c+60|0]&1)){x[c>>2]=32767}fb=i+32|0;j=0;while(1){c=y[d+486|0]|y[d+487|0]<<8;if(c>>>0<=j>>>0){f=c+f|0;continue h}h$(b,d+44|0);j:{c=f+j|0;g=c&65535;k:{if(g>>>0>=4e3){Vb(b,y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24));break k}w[a+480190>>1]=c;i=fb-32|0;fb=i;h=n+D(g,104)|0;c=h;nd(c,0);m=i+8|0;dk(m,1,d+44|0);e=i+20|0;Cc(e,m);Be(c+43|0,e);tb(e);m=y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24);x[c>>2]=m;o=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);x[c+4>>2]=o;q=y[d+68|0]|y[d+69|0]<<8|(y[d+70|0]<<16|y[d+71|0]<<24);x[c+8>>2]=q;x[c+24>>2]=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);w[c+30>>1]=y[d+76|0]<<2;w[c+28>>1]=y[d+77|0];e=y[d+92|0];if(e&1){w[c+34>>1]=z[c+34>>1]|2;e=y[d+92|0]}if(e&2){w[c+34>>1]=z[c+34>>1]|4;e=y[d+92|0]}if(e&4){x[c+8>>2]=q>>>1;x[c+4>>2]=o>>>1;x[c>>2]=m>>>1;w[c+34>>1]=z[c+34>>1]|1;e=y[d+92|0]}if(e&8){w[c+34>>1]=z[c+34>>1]|32}fb=i+32|0;c=fb-16|0;fb=c;Tw(c+8|0,h+43|0);e=d+24|0;zp(e,x[c+8>>2],x[c+12>>2]);fb=c+16|0;Ac(s+(g<<5)|0,e);tb(e);i=y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24);if(!i){break k}c=d+4|0;he(c,b,i);i=hc(e,c);ub(c);if(k){c=Zc(c,w[h+34>>1]&1?16:8,1,0,0);x[31609]=0;U(215,c|0,h|0,i|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break j}}ub(i)}j=j+1|0;continue}break}break}a=N()|0;break a}e=gh(b);m=gh(b);f=d+44|0;he(f,b,e-4|0);i=hc(d+108|0,f);ub(f);l:{m:{if(!q){break m}x[31609]=0;f=U(196,n|0,l&65535,m|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break l}if(!f){break m}e=0;j=Ng(d+24|0);n:while(1){u=e>>>0>=m>>>0;while(1){if(u){break m}x[31609]=0;h=R(197,i|0)|0;f=x[31609];x[31609]=0;o:{if((f|0)!=1){if(h){break o}e=e+1|0;continue n}break b}f=j;o=h&31;if(o>>>0<z[a+480188>>1]){f=Wb(x[n>>2],l);f=md(x[f>>2],x[x[f+48>>2]+12>>2],e,o)}if(h&32){x[31609]=0;k=d+44|0;O(198,k|0,i|0);g=x[31609];x[31609]=0;if((g|0)==1){break b}g=y[d+44|0];v[f|0]=g;B=f,C=y[Jc(k)|0],v[B+1|0]=C;k=255;p:{if((g|0)==160){break p}k=0;if((g|0)==255){break p}g=(D(g>>>4|0,12)+(g&15)|0)+13|0;k=KZ(g)?g:0}v[f|0]=k}h=h&192;q:{if(!h){break q}if((h|0)==192){x[31609]=0;h=d+44|0;O(357,h|0,i|0);g=x[31609];x[31609]=0;if((g|0)!=1){g=Jc(h);k=_e(h);h=Yi(h);r=d+4|0;GD(r,y[d+44|0],y[g|0]);g=Jc(r);r=d+494|0;GD(r,y[k|0],y[h|0]);em(d+492|0,f,y[d+4|0],y[g|0],y[d+494|0],y[Jc(r)|0]);break q}break b}x[31609]=0;h=d+44|0;O(198,h|0,i|0);g=x[31609];x[31609]=0;if((g|0)==1){break g}g=d+4|0;GD(g,y[d+44|0],y[Jc(h)|0]);g=y[Jc(g)|0];k=y[d+4|0];h=(k|0)==13;v[(h?2:3)+f|0]=h?1:k;v[(h?4:5)+f|0]=g}Qc(d+44|0,s,o);if(!Gb(x[x[d+44>>2]>>2],x[d+48>>2])){continue}if(!f0(y[f+3|0],y[f+5|0])){continue}v[f+3|0]=0;continue}}}ub(i);l=l+1|0;continue}break}break b}break b}fb=d+1344|0;return t|0}a=N()|0}ub(i);Q(a|0);p()}function sL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0;j=fb-80|0;fb=j;x[j+76>>2]=b;E=j+55|0;r=j+56|0;a:{b:{c:{d:{e:while(1){h=0;f:while(1){k=b;if((o^2147483647)<(h|0)){break d}o=h+o|0;g:{h:{i:{h=b;i=y[h|0];if(i){while(1){j:{b=i&255;k:{if(!b){b=h;break k}if((b|0)!=37){break j}i=h;while(1){if(y[i+1|0]!=37){b=i;break k}h=h+1|0;m=y[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;B=o^2147483647;if((h|0)>(B|0)){break d}if(a){Kf(a,k,h)}if(h){continue f}x[j+76>>2]=b;h=b+1|0;q=-1;m=v[b+1|0]-48|0;if(!(y[b+2|0]!=36|m>>>0>9)){s=1;q=m;h=b+3|0}x[j+76>>2]=h;n=0;i=v[h|0];b=i-32|0;l:{if(b>>>0>31){m=h;break l}m=h;b=1<<b;if(!(b&75913)){break l}while(1){m=h+1|0;x[j+76>>2]=m;n=b|n;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break l}h=m;b=1<<b;if(b&75913){continue}break}}m:{if((i|0)==42){b=v[m+1|0]-48|0;n:{if(!(y[m+2|0]!=36|b>>>0>9)){o:{if(!a){x[(b<<2)+e>>2]=10;p=0;break o}p=x[(b<<3)+d>>2]}b=m+3|0;s=1;break n}if(s){break i}b=m+1|0;if(!a){x[j+76>>2]=b;s=0;p=0;break m}h=x[c>>2];x[c>>2]=h+4;p=x[h>>2];s=0}x[j+76>>2]=b;if((p|0)>=0){break m}p=0-p|0;n=n|8192;break m}p=rL(j+76|0);if((p|0)<0){break d}b=x[j+76>>2]}h=0;l=-1;i=0;p:{if(y[b|0]!=46){break p}if(y[b+1|0]==42){m=v[b+2|0]-48|0;q:{if(!(y[b+3|0]!=36|m>>>0>9)){b=b+4|0;r:{if(!a){x[(m<<2)+e>>2]=10;l=0;break r}l=x[(m<<3)+d>>2]}break q}if(s){break i}b=b+2|0;l=0;if(!a){break q}m=x[c>>2];x[c>>2]=m+4;l=x[m>>2]}x[j+76>>2]=b;i=(l|0)>=0;break p}x[j+76>>2]=b+1;l=rL(j+76|0);b=x[j+76>>2];i=1}u=i;while(1){t=h;m=28;z=b;i=v[b|0];if(i-123>>>0<4294967238){break c}b=b+1|0;h=y[(i+D(h,58)|0)+92703|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;s:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){if(!a){x[(q<<2)+e>>2]=h;continue e}h=(q<<3)+d|0;m=x[h+4>>2];x[j+64>>2]=x[h>>2];x[j+68>>2]=m;break s}if(!a){break g}qL(j- -64|0,h,c,g);break s}if((q|0)>=0){break c}h=0;if(!a){continue f}}if(y[a|0]&32){break b}i=n&-65537;n=n&8192?i:n;q=0;A=5286;m=r;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{h=v[z|0];h=t?(h&15)==3?h&-45:h:h;switch(h-88|0){case 11:break t;case 9:case 13:case 14:case 15:break u;case 27:break z;case 12:case 17:break C;case 23:break D;case 0:case 32:break E;case 24:break F;case 22:break G;case 29:break H;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break h;default:break I}}J:{switch(h-65|0){case 0:case 4:case 5:case 6:break u;case 2:break x;case 1:case 3:break h;default:break J}}if((h|0)==83){break y}break h}k=x[j+64>>2];i=x[j+68>>2];b=5286;break B}h=0;K:{switch(t&255){case 0:x[x[j+64>>2]>>2]=o;continue f;case 1:x[x[j+64>>2]>>2]=o;continue f;case 2:k=x[j+64>>2];x[k>>2]=o;x[k+4>>2]=o>>31;continue f;case 3:w[x[j+64>>2]>>1]=o;continue f;case 4:v[x[j+64>>2]]=o;continue f;case 6:x[x[j+64>>2]>>2]=o;continue f;case 7:break K;default:continue f}}k=x[j+64>>2];x[k>>2]=o;x[k+4>>2]=o>>31;continue f}l=l>>>0<=8?8:l;n=n|8;h=120}b=r;z=h&32;k=x[j+64>>2];i=x[j+68>>2];if(k|i){while(1){b=b-1|0;v[b|0]=z|y[(k&15)+93232|0];F=!i&k>>>0>15|(i|0)!=0;t=i;i=i>>>4|0;k=(t&15)<<28|k>>>4;if(F){continue}break}}k=b;if(!(n&8)|!(x[j+64>>2]|x[j+68>>2])){break A}A=(h>>>4|0)+5286|0;q=2;break A}b=r;h=x[j+68>>2];i=h;k=x[j+64>>2];if(h|k){while(1){b=b-1|0;v[b|0]=k&7|48;t=!i&k>>>0>7|(i|0)!=0;h=i;i=h>>>3|0;k=(h&7)<<29|k>>>3;if(t){continue}break}}k=b;if(!(n&8)){break A}b=r-b|0;l=(b|0)<(l|0)?l:b+1|0;break A}k=x[j+64>>2];b=x[j+68>>2];i=b;if((b|0)<0){h=0-(b+((k|0)!=0)|0)|0;i=h;k=0-k|0;x[j+64>>2]=k;x[j+68>>2]=h;q=1;b=5286;break B}if(n&2048){q=1;b=5287;break B}q=n&1;b=q?5288:5286}A=b;k=lo(k,i,r)}if((l|0)<0&u){break d}n=u?n&-65537:n;b=x[j+64>>2];h=x[j+68>>2];if(!((b|h)!=0|l)){k=r;l=0;break h}b=!(b|h)+(r-k|0)|0;l=(b|0)<(l|0)?l:b;break h}b=x[j+64>>2];k=b?b:17107;b=l>>>0>=2147483647?2147483647:l;h=Mz(k,0,b);b=h?h-k|0:b;m=b+k|0;if((l|0)>=0){n=i;l=b;break h}n=i;l=b;if(y[m|0]){break d}break h}if(l){i=x[j+64>>2];break w}h=0;Wf(a,32,p,0,n);break v}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;while(1){L:{k=x[i>>2];if(!k){break L}k=Kt(j+4|0,k);if((k|0)<0){break b}if(k>>>0>l-h>>>0){break L}i=i+4|0;h=h+k|0;if(l>>>0>h>>>0){continue}}break}m=61;if((h|0)<0){break c}Wf(a,32,p,h,n);if(!h){h=0;break v}m=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break v}l=j+4|0;k=Kt(l,k);m=k+m|0;if(m>>>0>h>>>0){break v}Kf(a,l,k);i=i+4|0;if(h>>>0>m>>>0){continue}break}}Wf(a,32,p,h,n^8192);h=(h|0)<(p|0)?p:h;continue f}if((l|0)<0&u){break d}m=61;h=ib[f|0](a,C[j+64>>3],p,l,n,h)|0;if((h|0)>=0){continue f}break c}v[j+55|0]=x[j+64>>2];l=1;k=E;n=i;break h}i=y[h+1|0];h=h+1|0;continue}}if(a){break a}if(!s){break g}h=1;while(1){a=x[(h<<2)+e>>2];if(a){qL((h<<3)+d|0,a,c,g);o=1;h=h+1|0;if((h|0)!=10){continue}break a}break}o=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break i}h=h+1|0;if((h|0)!=10){continue}break}break a}m=28;break c}i=m-k|0;l=(i|0)<(l|0)?l:i;if((l|0)>(q^2147483647)){break d}m=61;b=l+q|0;h=(b|0)<(p|0)?p:b;if((B|0)<(h|0)){break c}Wf(a,32,h,b,n);Kf(a,A,q);Wf(a,48,h,b,n^65536);Wf(a,48,l,i,0);Kf(a,k,i);Wf(a,32,h,b,n^8192);b=x[j+76>>2];continue}break}break}o=0;break a}m=61}x[31484]=m}o=-1}fb=j+80|0;return o}function Mra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;g=fb-192|0;fb=g;n=ak(b,13935);if(n){if(d){v[d|0]=1}k=a+480204|0;o=a+480216|0;q=a+480220|0;r=a+480224|0;l=a+1074368|0;t=a+480228|0;u=a+480232|0;s=a+480200|0;m=a+480268|0;B=a+1298320|0;C=a+480280|0;E=a+484380|0;F=a+480248|0;G=Uv(a+1074312|0);a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Mb(x[b>>2],x[b+8>>2],7)){break a}e=Rg(b);f=gh(b);if((e|0)==70791730){Ih(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Mb(x[b>>2],x[b+8>>2],f)){break a}i=g+152|0;he(i,b,f);h=hc(g+172|0,i);ub(i);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=u;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=o;if((e|0)==1380991534){break s}d=q;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=t;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}x[31609]=0;S(451,h|0,f|0,i|0);d=x[31609];x[31609]=0;if((d|0)==1){break i}x[k>>2]=D(x[g+152>>2],1e4)+(A[k>>2]%1e4|0);break j}x[31609]=0;S(451,h|0,f|0,g+152|0);d=x[31609];x[31609]=0;if((d|0)!=1){d=x[k>>2];x[k>>2]=d-((d>>>0)%1e4|0)+A[g+152>>2]%1e4;break j}e=N()|0;break b}if(c){break j}x[31609]=0;w[g+152>>1]=0;S(452,h|0,f|0,g+152|0);d=x[31609];x[31609]=0;if((d|0)!=1){H=a,I=Ld(z[g+152>>1],z[a+480188>>1],127),w[H+480188>>1]=I;break j}e=N()|0;break b}x[31609]=0;S(453,h|0,f|0,l|0);d=x[31609];x[31609]=0;if((d|0)!=1){break j}break c}x[31609]=0;x[g+152>>2]=0;S(451,h|0,f|0,g+152|0);d=x[31609];x[31609]=0;if((d|0)!=1){x[a+1074304>>2]=x[g+152>>2];break j}e=N()|0;break b}x[31609]=0;x[g+152>>2]=0;S(451,h|0,f|0,g+152|0);d=x[31609];x[31609]=0;if((d|0)==1){break h}d=x[g+152>>2];if(!d){break j}x[a+1074308>>2]=d;break j}d=s}x[31609]=0;S(451,h|0,f|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}break j}if(x[a+480180>>2]==4){break j}x[31609]=0;S(452,h|0,f|0,g+152|0);d=x[31609];x[31609]=0;if((d|0)!=1){$e(Xb(x[a+484360>>2],y[a+484376|0]),z[g+152>>1]);break j}e=N()|0;break b}x[31609]=0;S(454,h|0,f|0,m|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}if(up(y[m|0])){break j}v[m|0]=5;break j}d=Fb(g+152|0);e=x[h>>2];x[31609]=0;e=R(154,e|0)|0;f=x[31609];x[31609]=0;x:{if((f|0)==1){break x}x[31609]=0;S(455,h|0,d|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break x}x[31609]=0;e=g+140|0;S(258,e|0,0,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break x}zb(B,e);tb(e);tb(d);break j}e=N()|0;tb(d);break b}if(f&1|f>>>0>126){break j}d=64;w[g+152>>1]=f>>>1|64;w[g+140>>1]=127;e=z[Oc(g+152|0,g+140|0)>>1];i=e>>>0<=64?64:e;while(1){if((d|0)==(i|0)){break j}x[31609]=0;e=g+152|0;O(198,e|0,h|0);f=x[31609];x[31609]=0;if((f|0)==1){break g}f=y[g+152|0];y:{if((f|0)==255){break y}j=y[Jc(e)|0];e=(d<<5)+C|0;w[e+4>>1]=128;w[e+6>>1]=j;j=(f&128)<<3;x[e>>2]=j;f=f&127;if(f>>>0<65){w[e+4>>1]=f<<2;break y}if((f|0)!=100){break y}x[e>>2]=j|256}d=d+1|0;continue}}if(f>>>0<3){break j}x[31609]=0;d=R(189,h|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break f}if(z[a+480190>>1]<=(d-1&65535)>>>0){break j}d=(D(d,104)+E|0)+68|0;f=BZ(d);while(1){if((d|0)==(f|0)){break j}e=x[h>>2];x[31609]=0;i=U(150,e|0,x[g+180>>2],4)|0;e=x[31609];x[31609]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}x[31609]=0;e=R(151,h|0)|0;i=x[31609];x[31609]=0;if((i|0)!=1){break z}}e=N()|0;break b}x[d>>2]=e;d=d+4|0;continue}}if(f>>>0<3){break j}x[31609]=0;f=g+140|0;O(456,f|0,h|0);d=x[31609];x[31609]=0;A:{B:{C:{D:{if((d|0)!=1){x[31609]=0;e=g+152|0;S(457,e|0,x[g+140>>2],x[g+144>>2]);d=x[31609];x[31609]=0;if((d|0)==1){break D}x[31609]=0;d=P(103,g|0,e|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break C}tb(e);fc(f);e=x[h>>2];x[31609]=0;R(154,e|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break A}x[31609]=0;S(458,d|0,F|0,d|0);e=x[31609];x[31609]=0;if((e|0)==1){break A}Gf(d);break j}e=N()|0;break b}e=N()|0;break B}e=N()|0;tb(g+152|0)}fc(g+140|0);break b}e=N()|0;Gf(d);break b}e=0;f=Uv(G);E:while(1){d=x[h>>2];x[31609]=0;d=U(150,d|0,x[g+180>>2],1)|0;i=x[31609];x[31609]=0;if((i|0)==1){break d}if(!(e>>>0<122&d)){break j}x[31609]=0;i=R(197,h|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>121){break F}x[31609]=0;U(266,f|0,e|0,1)|0;j=x[31609];x[31609]=0;if((j|0)!=1){break F}e=N()|0;break b}e=e+1|0;d=d+1|0;continue}}}x[31609]=0;S(459,h|0,f|0,r|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}}ub(h);continue}break}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0}ub(h);Q(e|0);p()}b=x[a+8>>2];Fp(k,D(x[b+20>>2],1e4),D(x[b+24>>2],1e4));if(y[a+480224|0]>=3){v[r|0]=0}if(y[l|0]>=6){v[l|0]=0}xc(s,256);xc(o,65536);xc(q,65536)}fb=g+192|0;return n|0}function Hoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-352|0;fb=d;a:{b:{c:{if(!dd(b,60)){break c}e=d+332|0;if(!Mp(b,e)){break c}f=15;if(yv(e,15)){break b}}e=0;if(!dd(b,124)){break a}g=d+332|0;if(!Mp(b,g)){break a}f=31;if(!yv(g,31)){break a}}Dd(a,536870912);w[a+480190>>1]=f;yc(b);e=0;d:{while(1){if(z[a+480190>>1]>e>>>0){g=op(b);x[(d+208|0)+(e<<2)>>2]=g;e=e+1|0;if(g>>>0<=131072){continue}break d}break}Vb(b,20);f=0;w[a+480192>>1]=0;w[a+480188>>1]=4;e=y[d+336|0]|y[d+337|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;q=a,r=Te(1776930/+(Bb(e)>>>0)*1e4),x[q+480204>>2]=r;x[a+480228>>2]=64;Uh(a,1);n=a+946304|0;o=a+484380|0;m=1;e:while(1){l=m&65535;if(l>>>0<=z[a+480190>>1]){OC(b,d+52|0);e=x[((l<<2)+d|0)+204>>2];h=fb-16|0;fb=h;i=D(l,104)+o|0;nd(i,1);x[i>>2]=e;v[i+37|0]=y[d+76|0]<<4;v[h+15|0]=y[d+77|0];v[h+14|0]=64;q=i,r=y[Qb(h+15|0,h+14|0)|0]<<2,w[q+30>>1]=r;f:{if(!e){break f}g=Bb(y[d+80|0]|y[d+81|0]<<8);k=Bb(y[d+78|0]|y[d+79|0]<<8);x[i+4>>2]=k;g=(g<<1)+k|0;x[i+8>>2]=g;if(e>>>0<=k>>>0){k=e-1|0;x[i+4>>2]=k}if(e>>>0<g>>>0){x[i+8>>2]=e;g=e}if(!(!(g>>>0<4|g>>>0<k>>>0)&g-k>>>0>3)){x[i+4>>2]=0;x[i+8>>2]=0;break f}if(g>>>0<=k>>>0){break f}w[i+34>>1]=z[i+34>>1]|2}fb=h+16|0;e=0;while(1)if((e|0)==22){if(f>>>0>=128){break d}g=d+184|0;Rk(g,3,d+52|0);e=d+196|0;Cc(e,g);Ac(n+(l<<5)|0,e);m=m+1|0;tb(e);continue e}else{g=(d+52|0)+e|0;if((y[g|0]-1&255)>>>0<=30){v[g|0]=32;f=f+1|0}e=e+1|0;continue}}break}m=1;g:{h:{f=a+946336|0;e=Dc(d+52|0,14097);if(!HW(f,e)){x[31609]=0;g=P(36,d+196|0,14108)|0;i=x[31609];x[31609]=0;if((i|0)==1){break h}m=HW(f,g);tb(g)}tb(e);e=0;g=d+52|0;f=RC(b,g);if(!f){MC(g)}if(!f){break a}g=y[d+52|0];if(!JW(g)){break a}e=1;if((c|0)==64){break a}e=0;w[d+50>>1]=0;f=d+54|0;while(1)if((e|0)==(g|0)){h=Xb(x[a+484360>>2],y[a+484376|0]);e=y[d+53|0];$e(h,e>>>0<g>>>0?e:0);Jw(Xb(x[a+484360>>2],y[a+484376|0]),f,y[d+52|0],65535,65535);if(z[a+480190>>1]==31){Vb(b,4)}x[d+44>>2]=0;x[d+40>>2]=0;x[d+36>>2]=0;v[d+35|0]=0;n=c&1;if(n){Tf(a+484344|0,z[d+50>>1])}l=a+484344|0;i=0;while(1){i:{j:{k:{if(z[d+50>>1]<=i>>>0){if(!(c&2)){break k}e=1;while(1){f=z[a+480190>>1];c=e&65535;if(f>>>0<c>>>0){break j}c=D(c,104)+o|0;if(x[c>>2]){dg(Zc(d+184|0,8,1,0,0),c,b)}e=e+1|0;continue}}l:{if(n){k=0;if(Pg(l,i&65535,64)){break l}}Vb(b,1024);break i}m:while(1){if((k|0)==64){break i}e=Wb(x[l>>2],i);af(d+184|0,x[e>>2],x[x[e+48>>2]+12>>2],k);e=0;while(1)if((e|0)==4){k=k+1|0;continue m}else{g=Yc(x[d+184>>2],e);f=d+12|0;lm(f,b);n:{o:{p:{q:{if(y[xb(f,0)|0]!=255){break q}v[(d+44|0)+e|0]=0;v[(d+36|0)+e|0]=0;f=xb(f,1);h=y[f|0];if((h|0)==252&m){v[f|0]=254;break o}switch(h-252|0){case 1:break n;case 2:break o;case 0:break p;default:break q}}f=x[d+12>>2];x[d+28>>2]=f;x[d+8>>2]=f;f=d+33|0;ep(f,d+8|0,g);h=Jc(f);f=y[g|0];r:{if(!f){break r}v[(d+36|0)+e|0]=0;v[(d+44|0)+e|0]=f;if(f>>>0>48){break r}v[d+27|0]=8;q=d,r=y[cf(d+35|0,d+27|0)|0],v[q+35|0]=r}j=y[d+33|0];f=y[h|0];s:{if(j|f){v[g+5|0]=f;t:{u:{v:{switch(j-1|0){case 0:v[g+3|0]=1;break n;case 1:if(f>>>0>=16){v[g+3|0]=3;v[g+5|0]=(f&240)>>>4;break n}if(!f){break u}v[g+5|0]=f;v[g+3|0]=2;break n;case 2:if(y[(d+36|0)+e|0]){break u}v[g+5|0]=0;v[g+3|0]=19;break n;case 3:if(y[(d+36|0)+e|0]){break u}v[g+5|0]=1;v[g+3|0]=19;break n;case 4:h=y[g+1|0];if(!h){break u}v[d+27|0]=63;v[d+26|0]=f+(z[(D(h,104)+o|0)+30>>1]>>>2|0);f=y[Qb(d+27|0,d+26|0)|0];v[g+5|0]=f;v[g+3|0]=13;if(!y[(d+36|0)+e|0]){break n}h=g+3|0;v[g+4|0]=f;v[g+2|0]=1;break t;case 5:h=g+3|0;j=y[g+1|0];if(!j){break t}v[g+3|0]=13;j=z[(D(j,104)+o|0)+30>>1]>>>2|0;f=f>>>0<=j>>>0?j-f|0:0;v[g+5|0]=f;if(!y[(d+36|0)+e|0]){break n}v[g+4|0]=f;v[g+2|0]=1;break t;case 6:h=f&15;v[(d+36|0)+e|0]=h;j=y[(d+44|0)+e|0];f=j-((f&240)>>>4|0)|0;v[(d+40|0)+e|0]=f;q=g,r=GW(h,f&255,j),v[q+5|0]=r;v[g+3|0]=3;break n;case 7:h=f&15;v[(d+36|0)+e|0]=h;j=(f&240)>>>4|0;f=y[(d+44|0)+e|0];j=j+f|0;v[(d+40|0)+e|0]=j;q=g,r=GW(h,f,j&255),v[q+5|0]=r;v[g+3|0]=2;break n;case 8:break v;default:break u}}v[d+27|0]=8;q=d,r=y[cf(d+35|0,d+27|0)|0],v[q+35|0]=r}h=g+3|0}v[h|0]=0;break s}if(y[g+3|0]){break n}}h=y[(d+36|0)+e|0];if(!h){break n}j=(d+40|0)+e|0;f=y[j|0];if(f){v[(d+44|0)+e|0]=f;v[g+5|0]=h;v[g|0]=f;v[j|0]=0}v[g+3|0]=4;break n}v[g+3|0]=14;v[d+35|0]=9;break n}v[g+3|0]=13}e=e+1|0;continue}}}f=z[a+480190>>1]}w:{x:{if((f&65535)==15){b=d+12|0;gg(b,4418);x[31609]=0;S(209,d+184|0,b|0,d+35|0);c=x[31609];x[31609]=0;if((c|0)!=1){break x}f=N()|0;Eb(b);break g}x[31609]=0;P(1,d+184|0,12406)|0;b=x[31609];x[31609]=0;if((b|0)==1){break w}}b=d+184|0;zb(a+1298344|0,b);tb(b);if((f&65535)==15){Eb(d+12|0)}Zh(a+1298356|0,z[a+480190>>1]==15?5282:15209);q=a,r=x[Fc(d+184|0,28)>>2],x[q+1298404>>2]=r;e=1;break a}f=N()|0;break g}i=i+1|0;continue}}else{w[d+184>>1]=y[e+f|0]+1;q=d,r=z[qe(d+50|0,d+184|0)>>1],w[q+50>>1]=r;e=e+1|0;continue}}f=N()|0;tb(e)}Q(f|0);p()}e=0}fb=d+352|0;return e|0}function xpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0;f=fb-272|0;fb=f;yc(b);a:{b:{c:{e=f+206|0;if(!E$(b,e)){break c}if(!zX(e)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(yX(e),hb))){break c}d=1;if((c|0)==64){break c}Dd(a,16);e=f+44|0;pi(e,2,f+210|0);d=f- -64|0;Cc(d,e);zb(a+1298308|0,d);tb(d);w[a+480190>>1]=y[f+236|0];w[a+480188>>1]=y[f+239|0];g=uc(d,8365);zb(a+1298344|0,g);tb(g);g=uc(d,10145);zb(a+1298356|0,g);tb(g);gg(e,4211);g=y[f+209|0];x[f+24>>2]=g>>>4;x[31609]=0;x[f+12>>2]=g&15;V(307,d|0,e|0,f+24|0,f+12|0);g=x[31609];x[31609]=0;if((g|0)!=1){zb(a+1298368|0,d);tb(d);Eb(e);u=a,B=x[Fc(d,4)>>2],x[u+1298404>>2]=B;m=a+946304|0;o=a+484380|0;d=1;while(1){k=d&65535;if(k>>>0>z[a+480190>>1]){e=a+480280|0;g=f+240|0;d=0;while(1)if(z[a+480188>>1]<=d>>>0){e=f- -64|0;d=fb-16|0;fb=d;k=b;d:{if(!Mb(x[b>>2],x[b+8>>2],128)){b=0;while(1){if((b|0)!=128){dh(b+e|0);b=b+1|0;continue}break}break d}$Y(d+8|0,e);sd(d,k,x[d+8>>2],x[d+12>>2])}fb=d+16|0;Jw(Xb(x[a+484360>>2],y[a+484376|0]),e,y[f+233|0]+1|0,255,254);b=y[f+238|0];d=f+24|0;he(d,k,D(y[f+230|0]|y[f+231|0]<<8,192));m=hc(f+44|0,d);ub(d);e:{q=c&1;if(!q){break e}x[31609]=0;O(223,a+484344|0,y[f+232|0]+1|0);d=x[31609];x[31609]=0;if((d|0)!=1){break e}break b}r=b?b:64;s=a+484344|0;b=0;while(1){f:{g:{h:{if(y[f+232|0]<l>>>0){if(!(b&t)){break g}u=f,B=wb(x[a+484344>>2]),x[u+12>>2]=B;j=wb(x[a+484348>>2]);break h}i:{if(q){x[31609]=0;d=U(196,s|0,l&65535,r|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}n=0;if(d){break i}}x[31609]=0;P(183,k|0,64)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break f}break b}while(1){d=n&65535;if(d>>>0>31){break f}x[31609]=0;e=R(189,k|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}j:{if((e-1&65535)>>>0>=(y[f+230|0]|y[f+231|0]<<8)>>>0|d>>>0>=z[a+480188>>1]){break j}x[31609]=0;P(149,m|0,D(e,192)-192|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}e=0;g=Wb(x[s>>2],l);d=md(x[g>>2],x[x[g+48>>2]+12>>2],0,d);while(1){if((e|0)==(r|0)){break j}j=b;x[31609]=0;b=f+24|0;O(549,b|0,m|0);g=x[31609];x[31609]=0;k:{l:{m:{n:{o:{if((g|0)!=1){i=Jc(b);g=_e(b);b=y[f+24|0];if(b>>>0>=4){v[d|0]=(b>>>2|0)+37;b=y[f+24|0]}v[d+1|0]=b<<4&48|y[i|0]>>>4;b=v[g|0];h=0;g=0;p:{q:{i=y[i|0]&15;switch(i-8|0){case 0:break n;case 2:break p;case 6:break q;default:break o}}i=14;if(!(435>>>((b+16&240)>>>4)&1)|(b|0)<=-17){break m}break n}g=b&-16;b=g?g:b;i=10;break m}break b}h=i;g=b}b=g;i=h;if(!(b|h)){break l}}Cf(d,i,b&255);b=1;r:{switch(y[d+3|0]-16|0){case 0:break k;case 1:break r;default:break l}}t=1}b=j}e=e+1|0;d=D(z[a+480188>>1],6)+d|0;continue}}n=n+1|0;continue}}while(1){s:{b=x[f+12>>2];if(Ib(b,j)){h=0;t:while(1){if(A[b+12>>2]<=h>>>0){break s}af(f+24|0,x[b>>2],x[x[b+48>>2]+12>>2],h);u=f,B=wb(x[f+24>>2]),x[u+20>>2]=B;e=0;i=nw(x[f+24>>2],x[f+28>>2]);g=0;while(1){l=x[f+20>>2];if(Ib(l,i)){d=1;u:{switch(y[l+3|0]-16|0){case 1:g=1;default:d=e;break;case 0:break u}}tg(f+20|0);e=d;continue}else{h=h+1|0;if(!(e&g&1)){continue t}break g}}}}i=wb(x[a+484344>>2]);x[f+20>>2]=i;b=wb(x[a+484348>>2]);v:while(1){if(!Ib(i,b)){break g}e=0;w:while(1){if(A[i+12>>2]<=e>>>0){i=x[Ul(f+20|0)>>2];continue v}af(f+12|0,x[i>>2],x[x[i+48>>2]+12>>2],e);u=f,B=wb(x[f+12>>2]),x[u+8>>2]=B;d=nw(x[f+12>>2],x[f+16>>2]);while(1){x:{g=x[f+8>>2];if(Ib(g,d)){g=y[g+3|0];if((g&254)!=16){break x}d=(g|0)==16;Ae(i,We(Oe(f+24|0,d?17:16,d?125:6),e))}e=e+1|0;continue w}tg(f+8|0);continue}}}}Ul(f+12|0);continue}}y:{b=y[f+234|0]|y[f+235|0]<<8;if(!b){break y}x[31609]=0;aa(316,a+1298332|0,k|0,b|0,39,1);b=x[31609];x[31609]=0;if((b|0)!=1){break y}break b}z:{if(!(c&2)){break z}d=1;while(1){b=d&65535;if(b>>>0>z[a+480190>>1]){break z}b=D(b,104)+o|0;c=Zc(f+24|0,w[b+34>>1]&1?16:8,1,0,1);x[31609]=0;U(215,c|0,b|0,k|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){d=d+1|0;continue}break}break b}x[a+480260>>2]=64;x[a+480264>>2]=32767;ub(m);d=1;break c}l=l+1|0;continue}}else{h=e+(d<<5)|0;Ve(h);w[h+4>>1]=(y[d+g|0]<<4|8)&248;d=d+1|0;continue}}else{h=f- -64|0;fF(b,h);j=fb-16|0;fb=j;e=D(k,104)+o|0;nd(e,0);w[j+14>>1]=y[h+35|0]<<2;w[j+12>>1]=256;u=e,B=z[Oc(j+14|0,j+12|0)>>1],w[u+30>>1]=B;g=y[h+22|0]|y[h+23|0]<<8|(y[h+24|0]<<16|y[h+25|0]<<24);A:{if(g>>>0<3){break A}x[e>>2]=g;x[e+4>>2]=y[h+26|0]|y[h+27|0]<<8|(y[h+28|0]<<16|y[h+29|0]<<24);x[j+8>>2]=y[h+30|0]|y[h+31|0]<<8|(y[h+32|0]<<16|y[h+33|0]<<24);x[j+4>>2]=1;u=e,B=x[bd(j+8|0,j+4|0)>>2]-1|0,x[u+8>>2]=B;xc(e+8|0,g);i=x[e+8>>2];g=x[e+4>>2];B:{if(i>>>0<=g+4>>>0){x[e+4>>2]=0;x[e+8>>2]=0;i=0;g=0;break B}if(i>>>0<3){break B}w[e+34>>1]=z[e+34>>1]|2}n=v[h+34|0];v[e+37|0]=n;u=e,B=xw(0,n<<4),x[u+24>>2]=B;if(!(v[h+36|0]&1)){break A}x[e+8>>2]=i>>>1;x[e+4>>2]=g>>>1;w[e+34>>1]=z[e+34>>1]|1;x[e>>2]=x[e>>2]>>>1}fb=j+16|0;g=f+24|0;Rk(g,2,h);e=f+44|0;Cc(e,g);Ac(m+(k<<5)|0,e);d=d+1|0;tb(e);continue}}}d=N()|0;Eb(f+44|0);break a}fb=f+272|0;return d|0}d=N()|0;ub(m)}Q(d|0);p()}function UL(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0,k=E(0),l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=E(0),A=E(0),C=0,F=0,G=E(0),H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=E(0),O=0,P=0;F=(d|0)>0?d:0;while(1){if((t|0)!=(F|0)){q=D(t,2304)+b|0;u=0;s=(c|0)>0?c:0;h=fb-128|0;x=h+32|0;g=h+96|0;C=h- -64|0;while(1){if((s|0)!=(u|0)){n=q+(u<<2)|0;v=0;j=h;p=j;o=0;while(1){if((o|0)!=8){k=B[D(o^15,72)+n>>2];y=D(o,72)+n|0;i=B[y+1152>>2];l=E(k+i);m=B[y>>2];z=B[D(o^31,72)+n>>2];A=E(m+z);B[p>>2]=l+A;y=D(o,12);k=E(E(k-i)*B[y+87456>>2]);i=E(E(m-z)*B[y+87460>>2]);B[p+64>>2]=k+i;m=E(A-l);l=B[y+87464>>2];B[p+32>>2]=m*l;B[p+96>>2]=l*E(i-k);p=p+4|0;o=o+1|0;continue}break}while(1){if((v|0)!=4){l=B[j+8>>2];m=B[j+20>>2];i=E(l+m);z=B[j+4>>2];A=B[j+24>>2];G=E(z+A);k=E(i+G);H=B[j+12>>2];I=B[j+16>>2];J=E(H+I);K=B[j>>2];L=B[j+28>>2];M=E(K+L);N=E(J+M);B[j>>2]=k+N;B[j+16>>2]=E(N-k)*E(.7071067690849304);k=E(M-J);i=E(E(k+E(G-i))*E(.7071067690849304));B[j+24>>2]=E(k-i)*E(1.3065630197525024);B[j+8>>2]=E(k+i)*E(.5411961078643799);k=E(K-L);i=E(l-m);l=E(z-A);m=E(E(i+l)*E(.7071067690849304));z=E(k+m);A=E(E(H-I)+i);i=E(l+k);l=E(A-E(i*E(.1989123672246933)));i=E(E(l*E(.3826834261417389))+i);B[j+28>>2]=E(z-i)*E(2.562915563583374);B[j+4>>2]=E(z+i)*E(.509795606136322);k=E(k-m);i=E(l-E(i*E(.1989123672246933)));B[j+20>>2]=E(k+i)*E(.8999761939048767);B[j+12>>2]=E(k-i)*E(.601344883441925);j=j+32|0;v=v+1|0;continue}break}j=0;while(1){if((j|0)!=7){o=j<<2;B[n>>2]=B[o+h>>2];k=B[g+o>>2];j=j+1|0;p=j<<2;i=B[p+g>>2];B[n+72>>2]=E(B[o+C>>2]+k)+i;B[n+144>>2]=B[o+x>>2]+B[p+x>>2];B[n+216>>2]=i+E(k+B[p+C>>2]);n=n+288|0;continue}break}B[n>>2]=B[h+28>>2];k=B[h+124>>2];B[n+72>>2]=B[h+92>>2]+k;i=B[h+60>>2];B[n+216>>2]=k;B[n+144>>2]=i;u=u+1|0;continue}break}t=t+1|0;continue}break}C=zc(f,a,3840);y=d<<5;t=0;while(1){if((c|0)>(t|0)){j=fb-32|0;fb=j;f=C+(t<<8)|0;p=(t<<2)+b|0;B[f+4080>>2]=B[p+1152>>2];h=d-1|0;u=p+D(h,2304)|0;B[f+4084>>2]=B[u+1152>>2];B[f+4088>>2]=B[p>>2];B[f+4092>>2]=B[u>>2];B[f+4336>>2]=B[p+1156>>2];B[f+4340>>2]=B[u+1156>>2];B[f+4344>>2]=B[p+4>>2];B[f+4348>>2]=B[u+4>>2];v=(D(t,y)<<1)+e|0;x=v+(h<<1)|0;Tt(x,d,f+244|0);h=d<<6;Tt(h+x|0,d,f+500|0);Tt(v,d,f+240|0);Tt(h+v|0,d,f+496|0);F=f+3840|0;o=14;n=87552;while(1){if((o|0)>=0){h=F+(o<<4)|0;f=D(31-o|0,72);B[h>>2]=B[f+p>>2];B[h+4>>2]=B[f+u>>2];f=f|4;B[h+8>>2]=B[f+p>>2];B[h+12>>2]=B[f+u>>2];f=D(o,72);g=f+76|0;B[h+256>>2]=B[g+p>>2];B[h+260>>2]=B[g+u>>2];f=f+72|0;B[h-248>>2]=B[f+p>>2];B[h-244>>2]=B[f+u>>2];q=h-3840|0;k=B[n+4>>2];i=B[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=B[g+h>>2];m=B[g+q>>2];B[g+(j+16|0)>>2]=E(l*i)-E(k*m);B[j+g>>2]=E(l*k)+E(i*m);f=f+1|0;continue}break}q=h-3584|0;s=h-256|0;k=B[n+12>>2];i=B[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+j|0;l=B[g+s>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(i*m));g=g+(j+16|0)|0;B[g>>2]=E(E(m*k)-E(i*l))+B[g>>2];f=f+1|0;continue}break}q=h-3328|0;s=h-512|0;k=B[n+20>>2];i=B[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+j|0;l=B[g+s>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(i*m));g=g+(j+16|0)|0;B[g>>2]=E(E(l*i)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=h-3072|0;s=h-768|0;k=B[n+28>>2];i=B[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+j|0;l=B[g+s>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(i*m));g=g+(j+16|0)|0;B[g>>2]=E(E(m*k)-E(i*l))+B[g>>2];f=f+1|0;continue}break}q=h-2816|0;s=h-1024|0;k=B[n+36>>2];i=B[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+j|0;l=B[g+s>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(i*m));g=g+(j+16|0)|0;B[g>>2]=E(E(l*i)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=h-2560|0;s=h-1280|0;k=B[n+44>>2];i=B[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+j|0;l=B[g+s>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(i*m));g=g+(j+16|0)|0;B[g>>2]=E(E(m*k)-E(i*l))+B[g>>2];f=f+1|0;continue}break}q=h-2304|0;s=h-1536|0;k=B[n+52>>2];i=B[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+j|0;l=B[g+s>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(i*m));g=g+(j+16|0)|0;B[g>>2]=E(E(l*i)-E(k*m))+B[g>>2];f=f+1|0;continue}break}g=h-2048|0;q=h-1792|0;k=B[n+60>>2];i=B[n+56>>2];f=0;while(1){if((f|0)!=4){h=f<<2;s=h+j|0;l=B[h+q>>2];m=B[h+g>>2];B[s>>2]=B[s>>2]+E(E(l*k)+E(i*m));h=h+(j+16|0)|0;B[h>>2]=E(E(m*k)-E(i*l))+B[h>>2];f=f+1|0;continue}break}f=D(15-o|0,d)<<1;O=f+x|0,P=sj(B[j+20>>2]),w[O>>1]=P;h=D(o+17|0,d)<<1;O=h+x|0,P=sj(B[j+4>>2]),w[O>>1]=P;O=f+v|0,P=sj(B[j+16>>2]),w[O>>1]=P;O=h+v|0,P=sj(B[j>>2]),w[O>>1]=P;f=D(47-o|0,d)<<1;O=f+x|0,P=sj(B[j+28>>2]),w[O>>1]=P;h=D(o+49|0,d)<<1;O=h+x|0,P=sj(B[j+12>>2]),w[O>>1]=P;O=f+v|0,P=sj(B[j+24>>2]),w[O>>1]=P;O=h+v|0,P=sj(B[j+8>>2]),w[O>>1]=P;o=o-1|0;n=n- -64|0;continue}break}fb=j+32|0;t=t+2|0;continue}break}b=C+(c<<8)|0;a:{if((d|0)==1){t=0;while(1){if(t>>>0>959){break a}c=t<<2;B[c+a>>2]=B[b+c>>2];t=t+2|0;continue}}zc(a,b,3840)}}function Msa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;f=fb-272|0;fb=f;yc(b);e=fb-16|0;fb=e;g=f+66|0;k_(e+8|0,g);i=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(i|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(h|0)==(i|0);if(!e){j_(g)}a:{if(!e){break a}if(!m_(g)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(l_(g),hb))){break a}d=1;if((c|0)==64){break a}Dd(a,16777216);eg(a);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+44|0;sr(d,32);g=x[f+56>>2];e=a+1074320|0;x[e>>2]=x[f+52>>2];x[e+4>>2]=g;e=x[f+48>>2];x[a+1074312>>2]=x[f+44>>2];x[a+1074316>>2]=e;Lb(a+1074312|0,114,1);s=a,t=Bb(y[f+266|0]|y[f+267|0]<<8),w[s+480188>>1]=t;Uh(a,1);e=uc(d,8557);zb(a+1298368|0,e);tb(e);e=f+24|0;gg(e,3924);x[31609]=0;S(370,d|0,e|0,y[f+69|0]);g=x[31609];x[31609]=0;b:{c:{d:{e:{if((g|0)!=1){zb(a+1298344|0,d);tb(d);Eb(e);g=uc(d,10805);zb(a+1298356|0,g);tb(g);s=a,t=x[Fc(d,26)>>2],x[s+1298404>>2]=t;Ue(e,3,f+70|0);Cc(d,e);zb(a+1298308|0,d);tb(d);g=f+102|0;e=160;while(1){f:{d=e;if(!d){d=0;break f}e=d-1|0;if(y[g+e|0]==32){continue}}break}i_(a+1298332|0,g,d,4);d=Bb(y[f+262|0]|y[f+263|0]<<8);w[a+480190>>1]=d;n=a+946304|0;o=a+484380|0;h=1;while(1){g:{e=h&65535;if(e>>>0>(d&65535)>>>0){$e(Xb(x[a+484360>>2],y[a+484376|0]),Bb(y[f+270|0]|y[f+271|0]<<8));d=f+24|0;he(d,b,512);i=hc(f+44|0,d);ub(d);d=y[a+484376|0];e=x[a+484360>>2];g=y[f+268|0]|y[f+269|0]<<8;x[31609]=0;S(276,Xb(e,d)|0,i|0,Bb(g)|0);d=x[31609];x[31609]=0;if((d|0)!=1){break g}d=N()|0;break d}d=D(e,104)+o|0;nd(d,1);fp(d);D$(b,n+(e<<5)|0,y[f+69|0]==1?32:28);l=1;e=y[f+69|0];if(e>>>0>=3){Vb(b,14);e=ND(b);if((e|0)>=0){w[d+34>>1]=z[d+34>>1]|32;s=d,t=Bc((((e&65535)<<8)+2047>>>0)/4095|0,0),w[s+28>>1]=t}e=y[f+69|0]}if((e&255)>>>0>=2){l=Pk(b);s=d,t=Pk(b),x[s+24>>2]=t}g=f+44|0;i=fb-16|0;fb=i;h:{if(!Mb(x[b>>2],x[b+8>>2],12)){x[i>>2]=0;e=g;k=3;while(1){if(k){m=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);v[e|0]=m;v[e+1|0]=m>>>8;v[e+2|0]=m>>>16;v[e+3|0]=m>>>24;k=k-1|0;e=e+4|0;continue}break}break h}zr(i+8|0,g);sd(i,b,x[i+8>>2],x[i+12>>2])}fb=i+16|0;i=gc(g);e=Ab(g);k=$b(x[f+44>>2]);x[d>>2]=k;g=$b(y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24));x[d+4>>2]=g;i=$b(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))+g|0;x[d+8>>2]=i;i:{j:{if(!g){if($b(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))>>>0<3){break j}}e=z[d+34>>1]|2;break i}e=z[d+34>>1]&-3}w[d+34>>1]=e;if((l|0)==2){x[d+8>>2]=i>>>1;x[d+4>>2]=g>>>1;x[d>>2]=k>>>1;w[d+34>>1]=e|1}s=d,t=Pk(b),w[s+30>>1]=t;e=ND(b);if(e){_l(d,+(e|0)/96)}v[d+37|0]=e<<4;h=h+1|0;d=z[a+480190>>1];continue}break}d=wb(x[Xb(x[a+484360>>2],y[a+484376|0])>>2]);g=wb(x[Xb(x[a+484360>>2],y[a+484376|0])+4>>2]);e=fb-16|0;fb=e;k:{if(!Ib(d,g)){break k}x[e+12>>2]=d;while(1){h=x[ge(e+12|0)>>2];if(!Ib(h,g)){break k}d=Yk(z[d>>1],z[h>>1])?h:d;continue}}fb=e+16|0;d=z[d>>1];x[31609]=0;m=a+484344|0;q=d+1&65535;O(223,m|0,q|0);d=x[31609];x[31609]=0;if((d|0)==1){break e}d=y[f+69|0];x[f+20>>2]=x[a+480204>>2];x[f+16>>2]=x[a+480196>>2];n=d>>>0<4?4:5;r=c&1;e=0;while(1){if((e|0)==(q|0)){if(!(c&2)){break b}d=1;while(1){c=d&65535;if(c>>>0>z[a+480190>>1]){break b}c=D(c,104)+o|0;e=Zc(f+8|0,w[c+34>>1]&1?16:8,1,1,0);x[31609]=0;U(215,e|0,c|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){d=d+1|0;continue}break}d=N()|0;break d}l:{if(!r){break l}d=y[f+264|0]|y[f+265|0]<<8;g=x[b+8>>2];h=x[b>>2];l=z[a+480188>>1];x[31609]=0;d=U(150,h|0,g|0,D(l,D(Bb(d),n))|0)|0;g=x[31609];x[31609]=0;m:{n:{if((g|0)==1){break n}if(!d){break l}d=y[f+264|0]|y[f+265|0]<<8;x[31609]=0;d=U(196,m|0,e&65535,Bb(d)|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break n}if(!d){break l}d=z[a+480188>>1];v[f|0]=0;g=ee(f+8|0,0,f);x[31609]=0;k=U(371,f+24|0,d|0,g|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break m}l=0;o:while(1){if(Bb(y[f+264|0]|y[f+265|0]<<8)>>>0<=l>>>0){od(k);break l}d=Wb(x[m>>2],e);af(f+8|0,x[d>>2],x[x[d+48>>2]+12>>2],l);d=0;while(1){if(z[a+480188>>1]<=d>>>0){l=l+1|0;continue o}g=Yc(x[f+8>>2],d);v[f+4|0]=0;x[31609]=0;x[f>>2]=0;S(372,b|0,f|0,n|0);h=x[31609];x[31609]=0;p:{if((h|0)==1){break p}h=x[k>>2];j=y[f|0];if((j-24&255)>>>0<=59){j=j+13|0;v[g|0]=j;s=ac(h,d),t=j,v[s|0]=t}j=y[f+1|0];q:{if(!j){h=ac(h,d);break q}v[g+1|0]=j;h=ac(h,d);v[h+1|0]=j}j=y[h+1|0];h=y[h|0];x[31609]=0;ya(373,a|0,g|0,y[f+2|0],y[f+3|0],0-y[f+69|0]|0,h|0,j|0,f+20|0,f+16|0);h=x[31609];x[31609]=0;if((h|0)==1){break p}h=y[f+4|0];if(h){v[g+2|0]=1;v[g+4|0]=h+1>>>2}d=d+1|0;continue}break}break}d=N()|0;od(k);break d}d=N()|0;break d}d=N()|0;break d}e=e+1|0;continue}}d=N()|0;Eb(f+24|0);break c}d=N()|0}ub(i)}Q(d|0);p()}ub(i);d=1}fb=f+272|0;return d|0}function Qna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;h=fb-176|0;fb=h;yc(b);a:{d=h+128|0;if(!SD(b,d)){break a}if(!FV(d)){break a}f=1;if((c|0)==64){break a}f=0;if(!Mb(x[b>>2],x[b+8>>2],Bc(EV(y[h+175|0]),hb))){break a}Dd(a,128);f=h+112|0;Ue(f,2,h+143|0);d=h+32|0;Cc(d,f);zb(a+1298308|0,d);tb(d);x[h+124>>2]=14999;x[h+120>>2]=15056;x[h+116>>2]=15079;x[h+112>>2]=15078;f=uc(d,8453);zb(a+1298344|0,f);tb(f);f=uc(d,6056);zb(a+1298356|0,f);tb(f);f=uc(h+100|0,18188);x[31609]=0;S(756,d|0,f|0,x[((y[h+142|0]<<2)+h|0)-84>>2]);e=x[31609];x[31609]=0;b:{if((e|0)!=1){zb(a+1298368|0,d);tb(d);tb(f);B=a,C=x[Fc(d,4)>>2],x[B+1298404>>2]=C;x[a+480208>>2]=12;lE(a+1298332|0,b,y[h+175|0]<<5,32,0);i=Zd(b);w[a+480190>>1]=i;m=a+946304|0;t=a+484380|0;f=1;while(1){j=f&65535;if(j>>>0>(i&65535)>>>0){$j(Xb(x[a+484360>>2],y[a+484376|0]),b,256,255,254);f=0;d=Zd(b);if(d>>>0>=127){break a}w[a+480188>>1]=d+1&255;i=a+480280|0;e=Zd(b);while(1)if(z[a+480188>>1]<=f>>>0){n=a+484344|0;u=e+1|0;Tf(n,u);f=0;while(1){d=f&65535;if(d>>>0>e>>>0){c:while(1){r=A&65535;f=z[a+480188>>1];if(r>>>0>=f>>>0){d=To(h);v[d+16|0]=0;w[d+14>>1]=0;w[d+12>>1]=f;x[31609]=0;O(758,d|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){a=N()|0;tf(d);Q(a|0);p()}x[31609]=0;O(757,n|0,d|0);e=x[31609];x[31609]=0;f=1;if((e|0)!=1){tf(d);if(!(c&2)){break a}while(1){c=f&65535;if(c>>>0>z[a+480190>>1]){f=1;break a}else{c=D(c,104)+t|0;dg(Zc(h+32|0,w[c+34>>1]&1?16:8,1,0,0),c,b);f=f+1|0;continue}}}i=N()|0;tf(d);break b}l=0;e=Ng(h+32|0);d:while(1){e:{if((l|0)!=(u|0)){if(Mb(x[b>>2],x[b+8>>2],5)){break e}}A=A+1|0;continue c}i=0;d=Wb(x[n>>2],l);f=md(x[d>>2],x[x[d+48>>2]+12>>2],0,r);while(1){f:{g:{if(i>>>0>63){break g}m=y[h+142|0];g=fb-16|0;fb=g;s=1;d=Zd(b);if((d|0)==252){s=Zd(b);d=Zd(b)}v[e|0]=(d-1&255)>>>0<60?d+36|0:0;d=g+12|0;lm(d,b);j=Jc(d);k=_e(d);d=Yi(d);v[e+1|0]=y[g+12|0];o=g+10|0;q=y[j|0];DV(o,q&15,y[k|0],m);j=Jc(o);k=g+8|0;DV(k,q>>>4|0,y[d|0],m);m=Jc(k);k=y[g+10|0];o=(k|0)!=10;d=y[g+8|0];h:{if(!(o|(d|0)!=10)){j=y[j|0];d=y[m|0];v[e+3|0]=10;j=j|d<<8;v[e+5|0]=j>>>6;if(j>>>0<16384){break h}v[e+2|0]=15;v[e+4|0]=d>>>6;break h}i:{j:{k:{l:{m:{if(!o){k=y[j|0];o=k<<2;B=j,C=si(o),v[B|0]=C;if(k>>>0<64){break m}if(ri(d)>>>0>=ri(10)>>>0){break l}v[e+5|0]=o;v[e+2|0]=15;v[e+3|0]=10;v[e+4|0]=k>>>6;break h}if((d|0)==10){d=y[m|0];k=d<<2;B=m,C=si(k),v[B|0]=C;if(d>>>0<64){break m}if(ri(y[g+10|0])>>>0>=ri(10)>>>0){break m}v[e+5|0]=k;v[e+2|0]=15;v[e+3|0]=10;v[e+4|0]=d>>>6;break h}if((d|0)!=(k|0)){break m}v[g+8|0]=0;break k}d=y[g+8|0]}if((d|0)==13){break j}if(d){break i}k=y[g+10|0]}if((k|0)==13){break i}}rg(g+10|0,g+8|0);rg(j,m)}vw(g+8|0,m,g+10|0,j);em(g+6|0,e,y[g+10|0],y[j|0],y[g+8|0],y[m|0])}fb=g+16|0;g=i+s|0;i=g>>>0>64?64-i|0:s;if(!i){break g}while(1){if(!i){break f}d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[f|0]=d;v[f+1|0]=d>>>8;v[f+2|0]=d>>>16;v[f+3|0]=d>>>24;d=y[e+4|0]|y[e+5|0]<<8;v[f+4|0]=d;v[f+5|0]=d>>>8;i=i-1|0;f=D(z[a+480188>>1],6)+f|0;continue}}l=l+1|0;continue d}i=g>>>0>=64?64:g;continue}}}}f=f+1|0;if(Pg(n,d,64)){continue}break}f=0;break a}else{d=i+(f<<5)|0;Ve(d);n:{if(y[h+142|0]>=51){q=(Zd(b)<<4|8)&248;break n}q=f&1?192:64}w[d+4>>1]=q;f=f+1|0;continue}}else{o:{if(y[h+142|0]>=52){d=h+32|0;if(!l$(b,d)){oE(d)}break o}g=h+32|0;d=fb-32|0;fb=d;x[d+28>>2]=64;x[d+8>>2]=66;r=x[b>>2];q=x[b+8>>2];e=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(r,q,e)){e=jf(b)}i=d+8|0;lw(i,g);l=Zb(d+16|0,x[d+8>>2],e);n=x[l>>2];kc(d,x[b>>2],x[b+8>>2],n,x[l+4>>2]);lw(i,g);Rb(x[d+8>>2]+e|0,0,66-e|0);Vb(b,x[d+28>>2]);fb=d+32|0;d=y[h+94|0]|y[h+95|0]<<8;v[h+96|0]=d;v[h+97|0]=d>>>8;v[h+94|0]=171;v[h+95|0]=32}i=fb-32|0;fb=i;g=D(j,104)+t|0;nd(g,0);fp(g);l=i+8|0;e=h+32|0;Lk(l,2,e+32|0);d=i+20|0;Cc(d,l);Be(g+43|0,d);tb(d);l=y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24);n=y[e+52|0]|y[e+53|0]<<8|(y[e+54|0]<<16|y[e+55|0]<<24);p:{if(l>>>0<=n>>>0){break p}x[g>>2]=l-n;x[g+12>>2]=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[i+20>>2]=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);B=g,C=x[Hb(d,g)>>2],x[B+16>>2]=C;w[g+30>>1]=y[e+60|0];x[g+24>>2]=y[e+62|0]|y[e+63|0]<<8;d=y[e+64|0]|y[e+65|0]<<8;if(d){_l(g,+(d<<16>>16)/393216)}d=y[e+61|0];if(d&8){w[g+34>>1]=z[g+34>>1]|8;d=y[e+61|0]}if(d&16){w[g+34>>1]=z[g+34>>1]|16;d=y[e+61|0]}if(!(d&4)){break p}w[g+34>>1]=z[g+34>>1]|1;x[g+12>>2]=x[g+12>>2]>>>1;x[g+16>>2]=x[g+16>>2]>>>1}fb=i+32|0;g=h+20|0;Ue(g,2,e);d=h+100|0;Cc(d,g);Ac(m+(j<<5)|0,d);f=f+1|0;tb(d);i=z[a+480190>>1];continue}}}i=N()|0;tb(f)}Q(i|0);p()}fb=h+176|0;return f|0}function doa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=fb-112|0;fb=e;yc(c);a:{b:{c:{d:{if(!gp(c,e+100|0)|(y[e+100|0]|y[e+101|0]<<8|(y[e+102|0]<<16|y[e+103|0]<<24))!=1297239878){break d}d=y[e+108|0]|y[e+109|0]<<8|(y[e+110|0]<<16|y[e+111|0]<<24);if(!((d|0)==1482052408|(d|0)==1448293937)&(d|0)!=1146437965){break d}d=fb-32|0;fb=d;g=e+88|0;k=Nb(g);e:{f:{g:{h:{i:{while(1){j=x[c+8>>2];f=x[c>>2];x[31609]=0;j=U(150,f|0,j|0,8)|0;f=x[31609];x[31609]=0;if((f|0)==1){break g}if(!j){break h}x[31609]=0;j=d+4|0;O(829,j|0,c|0);f=x[31609];x[31609]=0;if((f|0)!=1){x[31609]=0;O(830,k|0,j|0);f=x[31609];x[31609]=0;if((f|0)==1){break i}Hd(j);continue}break}a=N()|0;break f}a=N()|0;Hd(d+4|0);break f}fb=d+32|0;break e}a=N()|0}ke(k);Q(a|0);p()}x[31609]=0;j=R(168,e+68|0)|0;c=x[31609];x[31609]=0;j:{k:{l:{m:{n:{o:{p:{if((c|0)!=1){k=Zc(e- -64|0,8,1,1,0);if((y[e+108|0]|y[e+109|0]<<8|(y[e+110|0]<<16|y[e+111|0]<<24))!=1146437965){break n}x[31609]=0;d=e+44|0;S(741,d|0,g|0,1296581714);c=x[31609];x[31609]=0;if((c|0)==1){break m}x[31609]=0;c=e+24|0;S(741,c|0,g|0,1296318804);g=x[31609];x[31609]=0;if((g|0)==1){break l}h=kd(j,c);ub(c);g=0;x[31609]=0;f=R(742,d|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break l}c=0;if(!f){break o}c=x[h>>2];x[31609]=0;h=R(172,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break l}c=0;if(!h){break o}x[31609]=0;m=R(281,d|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break l}x[31609]=0;f=R(273,d|0)|0;c=x[31609];x[31609]=0;q:{if((c|0)==1){break q}x[31609]=0;P(183,d|0,2)|0;c=x[31609];x[31609]=0;if((c|0)==1){break q}x[31609]=0;g=R(281,d|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break p}}break l}c=N()|0;break a}c=0;x[31609]=0;h=e+24|0;O(653,h|0,e+44|0);d=x[31609];x[31609]=0;if((d|0)==1){break l}d=b_(h);i=Bb(z[e+24>>1]);if(!i){break o}g=(g>>>0)/(i>>>0)|0;i=gc(h);h=_e(h);i=Bb(y[i|0]|y[i+1|0]<<8);if((i|0)!=(Bb(y[h|0]|y[h+1|0]<<8)+1|0)){break o}if((i|0)==2){wp(k,2)}r:{if((f|0)!=16){if((f|0)!=8){break o}s:{switch(Bb(y[d|0]|y[d+1|0]<<8)|0){case 0:c=1;wg(k,1);break o;case 2:wg(k,17);break r;case 3:break s;default:break o}}wg(k,16);break r}if(Bb(y[d|0]|y[d+1|0]<<8)){break o}hd(k,16)}c=1}ub(e+44|0);i=0;d=0;h=0;if(!c){break j}break k}x[31609]=0;n=e+44|0;c=e+88|0;S(741,n|0,c|0,1447576658);d=x[31609];x[31609]=0;t:{u:{v:{if((d|0)!=1){x[31609]=0;q=e+24|0;S(741,q|0,c|0,1128808782);d=x[31609];x[31609]=0;if((d|0)==1){break v}x[31609]=0;f=e+4|0;S(741,f|0,c|0,1112491097);c=x[31609];x[31609]=0;if((c|0)==1){break u}o=kd(j,f);ub(f);c=x[o>>2];x[31609]=0;d=R(172,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break u}g=0;c=0;l=0;w:{if(!d){break w}x[31609]=0;d=R(172,x[e+44>>2])|0;c=x[31609];x[31609]=0;if((c|0)==1){break u}c=0;l=0;if(!d){break w}x[31609]=0;f=P(743,n|0,f|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break u}c=0;l=0;if(!f){break w}c=y[e+108|0]|y[e+109|0]<<8|(y[e+110|0]<<16|y[e+111|0]<<24);x[31609]=0;g=R(281,q|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break u}h=(c|0)!=1482052408;if(h){hd(k,16)}if((g|0)==6){wp(k,3)}m=$b(x[e+4>>2]);d=x[e+8>>2];f=x[e+12>>2];c=$b(f);x:{if(c>>>0<33){break x}i=$b(d);if(i>>>0<=c>>>0){break x}d=(i>>>0)%(c>>>0)|0?d:f}c=x[o>>2];x[31609]=0;i=x[e+20>>2];o=z[e+16>>1];n=R(154,c|0)|0;f=x[31609];x[31609]=0;c=1;if((f|0)==1){break u}f=h+((g|0)==6)|0;h=m>>>f|0;m=n>>>f|0;i=$b(i);g=Bb(o);l=$b(d)>>>f|0}d=l;ub(e+24|0);ub(e+44|0);if(c){break k}break j}c=N()|0;break b}c=N()|0;break t}c=N()|0;ub(e+24|0)}ub(e+44|0);break b}c=N()|0;break b}c=N()|0;ub(e+44|0);break b}Vu(a,b);x[31609]=0;c=(D(b,104)+a|0)+484380|0;O(279,c|0,0);f=x[31609];x[31609]=0;y:{if((f|0)!=1){x[c+4>>2]=h;x[c>>2]=m;d=d+h|0;x[c+8>>2]=d;if(!(d>>>0<=h+4>>>0|d>>>0>m>>>0)){w[c+34>>1]=z[c+34>>1]|2}x[c+24>>2]=g>>>0<2?22050:g;d=i+128|0;g=d>>>8|0;w[c+30>>1]=(d&16776960)>>>0>65536?256:g&65535?g:256;eC(c,x[a+480180>>2]);x[31609]=0;d=e+44|0;S(741,d|0,e+88|0,1312902469);g=x[31609];x[31609]=0;if((g|0)==1){break y}x[31609]=0;g=R(172,x[e+44>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break c}z:{A:{if(g){x[31609]=0;g=R(154,x[e+44>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break c}x[31609]=0;S(331,d|0,((b<<5)+a|0)+946304|0,g|0);b=x[31609];x[31609]=0;if((b|0)!=1){break A}break c}x[31609]=0;d=P(36,e+24|0,22292)|0;g=x[31609];x[31609]=0;if((g|0)==1){break z}Ac(((b<<5)+a|0)+946304|0,d);tb(d)}x[31609]=0;U(215,k|0,c|0,j|0)|0;b=x[31609];x[31609]=0;r=1;if((b|0)==1){break c}Ij(c,a);ub(e+44|0);break j}break c}c=N()|0;break b}c=N()|0;break b}ub(j);ke(e+88|0)}fb=e+112|0;return r|0}c=N()|0;ub(e+44|0)}ub(j)}ke(e+88|0);Q(c|0);p()}function Xd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=fb-96|0;fb=k;u=i&65535;o=(e^i)&-2147483648;r=e&65535;z=r;R=i>>>16&32767;S=e>>>16&32767;a:{b:{if(R-32767>>>0>4294934529&S-32767>>>0>=4294934530){break b}s=e&2147483647;q=s;j=d;if(!(!d&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){m=d;o=e|32768;break a}s=i&2147483647;p=s;e=h;if(!(!e&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){m=e;o=i|32768;b=f;c=g;break a}if(!(b|j|(q^2147418112|c))){if(!(e|f|(g|p))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(e|f|(p^2147418112|g))){e=b|j;d=c|q;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|q))){b=0;c=0;break a}if(!(e|f|(g|p))){b=0;c=0;break a}if((q|0)==65535|q>>>0<65535){j=!(d|r);i=j?b:d;s=j<<6;e=G(i)+32|0;i=G(j?c:r);i=s+((i|0)==32?e:i)|0;$f(k+80|0,b,c,d,r,i-15|0);t=16-i|0;d=x[k+88>>2];z=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(p>>>0>65535){break b}i=!(h|u);e=i?f:h;r=i<<6;j=G(e)+32|0;e=G(i?g:u);e=r+((e|0)==32?j:e)|0;$f(k- -64|0,f,g,h,u,e-15|0);t=(t-e|0)+16|0;h=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;f=g<<15|f>>>17;i=e<<15;e=0;v=i&-32768;L=c;s=Aua(v,e,c,0);e=hb;A=e;M=f;q=b;c=Aua(f,0,b,0);b=c+s|0;f=hb+e|0;i=b;c=b>>>0<c>>>0?f+1|0:f;f=b;j=0;b=Aua(q,l,v,l);p=j+b|0;e=hb+f|0;e=b>>>0>p>>>0?e+1|0:e;r=e;N=(f|0)==(e|0)&j>>>0>p>>>0|e>>>0<f>>>0;O=d;w=Aua(v,l,d,0);P=hb;b=Aua(L,l,M,l);y=b+w|0;j=hb+P|0;j=b>>>0>y>>>0?j+1|0:j;b=u<<15|h>>>17;B=h<<15|g>>>17;d=Aua(B,0,q,l);C=d+y|0;f=hb+j|0;f=d>>>0>C>>>0?f+1|0:f;D=f;d=(c|0)==(A|0)&i>>>0<s>>>0|c>>>0<A>>>0;E=c+C|0;f=d+f|0;f=c>>>0>E>>>0?f+1|0:f;u=f;g=E;c=f;F=z|65536;z=Aua(v,l,F,n);Q=hb;d=Aua(O,m,M,l);H=d+z|0;e=hb+Q|0;e=d>>>0>H>>>0?e+1|0:e;i=e;I=b|-2147483648;b=Aua(I,0,q,l);J=b+H|0;f=hb+e|0;f=b>>>0>J>>>0?f+1|0:f;d=Aua(B,m,L,l);b=d+J|0;K=f;f=f+hb|0;A=b;s=b>>>0<d>>>0?f+1|0:f;f=b;b=0;q=b+g|0;e=c+f|0;e=b>>>0>q>>>0?e+1|0:e;v=e;f=e;b=q+N|0;c=b>>>0<q>>>0?f+1|0:f;t=((S+R|0)+t|0)-16383|0;d=Aua(I,m,L,l);h=hb;e=Aua(F,m,M,l);g=e+d|0;f=hb+h|0;f=e>>>0>g>>>0?f+1|0:f;n=(h|0)==(f|0)&d>>>0>g>>>0|f>>>0<h>>>0;h=f;e=Aua(B,m,O,m);d=e+g|0;f=hb+f|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(f|0)==(h|0)&d>>>0<g>>>0|f>>>0<h>>>0;f=0;h=g;g=g+n|0;f=h>>>0>g>>>0?1:f;h=g;g=Aua(I,m,F,m);h=h+g|0;f=hb+f|0;N=h;g=g>>>0>h>>>0?f+1|0:f;h=d;l=e;e=(j|0)==(P|0)&w>>>0>y>>>0|j>>>0<P>>>0;f=0;j=(j|0)==(D|0)&y>>>0>C>>>0|j>>>0>D>>>0;n=j;j=e+j|0;e=(n>>>0>j>>>0?1:f)+l|0;f=g;d=d+j|0;e=d>>>0<j>>>0?e+1|0:e;n=e;w=d;d=(e|0)==(l|0)&d>>>0<h>>>0|e>>>0<l>>>0;e=d;d=d+N|0;f=e>>>0>d>>>0?f+1|0:f;j=d;h=f;e=Aua(B,m,F,m);l=hb;g=Aua(I,m,O,m);d=g+e|0;f=hb+l|0;f=d>>>0<g>>>0?f+1|0:f;g=f;f=(l|0)==(f|0)&d>>>0<e>>>0|f>>>0<l>>>0;y=g+j|0;e=f+h|0;e=g>>>0>y>>>0?e+1|0:e;l=y;h=e;j=d;e=0;d=e+w|0;f=j+n|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(n|0)==(f|0)&d>>>0<w>>>0|f>>>0<n>>>0;f=h;h=g;g=g+l|0;f=h>>>0>g>>>0?f+1|0:f;w=g;g=f;h=d;j=e;e=(s|0)==(K|0)&A>>>0<J>>>0|s>>>0<K>>>0;d=(i|0)==(Q|0)&z>>>0>H>>>0|i>>>0<Q>>>0;i=(i|0)==(K|0)&H>>>0>J>>>0|i>>>0>K>>>0;d=d+i|0;d=d+e|0;n=s;i=n+h|0;e=d+j|0;f=g;d=i;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0<j>>>0;g=h+w|0;f=h>>>0>g>>>0?f+1|0:f;j=g;g=f;h=d;f=0;i=e;n=(u|0)==(v|0)&q>>>0<E>>>0|u>>>0>v>>>0;l=n;n=n+((u|0)==(D|0)&C>>>0>E>>>0|u>>>0<D>>>0)|0;e=e+(l>>>0>n>>>0?1:f)|0;f=g;d=d+n|0;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(i|0)&d>>>0<h>>>0|e>>>0<i>>>0;g=h;h=h+j|0;f=g>>>0>h>>>0?f+1|0:f;i=f;c:{if(f&65536){t=t+1|0;break c}j=r>>>31|0;g=0;f=i<<1|h>>>31;h=h<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;f=r<<1|p>>>31;p=p<<1;r=f;f=c<<1|b>>>31;b=b<<1|j;c=f|g}if((t|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){g=1-t|0;if(g>>>0<=127){f=t+127|0;$f(k+48|0,p,r,b,c,f);$f(k+32|0,d,e,h,i,f);cn(k+16|0,p,r,b,c,g);cn(k,d,e,h,i,g);p=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;r=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];g=x[k+8>>2];f=x[k+12>>2];break d}b=0;c=0;break a}g=h;f=i&65535|t<<16}m=g|m;o=f|o;if(!(!b&(c|0)==-2147483648?!(p|r):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;e=o;c=j;d=!(j|b);m=d+m|0;o=d>>>0>m>>>0?e+1|0:e;break a}if(b|p|(c^-2147483648|r)){b=d;c=e;break a}f=e;b=d&1;c=b;b=b+d|0;f=c>>>0>b>>>0?f+1|0:f;c=f;d=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;f=o;m=d+m|0;o=m>>>0<d>>>0?f+1|0:f}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=m;x[a+12>>2]=o;fb=k+96|0}function ppa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-128|0;fb=g;yc(b);a:{b:{c:{d:{e:{if(!rX(b,14208)){break e}l=Nb(g+116|0);j=Nb(g+104|0);x[31609]=0;x[g+96>>2]=0;x[g+100>>2]=0;O(246,a|0,32768);d=x[31609];x[31609]=0;if((d|0)==1){break b}x[31609]=0;d=P(1,g+84|0,8169)|0;e=x[31609];x[31609]=0;if((e|0)==1){break c}zb(a+1298344|0,d);tb(d);x[31609]=0;d=P(1,g+72|0,6060)|0;e=x[31609];x[31609]=0;if((e|0)==1){break d}zb(a+1298356|0,d);tb(d);o=a,q=x[Fc(g+44|0,28)>>2],x[o+1298404>>2]=q;k=a+480280|0;n=(c|0)==64;while(1){d=x[b+8>>2];e=x[b>>2];x[31609]=0;d=U(150,e|0,d|0,8)|0;e=x[31609];x[31609]=0;f:{g:{h:{if((e|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}x[31609]=0;d=P(652,b|0,g- -64|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break m}if(!d){break n}e=x[g+68>>2];x[31609]=0;d=g+24|0;S(185,d|0,b|0,$b(e)|0);e=x[31609];x[31609]=0;if((e|0)==1){break l}e=hc(g+44|0,d);ub(d);d=x[e>>2];x[31609]=0;d=R(172,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}if(d){break k}ub(e)}if(z[a+480188>>1]){break i}i=0;break g}a=N()|0;break a}a=N()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=$b(x[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(z[a+480188>>1]){break f}d=x[e>>2];x[31609]=0;d=R(154,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}if(d>>>0<8){break f}d=0;x[31609]=0;O(653,g+24|0,e|0);f=x[31609];x[31609]=0;if((f|0)==1){break j}while(1)if((d|0)==4){if(!n){break f}i=1;break o}else{f=z[a+480188>>1];h=ac(g+24|0,d);v:{if(!Bb(y[h|0]|y[h+1|0]<<8)){h=d-1|0;break v}h=g+96|0;o=xb(h,f),q=1,v[o|0]=q;o=xb(h,z[a+480188>>1]+1|0),q=255,v[o|0]=q;Ve(k+(z[a+480188>>1]<<5)|0);h=z[a+480188>>1];f=h+1|0;w[a+480188>>1]=f;m=k+(h<<5)|0;h=d-1|0;w[m+4>>1]=(h&65535)>>>0<2?192:64}Ve(k+((f&65535)<<5)|0);f=z[a+480188>>1];w[a+480188>>1]=f+1;w[(k+(f<<5)|0)+4>>1]=(h&65535)>>>0<2?192:64;d=d+1|0;continue}}if(z[a+480190>>1]){break f}x[31609]=0;O(654,e|0,a|0);d=x[31609];x[31609]=0;if((d|0)!=1){break f}break j}d=x[e>>2];x[31609]=0;d=R(154,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}if(d>>>0<2){break f}x[31609]=0;d=R(273,e|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}o=a,q=Ld(d,1,255),x[o+480196>>2]=q;break f}d=x[e>>2];x[31609]=0;d=R(154,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}if(d>>>0<2){break f}x[31609]=0;i=R(273,e|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break f}break j}d=y[a+484376|0];f=x[a+484360>>2];h=x[e>>2];x[31609]=0;h=R(154,h|0)|0;m=x[31609];x[31609]=0;if((m|0)==1){break j}x[31609]=0;aa(348,Xb(f,d)|0,e|0,h|0,255,254);d=x[31609];x[31609]=0;if((d|0)==1){break j}break f}d=l;if(Sf(x[d>>2],x[d+4>>2])>>>0>=256){break f}break q}if(Sf(x[j>>2],x[j+4>>2])>>>0>3998){break f}d=x[e>>2];x[31609]=0;f=R(154,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break j}d=j;if(!f){break f}}x[31609]=0;O(655,d|0,e|0);d=x[31609];x[31609]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}ub(e);break g}a=N()|0;ub(e);break a}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=x[a+484360>>2];d=y[a+484376|0];x[31609]=0;O(330,Xb(b,d)|0,i&65535);b=x[31609];x[31609]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=x[l+4>>2];i=x[l>>2];d=0;x[31609]=0;O(223,a+484344|0,Sf(i,b)&65535);b=x[31609];x[31609]=0;if((b|0)==1){break b}while(1){k=x[l>>2];b=d&65535;if(Sf(k,x[l+4>>2])>>>0<=b>>>0){break w}x[31609]=0;i=x[g+100>>2];e=x[g+96>>2];x[g+16>>2]=e;x[g+20>>2]=i;x[g+8>>2]=e;x[g+12>>2]=i;V(656,ch(k,b)|0,b|0,a|0,g+8|0);b=x[31609];x[31609]=0;if((b|0)!=1){d=d+1|0;continue}break}a=N()|0;break a}e=a+484380|0;k=c&2;i=1;d=1;b=0;while(1){if(z[a+480190>>1]<=d>>>0){break g}if(!k|Sf(x[j>>2],x[j+4>>2])>>>0<=b>>>0){break g}c=e+D(d,104)|0;xp(c);x:{if(x[c>>2]){f=x[ch(x[j>>2],b)>>2];x[31609]=0;f=R(154,f|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break h}xc(c,f);f=Zc(g+44|0,8,1,1,0);h=x[j>>2];x[31609]=0;U(215,f|0,c|0,ch(h,b)|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Rc(j);Rc(l);break e}ub(e);continue}}fb=g+128|0;return i|0}a=N()|0;break a}a=N()|0;break a}a=N()|0}Rc(j);Rc(l);Q(a|0);p()}function U0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-80|0;fb=g;yc(b);a:{if(!Or(b,11790)){break a}i=g+69|0;if(!zw(b,i)){break a}if(!NE(y[g+70|0])){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(ME(i),hb))){break a}if(!Vb(b,y[g+78|0]|y[g+79|0]<<8)){break a}d=1;if((c|0)==64){break a}Dd(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[g+71|0]&31)+1;w[a+480190>>1]=y[g+72|0];Uh(a,1);d=g+20|0;f=uc(d,8476);zb(a+1298344|0,f);tb(f);f=uc(d,7105);zb(a+1298356|0,f);tb(f);f=fb-16|0;fb=f;e=uc(f+4|0,4247);Uc(g,e);tb(e);fb=f+16|0;x[31609]=0;V(229,d|0,g|0,y[g+70|0],i|0);i=x[31609];x[31609]=0;b:{if((i|0)!=1){zb(a+1298368|0,d);tb(d);Eb(g);m=a,n=x[Fc(d,4)>>2],x[m+1298404>>2]=n;d=y[g+72|0];i=g+56|0;x[i>>2]=0;x[i+4>>2]=0;Fc(i+8|0,0);if(d){Xr(i,d);LF(i,d,0)}l=a+484380|0;d=1;c:{while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){x[31609]=0;P(230,b|0,a+1298308|0)|0;d=x[31609];x[31609]=0;d:{if((d|0)==1){break d}f=a+946304|0;d=1;while(1){e=d&65535;if(e>>>0>z[a+480190>>1]){f=a+480280|0;d=0;e:{while(1){if(z[a+480188>>1]<=d>>>0){d=0;x[31609]=0;f=a+484344|0;O(223,f|0,y[g+73|0]|y[g+74|0]<<8);e=x[31609];x[31609]=0;if((e|0)==1){break d}break e}e=f+(d<<5)|0;Ve(e);x[31609]=0;O(231,b|0,e+9|0);e=x[31609];x[31609]=0;if((e|0)!=1){d=d+1|0;continue}break}b=N()|0;break c}f:{g:{h:{i:{while(1){if((y[g+73|0]|y[g+74|0]<<8)>>>0<=d>>>0){x[31609]=0;e=R(189,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break g}if(!e){break h}d=x[b+8>>2];f=x[b>>2];x[31609]=0;d=U(150,f|0,d|0,e|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break g}if(d){break i}break h}x[31609]=0;e=g+20|0;h=P(232,b|0,e|0)|0;j=x[31609];x[31609]=0;j:{if((j|0)==1){break j}x[31609]=0;j=U(196,f|0,d&65535,64)|0;k=x[31609];x[31609]=0;if((k|0)==1){break j}if((h&j)==1){h=x[f>>2];x[31609]=0;O(233,Wb(h,d)|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break j}}d=d+1|0;continue}break}b=N()|0;break c}f=Nb(g+20|0);x[31609]=0;S(234,b|0,f|0,e|0);d=x[31609];x[31609]=0;k:{if((d|0)!=1){d=Fb(g);x[31609]=0;O(114,d|0,e|0);e=x[31609];x[31609]=0;l:{if((e|0)==1){break l}m=g,n=wb(x[f>>2]),x[m+40>>2]=n;h=wb(x[f+4>>2]);while(1){m:{e=x[g+40>>2];if(!Ib(e,h)){x[31609]=0;h=g+40|0;S(235,h|0,20,d|0);e=x[31609];x[31609]=0;if((e|0)==1){break m}e=zb(d,h);tb(h);h=Kb(e);j=y[e+11|0];k=x[e+4>>2];x[31609]=0;aa(236,a+1298332|0,h|0,_c(k,j)|0,76,0);h=x[31609];x[31609]=0;if((h|0)==1){break l}tb(e);fc(f);break h}n:{e=v[e|0];if((e|0)<0){j=x[vb(g+52|0,Df(d))>>2];x[31609]=0;V(237,d|0,j|0,e&127,32);e=x[31609];x[31609]=0;if((e|0)!=1){break n}break l}x[31609]=0;O(115,d|0,e|0);e=x[31609];x[31609]=0;if((e|0)!=1){break n}break l}we(g+40|0);continue}break}}b=N()|0;tb(d);break k}b=N()|0}fc(f);break c}d=y[a+484376|0];f=x[a+484360>>2];x[31609]=0;S(238,Xb(f,d)|0,b|0,y[g+75|0]|y[g+76|0]<<8);d=x[31609];x[31609]=0;if((d|0)==1){break g}e=c&1;d=0;while(1){o:{p:{if((y[g+73|0]|y[g+74|0]<<8)>>>0>d>>>0){f=x[b+8>>2];h=x[b>>2];x[31609]=0;f=U(150,h|0,f|0,4)|0;h=x[31609];x[31609]=0;if((h|0)==1){break o}if(f){break p}}if(!(c&2)){break f}d=1;while(1){c=d&65535;if(c>>>0>z[a+480190>>1]){break f}f=D(c,104)+l|0;e=z[f+34>>1];Jb(g+20|0,x[i>>2],c-1|0);c=Zc(g,e&1?16:8,1,0,Gb(x[x[g+20>>2]>>2],x[g+24>>2])?6:0);x[31609]=0;U(215,c|0,f|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){d=d+1|0;continue}break}b=N()|0;break c}x[31609]=0;f=R(151,b|0)|0;h=x[31609];x[31609]=0;q:{r:{if((h|0)!=1){x[31609]=0;S(185,g|0,b|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break r}f=hc(g+20|0,g);ub(g);if(!e){break q}h=x[a+484344>>2];if(!Je(h,x[a+484348>>2],d&65535)){break q}x[31609]=0;S(239,Wb(h,d)|0,0,f|0);h=x[31609];x[31609]=0;if((h|0)!=1){break q}b=N()|0;ub(f);break c}b=N()|0;break c}b=N()|0;break c}ub(f);d=d+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}tf(i);d=1;break a}x[31609]=0;P(240,b|0,f+(e<<5)|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){d=d+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}x[31609]=0;e=g+20|0;O(241,b|0,e|0);h=x[31609];x[31609]=0;s:{if((h|0)==1){break s}x[31609]=0;O(242,e|0,D(f,104)+l|0);e=x[31609];x[31609]=0;if((e|0)==1){break s}e=y[g+36|0];Jb(g,x[i>>2],f-1|0);kf(g,(e&3)!=0);d=d+1|0;continue}break}b=N()|0}tf(i);break b}b=N()|0;Eb(g)}Q(b|0);p()}fb=g+80|0;return d|0}function Mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,q=0,r=0;d=fb-80|0;fb=d;h=-1;a:{b:{c:{d:{if(x[(x[x[b>>2]-12>>2]+b|0)+16>>2]){break d}ae(d- -64|0,b);e=x[d+72>>2];g=x[d+76>>2];f=d+56|0;$k(f);b=vj(b,f,8);if((y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24))!=1414681667|(y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24))!=776101705){Ci(b,e,g,0);break d}w[d+54>>1]=0;ng(b,d+54|0);k=w[d+54>>1];if((k-4&65535)>>>0<65534){break d}e=d+46|0;$k(e);e=vj(b,e,8);if((y[d+46|0]|y[d+47|0]<<8|(y[d+48|0]<<16|y[d+49|0]<<24))!=1933333571|(y[d+50|0]|y[d+51|0]<<8|(y[d+52|0]<<16|y[d+53|0]<<24))!=1111389030){break d}w[d+44>>1]=0;ng(e,d+44|0);g=w[d+44>>1];if((g-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(g>>>0<=3){b=Fb(d- -64|0);x[31609]=0;f=U(495,e|0,b|0,65535)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}if(!f){break i}x[31609]=0;f=d+32|0;S(496,f|0,c|0,b|0);i=x[31609];x[31609]=0;if((i|0)!=1){break j}break b}b=Fb(d- -64|0);x[31609]=0;f=P(498,e|0,b|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break c}if(!f){break h}x[31609]=0;f=d+32|0;S(496,f|0,c|0,b|0);i=x[31609];x[31609]=0;if((i|0)==1){break c}}zb(a+40|0,f);tb(f);tb(b);w[d+30>>1]=0;ng(e,d+30|0);w[d+28>>1]=0;ng(e,d+28|0);w[a>>1]=z[d+28>>1];w[d+26>>1]=0;k:{if((g|0)<=3){x[d+64>>2]=0;Gk(e,d- -64|0);b=x[d+64>>2];if(b>>>0>65535){break d}b=bm(b);w[d+26>>1]=b;break k}ng(e,d+26|0);b=z[d+26>>1]}i=a+52|0;m=b&65535;n=(g|0)>3;b=0;l:{m:{while(1){if((b&65535)>>>0>=m>>>0){break l}g=Fb(d- -64|0);x[31609]=0;w[d+8>>1]=0;O(934,e|0,d+8|0);f=x[31609];x[31609]=0;if((f|0)==1){break g}n:{if(!n){x[31609]=0;f=U(495,e|0,g|0,65535)|0;j=x[31609];x[31609]=0;if((j|0)==1){break g}if(f){break n}break e}x[31609]=0;f=P(498,e|0,g|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break g}if(!f){break e}}x[31609]=0;f=d+32|0;S(496,f|0,c|0,g|0);j=x[31609];x[31609]=0;if((j|0)!=1){x[31609]=0;j=P(931,i|0,d+8|0)|0;o=x[31609];x[31609]=0;if((o|0)==1){break m}zb(j,f);tb(f);tb(g);b=b+1|0;continue}break}h=N()|0;break f}h=N()|0;tb(d+32|0);break f}b=d+32|0;$k(b);b=vj(e,b,8);if((y[d+32|0]|y[d+33|0]<<8|(y[d+34|0]<<16|y[d+35|0]<<24))!=1933333571|(y[d+36|0]|y[d+37|0]<<8|(y[d+38|0]<<16|y[d+39|0]<<24))!=1161720678){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;o:{if((k|0)<=2){if(OQ(b,c)){break o}break d}if(!NQ(b,c)){break d}}q=d,r=wb(x[a+4>>2]),x[q+64>>2]=r;c=wb(x[a+8>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!Um(B[e>>2])){break d}Xe(d- -64|0);continue}break}c=a+16|0;p:{if((k|0)<=2){if(OQ(b,c)){break p}break d}if(!NQ(b,c)){break d}}q=d,r=wb(x[a+16>>2]),x[q+64>>2]=r;c=wb(x[a+20>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!Um(B[e>>2])){break d}Xe(d- -64|0);continue}break}q=a,r=oc(x[a+16>>2],x[a+20>>2]),x[q+36>>2]=r;w[d+24>>1]=0;ng(b,d+24|0);c=z[d+24>>1];w[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}w[d+22>>1]=0;ng(b,d+22|0);c=w[d+22>>1];w[a+30>>1]=c;if((c|0)<0){break d}x[d+16>>2]=0;wq(b,d+16|0);l=QQ(B[d+16>>2]);B[a+32>>2]=l;if(!Um(l)){break d}x[d+8>>2]=0;x[d+12>>2]=0;c=fb-32|0;fb=c;e=d+8|0;_k(c+16|0,e);Nm(c+24|0,b,x[c+16>>2],x[c+20>>2]);_k(c+8|0,e);fb=c+32|0;if(x[d+8>>2]!=1414681667|x[d+12>>2]!=776298313){break d}b=oc(x[a+4>>2],x[a+8>>2]);if(b>>>0>32767){break d}c=w[a+30>>1];e=z[a>>1];if(!(e?!(B[a+32>>2]<=E(0))&(c|0)>0:1)){break d}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break q}}b=0;c=x[a+36>>2];if(c){b=c-1|0;x[a+36>>2]=b}q=d,r=uh(b),x[q+64>>2]=r;x[d+4>>2]=0;b=d- -64|0;q=a,r=x[Zj(b,d+4|0,42224)>>2],x[q+36>>2]=r;xq(a);h=1;if(z[a>>1]!=3){break d}c=w[a+30>>1];if((c-w[a+28>>1]|0)>(XQ(oc(x[a+4>>2],x[a+8>>2]))|0)){break d}h=a+32|0;e=Nb(b);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=z[a+28>>1];w[d+4>>1]=b;q=d,r=(oc(x[a+4>>2],x[a+8>>2])+b|0)-1|0,w[q+6>>1]=r;x[31609]=0;w[d+2>>1]=0;ha(929,a|0,e|0,h|0,d+4|0,d+2|0)|0;a=x[31609];x[31609]=0;h=1;if((a|0)==1){break r}wc(e);break d}c=w[a+28>>1];g=x[a+4>>2];x[31609]=0;O(935,e|0,yb(g,b-c|0)|0);c=x[31609];x[31609]=0;if((c|0)!=1){b=b+1|0;c=z[a+30>>1];continue}}break}h=N()|0;wc(e);break a}tb(b);break d}tb(b);break d}h=N()|0}tb(g);break a}tb(g)}fb=d+80|0;return h|0}h=N()|0;tb(b);break a}h=N()|0;tb(b)}Q(h|0);p()}function Tia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;d=fb-304|0;fb=d;e=-1;a:{b:{c:{if(!nk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){f=Km(d+192|0,b);x[31609]=0;b=P(461,d+180|0,14062)|0;e=x[31609];x[31609]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((e|0)!=1){x[31609]=0;x[d+160>>2]=83886084;x[d+164>>2]=0;e=d+160|0;S(462,f|0,b|0,e|0);g=x[31609];x[31609]=0;if((g|0)==1){break A}Eb(b);v[d+179|0]=0;x[31609]=0;b=P(461,e|0,14778)|0;e=x[31609];x[31609]=0;if((e|0)==1){break z}x[31609]=0;S(463,f|0,d+179|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break y}Eb(b);c=Fc(d+156|0,y[d+179|0]?0:c);x[31609]=0;b=P(461,d+144|0,15869)|0;e=x[31609];x[31609]=0;if((e|0)==1){break x}e=x[c>>2];x[31609]=0;V(923,f|0,a+40|0,b|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break w}Eb(b);w[d+142>>1]=65535;x[31609]=0;b=P(461,d+128|0,15566)|0;e=x[31609];x[31609]=0;if((e|0)==1){break v}x[31609]=0;U(491,f|0,d+142|0,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break u}Eb(b);w[d+126>>1]=0;x[31609]=0;b=P(461,d+112|0,15467)|0;e=x[31609];x[31609]=0;if((e|0)==1){break t}x[31609]=0;U(491,f|0,d+126|0,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break s}Eb(b);w[a>>1]=z[d+126>>1];x[31609]=0;b=P(461,d+100|0,15140)|0;e=x[31609];x[31609]=0;if((e|0)==1){break r}c=x[c>>2];x[31609]=0;V(924,f|0,a+52|0,b|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break q}Eb(b);x[31609]=0;b=P(461,d+88|0,15081)|0;c=x[31609];x[31609]=0;if((c|0)==1){break p}x[31609]=0;S(915,f|0,a+36|0,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break o}Eb(b);x[31609]=0;b=P(461,d+76|0,15568)|0;c=x[31609];x[31609]=0;if((c|0)==1){break n}x[31609]=0;h=a+4|0;S(925,f|0,h|0,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break m}Eb(b);x[31609]=0;b=P(461,d- -64|0,15469)|0;c=x[31609];x[31609]=0;if((c|0)==1){break l}x[31609]=0;c=a+28|0;S(926,f|0,c|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break k}Eb(b);x[31609]=0;b=P(461,d+52|0,15324)|0;e=x[31609];x[31609]=0;if((e|0)==1){break j}x[31609]=0;S(926,f|0,a+30|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break i}Eb(b);x[31609]=0;b=P(461,d+40|0,15105)|0;e=x[31609];x[31609]=0;if((e|0)==1){break h}x[31609]=0;S(927,f|0,a+32|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break g}Eb(b);w[d+38>>1]=0;x[31609]=0;b=P(461,d+24|0,15060)|0;e=x[31609];x[31609]=0;if((e|0)==1){break c}x[31609]=0;U(491,f|0,d+38|0,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break f}Eb(b);i=QQ(B[a+32>>2]);B[a+32>>2]=i;e=-1;if(!Um(i)){break d}b=wb(x[a+4>>2]);x[d+20>>2]=b;g=wb(x[a+8>>2]);while(1){if(!Ib(b,g)){break e}if(!Um(B[b>>2])){break d}b=x[Xe(d+20|0)>>2];continue}}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;break a}a=N()|0;Eb(b);break a}a=N()|0;Eb(b);break a}if(ql(y[f|0])){break d}b=z[c>>1];if((b-301&65535)>>>0<64935){break d}g=z[a>>1];if(g>>>0>3|(g|0)==2){break d}j=w[a+30>>1];if((j|0)<0){break d}k=d,l=uh(x[a+36>>2]),x[k+20>>2]=l;x[d+16>>2]=0;k=a,l=x[Zj(d+20|0,d+16|0,42224)>>2],x[k+36>>2]=l;if(oc(x[a+4>>2],x[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:c=w[d+38>>1];if((c|0)<=0){break d}w[d+14>>1]=j;B[d+20>>2]=B[a+32>>2];x[31609]=0;w[d+16>>1]=b;w[d+18>>1]=(b+c|0)-1;a=ba(928,a|0,d+14|0,d+20|0,d+16|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){if(a){break B}break d}a=N()|0;break a;case 0:g=w[d+38>>1];if((g|0)<=0){break d}B[d+20>>2]=B[a+32>>2];x[31609]=0;w[d+16>>1]=b;w[d+18>>1]=(b+g|0)-1;a=ha(929,a|0,h|0,d+20|0,d+16|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){if(a){break B}break d}a=N()|0;break a;default:break C}}x[31609]=0;W(930,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}}e=1}Ch(f)}fb=d+304|0;return e|0}a=N()|0;break a}a=N()|0}Ch(f);Q(a|0);p()}function bt(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-592|0;fb=e;x[e+572>>2]=6;x[e+576>>2]=364;x[e+564>>2]=11;x[e+568>>2]=161;x[e+556>>2]=23;x[e+560>>2]=31;x[e+548>>2]=59;x[e+552>>2]=55;x[e+584>>2]=0;x[e+588>>2]=0;x[e+580>>2]=-1;v[e+446|0]=c;v[e+445|0]=37;v[e+447|0]=0;h=e+448|0;fa(h|0,100,e+445|0,e+548|0,x[b>>2])|0;f=e+32|0;x[e+28>>2]=f;x[e+16>>2]=0;x[e+20>>2]=0;x[e+12>>2]=h;h=Di(f,e+12|0,100,e+16|0,x[b>>2]);if((h|0)!=-1){l=b+484|0;j=b+460|0;i=b+172|0;k=b+4|0;h=(h<<2)+f|0;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){a=x[f>>2];x[31609]=0;a=U(1285,d|0,1,a|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}if(a){x[31609]=0;O(35,g|0,32);a=x[31609];x[31609]=0;if((a|0)==1){break c}while(1){f=f+4|0;if((h|0)==(f|0)){f=h;break b}a=x[f>>2];x[31609]=0;a=U(1285,d|0,1,a|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}if(a){continue}break}break b}x[e+8>>2]=f;x[31609]=0;x[e+4>>2]=0;a=ea(1380,e+8|0,h|0,k|0,i|0,d|0,e+4|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31609]=0;O(35,g|0,37);c=x[31609];x[31609]=0;if((c|0)==1){break c}x[31609]=0;O(35,g|0,((a|0)<84?65:97)|0);a=x[31609];x[31609]=0;if((a|0)!=1){break q}break c}x[31609]=0;x[e+8>>2]=f;a=ea(1380,e+8|0,h|0,i|0,j|0,d|0,e+4|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}a=a-i|0;c=(a|0)/12|0;if((a|0)<=287){x[31609]=0;O(35,g|0,37);f=x[31609];x[31609]=0;if((f|0)==1){break c}x[31609]=0;O(35,g|0,((a|0)<144?66:98)|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}if(m){break q}a=x[Wd(D(c,12)+i|0,0)>>2];x[31609]=0;a=U(1285,d|0,64,a|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}if(!a){break q}n=(Kb(g)+(Cb(x[g+4>>2],y[g+11|0])<<2)|0)-4|0,o=109,x[n>>2]=o;break q}if((Cb(x[b+464>>2],y[b+471|0])|0)==(0-Cb(x[b+476>>2],y[b+483|0])|0)){break p}x[31609]=0;x[e+8>>2]=f;a=ea(1380,e+8|0,h|0,j|0,l|0,d|0,e+4|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}if((a-j|0)>23){break p}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;O(35,g|0,112);a=x[31609];x[31609]=0;if((a|0)==1){break c}}f=x[e+8>>2];break b}x[e+8>>2]=f;a=x[f>>2];x[31609]=0;a=U(1285,d|0,64,a|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}if(a){x[31609]=0;a=ba(1381,e+28|0,h|0,e+4|0,d|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+28>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=x[f>>2];x[31609]=0;O(35,g|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}f=f+4|0;continue}}a=x[f>>2];x[31609]=0;a=P(1382,d|0,a|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}u:{if((a|0)==37){x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;O(35,g|0,37);break u}a=x[f>>2];x[31609]=0;O(35,g|0,a|0)}a=x[31609];x[31609]=0;if((a|0)==1){break c}f=f+4|0;break b}fb=e+592|0;return}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=89;break d}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=106;break d}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=121;break d}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=83;break d}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=77;break d}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=100;break d}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=72;break d}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=109;break d}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=73;break d}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=117;break d}x[31609]=0;O(35,g|0,37);a=x[31609];x[31609]=0;c=119}if((a|0)==1){break c}x[31609]=0;O(35,g|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}f=x[e+28>>2];continue}a=N()|0;Ub(g);Q(a|0);p()}x[e+28>>2]=f;continue}}go(12677);p()}function m1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;g=fb-864|0;fb=g;yc(b);e=fb-16|0;fb=e;d=g+92|0;xF(e+8|0,d);h=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(h|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(h|0)==(j|0);if(!e){wF(d)}a:{if(!e){break a}if(!zF(d)){break a}if(!Mb(x[b>>2],x[b+8>>2],yF(y[g+607|0]))){break a}l=1;if((c|0)==64){break a}Dd(a,2);x[a+480204>>2]=15e5;x[a+480208>>2]=x[a+480208>>2]|16777216;e=y[g+606|0];x[a+480188>>2]=4194322;x[a+480196>>2]=e;$j(Xb(x[a+484360>>2],y[a+484376|0]),b,y[g+607|0],65535,65535);e=Xb(x[a+484360>>2],y[a+484376|0]);q=g,r=wb(x[e>>2]),x[q+40>>2]=r;e=wb(x[e+4>>2]);b:{while(1){d=x[g+40>>2];if(Ib(d,e)){if(z[d>>1]>127){break b}ge(g+40|0);continue}break}eg(a);j=a+946304|0;m=a+484380|0;i=g+94|0;while(1){h=l&65535;if(h>>>0>z[a+480190>>1]){c:{l=1;d:{e:{f:{if(!(c&1)){break f}n=x[b+8>>2];h=a+484344|0;Tf(h,128);o=g+608|0;c=0;j=0;m=0;g:{while(1){if((c|0)==128){break g}d=g+16|0;e=(c<<1)+o|0;uF(d,b,(y[e|0]|y[e+1|0]<<8)+n|0,4674);e=hc(g+40|0,d);ub(d);i=x[e>>2];x[31609]=0;i=R(172,i|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}h:{if(!i){break h}x[31609]=0;i=U(196,h|0,c&65535,32)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}if(!i){break h}i=0;k=d;d=Wb(x[h>>2],c);af(k,x[d>>2],x[x[d+48>>2]+12>>2],0);while(1){i:{d=x[e>>2];x[31609]=0;d=U(150,d|0,x[g+48>>2],1)|0;f=x[31609];x[31609]=0;j:{k:{l:{m:{n:{if((f|0)!=1){if(!d){break i}x[31609]=0;d=R(197,e|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break c}o:{switch(d-251|0){case 0:break k;case 1:break l;case 2:break m;case 3:break n;case 4:break o;default:break j}}x[31609]=0;d=R(197,e|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break c}if(!d){break i}i=d+i|0;if(i>>>0>=32){break i}d=Wb(x[h>>2],c);af(g- -64|0,x[d>>2],x[x[d+48>>2]+12>>2],i);d=x[g+68>>2];x[g+16>>2]=x[g+64>>2];x[g+20>>2]=d;continue}break c}x[31609]=0;d=g- -64|0;O(198,d|0,e|0);f=x[31609];x[31609]=0;if((f|0)==1){break c}k=z[a+480188>>1];f=y[xb(d,0)|0];if(k>>>0<=f>>>0){break e}d=y[xb(d,1)|0];if(d>>>0>63){break e}q=Yc(x[g+16>>2],f),r=d+1|0,v[q+1|0]=r;continue}x[31609]=0;d=g- -64|0;O(198,d|0,e|0);f=x[31609];x[31609]=0;if((f|0)==1){break c}k=z[a+480188>>1];f=y[xb(d,0)|0];if(k>>>0<=f>>>0){break e}d=y[xb(d,1)|0];if(d>>>0>63){break e}f=Yc(x[g+16>>2],f);v[f+4|0]=d^63;v[f+2|0]=1;continue}x[31609]=0;d=R(197,e|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){f=Yc(x[g+16>>2],0);v[f+5|0]=d;v[f+3|0]=12;continue}break c}d=Yc(x[g+16>>2],0);v[d+5|0]=0;v[d+3|0]=14;continue}if(d>>>0>=z[a+480188>>1]){break e}x[31609]=0;f=R(197,e|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break c}if(f>>>0>=124){break e}q=Yc(x[g+16>>2],d),r=(D(f>>>4|0,12)+(f&15)|0)+13|0,v[q|0]=r;m=d|m;j=!(d&1)|j;continue}break}ub(e);c=c+1|0;continue}break}ub(e)}if(!(j&m&1)){break f}c=a+480280|0;e=z[a+480188>>1];b=0;while(1){if((b|0)==(e|0)){break f}w[(c+(b<<5)|0)+4>>1]=b<<8&256;b=b+1|0;continue}}Zh(a+1298344|0,14799);Zh(a+1298356|0,14808);Zh(a+1298368|0,14799);q=a,r=x[Fc(g+40|0,4)>>2],x[q+1298404>>2]=r;break a}ub(e);break b}}}else{e=g+81|0;d=fb-16|0;fb=d;p:{if(!Mb(x[b>>2],x[b+8>>2],11)){v[d|0]=0;Sh(e,11,d);break p}Lw(d+8|0,e);sd(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;x[g+48>>2]=0;x[g+40>>2]=0;x[g+44>>2]=0;f=xb(e,1);d=g+40|0;q=xb(d,0),r=y[f|0],v[q|0]=r;f=xb(e,6);q=xb(d,1),r=y[f|0],v[q|0]=r;f=xb(e,2);q=xb(d,2),r=y[f|0],v[q|0]=r;f=xb(e,7);q=xb(d,3),r=y[f|0],v[q|0]=r;f=xb(e,3);q=xb(d,4),r=y[f|0],v[q|0]=r;f=xb(e,8);q=xb(d,5),r=y[f|0],v[q|0]=r;f=xb(e,4);q=xb(d,6),r=y[f|0],v[q|0]=r;f=xb(e,9);q=xb(d,7),r=y[f|0],v[q|0]=r;f=xb(e,5);q=xb(d,8),r=y[f|0],v[q|0]=r;f=xb(e,10);q=xb(d,9),r=y[f|0],v[q|0]=r;e=xb(e,0);q=xb(d,10),r=y[e|0],v[q|0]=r;e=m+D(h,104)|0;nd(e,2);x[g+8>>2]=x[g+48>>2];d=x[g+44>>2];x[g>>2]=x[g+40>>2];x[g+4>>2]=d;Sk(e,1,g);d=g- -64|0;tF(d,(i+(h<<3)|0)-8|0);e=g+16|0;Cc(e,d);Ac(j+(h<<5)|0,e);l=l+1|0;tb(e);continue}break}a=N()|0;ub(e);Q(a|0);p()}l=0}fb=g+864|0;return l|0}function FS(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;i=fb-16|0;fb=i;a:{if(!Tc(d&255)){break a}k=a+1074992|0;f=k+D(b,872)|0;b:{j=e;e=z[a+480192>>1];if(!(j|(!(x[a+480180>>2]&17825824)|!e))){break b}if(Bj(x[f+656>>2])){break b}if(!x[f+76>>2]){break a}c=x[f+88>>2];if(!(x[f+20>>2]|x[f+24>>2])|c&1024){break a}c:{if(!(c&512)){break c}c=x[a+1298300>>2];if(!Ed(c)){break c}Ej(c,b,0);break a}a=eB(a,b);if((a|0)==65535){break a}a=Gq(k+D(a,872)|0,f);v[a+831|0]=0;v[a+805|0]=0;w[a+786>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;Wo(a+788|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[f>>2]=0;x[f+4>>2]=0;x[f+76>>2]=0;x[f+92>>2]=0;x[f+96>>2]=0;x[f+20>>2]=0;x[f+24>>2]=0;break a}m=x[f+104>>2];c=c>>>0<=e>>>0?c:0;h=x[(c?((c<<2)+a|0)+900380|0:f+656|0)>>2];d:{if(!h){break d}g=d-1|0;c=z[ac(h+236|0,g)>>1];e=a+1074312|0;Jb(i+8|0,e,104);e:{if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){Jb(i,e,34);if(Gb(x[x[i>>2]>>2],x[i+4>>2])){break e}}d=y[xb(h+108|0,g)|0]}if((c-1&65535)>>>0<=3998){m=(D(c,104)+a|0)+484380|0;break d}Jb(i+8|0,e,43);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break d}if(!Jj(y[h+31|0])){break a}}if(y[f+89|0]&4){break a}n=a+1074376|0;o=b>>>0<=256?256:b;l=a+1074312|0;p=b+1|0;c=b;f:{g:{while(1){if((c|0)==(o|0)){h:{c=0;if(Bj(x[f+656>>2])){break h}break g}}else{g=(b|0)==(c|0);i:{if(!g&z[a+480188>>1]>c>>>0){break i}e=k+D(c,872)|0;if(!g&z[e+786>>1]!=(p|0)){break i}g=x[e+656>>2];if(!g){break i}j:{k:{l:{m:{n:{o:{p:{switch(y[g+17|0]-1|0){case 0:if(!d){break i}j=(g|0)==(h|0)&y[e+797|0]==(d|0);if(!h){break o}if(j){break l}break i;case 1:if(!m|x[e+104>>2]!=(m|0)){break i}if((g|0)==(h|0)){break j}Jb(i+8|0,l,104);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break j}break i;case 3:break n;case 2:break p;default:break i}}if(h){break m}j=(g|0)==(h|0)}if(j){break j}break i}if(!h){break i}j=y[h+34|0];if(!j){break i}if((j|0)==y[g+34|0]){break k}break i}if((g|0)!=(h|0)){break i}}if(!y[h+34|0]){break j}}if(!y[e+797|0]|y[g+18|0]>2){break j}g=y[e+801|0];if(!g){break j}Xm(a,c&65535,g|256,0);v[e+801|0]=0}q:{r:{switch(y[x[e+656>>2]+18|0]){case 0:Fo(a,e);x[e+688>>2]=0;if(!(y[e+89|0]&2)){break q}g=x[a+1298300>>2];if(!Ed(g)){break q}Ej(g,c&65535,1);break q;case 1:Fo(a,e);if(!(y[e+89|0]&2)){break q}g=x[a+1298300>>2];if(!Ed(g)){break q}yk(g,c&65535);break q;case 2:break r;default:break q}}g=x[e+88>>2];x[e+88>>2]=g|4096;if(!(g&512)){break q}if(!Ed(x[a+1298300>>2])){break q}Jb(i+8|0,l,105);if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break q}yk(x[a+1298300>>2],c&65535)}if(x[e+688>>2]){break i}x[e+696>>2]=0;x[e+88>>2]=x[e+88>>2]|2101248}c=c+1|0;continue}break}if(!Tc(y[f+797|0])){break g}d=om(a,n,b,2,1)-1|0;if((d&255)>>>0>249){break g}d=x[$d(a+906300|0,d)>>2];if(!d){break g}e=1;h=y[f+801|0];if(!h){break f}c=ib[x[x[d>>2]+104>>2]](d,h,b)|0;break f}e=0}if(!(Mi(x[f+8>>2],x[f+12>>2])|c)){break a}s:{if(!(c&e)){break s}c=y[f+798|0];if(c>>>0>3|(c|0)==1){break s}Xm(a,b,255,0);w[f+800>>1]=0}e=eB(a,b);if((e|0)==65535){break a}c=k+D(e,872)|0;t:{if(!(y[c+89|0]&2)){break t}d=x[a+1298300>>2];if(!Ed(d)){break t}Ej(d,e,1)}d=Gq(c,f);h=x[c+88>>2];g=h&-917505;x[c+88>>2]=g;v[d+831|0]=0;k=z[a+480188>>1];v[d+805|0]=0;w[d+786>>1]=b>>>0<k>>>0?b+1|0:0;u:{v:{switch(y[f+798|0]){case 2:Fo(a,d);if(!(y[c+89|0]&2)){break u}h=x[a+1298300>>2];if(!Ed(h)){break u}yk(h,b);Jb(i+8|0,l,105);if(!Gb(x[x[i+8>>2]>>2],x[i+12>>2])){break u}TB(x[a+1298300>>2],b,e);break u;case 0:x[d+696>>2]=0;x[c+88>>2]=g|4096;if(!(h&512)){break u}a=x[a+1298300>>2];if(!Ed(a)){break u}Ej(a,b,1);break u;case 3:x[c+88>>2]=g|4096;if(!(h&512)){break u}if(!Ed(x[a+1298300>>2])){break u}Jb(i+8|0,l,105);a=x[a+1298300>>2];if(Gb(x[x[i+8>>2]>>2],x[i+12>>2])){TB(a,b,e);break u}yk(a,b);break u;case 1:break v;default:break u}}if(!(h&512)){break u}a=x[a+1298300>>2];if(!Ed(a)){break u}TB(a,b,e)}if(!x[d+688>>2]){x[d+696>>2]=0;x[c+88>>2]=x[c+88>>2]|2101248}x[f>>2]=0;x[f+4>>2]=0;x[f+76>>2]=0;x[f+92>>2]=0;x[f+96>>2]=0}fb=i+16|0}function uL(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;i=fb-560|0;fb=i;g=c;c=(c-3|0)/24|0;t=(c|0)>0?c:0;k=g+D(t,-24)|0;n=x[(e<<2)+89920>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=t-j|0;while(1){C[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+x[(c<<2)+89936>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;h=(n|0)>0?n:0;m=(d|0)<=0;while(1){a:{if(m){f=0;break a}r=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(r-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;c=(g|0)==(h|0);g=g+1|0;if(!c){continue}break}y=47-k|0;r=48-k|0;u=(k|0)<25;z=k-25|0;g=n;while(1){f=C[(g<<3)+i>>3];c=0;h=g;o=(g|0)<=0;if(!o){while(1){m=(i+480|0)+(c<<2)|0;l=f*5.960464477539063e-8;b:{if(F(l)<2147483648){j=~~l;break b}j=-2147483648}l=+(j|0);f=l*-16777216+f;c:{if(F(f)<2147483648){j=~~f;break c}j=-2147483648}x[m>>2]=j;h=h-1|0;f=C[(h<<3)+i>>3]+l;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=ok(f,q);f=f+J(f*.125)*-8;d:{if(F(f)<2147483648){m=~~f;break d}m=-2147483648}f=f-+(m|0);e:{f:{g:{h:{if(!u){h=(g<<2)+i|0;j=x[h+476>>2];c=j>>r;s=h;h=j-(c<<r)|0;x[s+476>>2]=h;m=c+m|0;j=h>>y;break h}if(q){break g}j=x[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break e}break f}j=2;if(f>=.5){break f}j=0;break e}c=0;h=0;if(!o){while(1){s=(i+480|0)+(c<<2)|0;o=x[s>>2];v=16777215;i:{j:{if(h){break j}v=16777216;if(o){break j}h=0;break i}x[s>>2]=v-o;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}k:{if(u){break k}c=8388607;l:{switch(z|0){case 1:c=4194303;break;case 0:break l;default:break k}}o=(g<<2)+i|0;x[o+476>>2]=x[o+476>>2]&c}m=m+1|0;if((j|0)!=2){break e}f=1-f;j=2;if(!h){break e}f=f-ok(1,q)}m:{n:{if(f==0){h=0;c=g;if((c|0)<=(n|0)){break m}while(1){c=c-1|0;h=x[(i+480|0)+(c<<2)>>2]|h;if((c|0)>(n|0)){continue}break}if(!h){break m}k=q;while(1){k=k-24|0;g=g-1|0;if(!x[(i+480|0)+(g<<2)>>2]){continue}break}break n}f=ok(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;l=f*5.960464477539063e-8;p:{if(F(l)<2147483648){c=~~l;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}k=q}x[(i+480|0)+(g<<2)>>2]=c}f=ok(1,k);if((g|0)>=0){d=g;while(1){a=d;C[(a<<3)+i>>3]=f*+x[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}h=g;while(1){f=0;c=0;a=g-h|0;d=(a|0)>(n|0)?n:a;if((d|0)>=0){while(1){f=C[(c<<3)+92704>>3]*C[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}}C[(i+160|0)+(a<<3)>>3]=f;a=(h|0)>0;h=h-1|0;if(a){continue}break}}r:{s:{t:{switch(e-1|0){case 2:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=C[d>>3];c=g;while(1){l=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;w=C[h>>3];f=w+f;C[e+(c<<3)>>3]=l+(w-f);C[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)==1){break u}f=C[d>>3];c=g;while(1){l=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=l+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+C[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[i+160>>3];if(j){break s}C[b>>3]=f;f=C[i+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break r;default:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break r;case 0:case 1:break t}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break r}C[b>>3]=-f;f=C[i+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}fb=i+560|0;return m&7}c=1;while(1){h=c;c=c+1|0;if(!x[(i+480|0)+(n-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;C[(i+320|0)+(j<<3)>>3]=x[(t+g<<2)+89936>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}}function Ppa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-192|0;fb=d;yc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{g=d+180|0;l:{if(!gp(b,g)){break l}if(!GX(g)){break l}g=Yh(d+160|0);h=Fb(d+148|0);fw(d+84|0);x[31609]=0;f=P(617,b|0,d+76|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break h}m:{if(!f){break m}n=d,o=$b($b(x[d+80>>2])-4|0),x[n+80>>2]=o;j=(c|0)!=64;while(1){f=$b($b(x[d+80>>2])-8|0);x[d+80>>2]=f;n:{if(j){break n}if(($b(x[d+76>>2])|0)!=1347699796){break n}k=1;break m}x[31609]=0;e=d+56|0;S(185,e|0,b|0,$b(f)|0);f=x[31609];x[31609]=0;if((f|0)==1){break d}f=hc(d,e);ub(e);e=x[f>>2];x[31609]=0;i=R(172,e|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=$b(x[d+76>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}x[31609]=0;P(183,f|0,4)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}x[31609]=0;e=R(618,f|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break b}if(!e){break o}e=$b(x[d+80>>2]);if(e>>>0<7){break o}l=x[Fc(d+52|0,28)>>2];x[31609]=0;V(619,f|0,h|0,l|0,e-6|0);e=x[31609];x[31609]=0;if((e|0)==1){break b}break o}x[31609]=0;m=P(620,f|0,d+84|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break o}break b}ax(g,f);break o}x[31609]=0;k=U(621,a|0,f|0,c|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}}ub(f);if(i){x[31609]=0;f=P(617,b|0,d+76|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break i}if(f){continue}}break}if(Ad(x[h+4>>2],y[h+11|0])){x[31609]=0;b=P(1,d+56|0,14978)|0;c=x[31609];x[31609]=0;if((c|0)==1){break g}zb(h,b);tb(b)}q:{if(!(k&m&1)){break q}b=y[d+126|0]|y[d+127|0]<<8;x[31609]=0;b=Bb(b)&256;U(266,a+1074312|0,5,!b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break f}c=Bb(y[d+122|0]|y[d+123|0]<<8);if(c){w[d>>1]=64;w[d+40>>1]=c;n=a,o=z[Oc(d,d+40|0)>>1],x[n+480228>>2]=o}c=!b;b=Bb(y[d+124|0]|y[d+125|0]<<8);if(!(c|!b)){x[a+480204>>2]=D(b,1e4)}if(y[d+84|0]){b=d+40|0;Ue(b,2,d+84|0);x[31609]=0;O(218,d|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break e}zb(a+1298308|0,d);tb(d)}c=y[d+130|0]|y[d+131|0]<<8;if(!er(c,1,12)){break q}f=y[d+128|0]|y[d+129|0]<<8;if(!er(f,1,31)){break q}e=y[d+134|0]|y[d+135|0]<<8;if(!er(e,0,23)){break q}i=y[d+136|0]|y[d+137|0]<<8;if(!er(i,0,59)){break q}j=y[d+138|0]|y[d+139|0]<<8;if(!er(j,0,59)){break q}x[a+1298408>>2]=0;b=kp(d);n=b,o=Bb(y[d+132|0]|y[d+133|0]<<8)+1900|0,x[n>>2]=o;n=b,o=Bb(c),x[n+4>>2]=o;n=b,o=Bb(f),x[n+8>>2]=o;n=b,o=Bb(e),x[n+12>>2]=o;n=b,o=Bb(i),x[n+16>>2]=o;n=b,o=Bb(j),x[n+24>>2]=o;x[b+28>>2]=0;x[31609]=0;O(447,a+1298412|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break q}a=N()|0;break a}if(k&1){b=x[g>>2];x[31609]=0;b=R(172,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break h}if(b){b=Fb(d);x[31609]=0;S(270,g|0,b|0,32);c=x[31609];x[31609]=0;if((c|0)==1){break c}if(!Nd(b,13859)){x[31609]=0;c=d+40|0;S(258,c|0,28,b|0);f=x[31609];x[31609]=0;if((f|0)==1){break c}zb(a+1298320|0,c);tb(c)}c=x[g+8>>2];f=x[g>>2];x[31609]=0;c=P(622,f|0,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break c}if(!c){x[31609]=0;c=R(202,g|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break c}x[31609]=0;aa(316,a+1298332|0,g|0,c|0,40,0);c=x[31609];x[31609]=0;if((c|0)==1){break c}}tb(b)}x[31609]=0;b=P(1,d+40|0,18176)|0;c=x[31609];x[31609]=0;if((c|0)==1){break k}x[31609]=0;S(489,d|0,b|0,h|0);c=x[31609];x[31609]=0;if((c|0)==1){break j}zb(a+1298368|0,d);tb(d);tb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[31609]=0;a=U(266,a+1074312|0,84,1)|0;b=x[31609];x[31609]=0;if((b|0)==1){break h}x[31609]=0;a=U(266,a|0,83,1)|0;b=x[31609];x[31609]=0;if((b|0)==1){break h}x[31609]=0;P(267,a|0,85)|0;a=x[31609];x[31609]=0;if((a|0)==1){break h}}tb(h);ub(g)}fb=d+192|0;return k&1}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;ub(f)}tb(h);ub(g);Q(a|0);p()}function Iz(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=fb-48|0;fb=l;x[l+44>>2]=0;a:{if(d|g|h|i){j=g?l+44|0:0;b:{if(!j){break b}k=x[j>>2];if(!k){break b}Db(k);x[j>>2]=0}x[31609]=0;X(84);k=x[31609];x[31609]=0;c:{d:{if((k|0)==1){m=Va(124540,47392,47448,48428,124728,124832,124780,124672,124660,124976,124944,124912,124900,125124,0)|0;e:{f:{n=gb;if((n|0)==($(124540)|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=277;if((j|0)==1){break f}break c}if(($(47392)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=358;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(47448)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=359;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(48428)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=357;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(124728)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=300;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(124832)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=299;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(124780)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=298;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(124672)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=297;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(124660)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=296;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(124976)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=289;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(124944)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=288;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(124912)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=287;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}if(($(124900)|0)==(n|0)){k=Y(m|0)|0;x[31609]=0;O(1098,j|0,k|0);j=x[31609];x[31609]=0;k=286;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break e}o=$(125124)|0;k=257;m=Y(m|0)|0;if((n|0)!=(o|0)){break c}x[31609]=0;O(1098,j|0,m|0);j=x[31609];x[31609]=0;k=267;if((j|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break e}break d}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break d}}T(0)|0;Sb()}p()}Q(a|0);p()}Z();m=!g;if(d){j=ib[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){x[g+16>>2]=k;m=g;g=x[l+44>>2];q=m,r=Cg(g?g:22292),x[q+20>>2]=r}if(h){x[h>>2]=k}g=x[l+44>>2];if(i){q=i,r=Cg(g?g:22292),x[q>>2]=r;g=x[l+44>>2]}if(g){Db(g);x[l+44>>2]=0}if(!(j&1)){break a}}x[31609]=0;g=l+32|0;O(1096,g|0,a|0);h=x[31609];x[31609]=0;g:{h:{if((h|0)!=1){i:{if(f){h=x[f+24>>2];x[31609]=0;O(1097,h|0,g|0);g=x[31609];x[31609]=0;if((g|0)!=1){break i}break h}g=Kb(l+32|0);if(b){x[31609]=0;O(b|0,g|0,c|0);g=x[31609];x[31609]=0;if((g|0)==1){break h}break i}ku(g,l)}tb(l+32|0);break a}g=T(0)|0;break g}g=T(0)|0;tb(l+32|0)}Y(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+8>>2]=a?a:22292;x[l+4>>2]=254;x[l>>2]=9190;pP(18485,l);ju(125480);Z()}fb=l+48|0}function Mo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;f=fb+-64|0;fb=f;r=NB(x[a+24>>2],y[a+32|0]);t=Hj(r);c=t;e=x[a>>2];d=Ud(e,x[a+4>>2]);a:{if(c>>>0>d>>>0){k=fb-32|0;fb=k;c=c-d|0;d=x[Ab(a)>>2];e=x[a+4>>2];b:{if(c>>>0<=(d-e|0)/12>>>0){e=fb-16|0;fb=e;c=uv(e+4|0,a,c);d=x[c+4>>2];g=x[c+8>>2];while(1){if((d|0)==(g|0)){jc(c);fb=e+16|0}else{RT(d);d=d+12|0;x[c+4>>2]=d;continue}break}break b}d=Ab(a);d=ym(k+12|0,Qp(a,Ud(x[a>>2],e)+c|0),Ud(x[a>>2],x[a+4>>2]),d);g=fb-16|0;fb=g;c=lW(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){RT(e);e=x[c>>2]+12|0;x[c>>2]=e;continue}break}je(c);fb=g+16|0;g=fb-16|0;fb=g;h=Ab(a);c=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);j=vb(g+4|0,x[d+4>>2]);e=x[c>>2];i=x[i>>2];c=fb+-64|0;fb=c;j=x[j>>2];x[c+56>>2]=j;x[c+60>>2]=e;x[c+52>>2]=j;h=Ag(c+24|0,h,c+52|0,c+56|0);x[c+16>>2]=x[h+8>>2];j=x[h+4>>2];x[c+8>>2]=x[h>>2];x[c+12>>2]=j;zg(c+36|0,c+8|0);while(1){if(Fd(e,i)){DC(Pp(x[c+56>>2]),bl(e));e=jk(c+60|0);jk(c+56|0);e=x[e>>2];continue}break}yg(c+36|0);j=x[c+56>>2];if(!y[c+48|0]){h=fb-16|0;fb=h;e=vb(h+12|0,x[x[c+44>>2]>>2]);n=x[vb(h+8|0,x[x[c+40>>2]>>2])>>2];i=fb-16|0;fb=i;e=x[e>>2];x[i+12>>2]=e;while(1){if(wi(e,n)){tf(Ax(e));e=x[xm(i+12|0)>>2];continue}break}fb=i+16|0;fb=h+16|0}fb=c- -64|0;x[d+4>>2]=j;Tb(a,d+4|0);Tb(a+4|0,d+8|0);Tb(Ab(a),nc(d));x[d>>2]=x[d+4>>2];fb=g+16|0;c=x[d+4>>2];while(1){e=x[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;x[d+8>>2]=e;tf(e);continue}break}c=x[d>>2];if(c){vs(d);Db(c)}}fb=k+32|0;break a}if(c>>>0<d>>>0){YT(a,e+D(c,12)|0)}}if(b){c=a+12|0;Mq(c,de(c));A=Ab(c),B=0,x[A>>2]=B;d=c;c=gc(c);x[d>>2]=c;x[c>>2]=0;x[a+28>>2]=0}h=Nb(f+52|0);c=x[a+24>>2];c=Zu(x[c+484344>>2],x[c+484348>>2]);x[31609]=0;i=U(626,f+40|0,c|0,28556)|0;c=x[31609];x[31609]=0;c:{if((c|0)!=1){g=a+12|0;while(1){if((l|0)==(t|0)){od(i);fc(h);fb=f- -64|0;return}c=x[a+24>>2];d=x[c+484344>>2];c=x[c+484348>>2];j=z[ac(x[r>>2],l)>>1];d=bU(d,c,j);x[f+36>>2]=d;c=Vd(x[a>>2],l);d:{e:{f:{if(b){x[31609]=0;v[f+20|0]=0;S(802,c|0,d|0,f+20|0);d=x[31609];x[31609]=0;if((d|0)!=1){break f}d=N()|0;break e}x[31609]=0;O(758,c|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){break f}d=N()|0;break e}if(!Wi(r,l&65535)){break d}x[f+20>>2]=b?0:x[c+4>>2];c=f+20|0;s=x[Hb(c,f+36|0)>>2];n=Pf(g);d=z[ac(x[i>>2],j)>>1];if((d|0)!=65535){d=$T(g,z[bn(c,d,s)>>1],x[f+24>>2]);g:{if(Zg(d,Pf(g))){c=$T(g,z[bn(c,z[ac(x[i>>2],j)>>1],x[f+36>>2])>>1],x[f+24>>2]);break g}c=Pf(g)}x[f+32>>2]=d;while(1){h:{if(!Zg(d,c)){break d}e=Nb(f+20|0);d=Sn(ud(d)+8|0);x[31609]=0;O(803,e|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){d=Fc(f+12|0,n);k=bn(f+4|0,l,x[ud(x[f+32>>2])+4>>2]);d=x[d>>2];x[31609]=0;d=ba(804,g|0,d|0,k|0,e|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break h}x[f+16>>2]=d;n=x[ah(f+16|0)>>2];Ce(e);d=x[ah(f+32|0)>>2];continue}}break}d=N()|0;Ce(e);break e}q=Wb(x[x[a+24>>2]+484344>>2],j);c=z[x[x[q+48>>2]+12>>2]+480188>>1];x[31609]=0;v[f+20|0]=0;S(779,h|0,c|0,f+20|0);c=x[31609];x[31609]=0;if((c|0)!=1){o=x[f+36>>2];i:while(1){j:{if((o|0)==(s|0)){if(s){break d}A=ac(x[i>>2],j),B=l,w[A>>1]=B;break d}c=1;k=0;e=x[x[q+48>>2]+12>>2];o=o-1|0;d=md(x[q>>2],e,o,0);while(1){if(c>>>0<16&z[e+480188>>1]>k>>>0){u=xb(x[h>>2],k);e=y[u|0];k:{l:{m:{switch(y[d+3|0]-19|0){case 1:m=y[d+5|0];if((m&240)==176){break l}break k;case 0:break m;default:break k}}m=y[d+5|0];if((m&240)!=96){break k}}v[u|0]=m&15;m=y[xb(x[h>>2],k)|0];e=m?m:e}d=d+6|0;k=k+1|0;c=D((e&255)+1|0,c);e=x[x[q+48>>2]+12>>2];continue}else{n:{if(c>>>0<=1){continue i}e=Nb(f+20|0);x[31609]=0;O(803,e|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break n}c=Fc(f,n);d=bn(f+4|0,l,o);c=x[c>>2];x[31609]=0;n=ba(804,g|0,c|0,d|0,e|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break j}Ce(e);continue i}}break}}break}d=N()|0;Ce(e);break e}d=N()|0}od(i);break c}l=l+1|0;continue}}d=N()|0}fc(h);Q(d|0);p()}function y7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-48|0;fb=h;x[h+44>>2]=b;x[e>>2]=0;cd(h,x[d+28>>2]);x[31609]=0;i=R(1252,x[h>>2])|0;j=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){_b(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;_b(h);Q(a|0);p()}hK(a,f+24|0,h+44|0,c,e,i);break b}fK(a,f+16|0,h+44|0,c,e,i);break b}b=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;g=a;i=x[h+44>>2];a=Kb(b);k=h,l=qk(g,i,c,d,e,f,a,a+(Cb(x[b+4>>2],y[b+11|0])<<2)|0),x[k+44>>2]=l;break b}a=gj(h+44|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h+24>>2]=37;x[h+28>>2]=121;x[h+16>>2]=100;x[h+20>>2]=47;x[h+8>>2]=47;x[h+12>>2]=37;x[h>>2]=37;x[h+4>>2]=109;k=h,l=qk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}x[h+24>>2]=37;x[h+28>>2]=100;x[h+16>>2]=109;x[h+20>>2]=45;x[h+8>>2]=45;x[h+12>>2]=37;x[h>>2]=37;x[h+4>>2]=89;k=h,l=qk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=gj(h+44|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=gj(h+44|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=gj(h+44|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=gj(h+44|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=gj(h+44|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+44|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(fi(a,b+12|0)){break H}if(!oj(i,1,sl(x[a>>2]))){break H}jo(a);continue}break}if(fi(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+44|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Cb(x[a+4>>2],y[a+11|0])|0)==(0-Cb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=tt(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}x[h+40>>2]=112;x[h+32>>2]=32;x[h+36>>2]=37;x[h+24>>2]=37;x[h+28>>2]=83;x[h+16>>2]=77;x[h+20>>2]=58;x[h+8>>2]=58;x[h+12>>2]=37;x[h>>2]=37;x[h+4>>2]=73;k=h,l=qk(a,b,c,d,e,f,h,h+44|0),x[k+44>>2]=l;break b}x[h+16>>2]=77;x[h+8>>2]=58;x[h+12>>2]=37;x[h>>2]=37;x[h+4>>2]=72;k=h,l=qk(a,b,c,d,e,f,h,h+20|0),x[k+44>>2]=l;break b}a=gj(h+44|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h+24>>2]=37;x[h+28>>2]=83;x[h+16>>2]=77;x[h+20>>2]=58;x[h+8>>2]=58;x[h+12>>2]=37;x[h>>2]=37;x[h+4>>2]=72;k=h,l=qk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=gj(h+44|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;g=a;i=x[h+44>>2];a=Kb(b);k=h,l=qk(g,i,c,d,e,f,a,a+(Cb(x[b+4>>2],y[b+11|0])<<2)|0),x[k+44>>2]=l;break b}eK(f+20|0,h+44|0,c,e,i);break b}a=gj(h+44|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+44|0;d=a+12|0;L:{M:{if(fi(c,d)){break M}b=4;if((pk(i,sl(x[c>>2]))|0)!=37){break M}b=2;if(!fi(jo(c),d)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+44>>2]}fb=h+48|0;return a|0}function gsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;i=fb-720|0;fb=i;a:{b:{if(d>>>0<=511){d=fb-16|0;fb=d;a=i+46|0;cc(d+8|0,a,554);e=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(b,x[d+12>>2])}fb=d+16|0;b=(e|0)==(f|0);if(!b){Rb(a,0,554)}if(!b){break b}d=fb-32|0;fb=d;c:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1229999433){break c}e=d+8|0;Yr(e,a+32|0);b=d+20|0;Cc(b,e);Ac(c+492|0,b);tb(b);dk(e,1,a+4|0);Cc(b,e);Ac(c+524|0,b);tb(b);b=y[a+24|0]|y[a+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[a+26|0];v[c+17|0]=y[a+27|0];f=c+108|0;j=c+236|0;h=a- -64|0;b=0;while(1)if((b|0)==120){b=y[c+60|0]&-2|v[a+17|0]&1;v[c+60|0]=b;b=b&-3|y[a+17|0]&2;v[c+60|0]=b;v[c+60|0]=b&251|y[a+17|0]&4;v[c+61|0]=y[a+18|0];v[c+62|0]=y[a+19|0];v[c+63|0]=y[a+20|0];v[c+64|0]=y[a+21|0];e=c+48|0;fh(e,25);f=a+504|0;j=c- -64|0;h=c+63|0;g=c+62|0;k=c+61|0;a=x[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=yb(a,b);m=f+(b<<1)|0;n=y[m|0];w[l>>1]=n;if((n|0)!=255){break d}fh(e,b);a=x[e>>2]}b=cf(k,g);a=Sd(a,x[c+52>>2]);if(a>>>0<=y[b|0]){v[c+60|0]=y[c+60|0]&253}if(a>>>0>y[cf(h,j)|0]){break c}v[c+60|0]=y[c+60|0]&251;break c}v[l+2|0]=y[m+1|0];b=b+1|0;continue}}else{g=h+(b<<1)|0;e=y[g|0];o=ac(j,b),q=y[g+1|0],w[o>>1]=q;o=xb(f,b),q=(e>>>0<120?e:b)+1|0,v[o|0]=q;b=b+1|0;continue}}fb=d+32|0;break b}j=x[b+8>>2];d=fb-32|0;fb=d;x[d+28>>2]=674;x[d+8>>2]=674;e=x[b>>2];g=x[b+8>>2];f=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(e,g,f)){f=jf(b)}h=d+8|0;e=i+46|0;JZ(h,e);g=Zb(d+16|0,x[d+8>>2],f);k=x[g>>2];kc(d,x[b>>2],x[b+8>>2],k,x[g+4>>2]);JZ(h,e);Rb(x[d+8>>2]+f|0,0,674-f|0);Vb(b,x[d+28>>2]);fb=d+32|0;h=x[a+480180>>2];a=0;d=fb-32|0;fb=d;if((y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24))==1229999433){f=d+8|0;Yr(f,e+32|0);a=d+20|0;Cc(a,f);Ac(c+492|0,a);tb(a);dk(f,1,e+4|0);Cc(a,f);Ac(c+524|0,a);tb(a);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;xc(c+4|0,64);g=y[e+25|0]&127;x[c+8>>2]=g>>>0>64?128:g<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[d+20|0]=y[e+26|0];v[d+8|0]=100;o=c,q=y[Qb(a,f)|0],v[o+20|0]=q;v[d+20|0]=y[e+27|0];v[d+8|0]=64;o=c,q=y[Qb(a,f)|0],v[o+19|0]=q;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];a=y[e+58|0];ck(c,a&127,a>>>7|0);a=y[e+59|0];bk(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=y[e+28|0]|y[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=y[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){v[c+30|0]=a}a=y[e+62|0]|y[e+63|0]<<8;if(a>>>0<129){break f}break e}a=v[e+61|0];if((a|0)<0){break g}v[c+30|0]=a+1}a=v[e+62|0];a=((a|0)>=0?a+1|0:0)&255;f=v[e+63|0];if((f|0)<0){break f}a=((f&255)<<7)+a|0}w[c+28>>1]=a}a=v[e+60|0];v[c+31|0]=a;if((a|0)<0){v[c+31|0]=0;v[c+34|0]=a&127}a=0;f=h&16777216?240:25;Xw(e+304|0,c+48|0,0,f);Xw(e+386|0,c+68|0,32,f);Xw(e+468|0,c+88|0,32,f);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;h=c+108|0;g=c+236|0;k=e- -64|0;while(1){if((a|0)!=120){l=k+(a<<1)|0;f=y[l|0];o=ac(g,a),q=y[l+1|0],w[o>>1]=q;o=xb(h,a),q=(f>>>0<120?f:a)+1|0,v[o|0]=q;a=a+1|0;continue}break}a=554}fb=d+32|0;d=0;k:{if(!a){break k}d=y[e+550|0]|y[e+551|0]<<8|(y[e+552|0]<<16|y[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){d=c+236|0;e=e+554|0;a=0;while(1){if((a|0)!=120){f=ac(d,a);w[f>>1]=z[f>>1]|y[a+e|0]<<8;a=a+1|0;continue}break}a=674}d=a}dd(b,d+j|0);if(!ak(b,14092)){break b}d=i+4|0;he(d,b,Rg(b));a=hc(i+24|0,d);ub(d);b=x[a>>2];x[31609]=0;R(154,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}x[31609]=0;b=P(412,a|0,13874)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}if(b){x[31609]=0;b=R(197,a|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}v[c+34|0]=b>>>0<=250?b:0}ub(a)}fb=i+720|0;return}b=N()|0;ub(a);Q(b|0);p()}function Qoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-736|0;fb=d;yc(b);f=fb-16|0;fb=f;g=d+128|0;TW(f+8|0,g);e=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);h=x[f+4>>2];if((h|0)==(e|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(e|0)==(h|0);if(!f){SW(g)}a:{if(!f){break a}if(!VW(g)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(UW(y[d+162|0]|y[d+163|0]<<8),hb))){break a}o=1;if((c|0)==64){break a}Dd(a,262144);e=d+92|0;Vi(e,2,g);f=d+12|0;Cc(f,e);zb(a+1298308|0,f);tb(f);g=uc(f,8317);zb(a+1298344|0,g);tb(g);g=uc(f,10141);zb(a+1298356|0,g);tb(g);g=fb-16|0;fb=g;h=uc(g+4|0,4193);Uc(e,h);tb(h);fb=g+16|0;v[d|0]=y[d+158|0];x[31609]=0;v[d+115|0]=y[d+157|0];g=d+116|0;O(691,g|0,d+115|0);h=x[31609];x[31609]=0;b:{c:{d:{if((h|0)!=1){x[31609]=0;V(250,f|0,e|0,d|0,g|0);h=x[31609];x[31609]=0;if((h|0)!=1){zb(a+1298368|0,f);tb(f);tb(g);Eb(e);t=a,u=x[Fc(f,4)>>2],x[t+1298404>>2]=u;x[a+480208>>2]=12;w[a+480188>>1]=y[d+166|0]|y[d+167|0]<<8;w[d+12>>1]=y[d+162|0]|y[d+163|0]<<8;w[d+92>>1]=3999;t=a,u=z[Oc(f,e)>>1],w[t+480190>>1]=u;z_(Xb(x[a+484360>>2],y[a+484376|0]),d+224|0,y[d+160|0]|y[d+161|0]<<8);e=a+480280|0;g=d+192|0;f=0;while(1)if(z[a+480188>>1]<=f>>>0){f=d+12|0;he(f,b,D(y[d+162|0]|y[d+163|0]<<8,80));m=c&2;j=a+946304|0;o=a+484380|0;g=hc(d+92|0,f);ub(f);n=d+60|0;f=0;e:{f:{while(1){if(z[a+480190>>1]<=f>>>0){o=1;if(c&1){break f}break b}x[31609]=0;h=d+12|0;O(692,g|0,h|0);e=x[31609];x[31609]=0;if((e|0)==1){break e}Vi(d,2,n);x[31609]=0;e=d+116|0;O(218,e|0,d|0);i=x[31609];x[31609]=0;if((i|0)==1){break e}f=f+1|0;Ac(j+(f<<5)|0,e);tb(e);x[31609]=0;i=h;h=o+D(f,104)|0;S(693,e|0,i|0,h|0);i=x[31609];x[31609]=0;g:{if((i|0)==1){break g}if(!m|!x[h>>2]){continue}x[31609]=0;i=P(149,b|0,y[d+30|0]|y[d+31|0]<<8|(y[d+32|0]<<16|y[d+33|0]<<24))|0;k=x[31609];x[31609]=0;if((k|0)==1){break g}if(!i){continue}x[31609]=0;U(215,e|0,h|0,b|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){continue}}break}break e}x[31609]=0;n=a+484344|0;O(223,n|0,y[d+164|0]|y[d+165|0]<<8);c=x[31609];x[31609]=0;if((c|0)==1){break e}r=d+480|0;f=0;while(1){if((y[d+164|0]|y[d+165|0]<<8)>>>0<=f>>>0){break b}x[31609]=0;c=U(196,n|0,f&65535,64)|0;e=x[31609];x[31609]=0;if((e|0)==1){break e}h:{if(!c){break h}c=(f<<1)+r|0;c=y[c|0]|y[c+1|0]<<8;if(!c){break h}x[31609]=0;c=P(149,b|0,c<<4)|0;e=x[31609];x[31609]=0;if((e|0)==1){break e}if(!c){break h}h=0;c=Wb(x[n>>2],f);m=md(x[c>>2],x[x[c+48>>2]+12>>2],0,0);i:while(1){s=h>>>0>63;while(1){if(s){break h}c=x[b+8>>2];e=x[b>>2];x[31609]=0;c=U(150,e|0,c|0,1)|0;e=x[31609];x[31609]=0;j:{if((e|0)!=1){if(!c){break h}x[31609]=0;c=R(197,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break e}j=c<<24>>24;if(j){break j}h=h+1|0;m=D(z[a+480188>>1],6)+m|0;continue i}break e}w[d+16>>1]=0;x[d+12>>2]=0;c=j&31;i=D(c,6)+m|0;e=Ng(d+12|0);k=c>>>0<z[a+480188>>1];c=k?i:e;l=j&255;k:{if(!(l&32)){break k}x[31609]=0;q=d+116|0;O(198,q|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break e}e=y[d+116|0];v[c|0]=e;t=c,u=y[Jc(q)|0],v[t+1|0]=u;l:{if(e){if((e|0)==254){break l}if(e>>>0<121){break k}}e=0}v[c|0]=e}m:{if(!(l&64)){break m}x[31609]=0;e=d+116|0;O(198,e|0,b|0);l=x[31609];x[31609]=0;if((l|0)==1){break e}l=y[Jc(e)|0];v[c+5|0]=l;e=y[d+116|0];n:{if(e>>>0<=15){Cf(c,e,l);break n}v[(k?i:d+12|0)+3|0]=e>>>0<=23?y[e+25383|0]:0}e=c+5|0;i=k?i:d+12|0;k=y[i+3|0];if((k|0)!=23){if((k|0)!=9){break m}v[i+3|0]=20;v[d|0]=y[e|0]>>>3;v[d+115|0]=1;t=e,u=y[cf(d,d+115|0)|0]-1&15|128,v[t|0]=u;break m}v[d|0]=64;t=e,u=y[Qb(e,d)|0]<<1,v[t|0]=u}if((j|0)>=0){continue}v[c+2|0]=1;x[31609]=0;e=R(197,b|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break e}v[c+4|0]=e;continue}}}f=f+1|0;continue}}b=N()|0;ub(g);break c}else{h=e+(f<<5)|0;Ve(h);w[h+4>>1]=(y[f+g|0]<<4|4)&244;f=f+1|0;continue}}b=N()|0;tb(d+116|0);break d}b=N()|0}Eb(d+92|0)}Q(b|0);p()}ub(g)}fb=d+736|0;return o|0}function wta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-320|0;fb=d;yc(b);a:{e=d+308|0;if(!gp(b,e)){break a}if(!j$(e)){break a}if((y[d+308|0]|y[d+309|0]<<8|(y[d+310|0]<<16|y[d+311|0]<<24))==1179472708){Vb(b,4)}if(!vi(b,d+300|0)|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1196314451){break a}i=1;if((c|0)==64){break a}f=d+108|0;u0(b,f,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));i=0;if((y[d+144|0]|y[d+145|0]<<8)>>>0>128|(y[d+150|0]|y[d+151|0]<<8)>>>0>16|((y[d+148|0]|y[d+149|0]<<8)>>>0>256|(y[d+142|0]|y[d+143|0]<<8)>>>0>128)){break a}Dd(a,8192);e=d+24|0;g=uc(e,6574);zb(a+1298344|0,g);tb(g);g=uc(e,10157);zb(a+1298356|0,g);tb(g);t=a,u=x[Fc(e,4)>>2],x[t+1298404>>2]=u;g=d+88|0;Vi(g,2,f);Cc(e,g);zb(a+1298308|0,e);tb(e);w[d+24>>1]=y[d+150|0]|y[d+151|0]<<8;w[d+88>>1]=1;f=z[qe(e,g)>>1];w[a+480188>>1]=f;x[a+480196>>2]=y[d+154|0];x[a+480204>>2]=D(y[d+155|0],1e4);v[d+24|0]=y[d+152|0];v[d+88|0]=64;e=y[Qb(e,g)|0];x[a+480200>>2]=e<<2;if(!e){x[a+480200>>2]=256}e=y[d+153|0];b:{if((e|0)==128){x[d+24>>2]=256/(f>>>0);x[d+88>>2]=128;e=x[Hb(d+24|0,d+88|0)>>2];break b}e=e&127}x[a+480228>>2]=e;g=a+480280|0;f=d+156|0;e=0;while(1){if((e|0)==16){f=Xb(x[a+484360>>2],y[a+484376|0]);j=d+172|0;g=fb-16|0;fb=g;x[g+12>>2]=y[d+144|0]|y[d+145|0]<<8;e=g+12|0;xc(e,128);xc(e,65535);h=z[g+12>>1];vg(f,h);e=0;while(1){if((e|0)==(h|0)){fb=g+16|0}else{i=y[e+j|0];t=Sr(x[f>>2],x[f+4>>2],e),u=(i|0)==255?-1:(i|0)==254?-2:i,w[t>>1]=u;e=e+1|0;continue}break}e=y[d+142|0]|y[d+143|0]<<8;if(e>>>0<(y[d+144|0]|y[d+145|0]<<8)>>>0){$e(Xb(x[a+484360>>2],y[a+484376|0]),e)}n=c&2;o=a+946304|0;q=a+484380|0;m=a+484344|0;i=1;r=c&1;s=d+60|0;j=0;while(1){if(!vi(b,d+300|0)){break a}e=d+24|0;he(e,b,y[d+304|0]|y[d+305|0]<<8|(y[d+306|0]<<16|y[d+307|0]<<24));c=hc(d+88|0,e);ub(e);c:{d:{if(!(!r|(y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414807888)){x[31609]=0;k=j&65535;e=U(196,m|0,k|0,64)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(!e){break c}x[31609]=0;P(183,c|0,2)|0;e=x[31609];x[31609]=0;if((e|0)==1){break d}g=0;e:{while(1){e=x[c>>2];x[31609]=0;e=U(150,e|0,x[d+96>>2],1)|0;f=x[31609];x[31609]=0;f:{if((f|0)!=1){if(!(e&g>>>0<64)){break e}x[31609]=0;e=R(197,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}h=e<<24>>24;if(h){break f}g=g+1|0;continue}break d}e=d+24|0;f=h&15;if(f>>>0<z[a+480188>>1]){e=Wb(x[m>>2],k);e=md(x[e>>2],x[x[e+48>>2]+12>>2],g,f)}g:{if((h|0)>=0){break g}x[31609]=0;f=R(197,c|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break d}if(!f){break g}v[e|0]=f>>>0<109?f+12|0:f}f=h&255;if(f&64){x[31609]=0;h=R(197,c|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break d}v[e+1|0]=h}if(f&32){v[e+2|0]=1;x[31609]=0;h=R(197,c|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break d}v[d+12|0]=h;v[d|0]=64;t=e,u=y[Qb(d+12|0,d)|0],v[t+4|0]=u}if(!(f&16)){continue}x[31609]=0;f=d+12|0;O(198,f|0,c|0);h=x[31609];x[31609]=0;if((h|0)!=1){Cf(e,y[d+12|0],y[Jc(f)|0]);continue}break}break d}j=j+1|0;break c}if((y[d+300|0]|y[d+301|0]<<8|(y[d+302|0]<<16|y[d+303|0]<<24))!=1414745673){break c}e=z[a+480190>>1];if(!oi(e)){break c}e=e+1|0;w[a+480190>>1]=e;x[31609]=0;g=d+24|0;O(324,c|0,g|0);f=x[31609];x[31609]=0;h:{if((f|0)==1){break h}x[31609]=0;k=D(e&65535,104)+q|0;O(325,g|0,k|0);e=x[31609];x[31609]=0;if((e|0)==1){break h}Vi(d,2,s);x[31609]=0;e=d+12|0;O(218,e|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break h}Ac((z[a+480190>>1]<<5)+o|0,e);tb(e);if(!n){break c}g=y[d+37|0]|y[d+38|0]<<8;f=2;h=Zc(e,8,1,0,1);i:{if(!(g&64)){f=0;if(!(g&2)){break i}}wg(h,f)}if(g&4){hd(h,16)}x[31609]=0;U(215,e|0,k|0,c|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break c}}}a=N()|0;ub(c);Q(a|0);p()}ub(c);continue}}i=g+(e<<5)|0;Ve(i);j=y[e+f|0];if(j>>>0<=128){w[i+4>>1]=j<<1}e=e+1|0;continue}}fb=d+320|0;return i|0}function kua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;g=fb-3056|0;fb=g;yc(b);e=fb-16|0;fb=e;f=g+1102|0;o0(e+8|0,f);j=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);n=x[e+4>>2];if((n|0)==(j|0)){Vb(b,x[e+12>>2])}fb=e+16|0;e=(j|0)==(n|0);if(!e){n0(f)}a:{if(!e){break a}if(!q0(f)){break a}d=1;if((c|0)==64){break a}d=0;if(!Mb(x[b>>2],x[b+8>>2],Bc(1024,0))){break a}m0(b,g+576|0);m0(b,g- -64|0);e=0;while(1){if((e|0)!=128){f=e<<2;j=x[f+(g+576|0)>>2];if(j>>>0>16777215){break a}f=x[f+(g- -64|0)>>2];if(f-4097>>>0<4294963202){break a}e=e+1|0;if(wm(x[b>>2],(f+j|0)+2978|0)){continue}break a}break}Dd(a,2);eg(a);d=g+40|0;e=uc(d,13940);zb(a+1298344|0,e);tb(e);e=uc(d,14795);zb(a+1298356|0,e);tb(e);e=uc(d,15584);zb(a+1298368|0,e);tb(e);q=a,r=x[Fc(d,4)>>2],x[q+1298404>>2]=r;d=y[g+1102|0];x[a+480204>>2]=143e4;x[a+480196>>2]=d;$e(Xb(x[a+484360>>2],y[a+484376|0]),y[g+1103|0]);x[a+480188>>2]=4194317;Lb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;e=a+480280|0;d=0;while(1){if((d|0)==4){b:{j=a+946304|0;n=a+484380|0;l=g+1520|0;o=g+1104|0;d=0;while(1){c:{if((d|0)==32){i=g+2448|0;l=g+2032|0;e=0;break c}e=d+1|0;f=n+D(e,104)|0;nd(f,2);h=g+20|0;l0(h,o+D(d,13)|0);i=g+40|0;Cc(i,h);Ac(j+(e<<5)|0,i);tb(i);d=l+(d<<4)|0;i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[f>>2]=i;k=i;i=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);if(k>>>0>=i>>>0){d=y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24);w[f+34>>1]=2;x[f+8>>2]=i;x[f+4>>2]=d}x[f+24>>2]=8287;d=e;continue}break}while(1){if((e|0)!=32){f=e+33|0;o=n+D(f,104)|0;nd(o,2);h=g+20|0;l0(h,l+D(e,13)|0);d=g+40|0;Cc(d,h);Ac(j+(f<<5)|0,d);tb(d);x[g+48>>2]=0;x[g+40>>2]=0;x[g+44>>2]=0;f=i+D(e,11)|0;h=xb(f,1);q=xb(d,0),r=y[h|0],v[q|0]=r;h=xb(f,6);q=xb(d,1),r=y[h|0],v[q|0]=r;h=xb(f,2);q=xb(d,2),r=y[h|0],v[q|0]=r;h=xb(f,7);q=xb(d,3),r=y[h|0],v[q|0]=r;h=xb(f,3);q=xb(d,4),r=y[h|0],v[q|0]=r;h=xb(f,8);q=xb(d,5),r=y[h|0],v[q|0]=r;h=xb(f,4);q=xb(d,6),r=y[h|0],v[q|0]=r;h=xb(f,9);q=xb(d,7),r=y[h|0],v[q|0]=r;h=xb(f,5);q=xb(d,8),r=y[h|0],v[q|0]=r;h=xb(f,10);q=xb(d,9),r=y[h|0],v[q|0]=r;f=xb(f,0);q=xb(d,10),r=y[f|0],v[q|0]=r;x[g+16>>2]=x[g+48>>2];d=x[g+44>>2];x[g+8>>2]=x[g+40>>2];x[g+12>>2]=d;Sk(o,1,g+8|0);e=e+1|0;continue}break}Qr(Xb(x[a+484360>>2],y[a+484376|0]),g+2800|0,256,255,65535);l=a+484344|0;Tf(l,128);o=c&1;f=0;while(1){d:{e:{if((f|0)!=128){a=f<<2;dd(b,x[a+(g+576|0)>>2]+2978|0);d=g+20|0;he(d,b,x[a+(g- -64|0)>>2]);a=hc(g+40|0,d);ub(d);if(!o){break d}x[31609]=0;d=U(196,l|0,f&65535,64)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}if(!d){break d}d=0;j=Wb(x[l>>2],f);while(1){h=d>>>0>63;while(1){if(h){break d}e=x[a>>2];x[31609]=0;e=U(150,e|0,x[g+48>>2],1)|0;i=x[31609];x[31609]=0;f:{if((i|0)!=1){if(!e){break d}x[31609]=0;e=R(197,a|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}if(e>>>0>12){break f}i=md(x[j>>2],x[x[j+48>>2]+12>>2],d,e);x[31609]=0;m=g+20|0;O(198,m|0,a|0);k=x[31609];x[31609]=0;if((k|0)==1){break b}k=y[g+20|0];e=e>>>0>3;v[i|0]=((k&15)+(e?13:37)|0)+D(k>>>4&7,12);m=Jc(m);v[i+1|0]=((y[m|0]>>>4|0)+(e?33:1)|0)+(y[g+20|0]>>>3&16);k0(i,y[m|0],e);continue}break b}i=e-32|0;if((i&255)>>>0<=12){i=md(x[j>>2],x[x[j+48>>2]+12>>2],d,i&65535);x[31609]=0;m=R(197,a|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break b}k0(i,m,e>>>0>35);continue}break}if((e|0)!=64){if((e|0)!=96){break e}if(!d){break d}q=md(x[j>>2],x[x[j+48>>2]+12>>2],d-1|0,0),r=14,v[q+3|0]=r;break d}x[31609]=0;e=R(197,a|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}d=d+e|0;continue}}d=1;if(!(c&2)){break a}while(1)if((d|0)==33){d=1;break a}else{dg(Zc(g+40|0,8,1,0,1),n+D(d,104)|0,b);d=d+1|0;continue}}ub(a);d=0;break a}ub(a);f=f+1|0;continue}}}else{w[(e+(d<<5)|0)+4>>1]=d&1?192:64;d=d+1|0;continue}break}b=N()|0;ub(a);Q(b|0);p()}fb=g+3056|0;return d|0}function E7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;x[h+12>>2]=b;x[e>>2]=0;cd(h,x[d+28>>2]);x[31609]=0;i=R(28,x[h>>2])|0;j=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){_b(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;_b(h);Q(a|0);p()}kK(a,f+24|0,h+12|0,c,e,i);break b}jK(a,f+16|0,h+12|0,c,e,i);break b}b=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;g=a;i=x[h+12>>2];a=Kb(b);k=h,l=rk(g,i,c,d,e,f,a,Cb(x[b+4>>2],y[b+11|0])+a|0),x[k+12>>2]=l;break b}a=hj(h+12|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}v[h|0]=37;v[h+1|0]=109;v[h+2|0]=47;v[h+3|0]=37;v[h+4|0]=100;v[h+5|0]=47;v[h+6|0]=37;v[h+7|0]=121;k=h,l=rk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}v[h|0]=37;v[h+1|0]=89;v[h+2|0]=45;v[h+3|0]=37;v[h+4|0]=109;v[h+5|0]=45;v[h+6|0]=37;v[h+7|0]=100;k=h,l=rk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=hj(h+12|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=hj(h+12|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=hj(h+12|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=hj(h+12|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=hj(h+12|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+12|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(th(a,b+12|0)){break H}c=tl(x[a>>2]);if(!Jf(x[i+8>>2],1,c)){break H}Fm(a);continue}break}if(th(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+12|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Cb(x[a+4>>2],y[a+11|0])|0)==(0-Cb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=yt(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}v[h+10|0]=112;v[h+8|0]=32;v[h+9|0]=37;v[h|0]=37;v[h+1|0]=73;v[h+2|0]=58;v[h+3|0]=37;v[h+4|0]=77;v[h+5|0]=58;v[h+6|0]=37;v[h+7|0]=83;k=h,l=rk(a,b,c,d,e,f,h,h+11|0),x[k+12>>2]=l;break b}v[h+4|0]=77;v[h|0]=37;v[h+1|0]=72;v[h+2|0]=58;v[h+3|0]=37;k=h,l=rk(a,b,c,d,e,f,h,h+5|0),x[k+12>>2]=l;break b}a=hj(h+12|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}v[h|0]=37;v[h+1|0]=72;v[h+2|0]=58;v[h+3|0]=37;v[h+4|0]=77;v[h+5|0]=58;v[h+6|0]=37;v[h+7|0]=83;k=h,l=rk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=hj(h+12|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;g=a;i=x[h+12>>2];a=Kb(b);k=h,l=rk(g,i,c,d,e,f,a,Cb(x[b+4>>2],y[b+11|0])+a|0),x[k+12>>2]=l;break b}iK(f+20|0,h+12|0,c,e,i);break b}a=hj(h+12|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+12|0;d=a+12|0;L:{M:{if(th(c,d)){break M}b=4;if((ml(i,tl(x[c>>2]))|0)!=37){break M}b=2;if(!th(Fm(c),d)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+12>>2]}fb=h+16|0;return a|0}function usa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;g=fb-32|0;fb=g;a:{b:{if(!c){break b}f=Wh(a,b);a=wb(x[d>>2]);x[g+28>>2]=a;d=wb(x[d+4>>2]);while(1){if(!Ib(a,d)){break b}yc(a);c:{if((Pk(a)|0)==(c|0)){Vb(a,20);d=Pk(a);l=og(g+16|0);c=Yl(g+12|0,0,b?32:64);x[31609]=0;O(402,f|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}o=(b|0)==2?4096:(b|0)==1?2048:16384;c=24;d=d+24|0;q=1;m=1;d:{while(1){i=o;while(1){e=x[a+8>>2];h=x[a>>2];x[31609]=0;e=U(150,h|0,e|0,1)|0;h=x[31609];x[31609]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(!e){break d}e=x[f+4>>2];h=x[f>>2];j=x[a+8>>2];x[31609]=0;x[g+12>>2]=j;j=P(403,l|0,g+12|0)|0;r=x[31609];x[31609]=0;if((r|0)==1){break a}u=j,A=Sd(h,e),x[u>>2]=A;x[31609]=0;e=R(197,a|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}q:{switch(e-128|0){case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:case 7:case 8:break e;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:break e;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(y[f+12|0]&4){break e}x[31609]=0;e=R(273,a|0)|0;h=x[31609];x[31609]=0;t:{if((h|0)==1){break t}x[31609]=0;x[g+12>>2]=e;e=P(403,l|0,g+12|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break t}v[f+15|0]=x[e>>2];u=f,A=Sd(x[f>>2],x[f+4>>2])-1|0,v[u+16|0]=A;v[f+12|0]=y[f+12|0]|4;break e}break a}x[31609]=0;e=R(273,a|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}w[g+12>>1]=e;w[g+10>>1]=1;h=g+12|0;j=g+10|0;e=z[qe(h,j)>>1];i=D(e,D(s<<16>>16,m))+i|0;u:{if(e>>>0<2){break u}u=g,A=bm((e+z[xf(x[f+4>>2])>>1]|0)-1|0),w[u+12>>1]=A;e=Xv(b,i);x[31609]=0;v[g+10|0]=e;S(404,f|0,h|0,j|0);e=x[31609];x[31609]=0;if((e|0)!=1){break u}break a}u=g,A=bm(z[xf(x[f+4>>2])>>1]+1|0),w[u+12>>1]=A;e=Xv(b,i);x[31609]=0;v[g+10|0]=e;S(404,f|0,g+12|0,g+10|0);e=x[31609];x[31609]=0;if((e|0)!=1){break e}break a}x[31609]=0;k=R(197,a|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}t=x[a+8>>2];break e}x[31609]=0;e=R(273,a|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}e=c+e|0;x[g+12>>2]=e;if(!(!(k&255)|e>>>0<t>>>0)){k=k-1|0;if(!(k&255)){break f}x[31609]=0;P(149,a|0,e|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break e}break a}if(!(k&255)){break f}x[31609]=0;e=P(405,l|0,g+12|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}v[f+13|0]=x[e>>2];u=f,A=Sd(x[f>>2],x[f+4>>2])-1|0,v[u+14|0]=A;v[f+12|0]=y[f+12|0]|2;break e}q=0;n=1;break e}x[31609]=0;i=R(273,a|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}e=Xv(b,i);u=xf(x[f+4>>2]),A=e,v[u+2|0]=A;break e}x[31609]=0;s=R(406,a|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break e}break a}x[31609]=0;e=R(197,a|0)|0;m=x[31609];x[31609]=0;if((m|0)!=1){v[g+12|0]=e;v[g+10|0]=1;m=y[cf(g+12|0,g+10|0)|0];break e}break a}x[31609]=0;P(183,a|0,1)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}break e}n=1;if(c>>>0<d>>>0){break e}break d}k=0}if(!n|c>>>0>=d>>>0){continue}break}x[31609]=0;c=P(149,a|0,d|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break a}if(!c){break d}c=x[a+8>>2];i=x[a>>2];x[31609]=0;c=U(150,i|0,c|0,2)|0;i=x[31609];x[31609]=0;if((i|0)==1){break a}if(!c){break d}c=x[f+4>>2];i=y[f+12|0];if(!(i&4)&q){e=x[f>>2];v[f+12|0]=i|4;i=Sd(e,c)-1|0;v[f+15|0]=i;v[f+16|0]=i}u=g,A=bm(z[xf(c)>>1]+1|0),w[u+12>>1]=A;c=Xv(b,o);x[31609]=0;v[g+10|0]=c;S(404,f|0,g+12|0,g+10|0);c=x[31609];x[31609]=0;if((c|0)!=1){n=1;v[f+17|0]=y[f+16|0]+1;c=d;continue}break}break a}v[f+12|0]=y[f+12|0]|1;UZ(l);break b}a=x[Qf(g+28|0)>>2];continue}break}break a}fb=g+32|0;return}a=N()|0;UZ(l);Q(a|0);p()}function Nz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-256|0;fb=f;g=x[b+4>>2];a:{if(!g){i=x[b>>2];break a}i=x[b>>2];h=y[zl(i,g)|0];if((h|0)==33){e=1}else{if((h|0)!=63){break a}e=0}Ml(f+96|0,i,g,g-1|0);g=x[f+100>>2];i=x[f+96>>2];x[b>>2]=i;x[b+4>>2]=g}j=f+96|0;ie(j);h=x[f+96>>2];k=f+236|0;ie(k);h=yl(h,x[f+240>>2],b);ie(j);b:{c:{d:{e:{if(x[f+100>>2]==(h|0)){h=pc(f+248|0,22292);a=x[h+4>>2];x[f+8>>2]=x[h>>2];x[f+12>>2]=a;if(Ic(i,g,f+8|0)){e=dc(8);x[31609]=0;c=$h(k,c,d);a=x[31609];x[31609]=0;f:{g:{h:{if((a|0)!=1){x[31609]=0;S(1011,j|0,18271,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break h}sc(e,j);a=0;x[31609]=0;S(97,e|0,48428,1e3);b=x[31609];x[31609]=0;if((b|0)!=1){break b}g=N()|0;tb(j);break g}g=N()|0;break f}g=N()|0;a=1}tb(c);if(!a){break c}}lc(e);break c}if(!e){break e}h=dc(8);e=x[b>>2];a=x[b+4>>2];x[31609]=0;i=$h(f+212|0,e,a);a=x[31609];x[31609]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31609]=0;b=f+224|0;S(1011,b|0,18307,i|0);a=x[31609];x[31609]=0;if((a|0)==1){break q}x[31609]=0;e=f+236|0;O(1013,e|0,b|0);b=x[31609];x[31609]=0;a=1;if((b|0)==1){break p}x[31609]=0;d=$h(f+200|0,c,d);a=x[31609];x[31609]=0;if((a|0)==1){break o}x[31609]=0;c=f+96|0;S(1015,c|0,e|0,d|0);b=x[31609];x[31609]=0;a=1;if((b|0)==1){break n}sc(h,c);x[31609]=0;S(97,h|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}g=N()|0;tb(c);a=0;break m}g=N()|0;break i}g=N()|0;a=1;break j}g=N()|0;break k}g=N()|0;a=1;break l}g=N()|0}tb(d)}tb(f+236|0)}tb(f+224|0)}tb(i);if(!a){break c}}lc(h);break c}e=pc(f+192|0,22292);b=x[e+4>>2];x[f+88>>2]=x[e>>2];x[f+92>>2]=b;if(Ic(i,g,f+88|0)){e=dc(8);x[31609]=0;d=$h(f+236|0,c,d);a=x[31609];x[31609]=0;r:{s:{t:{if((a|0)!=1){x[31609]=0;c=f+96|0;S(1011,c|0,18271,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break t}sc(e,c);a=0;x[31609]=0;S(97,e|0,48428,1e3);b=x[31609];x[31609]=0;if((b|0)!=1){break b}g=N()|0;tb(c);break s}g=N()|0;break r}g=N()|0;a=1}tb(d);if(!a){break c}}lc(e);break c}e=pc(f+184|0,12437);b=x[e+4>>2];x[f+80>>2]=x[e>>2];x[f+84>>2]=b;if(Ic(i,g,f+80|0)){e=pc(f+176|0,5601);b=x[e+4>>2];x[f+32>>2]=x[e>>2];x[f+36>>2]=b;if(Ic(c,d,f+32|0)){x[a+52>>2]=0;break e}e=pc(f+168|0,11301);b=x[e+4>>2];x[f+24>>2]=x[e>>2];x[f+28>>2]=b;if(Ic(c,d,f+24|0)){x[a+52>>2]=1;break e}e=pc(f+160|0,9222);b=x[e+4>>2];x[f+16>>2]=x[e>>2];x[f+20>>2]=b;if(Ic(c,d,f+16|0)){x[a+52>>2]=2;break e}e=dc(8);x[31609]=0;d=$h(f+236|0,c,d);a=x[31609];x[31609]=0;u:{v:{w:{if((a|0)!=1){x[31609]=0;c=f+96|0;S(1011,c|0,14667,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break w}sc(e,c);a=0;x[31609]=0;S(97,e|0,48428,1e3);b=x[31609];x[31609]=0;if((b|0)!=1){break b}g=N()|0;tb(c);break v}g=N()|0;break u}g=N()|0;a=1}tb(d);if(!a){break c}}lc(e);break c}e=pc(f+152|0,11538);b=x[e+4>>2];x[f+72>>2]=x[e>>2];x[f+76>>2]=b;if(!Ic(i,g,f+72|0)){break e}e=pc(f+144|0,15659);b=x[e+4>>2];x[f+64>>2]=x[e>>2];x[f+68>>2]=b;b=0;x:{if(Ic(c,d,f- -64|0)){break x}e=pc(f+136|0,15664);b=x[e+4>>2];x[f+56>>2]=x[e>>2];x[f+60>>2]=b;b=1;if(Ic(c,d,f+56|0)){break x}e=pc(f+128|0,12711);b=x[e+4>>2];x[f+48>>2]=x[e>>2];x[f+52>>2]=b;b=2;if(Ic(c,d,f+48|0)){break x}e=pc(f+120|0,9286);b=x[e+4>>2];x[f+40>>2]=x[e>>2];x[f+44>>2]=b;b=3;if(Ic(c,d,f+40|0)){break x}c=dc(8);x[31609]=0;b=P(36,f+96|0,11574)|0;a=x[31609];x[31609]=0;if((a|0)==1){break d}sc(c,b);x[31609]=0;S(97,c|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}g=N()|0;tb(b);break c}x[a+56>>2]=b;d=x[a+24>>2];if(!x[d+24668>>2]){break e}c=d+24664|0;a=x[c+4>>2];x[f+112>>2]=x[c>>2];x[f+116>>2]=a;c=d+24656|0;a=x[c+4>>2];x[f+104>>2]=x[c>>2];x[f+108>>2]=a;a=x[d+24652>>2];x[f+96>>2]=x[d+24648>>2];x[f+100>>2]=a;l=f,m=SM(b),x[l+116>>2]=m;a=f+96|0;if(!zz(a,d+24648|0)){break e}LA(d,a)}fb=f+256|0;return}g=N()|0;lc(c)}Q(g|0)}p()}function mk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;i=1;o(+b);e=j(1)|0;a:{b:{f=j(0)|0;p=e&2147483647;c:{if(!(f|p)){break c}o(+a);c=j(1)|0;g=j(0)|0;if(!g&(c|0)==1072693248){break c}t=g;r=c&2147483647;if(!(!(r>>>0>2146435072|(r|0)==2146435072&(g|0)!=0|p>>>0>2146435072)&(!f|(p|0)!=2146435072))){return a+b}g=0;d:{e:{f:{g:{h:{q=c;if((c|0)>0){q=1}else{q=(q|0)>=0}i:{if(q){break i}g=2;if(p>>>0>1128267775){break i}g=0;if(p>>>0<1072693248){break i}q=p>>>20|0;if(p>>>0<1094713344){break h}m=1075-q|0;q=f>>>m|0;if((f|0)!=q<<m){break i}g=2-(q&1)|0}m=g;if(f){break f}if((p|0)!=2146435072){break g}if(!(r-1072693248|t)){break c}if(r>>>0<1072693248){break e}return(e|0)>0|(e|0)>=0?b:0}if(f){break f}g=1043-q|0;f=p>>>g|0;if((p|0)!=f<<g){break g}m=2-(f&1)|0}if((p|0)==1072693248){if((e|0)>0|(e|0)>=0){return a}return 1/a}if((e|0)==1073741824){return a*a}if((e|0)!=1071644672|(c|0)<0){break f}return M(a)}d=F(a);if(t){break d}j:{if((c|0)<0){if((c|0)==-2147483648|(c|0)==-1074790400|(c|0)==-1048576){break j}break d}if(!c|(c|0)==2146435072){break j}if((c|0)!=1072693248){break d}}i=(e|0)<0?1/d:d;if((c|0)>0|(c|0)>=0){break c}if(!(r-1072693248|m)){a=i-i;return a/a}return(m|0)==1?-i:i}return(e|0)>0|(e|0)>=0?0:-b}k:{if((c|0)>0|(c|0)>=0){break k}l:{switch(m|0){case 0:a=a-a;return a/a;case 1:break l;default:break k}}i=-1}m:{if(p>>>0>=1105199105){if(p>>>0>=1139802113){if(r>>>0<=1072693247){return(e|0)<0?Infinity:0}return(e|0)>0?Infinity:0}if(r>>>0<=1072693246){return(e|0)<0?i*1e300*1e300:i*1e-300*1e-300}if(r>>>0>=1072693249){return(e|0)>0?i*1e300*1e300:i*1e-300*1e-300}a=d+-1;d=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;h=d;d=a*1.4426950216293335;o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-d);break m}a=d*9007199254740992;f=r>>>0<1048576;d=f?a:d;o(+a);c=j(1)|0;j(0)|0;m=f?c:r;g=m&1048575;c=g|1072693248;m=(m>>20)+(f?-1076:-1023)|0;f=0;n:{if(g>>>0<235663){break n}if(g>>>0<767610){f=1;break n}c=g|1071644672;m=m+1|0}g=((f<<18)+(c>>>1|0)|0)+537395200|0;f=f<<3;w=C[f+3536>>3];o(+d);j(1)|0;q=0;l(0,j(0)|q);l(1,c|0);k=+n();s=C[f+3520>>3];h=k-s;u=1/(s+k);d=h*u;o(+d);c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();x=a;l(0,q|0);l(1,g|0);v=a*a;y=h;h=+n();k=u*(y-a*h-a*(k-(h-s)));h=k*(d+a);a=d*d;s=h+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();h=x*a;d=k*a+d*(s-(a+-3-v));o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=w+(a*-7.028461650952758e-9+(d-(a-h))*.9617966939259756);h=d;k=C[f+3552>>3];d=a*.9617967009544373;s=+(m|0);o(+(k+(h+d)+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-s-k-d)}l(0,0);l(1,e|0);k=+n();d=(b-k)*a+d*b;b=a*k;a=d+b;o(+a);e=j(1)|0;c=j(0)|0;o:{if((e|0)>=1083179008){if(c|e-1083179008){break b}if(!(d+8008566259537294e-32>a-b)){break o}break b}if((e&2147482624)>>>0<1083231232){break o}if(c|e+1064252416){break a}if(!(d<=a-b)){break o}break a}f=0;g=e&2147483647;if(g>>>0>=1071644673){c=e+(1048576>>>(g>>>20|0)-1022|0)|0;g=c>>>20&2047;f=(c&1048575|1048576)>>>1043-g|0;f=(e|0)<0?0-f|0:f;l(0,0);l(1,c&-1048576>>g-1023);b=b-+n();o(+(d+b));e=j(1)|0;j(0)|0}l(0,0);l(1,e|0);a=+n();k=a*.6931471824645996;d=(d-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=k+d;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);h=a*b/(b+-2);b=a;a=d-(a-k);a=b-(h-(b*a+a))+1;o(+a);e=j(1)|0;c=j(0)|0;e=(f<<20)+e|0;p:{if((e|0)<=1048575){a=ok(a,f);break p}l(0,c|0);l(1,e|0);a=+n()}i=i*a}return i}return i*1e300*1e300}return i*1e-300*1e-300}function Ana(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-176|0;fb=e;a:{b:{if(Mb(x[c>>2],x[c+8>>2],8)){Vb(c,4);while(1){if(Sv(x[c>>2],x[c+8>>2])){break b}n=fb-288|0;fb=n;f=vU(n+6|0);j=fb-368|0;fb=j;l=zc(f,vU(j+80|0),282);f=0;g=fb-32|0;fb=g;x[g+28>>2]=0;k=Zb(g+8|0,g+28|0,4);i=x[k>>2];kc(g+20|0,x[c>>2],x[c+8>>2],i,x[k+4>>2]);k=x[g+24>>2]==4&x[g+28>>2]==1399285583;if(k){Vb(c,4)}fb=g+32|0;c:{d:{e:{f:{g:{if(k){wU(c,4);k=a0(j+60|0,c);x[31609]=0;g=P(789,k|0,l|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break g}h:{if(!g){break h}g=x[k+8>>2];i=x[k>>2];h=y[l+26|0];x[31609]=0;g=U(790,i|0,g|0,h|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break g}if(!g){break h}g=l+27|0;i=0;i:{while(1){if(y[l+26|0]<=f>>>0){h=x[k+8>>2];m=x[k>>2];f=0;x[31609]=0;i=i&65535;h=U(790,m|0,h|0,i|0)|0;m=x[31609];x[31609]=0;if((m|0)==1){break e}if(!h){break h}x[31609]=0;O(791,k|0,i|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}wU(k,xU(l));h=tc(j+56|0);f=j+80|0;QB(f);x[31609]=0;O(792,k|0,f|0);m=x[31609];x[31609]=0;if((m|0)!=1){w[j+102>>1]=0;w[j+104>>1]=0;f=uU(h,f,j+107|0);h=y[l+26|0];x[31609]=0;O(791,k|0,h|0);h=x[31609];x[31609]=0;if((h|0)!=1){break i}}f=N()|0;break d}x[31609]=0;h=R(793,k|0)|0;m=x[31609];x[31609]=0;if((m|0)!=1){v[f+g|0]=h;f=f+1|0;i=i+h|0;continue}break}f=N()|0;break d}g=uU(f,g,g+y[l+26|0]|0);x[31609]=0;h=j+36|0;S(794,h|0,k|0,i|0);f=x[31609];x[31609]=0;if((f|0)==1){break f}f=0;x[31609]=0;O(575,j+16|0,h|0);i=x[31609];x[31609]=0;if((i|0)==1){f=N()|0;ub(h);break d}m=j+16|0;cG(j+8|0,m);i=wb(x[j+8>>2]);o=Yj(x[j+8>>2],x[j+12>>2]);h=fb-16|0;fb=h;x[h+12>>2]=i;while(1){if(Ib(i,o)){rU(g,y[i|0]);i=x[we(h+12|0)>>2];continue}else{fb=h+16|0}break}Kc(m);ub(j+36|0);if(x[g>>2]!=(y[l+22|0]|y[l+23|0]<<8|(y[l+24|0]<<16|y[l+25|0]<<24))){break h}f=xU(l);x[31609]=0;O(791,c|0,f|0);g=x[31609];x[31609]=0;f=1;if((g|0)==1){break e}}ub(k)}fb=j+368|0;break c}f=N()|0;break d}f=N()|0;break d}f=N()|0}ub(k);Q(f|0);p()}fb=n+288|0;if(f){continue}break}}yc(c);dg(b,a,c);a=1;break a}v[d|0]=1;yc(c);f=Rg(c);d=e+136|0;he(d,c,jf(c));g=hc(e+156|0,d);ub(d);c=z[a+34>>1]&-66|y[b|0]>15;b=y[b+1|0]!=1;c=c|b<<6;w[a+34>>1]=c;x[a>>2]=f>>>(c&1)>>>b;x[e+132>>2]=0;x[e+128>>2]=0;x[31609]=0;O(575,d|0,g|0);b=x[31609];x[31609]=0;j:{k:{l:{m:{if((b|0)!=1){c=Ze(d);d=x[e+136>>2];j=bD(c,uh(d),e+132|0,e+128|0);x[31609]=0;b=x[e+132>>2];P(183,g|0,b|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){if(!j){break j}Gh(a);k=b+c|0;d=d-b|0;b=x[e+128>>2];c=0;while(1){n:{if(b){if(!d|(b|0)!=1){break k}b=x[a>>2];if(c>>>0<b>>>0){break n}break k}b=x[a>>2];if(c>>>0>=b>>>0){break k}}if(!le(b,x[a+20>>2])){break k}x[e+124>>2]=0;x[e+120>>2]=0;b=e+120|0;l=lY(j,k,uh(d),e+124|0,e+116|0,b);x[31609]=0;P(183,g|0,l|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break m}ui(b,uh(x[a>>2]-c|0));b=x[e+120>>2];o:{if((b|0)<=0){break o}f=x[e+124>>2];n=z[a+34>>1];if((_d(n)|0)!=(f|0)){break o}i=D(c,f);h=x[a+20>>2];if(n&1){x[e+112>>2]=b;x[e+100>>2]=b;x[e- -64>>2]=b;x[e+48>>2]=b;x[e+96>>2]=f;x[e+92>>2]=x[e+116>>2];x[e+108>>2]=f;x[e+104>>2]=h+(i<<1);x[31609]=0;f=x[e+96>>2];x[e+40>>2]=x[e+92>>2];x[e+44>>2]=f;f=x[e+108>>2];x[e+56>>2]=x[e+104>>2];x[e+60>>2]=f;O(576,e+56|0,e+40|0);f=x[31609];x[31609]=0;if((f|0)!=1){break o}break m}x[e+88>>2]=b;x[e+76>>2]=b;x[e+32>>2]=b;x[e+16>>2]=b;x[e+72>>2]=f;x[e+68>>2]=x[e+116>>2];x[e+84>>2]=f;x[e+80>>2]=i+h;x[31609]=0;f=x[e+72>>2];x[e+8>>2]=x[e+68>>2];x[e+12>>2]=f;f=x[e+84>>2];x[e+24>>2]=x[e+80>>2];x[e+28>>2]=f;O(577,e+24|0,e+8|0);f=x[31609];x[31609]=0;if((f|0)==1){break m}}d=d-l|0;k=k+l|0;c=b+c|0;b=kY(j);continue}}break m}c=N()|0;break l}c=N()|0;Kc(e+136|0)}ub(g);Q(c|0);p()}jY(j)}Kc(e+136|0);ub(g);a=(j|0)!=0}fb=e+176|0;return a|0}function yy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-32|0;fb=e;j=a+32|0;Qc(e+8|0,j,11);a:{b:{c:{if(Gb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+8>>2]){b=x[a+76>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+72>>2]|0;Ci(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);b=x[a+36>>2];if(nk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){Oh(a,2,256);break a}b=x[a+104>>2];c=a+52|0;f=x[c>>2];d=fj(f,x[c+4>>2]);d:{if(b>>>0>d>>>0){n=fb-32|0;fb=n;f=b-d|0;d=x[Ab(c)>>2];g=x[c+4>>2];e:{if(f>>>0<=(d-g|0)/24>>>0){d=fb-16|0;fb=d;c=CJ(d+4|0,c,f);b=x[c+4>>2];f=x[c+8>>2];while(1){if((b|0)==(f|0)){jc(c);fb=d+16|0}else{BJ(b);b=b+24|0;x[c+4>>2]=b;continue}break}break e}b=Ab(c);d=GJ(n+12|0,IJ(c,fj(x[c>>2],g)+f|0),fj(x[c>>2],x[c+4>>2]),b);g=fb-16|0;fb=g;h=x[d+8>>2];b=g+4|0;x[b+8>>2]=d+8;x[b>>2]=h;x[b+4>>2]=h+D(f,24);f=x[b>>2];while(1){if(x[b+4>>2]!=(f|0)){BJ(f);f=x[b>>2]+24|0;x[b>>2]=f;continue}break}je(b);fb=g+16|0;k=fb-16|0;fb=k;b=vb(k+12|0,x[c+4>>2]);g=vb(k+8|0,x[c>>2]);h=x[vb(k+4|0,x[d+4>>2])>>2];m=fb-16|0;fb=m;p=m+8|0;f=fb-32|0;fb=f;fd(f+24|0,x[b>>2],x[g>>2]);q=f+16|0;b=x[f+24>>2];r=x[f+28>>2];g=fb-16|0;fb=g;x[g+8>>2]=h;x[g+12>>2]=b;while(1){if(Fd(b,r)){b=il(b);h=il(x[g+8>>2]);l=z[b+18>>1]|z[b+20>>1]<<16;o=z[b+14>>1]|z[b+16>>1]<<16;w[h+14>>1]=o;w[h+16>>1]=o>>>16;w[h+18>>1]=l;w[h+20>>1]=l>>>16;l=x[b+12>>2];x[h+8>>2]=x[b+8>>2];x[h+12>>2]=l;l=x[b+4>>2];x[h>>2]=x[b>>2];x[h+4>>2]=l;b=gt(g+12|0);gt(g+8|0);b=x[b>>2];continue}break}qc(q,b,g+8|0);fb=g+16|0;b=x[f+16>>2];x[f+12>>2]=x[f+20>>2];qc(p,b,f+12|0);fb=f+32|0;fb=m+16|0;x[d+4>>2]=x[m+12>>2];Tb(c,d+4|0);Tb(c+4|0,d+8|0);Tb(Ab(c),nc(d));x[d>>2]=x[d+4>>2];fb=k+16|0;DJ(d)}fb=n+32|0;break d}if(b>>>0<d>>>0){Jd(c,f+D(b,24)|0)}}f=a+40|0;to(f,x[a+104>>2]<<2);while(1){if(A[a+104>>2]>i>>>0){c=x[a+36>>2];if(nk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){Oh(a,2,1024);break a}b=z[a+24>>1];w[e>>1]=b;if((b|0)==65535){By(c,e);b=z[e>>1]}c=Xc(x[a+40>>2],x[a+44>>2]);d=b&65535;f:{if(!d){b=0;break f}if(d>>>0>(c^-1)>>>0){break f}Jk(f,c+d|0);vj(x[a+36>>2],xb(x[a+40>>2],c),d)}d=wf(x[a+52>>2],i);x[d>>2]=c;w[d+20>>1]=b;b=e+8|0;Qc(b,j,6);if(Gb(x[x[e+8>>2]>>2],x[e+12>>2])){ol(x[a+36>>2],b);b=x[e+8>>2];c=x[e+12>>2];if(!zy(b,c)){break c}d=wf(x[a+52>>2],i);x[d+8>>2]=b;x[d+12>>2]=c}c=x[a+8>>2];g:{if(c){b=wf(x[a+52>>2],i);x[b+16>>2]=c;break g}Qc(e+8|0,j,7);if(!Gb(x[x[e+8>>2]>>2],x[e+12>>2])){b=wf(x[a+52>>2],i);break g}ol(x[a+36>>2],e+8|0);c=x[e+8>>2];if(!zy(c,x[e+12>>2])){break b}b=wf(x[a+52>>2],i);x[b+16>>2]=c}h:{if(x[b+16>>2]==-1){break h}Qc(e+8|0,j,6);if(Gb(x[x[e+8>>2]>>2],x[e+12>>2])){break h}i:{if(!i){c=0;d=wf(x[a+52>>2],0);b=0;break i}d=x[a+52>>2];b=wf(d,i-1|0);g=x[b+16>>2];c=x[b+8>>2]+g|0;b=x[b+12>>2];d=wf(d,i);b=c>>>0<g>>>0?b+1|0:b}x[d+8>>2]=c;x[d+12>>2]=b}b=e+8|0;Qc(b,j,8);if(Gb(x[x[e+8>>2]>>2],x[e+12>>2])){w[e+30>>1]=0;By(x[a+36>>2],e+30|0);Qc(b,j,9);Om(x[a+36>>2],z[e+30>>1]<<Gb(x[x[e+8>>2]>>2],x[e+12>>2]))}i=i+1|0;continue}break}ae(e+8|0,x[a+36>>2]);b=x[e+20>>2];x[a+80>>2]=x[e+16>>2];x[a+84>>2]=b}d=e+8|0;Qc(d,j,4);kf(d,1);f=x[a+80>>2];g=x[a+84>>2];b=x[a+96>>2];h=x[a+16>>2];i=b+h|0;k=x[a+100>>2];c=k+x[a+20>>2]|0;c=i>>>0<h>>>0?c+1|0:c;h=i;i=(b|0)==x[a+72>>2]&(k|0)==x[a+76>>2];b=i?f:h;x[a+88>>2]=b;c=i?g:c;x[a+92>>2]=c;Ci(x[a+36>>2],b,c,0);Qc(d,j,6);if(Gb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}Qc(e,j,7);if(!(Gb(x[x[e>>2]>>2],x[e+4>>2])|x[a+8>>2])){break a}c=x[a+88>>2];d=x[a+16>>2];b=c-d|0;f=x[a+92>>2]-(x[a+20>>2]+(c>>>0<d>>>0)|0)|0;j=x[a+52>>2];g=x[a+104>>2];a=0;while(1){if((a|0)==(g|0)){break a}c=wf(j,a);d=c;h=x[c+8>>2];i=h+b|0;c=x[c+12>>2]+f|0;x[d+8>>2]=i;x[d+12>>2]=i>>>0<h>>>0?c+1|0:c;a=a+1|0;continue}}Oh(a,2,2048);break a}Oh(a,2,2048)}fb=e+32|0}function Ssa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=fb-320|0;fb=f;yc(b);d=fb-16|0;fb=d;h=f+102|0;u_(d+8|0,h);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(g|0)){Vb(b,x[d+12>>2])}fb=d+16|0;a:{b:{c:{if((g|0)!=(i|0)){break c}if(!w_(h)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(v_(y[f+318|0],y[f+319|0]),hb))){break c}e=1;if((c|0)==64){break c}Dd(a,2);eg(a);x[a+480188>>2]=524296;t=a,u=Te(455e3),x[t+480204>>2]=u;Lb(a+1074312|0,110,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+72|0;Ue(d,2,f+133|0);e=f+88|0;Cc(e,d);zb(a+1298308|0,e);j=a+946304|0;l=a+484380|0;k=a+480280|0;tb(e);m=f+165|0;e=0;d:{e:{while(1){if((e|0)==8){f:{d=Xb(x[a+484360>>2],y[a+484376|0]);o=y[f+318|0];m=o+1|0;$j(d,b,m,65535,65535);d=Nb(f+88|0);x[31609]=0;S(234,b|0,d|0,m|0);e=x[31609];x[31609]=0;if((e|0)==1){break f}t=f,u=wb(x[d>>2]),x[t+72>>2]=u;e=wb(x[d+4>>2]);while(1){g=x[f+72>>2];q=Ib(g,e);if(q){if((y[g|0]-1&255)>>>0>7){break d}we(f+72|0);continue}break}t=a,u=y[xb(x[d>>2],0)|0],x[t+480196>>2]=u;e=y[f+317|0];h=y[f+319|0];g=Nb(f+72|0);x[31609]=0;n=h+1|0;S(234,b|0,g|0,n|0);h=x[31609];x[31609]=0;g:{if((h|0)==1){break g}x[31609]=0;h=a+484344|0;O(223,h|0,n|0);i=x[31609];x[31609]=0;if((i|0)==1){break g}r=e+1|0;if(!(c&1)){break e}c=0;while(1){if((c|0)==(n|0)){break e}e=y[xb(x[g>>2],c)|0];x[31609]=0;e=U(196,h|0,e|0,r|0)|0;i=x[31609];x[31609]=0;h:{if((i|0)!=1){if(!e){break e}i=0;l=Wb(x[h>>2],y[xb(x[g>>2],c)|0]);i:while(1){s=i&65535;if(s>>>0>7){break h}i=i+1|0;e=0;while(1){if(A[l+12>>2]<=e>>>0){continue i}x[31609]=0;j=R(197,b|0)|0;k=x[31609];x[31609]=0;j:{k:{if((k|0)!=1){j=j<<24>>24;if((j|0)>=0){break k}e=(j&127)+e|0;break j}break b}k=md(x[l>>2],x[x[l+48>>2]+12>>2],e,s);if((j|0)==1){v[k|0]=254;break j}if((j-1&255)>>>0>96){break j}v[k+1|0]=i;v[k|0]=j+12}e=e+1|0;continue}}}break b}c=c+1|0;continue}}break b}}else{h=f+88|0;d=m+D(e,19)|0;RD(h,d);g=f+72|0;Cc(g,h);gm((k+(e<<5)|0)+9|0,g);tb(g);e=e+1|0;i=l+D(e,104)|0;nd(i,2);v[f+83|0]=0;g=y[d+15|0]|y[d+16|0]<<8|(y[d+17|0]<<16|y[d+18|0]<<24);v[f+79|0]=g;v[f+80|0]=g>>>8;v[f+81|0]=g>>>16;v[f+82|0]=g>>>24;g=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);d=y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24);x[f+16>>2]=x[f+80>>2];x[f+72>>2]=d;x[f+76>>2]=g;d=x[f+76>>2];x[f+8>>2]=x[f+72>>2];x[f+12>>2]=d;Sk(i,1,f+8|0);x[i+24>>2]=8215;d=f+60|0;Cc(d,h);Ac(j+(e<<5)|0,d);tb(d);continue}break}e=N()|0;break a}i=o+1|0;e=0;while(1){l:{if((e|0)==(i|0)){x[31609]=0;b=P(1,f+60|0,8632)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break l}break b}b=Xb(x[a+484360>>2],y[a+484376|0]);j=e&65535;m:{if(!Wi(b,j)){x[31609]=0;c=P(367,h|0,r|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break b}if((c|0)==65535){break m}b=Xb(x[a+484360>>2],y[a+484376|0]);t=ac(x[b>>2],e),u=c,w[t>>1]=u}b=QD(wb(x[Wb(x[h>>2],z[ac(x[b>>2],e)>>1])+4>>2]),1);c=y[b+5|0];l=y[xb(x[d>>2],(e+1>>>0)%(m>>>0)|0)|0];if((c|0)==(l|0)){break m}n:{if(y[b+3|0]!=16){break n}c=y[a+484376|0];k=x[a+484360>>2];x[31609]=0;c=P(368,Xb(k,c)|0,j|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break b}if((c|0)==65535){break n}b=QD(wb(x[Wb(x[h>>2],c)+4>>2]),1)}v[b+5|0]=l;v[b+3|0]=16}e=e+1|0;continue}break}zb(a+1298344|0,b);tb(b);x[31609]=0;b=P(1,f+48|0,6049)|0;c=x[31609];x[31609]=0;if((c|0)==1){break b}zb(a+1298356|0,b);tb(b);c=f+24|0;pi(c,2,f+113|0);x[31609]=0;b=f+36|0;S(369,b|0,4,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}zb(a+1298368|0,b);tb(b);t=a,u=x[Fc(b,4)>>2],x[t+1298404>>2]=u;fc(g)}fc(d);e=q^1}fb=f+320|0;return e|0}e=N()|0;fc(g)}fc(d);Q(e|0);p()}function OR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=fb-16|0;fb=j;a:{b:{c:{if(!Tc(c)|!d|x[b+480180>>2]!=16777216|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}d=x[d+44>>2];if(!d){break c}w[j+14>>1]=c-61;b=fb+-64|0;fb=b;d:{e:{e=w[d+28>>1];i=j+14|0;c=w[i>>1];if((e|0)<=(c|0)){if((c|0)<=(oc(x[d+4>>2],x[d+8>>2])+e|0)-1<<16>>16){break e}}Fb(a);break d}f:{e=w[d+30>>1];if(!e){c=d+52|0;d=jA(c,i);if(!Zg(d,Pf(c))){break f}vm(a,ud(d)+4|0);break d}e=iA(c,e);w[b+62>>1]=e;c=Fb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=d+52|0;f=jA(a,b+62|0);t:{if(Zg(f,Pf(a))){x[31609]=0;O(129,c|0,ud(f)+4|0);a=x[31609];x[31609]=0;if((a|0)==1){break t}a=w[d+30>>1];d=w[i>>1];x[31609]=0;n=b,o=hA(d,a)+5|0,x[n+36>>2]=o;a=b+48|0;O(126,a|0,b+36|0);d=x[31609];x[31609]=0;u:{if((d|0)!=1){x[31609]=0;P(74,c|0,a|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break u}tb(a);break d}a=N()|0;break g}a=N()|0;tb(b+48|0);break g}if(w[d+30>>1]>26){break q}x[31609]=0;e=U(542,b+36|0,1,e+65<<24>>24)|0;a=x[31609];x[31609]=0;if((a|0)==1){break s}x[31609]=0;a=b+48|0;S(602,a|0,0,e|0);f=x[31609];x[31609]=0;if((f|0)==1){break r}f=zb(c,a);tb(a);tb(e);x[31609]=0;P(127,f|0,14690)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break p}}a=N()|0;break g}a=N()|0;break g}a=N()|0;tb(e);break g}x[31609]=0;g=e<<16>>16;a=(g|0)/16|0;x[b+32>>2]=e-(a<<4)<<16>>16;e=b+36|0;O(880,e|0,b+32|0);f=x[31609];x[31609]=0;if((f|0)==1){break o}x[31609]=0;x[b+16>>2]=(a<<16>>16)%16;a=b+20|0;O(880,a|0,b+16|0);f=x[31609];x[31609]=0;if((f|0)==1){break n}x[31609]=0;f=b+48|0;S(2,f|0,e|0,a|0);h=x[31609];x[31609]=0;if((h|0)==1){break m}k=zb(c,f);tb(f);tb(a);tb(e);if((g|0)<256){break p}x[31609]=0;g=b+4|0;O(881,g|0,k|0);a=x[31609];x[31609]=0;if((a|0)==1){break k}h=zd(g);l=Df(g);m=zd(g);a=fb-16|0;fb=a;x[a+8>>2]=m;x[a+12>>2]=h;while(1){if(Ib(h,l)){n=x[a+8>>2],o=Lq(v[h|0]),v[n|0]=o;h=we(a+12|0);we(a+8|0);h=x[h>>2];continue}break}fb=a+16|0;Uc(e,g);x[31609]=0;S(602,f|0,0,e|0);a=x[31609];x[31609]=0;if((a|0)==1){break j}zb(k,f);tb(f);tb(e);tb(g)}a=w[d+30>>1];d=w[i>>1];x[31609]=0;n=b,o=hA(d,a)+5|0,x[n+20>>2]=o;a=b+48|0;O(126,a|0,b+20|0);d=x[31609];x[31609]=0;if((d|0)==1){break i}x[31609]=0;P(74,c|0,a|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break h}tb(a);break d}a=N()|0;break g}a=N()|0;break l}a=N()|0;tb(b+20|0)}tb(b+36|0);break g}a=N()|0;break g}a=N()|0;tb(b+36|0);tb(b+4|0);break g}a=N()|0;break g}a=N()|0;tb(b+48|0)}tb(c);Q(a|0);p()}f=fb-16|0;fb=f;e=f+4|0;c=fb-32|0;fb=c;d=rf(c+20|0,1,0);v:{while(1){g=Kb(d);ts(c+12|0,g,Cb(x[d+4>>2],y[d+11|0])+g|0,w[i>>1]);if(!x[c+16>>2]){break v}g=ki(Cb(x[d+4>>2],y[d+11|0]));x[31609]=0;O(45,d|0,g|0);g=x[31609];x[31609]=0;if((g|0)!=1){continue}break}break a}g=x[c+12>>2];i=Kb(d);x[31609]=0;O(46,d|0,g-i|0);g=x[31609];x[31609]=0;w:{if((g|0)!=1){x[31609]=0;O(47,e|0,d|0);g=x[31609];x[31609]=0;if((g|0)!=1){break w}break a}break a}tb(d);fb=c+32|0;Qh(a,e);tb(e);fb=f+16|0}fb=b- -64|0;break b}e=x[b>>2];b=fb-32|0;fb=b;x:{if(Fl(c)){x[b+16>>2]=4013373;x[b+8>>2]=8289918;x[b+12>>2]=6184542;x[b>>2]=7553872;x[b+4>>2]=2114384;uc(a,(b+(c<<2)|0)-1004|0);break x}if(Tc(c)){d=Fb(b);x[31609]=0;c=c-1|0;f=(c|0)/12|0;c=P(882,d|0,e+(D(f,-12)+c<<16>>16<<2)|0)|0;e=x[31609];x[31609]=0;y:{if((e|0)==1){break y}x[31609]=0;c=P(883,c|0,f+48&255)|0;e=x[31609];x[31609]=0;if((e|0)==1){break y}x[31609]=0;P(3,a|0,c|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break y}tb(c);break x}break a}if(!c){uc(a,16800);break x}uc(a,14661)}fb=b+32|0}fb=j+16|0;return}a=N()|0;tb(d);Q(a|0);p()}function Usa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;f=fb-960|0;fb=f;yc(b);d=fb-16|0;fb=d;e=f+862|0;C_(d+8|0,e);h=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(h|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(g|0);if(!d){B_(e)}a:{if(!d){break a}if(!E_(e)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(D_(y[f+909|0]|y[f+910|0]<<8),hb))){break a}m=1;if((c|0)==64){break a}Dd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[f+937|0];x[a+480208>>2]=16;x[a+480200>>2]=256;x[a+480204>>2]=8e5;Lb(a+1074312|0,7,1);d=f+88|0;e=uc(d,8224);zb(a+1298344|0,e);tb(e);e=uc(d,8928);zb(a+1298356|0,e);tb(e);u=a,A=x[Fc(d,4)>>2],x[u+1298404>>2]=A;e=f+12|0;A_(e,f+866|0);Cc(d,e);zb(a+1298308|0,d);h=a+480280|0;tb(d);g=f+938|0;i=f+912|0;d=0;while(1){if((d|0)==16){b:{d=y[f+958|0]|y[f+959|0]<<8;if(d){lE(a+1298332|0,b,d,132,0)}d=fb-16|0;fb=d;e=f+88|0;cc(d+8|0,e,771);h=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(h|0)){Vb(b,x[d+12>>2])}fb=d+16|0;m=(h|0)==(g|0);if(!m){Rb(e,0,771)}if(!m){break a}z_(Xb(x[a+484360>>2],y[a+484376|0]),e,y[f+345|0]);$e(Xb(x[a+484360>>2],y[a+484376|0]),y[f+346|0]);dd(b,y[f+909|0]|y[f+910|0]<<8);k=a+484344|0;q=c&1;r=f+347|0;e=0;while(1){c:{if((e|0)==256){if(!(c&2)){break a}e0(b,f+60|0);k=a+484380|0;l=a+946304|0;d=0;while(1){if((d|0)==64){break a}if(!(y[f+60+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}c=f+12|0;if(!SD(b,c)){break a}d=d+1|0;w[a+480190>>1]=d;Ue(f,1,c);g=f+68|0;Cc(g,f);Ac(l+(z[a+480190>>1]<<5)|0,g);tb(g);e=k+D(d,104)|0;nd(e,0);j=y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24);x[e>>2]=j;h=y[c+38|0]|y[c+39|0]<<8|(y[c+40|0]<<16|y[c+41|0]<<24);x[e+4>>2]=h;i=y[c+42|0]|y[c+43|0]<<8|(y[c+44|0]<<16|y[c+45|0]<<24);x[e+24>>2]=16726;x[e+8>>2]=i;w[e+30>>1]=y[c+37|0]<<4;if(v[c+46|0]&1){i=i>>>1|0;x[e+8>>2]=i;h=h>>>1|0;x[e+4>>2]=h;x[e>>2]=j>>>1}if(!(!(y[c+47|0]&8)|h>>>0>=i>>>0)){w[e+34>>1]=z[e+34>>1]|2}Zc(g,v[f+58|0]&1?16:8,1,0,0);dg(g,e,b);continue}}d:{d=(e<<1)+r|0;g=y[d|0]|y[d+1|0]<<8;if(g){h=f+68|0;he(h,b,g);i=hc(f+12|0,h);ub(h);l=((y[d|0]|y[d+1|0]<<8)-2|0)/64|0;e:{if(!q){break e}x[31609]=0;d=U(196,k|0,e&65535,l|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(!d){break e}x[31609]=0;d=R(197,i|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break b}x[31609]=0;P(183,i|0,1)|0;h=x[31609];x[31609]=0;if((h|0)==1){break b}s=d?d>>>0>=l-2>>>0?-1:d+1|0:-1;h=0;f:while(1){if((h|0)!=(l|0)){d=Wb(x[k>>2],e);af(f+68|0,x[d>>2],x[x[d+48>>2]+12>>2],h);u=f,A=wb(x[f+68>>2]),x[u>>2]=A;t=nw(x[f+68>>2],x[f+72>>2]);while(1){d=x[f>>2];if(!Ib(d,t)){h=h+1|0;continue f}x[31609]=0;g=f+60|0;O(357,g|0,i|0);j=x[31609];x[31609]=0;if((j|0)==1){break c}n=_e(g);j=Yi(g);o=y[f+60|0];if((o-1&255)>>>0<=71){v[d|0]=o+36;u=d,A=y[Jc(g)|0]+1|0,v[u+1|0]=A}g=y[n|0];if((g-1&255)>>>0<=15){v[d+2|0]=1;v[d+4|0]=(((g<<6)+-64&65472)>>>0)/15}n=y[j|0];g=n&15;v[d+5|0]=g;g:{h:{switch((y[j|0]>>>4|0)-1|0){case 0:case 1:v[d+5|0]=n|240;break g;case 2:v[d+5|0]=g<<2;break g;case 3:v[d+5|0]=(6/(g+1>>>0)|0)+1;break g;case 5:case 6:v[d+5|0]=g<<3;break g;case 9:v[d+2|0]=1;v[d+4|0]=(g<<2)+4;break g;case 10:v[d+5|0]=g|128;break g;case 11:break h;default:break g}}v[d+5|0]=(6/(g+1>>>0)|0)+1|13}v[d+3|0]=y[(y[j|0]>>>4|0)+24768|0];tg(f);continue}}break}Ae(Wb(x[k>>2],e),Vh(We(Oe(f+68|0,14,0),s)))}ub(i)}e=e+1|0;continue}}break}}}else{e=h+(d<<5)|0;Ve(e);x[e>>2]=!y[d+i|0]<<10;w[e+4>>1]=(y[d+g|0]<<4|8)&248;d=d+1|0;continue}break}a=N()|0;ub(i);Q(a|0);p()}fb=f+960|0;return m|0}function j1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=fb-560|0;fb=f;yc(b);d=fb-16|0;fb=d;g=f+63|0;nF(d+8|0,g);e=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(e|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(e|0)==(h|0);if(!d){mF(g)}a:{b:{if(!d){break b}if(!qF(g)){break b}d=1;if((c|0)==64){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(pF(y[f+173|0],y[f+174|0]),hb))){break b}Dd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;Lb(a+1074312|0,7,1);d=f+36|0;g=uc(d,14692);zb(a+1298344|0,g);tb(g);g=uc(d,14725);zb(a+1298356|0,g);tb(g);Zh(a+1298368|0,(y[f+63|0]|y[f+64|0]<<8)==26217?14692:14720);r=a,s=x[Fc(d,4)>>2],x[r+1298404>>2]=s;e=y[f+173|0];w[a+480190>>1]=e;l=a+946304|0;m=a+484380|0;g=1;while(1){h=g&65535;if(h>>>0<=e>>>0){e=fb-16|0;fb=e;d=f+36|0;cc(e+8|0,d,25);j=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);i=x[e+4>>2];if((i|0)==(j|0)){Vb(b,x[e+12>>2])}fb=e+16|0;if((i|0)!=(j|0)){v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0}if((y[f+49|0]|y[f+50|0]<<8|(y[f+51|0]<<16|y[f+52|0]<<24))>>>0>67108863){break b}e=D(h,104)+m|0;nd(e,0);x[e+24>>2]=8363;i=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[e>>2]=i;k=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);x[e+4>>2]=k;j=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);x[e+8>>2]=j;c:{if(!(k|i>>>0>=j>>>0)){x[e+8>>2]=0;break c}if(j){w[e+34>>1]=2;Uk(e)}}e=f+12|0;dk(e,2,d);d=f+24|0;Cc(d,e);Ac(l+(h<<5)|0,d);g=g+1|0;tb(d);e=z[a+480190>>1];continue}break}g=f+24|0;e=f+65|0;ug(g,3,e,36);d=f+36|0;Cc(d,g);zb(a+1298308|0,d);tb(d);g=0;lF(a+1298332|0,e,108,36,0);Jw(Xb(x[a+484360>>2],y[a+484376|0]),f+176|0,128,255,254);d=Xb(x[a+484360>>2],y[a+484376|0]);e=y[f+175|0];if(z[ac(x[d>>2],e)>>1]<y[f+174|0]){$e(d,e)}d=a+480280|0;while(1)if((g|0)==8){j=a+484344|0;Tf(j,y[f+174|0]);o=c&1;p=f+304|0;q=f+432|0;h=0;while(1){d:{e:{if(y[f+174|0]<=h>>>0){d=1;if(!(c&2)){break a}c=Zc(f+36|0,8,1,0,1);g=1;break e}f:{if(o){if(Pg(j,h&65535,64)){break f}}Vb(b,1536);break d}x[f+24>>2]=-1;x[f+28>>2]=-1;l=0;g:while(1){if((l|0)==64){d=x[j>>2];g=y[h+q|0];if(g>>>0<63){Ae(Wb(d,h),Vh(We(Oe(f+36|0,14,0),g)));d=x[j>>2]}Ae(Wb(d,h),Vh(Oe(f+36|0,16,y[h+p|0])));break d}g=0;d=Wb(x[j>>2],h);e=md(x[d>>2],x[x[d+48>>2]+12>>2],l,0);while(1){if((g|0)==8){l=l+1|0;continue g}d=f+36|0;Tr(d,b);i=Jc(d);k=_e(d);i=y[i|0];d=y[f+36|0];if(d>>>0<=253){v[e|0]=(d>>>2|0)+37;v[e+1|0]=(d<<4&48|i>>>4)+1;v[(f+24|0)+g|0]=255;d=y[f+36|0]}if((d&255)!=255){v[e+2|0]=1;v[e+4|0]=(((i&15)<<6|8)>>>0)/15}d=y[k|0];if((d|0)!=255){v[(f+24|0)+g|0]=d}k=(f+24|0)+g|0;h:{i:{if(!(d&15)&(d|0)!=48){break i}d=v[k|0];if((d|0)==-1){break h}i=d&15;v[e+5|0]=i;j:{if((d|0)<0){break j}n=(d&240)>>>4|0;v[e+3|0]=y[n+24568|0];k:{switch(n-3|0){case 0:v[e+5|0]=i|32;break i;case 1:v[e+5|0]=i|d<<4;break h;case 2:break i;case 3:break k;default:break h}}l:{switch(i|0){case 0:v[e+5|0]=79;break h;case 1:break l;default:break j}}v[e+5|0]=244;break h}v[e+3|0]=0;break h}v[k|0]=255}e=e+6|0;g=g+1|0;continue}}}while(1){d=g&65535;if(d>>>0<=z[a+480190>>1]){dg(c,D(d,104)+m|0,b);g=g+1|0;continue}break}d=1;break a}h=h+1|0;continue}}else{e=d+(g<<5)|0;Ve(e);w[e+4>>1]=g&1?208:48;g=g+1|0;continue}}d=0}fb=f+560|0;return d|0}function $s(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-160|0;fb=e;x[e+148>>2]=-1;x[e+140>>2]=6;x[e+144>>2]=364;x[e+132>>2]=11;x[e+136>>2]=161;x[e+124>>2]=23;x[e+128>>2]=31;x[e+116>>2]=59;x[e+120>>2]=55;x[e+152>>2]=0;x[e+156>>2]=0;v[e+14|0]=c;v[e+13|0]=37;v[e+15|0]=0;l=b+484|0;j=b+460|0;i=b+172|0;k=b+4|0;f=e+16|0;h=f+(fa(f|0,100,e+13|0,e+116|0,x[b>>2])|0)|0;x[e+8>>2]=f;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){if(Jf(x[d+8>>2],1,v[f|0])){x[31609]=0;O(115,g|0,32);a=x[31609];x[31609]=0;if((a|0)==1){break c}a=x[d+8>>2];while(1){f=f+1|0;if((h|0)==(f|0)){f=h;break b}if(Jf(a,1,v[f|0])){continue}break}break b}x[e+4>>2]=f;x[31609]=0;x[e>>2]=0;a=ea(1383,e+4|0,h|0,k|0,i|0,d|0,e|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31609]=0;O(115,g|0,37);c=x[31609];x[31609]=0;if((c|0)==1){break c}x[31609]=0;O(115,g|0,((a|0)<84?65:97)|0);a=x[31609];x[31609]=0;if((a|0)!=1){break q}break c}x[31609]=0;x[e+4>>2]=f;a=ea(1383,e+4|0,h|0,i|0,j|0,d|0,e|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}a=a-i|0;c=(a|0)/12|0;if((a|0)<=287){x[31609]=0;O(115,g|0,37);f=x[31609];x[31609]=0;if((f|0)==1){break c}x[31609]=0;O(115,g|0,((a|0)<144?66:98)|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}if(m){break q}if(!Jf(x[d+8>>2],64,v[ec(D(c,12)+i|0,0)|0])){break q}n=yz(g),o=109,v[n|0]=o;break q}if((Cb(x[b+464>>2],y[b+471|0])|0)==(0-Cb(x[b+476>>2],y[b+483|0])|0)){break p}x[31609]=0;x[e+4>>2]=f;a=ea(1383,e+4|0,h|0,j|0,l|0,d|0,e|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}if((a-j|0)>23){break p}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;O(115,g|0,112);a=x[31609];x[31609]=0;if((a|0)==1){break c}}f=x[e+4>>2];break b}x[e+4>>2]=f;a=v[f|0];if(Jf(x[d+8>>2],64,a)){x[31609]=0;a=ba(1384,e+8|0,h|0,e|0,d|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+8>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=v[f|0];x[31609]=0;O(115,g|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}f=f+1|0;continue}}u:{if((a|0)==37){x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;O(115,g|0,37);break u}x[31609]=0;O(115,g|0,a|0)}a=x[31609];x[31609]=0;if((a|0)==1){break c}f=f+1|0;break b}fb=e+160|0;return}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=89;break d}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=106;break d}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=121;break d}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=83;break d}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=77;break d}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=100;break d}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=72;break d}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=109;break d}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=73;break d}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=117;break d}x[31609]=0;O(115,g|0,37);a=x[31609];x[31609]=0;c=119}if((a|0)==1){break c}x[31609]=0;O(115,g|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}f=x[e+8>>2];continue}a=N()|0;tb(g);Q(a|0);p()}x[e+8>>2]=f;continue}}function rna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=fb-48|0;fb=f;yc(b);o=Zd(b);h=0;a:{if((o-5&255)>>>0<253){break a}b:{if(!Mb(x[b>>2],x[b+8>>2],4355)){break b}i=1;while(1){if((i&65535)>>>0<=256){l=f+32|0;kE(b,l);if(!rV(l,o)){break b}d=e;e=0;j=fb-32|0;fb=j;m=y[l+11|0];h=y[l+9|0]|y[l+10|0]<<8;v[j+14|0]=0;v[j+26|0]=m;w[j+24>>1]=h;w[j+12>>1]=0;while(1){if((e|0)!=3){h=xb(j+24|0,e);q=xb(j+12|0,e),r=y[h|0],v[q|0]=r;e=e+1|0;continue}break}n=cg(j+12|0);m=y[l+8|0];h=y[l+6|0]|y[l+7|0]<<8;e=0;v[j+10|0]=0;v[j+18|0]=m;w[j+16>>1]=h;w[j+8>>1]=0;while(1){if((e|0)!=3){h=xb(j+16|0,e);q=xb(j+8|0,e),r=y[h|0],v[q|0]=r;e=e+1|0;continue}break}e=cg(j+8|0);fb=j+32|0;e=e>>>0<n>>>0?i:d;i=i+1|0;continue}break}if(!(e&65535)){break b}h=1;if((c|0)==64){break a}Dd(a,1);w[a+480190>>1]=e;x[a+480228>>2]=(o|0)==3?192:48;x[a+480208>>2]=x[a+480208>>2]&-25165825|16777216;dd(b,1);j=a+946304|0;p=a+484380|0;l=e+1|0;n=l&65535;i=1;while(1)if((i|0)==(n|0)){dd(b,4097);$j(Xb(x[a+484360>>2],y[a+484376|0]),b,256,255,65535);d=Zd(b);if(d>>>0>31){break b}w[a+480188>>1]=d+1&255;i=Zd(b);d=z[a+480188>>1];j=i+1|0;h=0;if(!Mb(x[b>>2],x[b+8>>2],D(D(d,j),384)+d|0)){break a}e=a+480280|0;i=0;while(1)if(z[a+480188>>1]<=i>>>0){n=a+484344|0;Tf(n,j);m=c&1;e=0;while(1){c:{if((e|0)!=(j|0)){d:{if(m){if(Pg(n,e&65535,64)){break d}}Vb(b,D(z[a+480188>>1],384));break c}h=Ng(f+32|0);d=Wb(x[n>>2],e);q=f,r=wb(x[d>>2]),x[q+16>>2]=r;i=wb(x[d+4>>2]);while(1){k=x[f+16>>2];if(!Ib(k,i)){break c}d=f+20|0;L_(d,b);d=y[xb(d,0)|0];if((d-1&255)>>>0<=76){v[k|0]=d+36}d=f+20|0;q=k,r=y[xb(d,1)|0],v[q+1|0]=r;if(!qV(k,y[xb(d,2)|0],y[xb(d,5)|0],o)){break b}if(!qV(h,y[xb(d,3)|0],y[xb(d,4)|0],o)){break b}d=y[f+35|0];if(d){em(f+14|0,k,y[k+3|0],y[k+5|0],d,y[f+37|0])}tg(f+16|0);continue}}e:{if(!(c&2)){break e}d=l&65535;i=1;while(1){if((d|0)==(i|0)){break e}c=p+D(i,104)|0;dg(Zc(f+32|0,w[c+34>>1]&1?16:8,1,0,0),c,b);i=i+1|0;continue}}Zh(a+1298344|0,14231);Zh(a+1298356|0,11152);sf(a+1298368|0);q=a,r=x[Fc(f+32|0,4)>>2],x[q+1298404>>2]=r;h=1;break a}e=e+1|0;continue}}else{d=e+(i<<5)|0;Ve(d);q=d,r=D(Zd(b),17),w[q+4>>1]=r;i=i+1|0;continue}}else{kE(b,f+32|0);e=0;g=fb-16|0;fb=g;k=p+D(i,104)|0;nd(k,1);h=y[f+43|0];d=y[f+41|0]|y[f+42|0]<<8;v[g+6|0]=0;v[g+10|0]=h;w[g+8>>1]=d;w[g+4>>1]=0;while(1){if((e|0)!=3){d=xb(g+8|0,e);q=xb(g+4|0,e),r=y[d|0],v[q|0]=r;e=e+1|0;continue}break}m=cg(g+4|0);h=y[f+40|0];d=y[f+38|0]|y[f+39|0]<<8;e=0;v[g+2|0]=0;v[g+10|0]=h;w[g+8>>1]=d;w[g>>1]=0;while(1){if((e|0)!=3){d=xb(g+8|0,e);q=xb(g,e),r=y[d|0],v[q|0]=r;e=e+1|0;continue}break}q=k,r=m-cg(g)|0,x[q>>2]=r;h=y[f+34|0];d=y[f+32|0]|y[f+33|0]<<8;e=0;v[g+6|0]=0;v[g+10|0]=h;w[g+8>>1]=d;w[g+4>>1]=0;while(1){if((e|0)!=3){d=xb(g+8|0,e);q=xb(g+4|0,e),r=y[d|0],v[q|0]=r;e=e+1|0;continue}break}q=k,r=cg(g+4|0)+1|0,x[q+4>>2]=r;h=y[f+37|0];d=y[f+35|0]|y[f+36|0]<<8;e=0;v[g+6|0]=0;v[g+10|0]=h;w[g+8>>1]=d;w[g+4>>1]=0;while(1){if((e|0)!=3){d=xb(g+8|0,e);q=xb(g+4|0,e),r=y[d|0],v[q|0]=r;e=e+1|0;continue}break}q=k,r=cg(g+4|0)+1|0,x[q+8>>2]=r;e=y[f+45|0];d=e>>>2|0;d=z[k+34>>1]&-7|d&2|d&4;w[k+34>>1]=d;if(e&4){w[k+34>>1]=d|1;x[k>>2]=x[k>>2]>>>1}w[k+30>>1]=y[f+44|0];if((o|0)!=2){x[k+24>>2]=y[f+46|0]|y[f+47|0]<<8}pV(k);fb=g+16|0;d=Dc(f+20|0,22292);Ac(j+(i<<5)|0,d);tb(d);i=i+1|0;continue}}h=0}fb=f+48|0;return h|0}function Ska(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-96|0;fb=e;h=e+76|0;i=a+140|0;Tj(h,i,1296125513);x[31609]=0;f=R(172,x[e+76>>2])|0;g=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((g|0)!=1){if(f){f=Fb(e+28|0);x[31609]=0;g=R(154,x[e+76>>2])|0;j=x[31609];x[31609]=0;if((j|0)==1){break p}x[31609]=0;S(813,h|0,f|0,g|0);h=x[31609];x[31609]=0;if((h|0)==1){break p}g=z[a+174>>1];x[31609]=0;h=e- -64|0;S(814,h|0,g|0,f|0);g=x[31609];x[31609]=0;if((g|0)==1){break o}x[31609]=0;g=e+4|0;S(815,g|0,c|0,h|0);c=x[31609];x[31609]=0;if((c|0)==1){break n}Ac(d,g);tb(g);tb(h);tb(f)}if(y[a+176|0]){x[31609]=0;c=e+28|0;O(816,c|0,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}Be(b+43|0,c);tb(c)}x[31609]=0;c=e+28|0;S(808,c|0,i|0,1413894985);f=x[31609];x[31609]=0;if((f|0)==1){break l}x[31609]=0;h=R(817,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break k}ub(c);f=a+40|0;yc(f);x[31609]=0;c=P(818,f|0,c|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break j}if(c){q:{if((y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24))>>>0<2){break q}x[31609]=0;c=e+4|0;g=P(819,f|0,c|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break i}if(!g){break q}sR(c,b+12|0,b+16|0,x[b>>2],b+34|0,8,16,h)}x[31609]=0;c=e+4|0;f=P(819,f|0,c|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break i}if(f){sR(c,b+4|0,b+8|0,x[b>>2],b+34|0,2,4,h)}c=y[e+40|0]|y[e+41|0]<<8|(y[e+42|0]<<16|y[e+43|0]<<24);v[b+42|0]=c&128?0:c+1|0;Uk(b)}r:{if(y[b+42|0]){break r}c=x[a+60>>2];x[31609]=0;c=P(679,c|0,7)|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;yc(c);x[31609]=0;c=P(820,c|0,e+4|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}if(!c){break r}c=v[e+4|0];v[b+42|0]=(c|0)>=0?c+1|0:0}c=x[a+120>>2];x[31609]=0;c=R(172,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}if(!c){break f}x[31609]=0;g=a+120|0;c=R(151,g|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break c}x[e+64>>2]=c;xc(e- -64|0,9);f=b+68|0;h=x[e+64>>2];c=0;while(1){if((c|0)==(h|0)){break g}x[31609]=0;O(821,g|0,e+4|0);i=x[31609];x[31609]=0;if((i|0)==1){break h}k=yb(f,c),l=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24),x[k>>2]=l;c=c+1|0;continue}}a=N()|0;break a}a=N()|0;break m}a=N()|0;break m}a=N()|0;tb(e- -64|0)}tb(f);break a}a=N()|0;break a}a=N()|0;ub(e+28|0);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Zz(f+(h<<2)|0,BZ(f),41076)}c=a+80|0;yc(c);x[31609]=0;f=P(822,c|0,e+4|0)|0;h=x[31609];x[31609]=0;s:{if((h|0)==1){break s}if(!f){break b}if(y[e+4|0]&32){w[b+34>>1]=z[b+34>>1]|32}w[e+64>>1]=z[e+8>>1];w[e+2>>1]=256;k=b,l=z[Oc(e- -64|0,e+2|0)>>1],w[k+28>>1]=l;w[e+64>>1]=z[e+10>>1];w[e+2>>1]=256;k=b,l=z[Oc(e- -64|0,e+2|0)>>1],w[k+30>>1]=l;w[e+64>>1]=z[e+12>>1];w[e+2>>1]=64;k=b,l=z[Oc(e- -64|0,e+2|0)>>1],w[k+32>>1]=l;v[b+38|0]=y[e+16|0];v[b+39|0]=y[e+17|0];v[b+40|0]=y[e+18|0];v[b+41|0]=y[e+19|0];f=x[a+88>>2];a=x[a+80>>2];x[31609]=0;a=U(150,a|0,f|0,32)|0;f=x[31609];x[31609]=0;if((f|0)==1){break s}if(!a){break b}x[31609]=0;O(823,c|0,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break s}x[31609]=0;a=R(202,c|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break s}x[31609]=0;S(824,c|0,b+43|0,a|0);a=x[31609];x[31609]=0;if((a|0)!=1){break b}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}ub(e+76|0);fb=e+96|0;return}ub(e+76|0);Q(a|0);p()}function Foa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=fb-176|0;fb=f;yc(b);d=f+128|0;a:{if(!SD(b,d)){break a}if(!EW(d)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(DW(y[f+159|0],y[f+161|0]),hb))){break a}e=1;if((c|0)==64){break a}Dd(a,256);g=f+16|0;pi(g,2,d);d=f+48|0;Cc(d,g);zb(a+1298308|0,d);tb(d);e=uc(d,15430);zb(a+1298344|0,e);tb(e);e=uc(d,10136);zb(a+1298356|0,e);tb(e);gg(g,4271);x[31609]=0;e=f+116|0;O(249,e|0,f+159|0);h=x[31609];x[31609]=0;b:{c:{if((h|0)!=1){x[31609]=0;V(700,d|0,g|0,f+158|0,e|0);h=x[31609];x[31609]=0;if((h|0)!=1){zb(a+1298368|0,d);tb(d);tb(e);Eb(g);o=a,q=x[Fc(d,4)>>2],x[o+1298404>>2]=q;d=Lb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;Lb(d,107,1);e=y[f+160|0];d=y[f+159|0];if(d>>>0<=20){g=((e&255)>>>0)/10|0;e=g<<4|D(g,-10)+e}g=(e&255?e:96)&255;e=AC(g);x[a+480196>>2]=g>>>4;x[a+480204>>2]=e;if(d>>>0>=11){v[f+48|0]=64;o=a,q=y[Qb(f+162|0,f+48|0)|0]<<2,x[o+480200>>2]=q}d=a+480280|0;e=0;while(1)if((e|0)==4){l=a+946304|0;m=a+484380|0;e=1;while(1){if((e|0)!=32){d=f+16|0;xr(b,d);g=y[f+28|0];if(g?(g|0)!=46:0){break b}h=fb-32|0;fb=h;g=D(e,104)+m|0;nd(g,0);j=h+8|0;Lk(j,2,d);i=h+20|0;Cc(i,j);Be(g+43|0,i);tb(i);x[g+24>>2]=y[d+24|0]|y[d+25|0]<<8;v[h+20|0]=y[d+22|0];v[h+8|0]=64;o=g,q=y[Qb(i,j)|0]<<2,w[o+30>>1]=q;i=y[d+16|0]|y[d+17|0]<<8;x[g>>2]=i;j=y[d+18|0]|y[d+19|0]<<8;x[g+4>>2]=j;k=y[d+20|0]|y[d+21|0]<<8;x[g+8>>2]=k;d:{if(i>>>0<=1){x[g>>2]=0;break d}if((k|0)==65535|i>>>0<=j>>>0|j>>>0>=k>>>0){break d}w[g+34>>1]=2;o=g,q=x[Hb(g+8|0,g)>>2],x[o+8>>2]=q}fb=h+32|0;g=f+4|0;Lk(g,2,d);d=f+116|0;Cc(d,g);Ac(l+(e<<5)|0,d);tb(d);w[((e<<1)+f|0)+46>>1]=y[f+30|0]|y[f+31|0]<<8;e=e+1|0;continue}break}$j(Xb(x[a+484360>>2],y[a+484376|0]),b,y[f+159|0]?128:64,65535,65535);e=0;if(!BW(Xb(x[a+484360>>2],y[a+484376|0]))){break a}n=c&1;if(n){Tf(a+484344|0,y[f+161|0])}j=a+484344|0;h=0;while(1)if(y[f+161|0]<=h>>>0){e=1;if(!(c&2)){break a}c=Zc(f+16|0,8,1,0,0);while(1)if((e|0)==32){e=1;break a}else{a=D(e,104)+m|0;e:{if(!x[a>>2]|!z[a+30>>1]){break e}d=z[((e<<1)+f|0)+46>>1];if(d>>>0<4){break e}if(!dd(b,d<<4)){break e}dg(c,a,b)}e=e+1|0;continue}}else{f:{g:{if(n){if(Pg(j,h&65535,64)){break g}}e=0;while(1){if((e|0)==256){break f}if((Zd(b)+2&255)>>>0<=252){Vb(b,3)}e=e+1|0;continue}}o=f,q=wb(x[Wb(x[j>>2],h)>>2]),x[o+116>>2]=q;w[f+2>>1]=65535;x[f+4>>2]=63;i=0;h:while(1){e=0;if((i|0)==64){a=z[f+2>>1];if((a|0)==65535){break f}Ae(Wb(x[j>>2],h),An(We(Oe(f+16|0,12,a&255),x[f+4>>2])));break f}while(1){i:{j:{k:{if((e&65535)>>>0<=3){d=0;a=0;k=0;l=0;l:{m:{n:{o:{g=Zd(b);switch(g-251|0){case 1:break i;case 0:break m;case 2:break o;default:break n}}v[x[f+116>>2]]=254;break i}d=f+16|0;Tr(d,b);a=y[xb(d,0)|0];k=y[xb(d,1)|0];l=y[xb(d,2)|0];d=254;if((g|0)==254){break l}if(g>>>0>=96){break k}d=g}d=(D(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=x[f+116>>2];v[d|0]=g;break j}i=i+1|0;continue h}d=x[f+116>>2]}v[d+1|0]=(a&248)>>>3;a=k>>>1&120|a&7;if(a>>>0<=64){v[d+4|0]=a;v[d+2|0]=1}v[d+5|0]=l;AW(d,k&15,i,y[f+159|0],f+2|0,f+4|0)}e=e+1|0;LC(f+116|0);continue}}}h=h+1|0;continue}}else{g=d+(e<<5)|0;Ve(g);w[g+4>>1]=e&1?64:192;e=e+1|0;continue}}e=N()|0;tb(f+116|0);break c}e=N()|0}Eb(f+16|0);Q(e|0);p()}e=0}fb=f+176|0;return e|0}function zS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;h=a+1074992|0;d=h+D(b,872)|0;e=c&15;a:{b:{switch(c-16>>>4|0){case 0:x[d+88>>2]=x[d+88>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(Kj(x[d+656>>2])){w[d+772>>1]=e-8;v[d+851|0]=y[d+851|0]|64;break a}if(x[a+480180>>2]!=64){b=e<<28>>24;w[d+772>>1]=b;c=z[(e<<1)+31648>>1];x[d+704>>2]=c;if(!x[d+700>>2]){break a}m=d,n=zh(a,y[d+797|0],b,c),x[m+700>>2]=n;break a}a=x[d+104>>2];if(!a){break a}x[d+704>>2]=x[a+24>>2]+D(e,80);break a;case 2:if(x[a+480180>>2]==2){v[d+822|0]=c&3;break a}Jb(f+8|0,a+1074312|0,21);if(Gb(x[x[f+8>>2]>>2],x[f+12>>2])){v[d+822|0]=e>>>0<4?e:0;break a}v[d+822|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[d+825|0]=c&3;break a}Jb(f+8|0,a+1074312|0,21);if(Gb(x[x[f+8>>2]>>2],x[f+12>>2])){v[d+825|0]=e>>>0<4?e:0;break a}v[d+825|0]=c&7;break a;case 4:Jb(f+8|0,a+1074312|0,21);if(Gb(x[x[f+8>>2]>>2],x[f+12>>2])){v[d+821|0]=0;v[d+828|0]=e>>>0<4?e:0;break a}v[d+828|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}x[a+1074400>>2]=x[a+1074400>>2]+e;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(e>>>0<=2){c=z[a+480188>>1];i=c>>>0<=256?256:c;j=a+906300|0;k=b+1|0;l=e-1|0;while(1){if((c|0)==(i|0)){break a}d=D(c,872)+h|0;c:{if(z[d+786>>1]!=(k|0)){break c}d:{e:{switch(l|0){case 0:Fo(a,d);if(!(y[d+89|0]&2)){break d}e=x[a+1298300>>2];if(!Ed(e)){break d}yk(e,c&65535);break d;case 1:e=x[d+88>>2];x[d+88>>2]=e|4096;if(!(e&512)){break d}e=x[a+1298300>>2];if(!Ed(e)){break d}yk(e,c&65535);break d;default:break e}}x[d+696>>2]=0;e=x[d+88>>2];x[d+88>>2]=e|4096;if(!(e&512)){break d}e=x[a+1298300>>2];if(!Ed(e)){break d}Ej(e,c&65535,1)}e=x[d+656>>2];if(!e){break c}g=y[e+34|0];if(!g){break c}g=x[$d(j,g-1|0)>>2];if(!g){break c}ib[x[x[g>>2]+96>>2]](g,e,y[d+797|0]|256,0,b)}c=c+1|0;continue}}dV(d,e,x[a+480180>>2]);break a;case 7:if(!(y[a+480209|0]&16)){break a}Zm(a,d,e,4);break a;case 8:b=x[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e|0){case 0:x[d+88>>2]=x[d+88>>2]&-257;break f;case 1:x[d+692>>2]=128;x[d+88>>2]=x[d+88>>2]|256;break f;case 8:x[d+88>>2]=x[d+88>>2]&-25165825|16777216;break f;case 9:x[d+88>>2]=x[d+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=b&-16385;break f;case 11:x[a+480208>>2]=b|16384;break f;case 12:x[a+480208>>2]=b&-8193;break f;case 13:x[a+480208>>2]=b|8192;break f;case 14:x[d+88>>2]=x[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(x[d>>2]|x[d+4>>2]){break h}a=x[d+76>>2];if(!a){break h}if(!(m=Tc(y[d+788|0]),n=1,o=y[d+88|0]&2,o?m:n)){break h}x[d>>2]=-1;x[d+4>>2]=a-1}x[d+88>>2]=x[d+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}v[d+836|0]=e;Jb(f+8|0,a+1074312|0,35);if(Gb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}if(!Tc(y[d+788|0])){break a}a=e<<16;if(a>>>0>=A[d+76>>2]){break a}x[d+4>>2]=a;break a;case 10:if(!(y[a+480209|0]&16)){break a}vB(a,a+1074376|0,b,e);break a;case 11:i:{if(e){break i}e=1;c=x[a+480180>>2];if(c&16777248){break i}e=0;if((c|0)==2){break a}}Jb(f+8|0,a+1074312|0,30);dB(a,b,e,Gb(x[x[f+8>>2]>>2],x[f+12>>2])|x[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[d+844|0]=e}fb=f+16|0}function bH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-32|0;fb=g;d=x[b+28>>2];x[g+24>>2]=x[b+24>>2];x[g+28>>2]=d;d=x[b+20>>2];x[g+16>>2]=x[b+16>>2];x[g+20>>2]=d;d=x[b+12>>2];x[g+8>>2]=x[b+8>>2];x[g+12>>2]=d;d=x[b+4>>2];x[g>>2]=x[b>>2];x[g+4>>2]=d;d=fb-144|0;fb=d;k=Fb(d+132|0);n=Fb(d+120|0);x[31609]=0;b=P(1,d+108|0,c|0)|0;c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=zb(n,b);tb(b);if(!x[g>>2]){break b}x[31609]=0;b=d+96|0;O(73,b|0,g|0);e=x[31609];x[31609]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){x[31609]=0;i=P(74,k|0,b|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break q}tb(b);x[31609]=0;e=P(1,d+84|0,16834)|0;f=x[31609];x[31609]=0;if((f|0)==1){break p}x[31609]=0;f=d+72|0;O(75,f|0,g+4|0);h=x[31609];x[31609]=0;if((h|0)==1){break o}x[31609]=0;S(2,b|0,e|0,f|0);h=x[31609];x[31609]=0;if((h|0)==1){break n}x[31609]=0;i=P(74,i|0,b|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break m}tb(b);tb(f);tb(e);x[31609]=0;e=P(1,f|0,16834)|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}x[31609]=0;f=d+60|0;O(75,f|0,g+8|0);h=x[31609];x[31609]=0;if((h|0)==1){break i}x[31609]=0;S(2,b|0,e|0,f|0);h=x[31609];x[31609]=0;if((h|0)==1){break h}x[31609]=0;i=P(74,i|0,b|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break g}tb(b);tb(f);tb(e);e=x[g+28>>2];o=e;b=x[g+24>>2];if(x[g+12>>2]|(x[g+16>>2]|!(e|b))){break d}break b}a=N()|0;break c}a=N()|0;tb(d+96|0);break c}a=N()|0;break c}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+96|0)}tb(d+72|0)}tb(e);break c}a=N()|0;break c}a=N()|0;break e}a=N()|0;break f}a=N()|0;tb(d+96|0)}tb(d+60|0)}tb(e);break c}x[31609]=0;e=P(1,d+96|0,13778)|0;f=x[31609];x[31609]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)!=1){x[31609]=0;l=P(74,i|0,e|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break J}tb(e);x[31609]=0;f=d+36|0;O(76,f|0,g+12|0);e=x[31609];x[31609]=0;if((e|0)==1){break I}x[31609]=0;e=P(1,d+24|0,14690)|0;i=x[31609];x[31609]=0;if((i|0)==1){break H}x[31609]=0;i=d+48|0;S(2,i|0,f|0,e|0);h=x[31609];x[31609]=0;if((h|0)==1){break G}x[31609]=0;h=d+12|0;O(76,h|0,g+16|0);j=x[31609];x[31609]=0;if((j|0)==1){break F}x[31609]=0;j=d+60|0;S(2,j|0,i|0,h|0);m=x[31609];x[31609]=0;if((m|0)==1){break E}x[31609]=0;l=P(74,l|0,j|0)|0;m=x[31609];x[31609]=0;if((m|0)==1){break D}tb(j);tb(h);tb(i);tb(e);tb(f);if(b|o){break y}x[31609]=0;S(77,a|0,l|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break x}break a}a=N()|0;break c}a=N()|0;tb(e);break c}a=N()|0;break c}a=N()|0;break z}a=N()|0;break A}a=N()|0;break B}a=N()|0;break C}a=N()|0;tb(d+60|0)}tb(d+12|0)}tb(d+48|0)}tb(e)}tb(d+36|0);break c}x[31609]=0;b=P(1,d+48|0,14690)|0;e=x[31609];x[31609]=0;if((e|0)==1){break w}x[31609]=0;e=d+36|0;O(78,e|0,g+24|0);f=x[31609];x[31609]=0;if((f|0)==1){break v}x[31609]=0;f=d+60|0;S(2,f|0,b|0,e|0);i=x[31609];x[31609]=0;if((i|0)==1){break u}x[31609]=0;i=P(74,l|0,f|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break t}tb(f);tb(e);tb(b);x[31609]=0;P(74,i|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break b}}a=N()|0;break c}a=N()|0;break c}a=N()|0;break r}a=N()|0;break s}a=N()|0;tb(d+60|0)}tb(d+36|0)}tb(b);break c}a=N()|0}tb(n);tb(k);Q(a|0);p()}Uc(a,k)}tb(c);tb(k);fb=d+144|0;fb=g+32|0}function uka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0;k=fb-32|0;fb=k;j=x[a+4>>2];e=Se(x[a+8>>2],b);r=x[e>>2];a:{if(r+1>>>0<2){break a}f=(j+D(b,872)|0)+616|0;if(!(Mi(x[f+8>>2],x[f+12>>2])|y[e+4|0])|!x[f+104>>2]){break a}i=x[f+88>>2]&2;e=x[(i?84:76)+f>>2];p=x[f+84>>2];g=x[f+80>>2];s=Ob(x[a>>2]+1074312|0,31);h=uf(x[f+8>>2],x[f+12>>2],c);l=y[f+88|0]&128;j=l?0-h|0:h;n=hb;l=l?0-(n+((h|0)!=0)|0)|0:n;h=i;n=h?0:0;q=h?g:0;m=p-g|0;t=m<<1;p=e;u=(y[f+746|0]&17)!=1;b:{c:{while(1){if((o|0)!=(r|0)){d:{if(d>>>0>o>>>0){g=(y[f+746|0]&17)==1;break d}x[x[a+4>>2]+16>>2]=o-d;v[f+851|0]=y[f+851|0]&254|(d|0)==(o|0);g=x[a>>2];i=x[a+4>>2];e=Wb(x[g+484344>>2],z[i+70>>1]);e=md(x[e>>2],x[x[e+48>>2]+12>>2],x[i+48>>2],b);h=y[e+3|0];e:{f:{switch(y[e+2|0]-11|0){case 0:i=k+8|0;wB(i,g,h,y[e+4|0],0);i=_e(i);Ou(x[a>>2],x[a+4>>2],b,z[k+8>>1]);g=1;if(!y[i|0]){break e}break d;case 1:qB(g,i,b,y[e+4|0]<<2&252,Ob(g+1074312|0,12));break e;case 2:break f;default:break e}}pB(g,i,b,y[e+4|0]<<2&252,Ob(g+1074312|0,12))}g=1;g:{h:{i:{j:{k:{switch(h-2|0){default:if(h-38>>>0<4){break h}if((h|0)==19){break j}if((h|0)!=28){break g}e=y[e+5|0];g=e&240;if((g|0)==32){break i}if((g|0)!=16){break g}oB(x[a>>2],f,e&15);break g;case 2:Ou(x[a>>2],x[a+4>>2],b,y[e+5|0]);break g;case 4:Ou(x[a>>2],x[a+4>>2],b,0);break g;case 0:e=y[e+5|0];h=x[a>>2];if(!e&(v[h+480180|0]&1)){break d}qB(h,x[a+4>>2],b,e,0);break g;case 1:break k;case 3:break d}}e=y[e+5|0];h=x[a>>2];if(!e&(v[h+480180|0]&1)){break d}pB(h,x[a+4>>2],b,e,0);break g}g=y[e+5|0];e=g&15;if(!(e|x[x[a>>2]+480180>>2]&1048580)){break g}g=g&240;if((g|0)!=32){if((g|0)!=16){break g}nB(x[a>>2],f,e);break g}mB(x[a>>2],f,e);break g}lB(x[a>>2],f,e&15);break g}_S(x[a>>2],f,y[e+5|0],(h|0)==38|(h|0)==40,(h&254)==40)}g=1}x[k+28>>2]=x[f+700>>2];if(s){Nu(x[a>>2],f)}if(!u){ZS(x[a>>2],f,k+28|0);g=1}if(!s){Nu(x[a>>2],f)}x[k+24>>2]=0;YS(f,k+24|0);l:{if(y[f+89|0]&2){break l}m:{if(!g){if(!y[Se(x[a+8>>2],b)+4|0]){break m}}if(y[f+851|0]&96){eV(f,E(1),0,x[a>>2]);j=y[f+851|0];v[f+851|0]=(j&64?-65:-97)&j}yB(k+8|0,x[a>>2],f,x[k+28>>2],0);e=x[k+12>>2];j=x[k+8>>2];x[f+8>>2]=j;x[f+12>>2]=e;A=Se(x[a+8>>2],b),B=0,v[A+4|0]=B;e=uf(j,e,c);g=y[f+88|0]&128;j=g?0-e|0:e;h=hb;l=g?0-(h+((e|0)!=0)|0)|0:h}Pb(f,j,l);h=x[f>>2];g=x[f+4>>2];e=g;if((h>>>0<w>>>0&(e|0)<=(p|0)|(e|0)<(p|0))&((e|0)>=(q|0)&h>>>0>=n>>>0|(e|0)>(q|0)|((l|0)>0|(l|0)>=0))){break l}e=x[f+88>>2];if(!(e&2)){break c}if(e&4){i=x[f+80>>2];if(h>>>0<n>>>0&(g|0)<=(q|0)|(g|0)<(q|0)){x[f+88>>2]=e^128;h=hh(0,i<<1,h,g);e=hb;g=e;x[f>>2]=h;x[f+4>>2]=e;e=j;j=0-e|0;l=0-(((e|0)!=0)+l|0)|0}e=(g-i>>>0)%(t-Ob(x[a>>2]+1074312|0,33)>>>0)|0;n:{if(e>>>0<m>>>0){g=e+x[f+80>>2]|0;break n}g=x[f+84>>2]+(m-e|0)|0}x[f+4>>2]=g;g=x[f+88>>2];if((g&128)>>>7^e>>>0<m>>>0){break l}x[f+88>>2]=g^128;e=j;j=0-e|0;l=0-(((e|0)!=0)+l|0)|0;break l}i=x[f+84>>2];if(i+m>>>0<=g>>>0){g=i+((g-i>>>0)%(m>>>0)|0)|0}while(1){e=g;g=e-m|0;if(e>>>0>=i>>>0){continue}break}x[f>>2]=h;x[f+4>>2]=e}o=o+1|0;continue}break}x[x[a+4>>2]+16>>2]=0;break b}x[x[a+4>>2]+16>>2]=0;gV(f);x[f+708>>2]=0}A=Se(x[a+8>>2],b),B=0,x[A>>2]=B}fb=k+32|0}function PP(a){var b=0,c=E(0),d=E(0),e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=E(0),o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=0,u=E(0);k=fb-16|0;fb=k;b=a+4208|0;e=Bk(E(B[yb(b,12)>>2]*E(3)));x[a+4264>>2]=e;d=E(x[x[a+16>>2]+24620>>2]>>>((e^-1)>>>1&1)>>>0);B[a+4268>>2]=d;t=a,u=E(E(B[yb(b,9)>>2]*E(100))*E(.0061803399585187435)),B[t+4272>>2]=u;t=k,u=Ee(E(10),E(E(OP(a)+E(E(B[yb(b,5)>>2]*E(11e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[k+8>>2]=1065353216;t=a,u=E(B[Rm(k+12|0,k+8|0)>>2]*E(.7609999775886536)),B[t+4280>>2]=u;c=Ee(E(10),E(E(E(E(B[yb(b,1)>>2]*E(1e4))+E(-1e4))/E(100))/E(10)));if(c!=E(1)){d=uq(E(E(NP(a)*E(6.2831854820251465))/d));g=E(c+c);f=E(c*c);c=CB(E(E(E(E(d*g)+E(-2))+E(M(E(E(E(E(d*E(E(d*f)*E(4)))+E(c*E(8)))-E(f*E(4)))-E(E(d*c)*E(8))))))/E(g+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=fb-16|0;fb=i;c=B[a+4268>>2];b=a+4208|0;d=E(B[yb(b,6)>>2]*E(.30000001192092896));t=i,u=E(B[yb(b,8)>>2]*E(.10000000149011612)),B[t+12>>2]=u;x[i+8>>2]=1000593162;g=B[Xz(i+12|0,i+8|0)>>2];f=E(c*E(E(d+g)+E(.007000000216066837)));a:{if(E(F(f))<E(2147483648)){b=~~f;break a}b=-2147483648}x[a+4352>>2]=b;m=a+4352|0;e=1;while(1){if((e|0)==12){t=i,u=E(E(E(E(B[yb(a+4208|0,10)>>2]*E(100))/E(100))+E(.10000000149011612))*E(.9090999960899353)),B[t+12>>2]=u;x[i+8>>2]=1065353216;m=a+4292|0;d=B[Rm(i+12|0,i+8|0)>>2];g=E(c*E(E(d*E(75))/E(1e3)));d=E(c*E(E(d*E(67))/E(1e3)));e=0;while(1){if((e|0)==6){d=E(c*E(.0035299998708069324));b:{if(E(F(d))<E(2147483648)){b=~~d;break b}b=-2147483648}x[a+4348>>2]=b;d=E(c*E(.0032500000670552254));c:{if(E(F(d))<E(2147483648)){b=~~d;break c}b=-2147483648}x[a+4344>>2]=b;c=E(c*E(.009999999776482582));d:{if(E(F(c))<E(2147483648)){b=~~c;break d}b=-2147483648}x[a+4340>>2]=b;b=a+4504|0}else{b=m+(e<<2)|0;o=e+o|0;f=Ee(E(.9300000071525574),E(o|0));h=E(g*f);e:{if(E(F(h))<E(2147483648)){j=~~h;break e}j=-2147483648}x[b+24>>2]=j;f=E(d*f);f:{if(E(F(f))<E(2147483648)){j=~~f;break f}j=-2147483648}x[b>>2]=j;e=e+1|0;continue}break}e=0;while(1){if((e|0)!=15){RP(b+D(e,24)|0,x[m+(e<<2)>>2]);e=e+1|0;continue}break}fb=i+16|0}else{j=(m+D(e&1,24)|0)+(e<<1&-4)|0;f=E(c*E(E(g*B[(e<<2)+45344>>2])+d));g:{if(E(F(f))<E(2147483648)){b=~~f;break g}b=-2147483648}x[j>>2]=b;e=e+1|0;continue}break}b=fb-16|0;fb=b;d=Ph(a,5);f=Ph(a,11);c=E(d*Ph(a,4));d=E(E(c*E(.03999999910593033))+E(E(d*E(.02250000089406967))+E(0)));g=E(f*Ph(a,10));f=E(E(g*E(.03999999910593033))+E(E(f*E(.02250000089406967))+E(0)));if(v[a+4264|0]&1){h=Ph(a,3);l=Ph(a,9);h=E(c*h);c=E(h*Ph(a,2));d=E(E(c*E(.1444000005722046))+E(E(h*E(.12250000238418579))+d));h=E(g*l);g=E(h*Ph(a,8));f=E(E(g*E(.1444000005722046))+E(E(h*E(.12250000238418579))+f))}Ph(a,12);h=B[a+4496>>2];l=Ph(a,1);n=Ph(a,7);q=Ph(a,0);r=Ph(a,6);t=b,u=Ee(E(10),E(E(OP(a)+E(E(B[yb(a+4208|0,7)>>2]*E(12e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[b+8>>2]=1065353216;p=B[Rm(b+12|0,b+8|0)>>2];s=c;c=E(h*h);h=E(l*E(s*c));l=E(q*h);c=E(n*E(g*c));g=E(r*c);n=E(E(E(l+g)*E(-.5))+E(1));B[a+4284>>2]=p*E(M(E(n/E(E(l*E(.1444000005722046))+E(E(c*E(.1444000005722046))+d)))));B[a+4288>>2]=p*E(M(E(n/E(E(g*E(.1444000005722046))+E(E(h*E(.1444000005722046))+f)))));fb=b+16|0;v[a+5046|0]=0;fb=k+16|0}function Qz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-240|0;fb=e;v[e+239|0]=c;g=x[b+4>>2];a:{if(!g){f=x[b>>2];break a}f=x[b>>2];h=y[zl(f,g)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Ml(e+80|0,f,g,g-1|0);g=x[e+84>>2];f=x[e+80>>2];x[b>>2]=f;x[b+4>>2]=g}h=e+80|0;ie(h);i=x[e+80>>2];j=e+216|0;ie(j);i=yl(i,x[e+220>>2],b);ie(h);b:{c:{d:{e:{f:{g:{h:{if(x[e+84>>2]==(i|0)){a=pc(e+228|0,22292);c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Ic(f,g,e)){g=dc(8);x[31609]=0;O(1004,j|0,e+239|0);a=x[31609];x[31609]=0;if((a|0)==1){break g}x[31609]=0;S(1011,h|0,18271,j|0);a=x[31609];x[31609]=0;if((a|0)==1){break f}sc(g,h);f=0;x[31609]=0;S(97,g|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(h);break e}if(!d){break h}g=dc(8);a=x[b>>2];b=x[b+4>>2];x[31609]=0;a=$h(e+192|0,a,b);b=x[31609];x[31609]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[31609]=0;b=e+204|0;S(1011,b|0,18307,a|0);c=x[31609];x[31609]=0;if((c|0)==1){break p}x[31609]=0;f=e+216|0;O(1013,f|0,b|0);b=x[31609];x[31609]=0;c=1;if((b|0)==1){break o}x[31609]=0;b=e+180|0;O(1004,b|0,e+239|0);c=x[31609];x[31609]=0;if((c|0)==1){break n}x[31609]=0;d=e+80|0;S(1015,d|0,f|0,b|0);b=x[31609];x[31609]=0;c=1;if((b|0)==1){break m}sc(g,d);x[31609]=0;S(97,g|0,48428,1e3);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=N()|0;tb(d);c=0;break l}b=N()|0;break d}b=N()|0;c=1;break i}b=N()|0;break j}b=N()|0;c=1;break k}b=N()|0}tb(e+180|0)}tb(e+216|0)}tb(e+204|0)}tb(a);if(c){break d}break c}b=pc(e+172|0,22292);d=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=d;if(Ic(f,g,e+72|0)){g=dc(8);x[31609]=0;b=e+216|0;O(1004,b|0,e+239|0);a=x[31609];x[31609]=0;q:{r:{if((a|0)!=1){x[31609]=0;a=e+80|0;S(1011,a|0,18271,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break r}sc(g,a);f=0;x[31609]=0;S(97,g|0,48428,1e3);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=N()|0;tb(a);break q}b=N()|0;break d}b=N()|0;f=1}tb(e+216|0);if(f){break d}break c}b=pc(e+164|0,7462);d=x[b+4>>2];x[e+64>>2]=x[b>>2];x[e+68>>2]=d;s:{if(!Ic(f,g,e- -64|0)){b=pc(e+156|0,7444);d=x[b+4>>2];x[e+56>>2]=x[b>>2];x[e+60>>2]=d;if(!Ic(f,g,e+56|0)){break s}}v[a+60|0]=c;break h}b=pc(e+148|0,6989);d=x[b+4>>2];x[e+48>>2]=x[b>>2];x[e+52>>2]=d;t:{if(!Ic(f,g,e+48|0)){b=pc(e+140|0,6970);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(!Ic(f,g,e+40|0)){break t}}v[a+61|0]=c;break h}b=pc(e+132|0,7073);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Ic(f,g,e+32|0)){v[a+62|0]=c;break h}b=pc(e+124|0,6064);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Ic(f,g,e+24|0)){v[a+63|0]=c;break h}b=pc(e+116|0,7511);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(Ic(f,g,e+16|0)){v[a+64|0]=c;break h}b=pc(e+108|0,13525);d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;if(!Ic(f,g,e+8|0)){break h}b=x[a+24>>2];d=b+24664|0;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;d=b+24656|0;f=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=f;d=x[b+24652>>2];x[e+80>>2]=x[b+24648>>2];x[e+84>>2]=d;if(c){a=SM(x[a+56>>2])}else{a=0}x[e+100>>2]=a;a=e+80|0;if(!zz(a,b+24648|0)){break h}LA(b,a)}fb=e+240|0;return}b=N()|0;break d}b=N()|0;f=1}tb(e+216|0);if(!f){break c}}lc(g)}Q(b|0)}p()}function tta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=fb-128|0;fb=f;yc(b);a:{d=f- -64|0;if(!yr(b,d)){break a}if(!c$(d)){break a}if(!Mb(x[b>>2],x[b+8>>2],b$(d))){break a}k=1;if((c|0)==64){break a}Dd(a,1);x[a+480208>>2]=x[a+480208>>2]|16777216;w[a+480188>>1]=y[f+109|0];w[a+480190>>1]=y[f+110|0];o=a,p=Bc((((y[f+113|0]<<8|48)&65328)>>>0)/100|0,0),x[o+480200>>2]=p;e=f+52|0;pi(e,3,f+69|0);d=f+16|0;Cc(d,e);zb(a+1298308|0,d);tb(d);pi(e,3,f+89|0);Er(d,4,e);zb(a+1298320|0,d);e=a+480280|0;tb(d);d=0;while(1)if(z[a+480188>>1]<=d>>>0){$j(Xb(x[a+484360>>2],y[a+484376|0]),b,y[f+111|0],65535,65535);w[f+50>>1]=0;d=Xb(x[a+484360>>2],y[a+484376|0]);o=f,p=wb(x[d>>2]),x[o+16>>2]=p;d=wb(x[d+4>>2]);while(1){g=x[f+16>>2];if(Ib(g,d)){w[f+52>>1]=z[g>>1];o=f,p=z[qe(f+52|0,f+50|0)>>1],w[o+50>>1]=p;ge(f+16|0);continue}else{d=z[f+50>>1]+1|0;w[f+50>>1]=d;k=Mb(x[b>>2],x[b+8>>2],D(D(z[a+480188>>1],d&65535),264)+(z[a+480190>>1]<<5)|0);if(!k){break a}d=0;while(1){g=z[a+480188>>1];if(g>>>0<=d>>>0){Vb(b,D(g,z[f+50>>1]-1|0)<<3);j=a+946304|0;l=a+484380|0;d=1;while(1){i=d&65535;if(i>>>0>z[a+480190>>1]){j=a+484344|0;Tf(j,z[f+50>>1]);m=c&1;g=0;while(1){b:{c:{if(z[f+50>>1]<=g>>>0){if(!(c&2)){break c}d=1;while(1){c=d&65535;if(c>>>0>A[a+480228>>2]){break c}c=D(c,104)+l|0;dg(Zc(f+16|0,w[c+34>>1]&1?16:8,1,0,0),c,b);d=d+1|0;continue}}d:{if(m){if(Pg(j,g&65535,64)){break d}}Vb(b,z[a+480188>>1]<<8);break b}d=Wb(x[j>>2],g);o=f,p=wb(x[d>>2]),x[o+16>>2]=p;n=wb(x[d+4>>2]);while(1){d=x[f+16>>2];if(!Ib(d,n)){break b}e=f+52|0;lm(e,b);e=y[xb(e,1)|0];if((e-1&255)>>>0<=167){v[d|0]=((e&254)>>>1|0)+36}h=f+52|0;o=d,p=y[xb(h,0)|0],v[o+1|0]=p;e=y[xb(h,3)|0];v[d+5|0]=e;e:{f:{i=xb(h,2);h=y[i|0];if((h|0)!=19){if((h|0)!=8){break f}g:{switch(e>>>4|0){case 0:v[d+3|0]=19;v[d+5|0]=e|128;break e;case 1:v[d+3|0]=11;v[d+5|0]=e<<4;break e;case 2:v[d+3|0]=19;v[d+5|0]=e|160;break e;case 3:case 4:break g;default:break e}}v[d+3|0]=19;v[d+5|0]=e-32;break e}v[d+3|0]=9;i=e<<1&254;h=i+128|0;h:{if(e>>>0<=64){break h}h=384-i|0;if(e<<24>>24>=0){break h}h=128-i|0;if(e>>>0<=191){break h}h=i-128|0}o=d,p=si(h),v[o+5|0]=p;break e}if((h&240)==32){v[d+3|0]=10;e=y[i|0];v[d+2|0]=1;v[d+4|0]=(e<<2&60)+4;break e}if((h-17&255)>>>0>1&h>>>0>=16){break e}Cf(d,h&15,e)}tg(f+16|0);continue}}b=f+16|0;c=uc(b,9526);zb(a+1298344|0,c);tb(c);c=uc(b,10157);zb(a+1298356|0,c);tb(c);o=a,p=x[Fc(b,4)>>2],x[o+1298404>>2]=p;break a}g=g+1|0;continue}}else{e=f+16|0;xr(b,e);h=fb-16|0;fb=h;v[h+15|0]=64;g=D(i,104)+l|0;o=g,p=y[Qb(e+26|0,h+15|0)|0]<<2,w[o+30>>1]=p;v[g+37|0]=y[e+25|0]<<4;x[g>>2]=y[e+23|0]|y[e+24|0]<<8;x[g+4>>2]=y[e+27|0]|y[e+28|0]<<8;x[g+8>>2]=(y[e+29|0]|y[e+30|0]<<8)+(y[e+27|0]|y[e+28|0]<<8);w[g+34>>1]=z[g+34>>1]&65532|((y[e+29|0]|y[e+30|0]<<8)>>>0>2)<<1|y[e+22|0]==16;fb=h+16|0;g=f+4|0;Rk(g,3,e);e=f+52|0;Cc(e,g);Ac(j+(i<<5)|0,e);d=d+1|0;tb(e);continue}}}else{g=f+4|0;a$(g,b);h=f+52|0;tF(h,g);g=f+16|0;Cc(g,h);gm((e+(d<<5)|0)+9|0,g);d=d+1|0;tb(g);continue}}}}}else{g=e+(d<<5)|0;Ve(g);o=g,p=D(Zd(b)&15,17),w[o+4>>1]=p;d=d+1|0;continue}}fb=f+128|0;return k|0}function oH(){var a=0,b=0,c=0,d=0;if(y[499800]){return x[124949]}b=xd(501432,1);x[b>>2]=95212;c=EJ(b+8|0);x[31609]=0;d=P(36,b+152|0,14337)|0;a=x[31609];x[31609]=0;a:{b:{c:{if((a|0)!=1){Nc(c);yJ(501104,1);x[31609]=0;W(1294,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xJ(501112,1);x[31609]=0;W(1295,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}wJ(501120,1);x[31609]=0;W(1296,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}vJ(501136,1);x[31609]=0;W(1297,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501144,1);x[125286]=97156;x[31609]=0;W(1298,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;X(1299);a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;W(1300,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501168,1);x[125292]=97304;x[31609]=0;W(1301,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501176,1);x[125294]=97536;x[31609]=0;W(1302,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501184,1);x[125296]=97420;x[31609]=0;W(1303,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501192,1);x[125298]=97652;x[31609]=0;W(1304,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}uJ(501200,1);x[31609]=0;W(1305,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}tJ(501224,1);x[31609]=0;W(1306,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501256,1);x[125314]=98372;x[31609]=0;W(1307,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501264,1);x[125316]=98616;x[31609]=0;W(1308,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501272,1);x[125318]=98828;x[31609]=0;W(1309,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501280,1);x[125320]=99060;x[31609]=0;W(1310,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}sJ(501288,1);x[31609]=0;W(1311,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}rJ(501296,1);x[31609]=0;W(1312,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}qJ(501304,1);x[31609]=0;W(1313,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}pJ(501312,1);x[31609]=0;W(1314,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501320,1);x[125330]=101752;x[31609]=0;W(1315,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501328,1);x[125332]=101916;x[31609]=0;W(1316,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501336,1);x[125334]=102080;x[31609]=0;W(1317,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}xd(501344,1);x[125336]=102244;x[31609]=0;W(1318,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}oJ(501352,1);x[31609]=0;W(1319,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}nJ(501368,1);x[31609]=0;W(1320,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;X(1321);a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;W(1322,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;X(1323);a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;W(1324,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}mJ(501416,1);x[31609]=0;W(1325,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}lJ(501424,1);x[31609]=0;W(1326,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}break a}b=N()|0;break b}b=N()|0;tb(d)}oy(c);Q(b|0);p()}x[124948]=501432;v[499800]=1;x[124949]=499792;return 499792}function lS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,z=0,A=0,B=0,D=0;if(b){j=a+327720|0;c=fb-352|0;fb=c;m=c+340|0;qU(m,8);x[31609]=0;n=c+328|0;la(795,n|0,9);k=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((k|0)!=1){x[31609]=0;k=P(796,c+312|0,14)|0;f=x[31609];x[31609]=0;if((f|0)==1){break l}x[31609]=0;O(797,m|0,k|0);f=x[31609];x[31609]=0;if((f|0)==1){break k}x[31609]=0;O(797,n|0,k|0);f=x[31609];x[31609]=0;if((f|0)==1){break k}g=c+240|0;pU(g,4900);l=c+168|0;pU(l,32e3);s=c+96|0;iU(s,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[31609]=0;i=P(798,c+72|0,m|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}f=c+84|0;av(f,g,i);Ce(i);x[31609]=0;g=P(798,c+48|0,n|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break i}i=c+60|0;av(i,l,g);Ce(g);x[31609]=0;g=P(798,c+24|0,f|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break h}l=c+36|0;av(l,s,g);Ce(g);x[31609]=0;g=P(798,c|0,i|0)|0;o=x[31609];x[31609]=0;if((o|0)==1){break g}o=c+12|0;av(o,s,g);Ce(g);Oq(f);Oq(l);Oq(i);Oq(o);Oq(n);Nq(x[c+84>>2],x[c+88>>2],No(j,0));Nq(x[c+36>>2],x[c+40>>2],No(j,1));Nq(x[c+60>>2],x[c+64>>2],No(j,2));Nq(x[c+12>>2],x[c+16>>2],No(j,3));Nq(x[c+328>>2],x[c+332>>2],No(j,4));Ce(o);Ce(l);Ce(i);Ce(f);kn(k);Ce(n);Ce(m);fb=c+352|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;Ce(c+36|0)}Ce(c+60|0)}Ce(c+84|0)}kn(k)}Ce(c+328|0)}Ce(c+340|0);Q(a|0);p()}BA(a+131112|0,9.6377,.97);BA(a+196648|0,8.5,.5);BA(a+262184|0,7,.425)}c=a+368680|0;if(!(A=0,B=vR(c,a),D=b,D?A:B)){k=a+24|0;v=C[a+8>>3];m=y[a+16|0];j=fb+-64|0;fb=j;m:while(1){if((r|0)!=8193){z=+(r-4096|0)*.0001220703125;b=0;t=0;while(1)if((b|0)==8){d=1/t;f=r<<3;b=0;while(1)if((b|0)==8){r=r+1|0;continue m}else{i=k+((b|f)<<1)|0;h=J(C[j+(b<<3)>>3]*32768*d+.5);h=h<-32768?-32768:h>32768?32768:h;n:{if(F(h)<2147483648){g=~~h;break n}g=-2147483648}w[i>>1]=g;b=b+1|0;continue}}else{h=v;e=1;d=+(b|0)-z;u=d+-3.5;if(!(F(u)<1e-8)){o:{p:{switch(m|0){case 0:e=hf(d*.8975979010256552)*-.5+.5;break o;case 1:e=hf(d*.8975979010256552)*-.46+.54;break o;case 2:e=hf(d*1.7951958020513104)*.08+(hf(d*.8975979010256552)*-.5+.42);break o;case 3:e=hf(d*1.7951958020513104)*.05677+(hf(d*.8975979010256552)*-.49364+.44959);break o;case 4:e=hf(d*1.7951958020513104)*.07922+(hf(d*.8975979010256552)*-.49755+.42323);break o;case 5:e=hf(d*1.7951958020513104);q=hf(d*.8975979010256552);e=hf(d*2.6927937030769655)*-.01168+(e*.14128+(q*-.48829+.35875));break o;case 6:e=hf(d*1.7951958020513104);q=hf(d*.8975979010256552);e=hf(d*2.6927937030769655)*-.00183+(e*.09392+(q*-.49703+.40217));break o;case 7:break p;default:break o}}e=hf(d*1.7951958020513104);q=hf(d*.8975979010256552);e=hf(d*2.6927937030769655)*-.00122+(e*.09831+(q*-.49804+.40243))}d=u*3.141592653589793;h=Pi(d*h)/d}h=e*h;C[j+(b<<3)>>3]=h;t=t+h;b=b+1|0;continue}}break}fb=j- -64|0;b=x[a+20>>2];x[c+16>>2]=x[a+16>>2];x[c+20>>2]=b;b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b}}function $A(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=fb-16|0;fb=g;e=D(b,872)+a|0;i=y[e+1075800|0];k=a+1074312|0;Jb(g+8|0,k,23);h=c&15;e=e+1074992|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(Gb(x[x[g+8>>2]>>2],x[g+12>>2])){if(!(x[a+1074392>>2]|!y[e+788|0])){v[e+808|0]=h;break i}f=y[e+808|0];if(f){j=f-1|0;v[e+808|0]=j;f=0;if(j&255){break c}}v[e+808|0]=h;f=1;break c}Jb(g+8|0,k,52);j=c&256;if(!(!j|!Gb(x[x[g+8>>2]>>2],x[g+12>>2]))){j=x[a+480208>>2]&4096;if(!j){break e}if(y[e+789|0]){i=KZ(y[e+788|0])?1:i}if(y[e+792|0]?y[e+790|0]==1:0){break b}if(h>>>0>i>>>0){break c}if(!j){break d}if(Tc(y[e+788|0])){break c}break d}l=x[a+480180>>2];if(l&16777250){if(i){f=(i>>>0)%((h>>>0<=1?1:h)>>>0)|0}else{f=1}f=!f;i=i+1|0;break c}if((l|0)==16){break g}if((l|0)!=1){break f}f=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!f){if(Tc(y[e+788|0])){break a}}if(h){break h}}f=0;break c}f=!((f>>>0)%(h>>>0)|0);break c}f=x[a+1074392>>2]==(h|0)&(h|0)!=0;break c}h=!j|y[e+790|0]!=1?h:(y[e+793|0]>15)+h|0;j:{if(x[a+480208>>2]&4096?j:1){h=h>>>0<=1?1:h;if(!(!x[a+1074416>>2]|j)){f=!(A[a+1074392>>2]%(h>>>0)|0)}i=i+1|0;break j}i=l&1048580?0:i}if(!(!(y[e+788|0]|!j?x[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){f=1}Jb(g+8|0,k,52);if(!Gb(x[x[g+8>>2]>>2],x[g+12>>2])|c){break c}f=!x[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;f=1}k:{if(x[e+76>>2]){break k}Jb(g+8|0,k,38);if(!Gb(x[x[g+8>>2]>>2],x[g+12>>2])){break k}if(!Bj(x[e+656>>2])){break a}}Jb(g+8|0,k,106);if(p=0,q=Gb(x[x[g+8>>2]>>2],x[g+12>>2]),r=x[e+696>>2],r?p:q){break a}if(f){h=x[e+688>>2];x[g+4>>2]=h;f=c>>>4&15;l:{if(!f){f=x[e+88>>2];break l}Jb(g+8|0,k,52);m:{if(p=Gb(x[x[g+8>>2]>>2],x[g+12>>2]),q=0,r=y[e+790|0]==1,r?p:q){break m}if(!(16191>>>f&1)){x[g+4>>2]=(D(h,v[f+32064|0])|0)/16;break m}x[g+4>>2]=h+(v[f+32080|0]<<2)}Ge(g+4|0,0,256);f=x[e+88>>2]|2097152;x[e+88>>2]=f}n=x[e+700>>2];h=y[e+802|0];j=0;if(f&512){Jb(g+8|0,k,108);j=Gb(x[x[g+8>>2]>>2],x[g+12>>2])}if(!((j^-1)&x[a+480180>>2]==2|(!x[e+76>>2]|(h-1&255)>>>0>119))){FS(a,b,0,h,1)}n:{if(!(x[a+480180>>2]&1048580)){l=0;break n}l=(c|0)<256;if((c|0)>255){break n}f=y[e+789|0];if(!f){break n}l=1;Lo(a,e,f,0,0,1)}Jb(g+8|0,k,85);o:{if(!Gb(x[x[g+8>>2]>>2],x[g+12>>2])){break o}f=y[e+789|0];if(!f){break o}m=z[e+772>>1];Lo(a,e,f,0,0,1);w[e+772>>1]=m}m=x[e+660>>2];x[e+660>>2]=0;o=x[e+88>>2];Jb(g+8|0,k,23);f=1;p:{if(Gb(x[x[g+8>>2]>>2],x[g+12>>2])){break p}f=0;if(x[a+480180>>2]!=2){break p}f=(j^1)&x[e+76>>2]!=0}Su(a,e,h,f,l,0,b);if(!y[e+789|0]){x[e+660>>2]=m}if(!(!(o&4096)|x[a+480180>>2]!=4)){x[e+88>>2]=x[e+88>>2]|4096}x[e+688>>2]=x[g+4>>2];if(z[a+480192>>1]){v[e+788|0]=h;DS(a,b)}b=x[a+480180>>2];if(!(!(b&16777248)|(y[e+788|0]|!n))){x[e+700>>2]=n}if(f){x[e>>2]=0;x[e+4>>2]=0}b=b&16777250;q:{if(d-11>>>0<4294967286){break q}f=x[e+104>>2];if(!f){break q}r:{if((d|0)==1){h=x[e+664>>2];break r}h=x[yb(f+68|0,d-2|0)>>2];x[e+664>>2]=h}Ko(a,e,h)}i=b?i:0}a=g+8|0;Jb(a,k,52);b=x[x[g+8>>2]>>2];d=x[g+12>>2];Jb(a,k,23);if(Gb(x[x[g+8>>2]>>2],x[g+12>>2])){break a}i=(Gb(b,d)&c>>>8)+i|0}v[e+808|0]=i}fb=g+16|0}function rra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-192|0;fb=g;l=g+80|0;ae(l,b);i=x[g+88>>2];m=x[g+92>>2];e=fb-32|0;fb=e;x[e+28>>2]=0;Gk(b,e+28|0);a:{b:{c:{if(x[e+28>>2]!=(Dn(14184)|0)){break c}x[e+24>>2]=0;h=fb-32|0;fb=h;x[h+28>>2]=0;cy(h+8|0,h+28|0);j=h+20|0;Nm(j,b,x[h+8>>2],x[h+12>>2]);Lm(j,x[h+28>>2]);x[e+24>>2]=x[h+20>>2];fb=h+32|0;h=-1;f=x[e+24>>2];if(f-3>>>0<4294967294){break c}d:{e:{f:{if(f>>>0<=1){f=Fb(e+12|0);x[31609]=0;j=U(495,b|0,f|0,256)|0;k=x[31609];x[31609]=0;if((k|0)==1){break b}if(!j){break e}x[31609]=0;S(496,e|0,d|0,f|0);j=x[31609];x[31609]=0;if((j|0)!=1){break f}break b}f=Fb(e+12|0);x[31609]=0;j=P(498,b|0,f|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break b}if(!j){break d}x[31609]=0;S(496,e|0,d|0,f|0);j=x[31609];x[31609]=0;if((j|0)==1){break b}}zb(c,e);tb(e);tb(f);ng(b,e);f=0;x[e+12>>2]=0;Gk(b,e+12|0);j=x[e+12>>2];if(j>>>0>50){break c}g:{while(1){if((f|0)==(j|0)){break g}f=f+1|0;if(LQ(a,b,d)){continue}break}break c}x[e+12>>2]=0;Gk(b,e+12|0);h=x[e+12>>2]==(Dn(14222)|0)?1:-1;break c}tb(f);break c}tb(f)}fb=e+32|0;break a}a=N()|0;tb(f);Q(a|0);p()}h:{if(h){break h}ig(x[x[b>>2]-12>>2]+b|0,0);b=Km(l,Ci(b,i,m,0));x[31609]=0;h=P(461,g+68|0,14333)|0;i=x[31609];x[31609]=0;i:{if((i|0)!=1){x[31609]=0;x[g+48>>2]=3;x[g+52>>2]=0;i=g+48|0;S(462,b|0,h|0,i|0);e=x[31609];x[31609]=0;if((e|0)!=1){Eb(h);v[g+67|0]=0;x[31609]=0;h=P(461,i|0,14778)|0;i=x[31609];x[31609]=0;if((i|0)!=1){x[31609]=0;S(463,b|0,g+67|0,h|0);i=x[31609];x[31609]=0;if((i|0)!=1){Eb(h);h=Fc(g+44|0,y[g+67|0]?0:d);x[31609]=0;d=R(476,b|0)|0;i=x[31609];x[31609]=0;if((i|0)!=1){x[31609]=0;i=R(477,b|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){x[g+40>>2]=d;j:{k:{l:{m:{while(1){if(!Ib(d,i)){a=ql(y[b|0]);Ch(b);h=a?-1:1;break h}x[31609]=0;d=P(461,g+24|0,15869)|0;e=x[31609];x[31609]=0;if((e|0)==1){break l}e=x[b+44>>2];f=x[b+40>>2];x[31609]=0;e=ba(478,f|0,e|0,x[g+40>>2],d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break k}Eb(d);n:{o:{if(e){d=x[h>>2];x[31609]=0;V(479,b|0,g+40|0,c|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){break o}break j}x[31609]=0;d=P(461,g+12|0,15566)|0;e=x[31609];x[31609]=0;p:{q:{if((e|0)!=1){e=x[b+44>>2];f=x[b+40>>2];x[31609]=0;e=ba(478,f|0,e|0,x[g+40>>2],d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break q}Eb(d);if(!e){break p}x[31609]=0;S(480,b|0,g+40|0,g+38|0);d=x[31609];x[31609]=0;if((d|0)==1){break j}break o}a=N()|0;break i}a=N()|0;Eb(d);break i}x[31609]=0;d=P(461,g|0,15467)|0;e=x[31609];x[31609]=0;if((e|0)==1){break n}e=x[b+44>>2];f=x[b+40>>2];x[31609]=0;e=ba(478,f|0,e|0,x[g+40>>2],d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break m}Eb(d);if(!e){break o}d=x[h>>2];x[31609]=0;V(481,b|0,g+40|0,a|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break j}}fA(g+40|0);d=x[g+40>>2];continue}break}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0}Ch(b);Q(a|0);p()}fb=g+192|0;return h|0}function Ug(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=fb-112|0;fb=k;j=i&2147483647;a:{b:{m=e&2147483647;l=2147418112;n=!(b|c);if(!(d|m?m-l>>>0<2147549184:n)){r=j-l|0;if(!h&(r|0)==-2147418112?f|g:(r|0)==-2147418112&(h|0)!=0|r>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?n:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(j|0)==2147418112?!(f|g):j>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}l=f|h;if(!(l|(j^2147418112|g))){break a}if(!(b|d|(c|m))){if(g|j|l){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|j)){break b}f=b;g=c;h=d;i=e;break a}l=(j|0)==(m|0);p=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|j>>>0>m>>>0;n=p;m=n?f:b;r=n?g:c;l=n?i:e;s=l;n=n?h:d;q=l&65535;j=p?d:h;l=p?e:i;d=l;l=d>>>16&32767;o=s>>>16&32767;if(!o){o=!(n|q);h=o;o=h<<6;t=G(h?m:n)+32|0;h=G(h?r:q);o=o+((h|0)==32?t:h)|0;$f(k+96|0,m,r,n,q,o-15|0);n=x[k+104>>2];q=x[k+108>>2];r=x[k+100>>2];o=16-o|0;m=x[k+96>>2]}f=p?b:f;g=p?c:g;b=j;c=d&65535;if(!l){j=!(b|c);p=j;d=j?f:b;j=j<<6;p=G(p?g:c);j=j+((p|0)==32?G(d)+32|0:p)|0;$f(k+80|0,f,g,b,c,j-15|0);l=16-j|0;f=x[k+80>>2];g=x[k+84>>2];b=x[k+88>>2];c=x[k+92>>2]}d=c<<3;c=b;b=d|b>>>29;j=c<<3;c=b;b=g>>>29|j;c=c|524288;j=q<<3|n>>>29;q=n<<3|r>>>29;p=j;h=e^i;j=g<<3|f>>>29;d=f<<3;c:{if((l|0)==(o|0)){break c}e=o-l|0;if(e>>>0>127){b=0;c=0;j=0;d=1;break c}$f(k- -64|0,d,j,b,c,128-e|0);cn(k+48|0,d,j,b,c,e);b=x[k+56>>2];c=x[k+60>>2];j=x[k+52>>2];d=x[k+48>>2]|(x[k+64>>2]|x[k+72>>2]|(x[k+68>>2]|x[k+76>>2]))!=0}n=d;l=j;p=p|524288;j=r<<3|m>>>29;m=m<<3;d:{if((h|0)<0){f=0;g=0;h=0;i=0;if(!(m^n|b^q|(j^l|c^p))){break a}d=m-n|0;e=j-((m>>>0<n>>>0)+l|0)|0;f=q-b|0;g=(j|0)==(l|0)&m>>>0<n>>>0|j>>>0<l>>>0;h=f-g|0;b=(p-((b>>>0>q>>>0)+c|0)|0)-(f>>>0<g>>>0)|0;i=b;if(b>>>0>524287){break d}c=!(b|h);g=c;i=c?d:h;c=c<<6;g=G(g?e:b);c=c+((g|0)==32?G(i)+32|0:g)|0;f=b;b=c-12|0;$f(k+32|0,d,e,h,f,b);o=o-b|0;h=x[k+40>>2];i=x[k+44>>2];d=x[k+32>>2];e=x[k+36>>2];break d}j=j+l|0;d=m+n|0;e=d>>>0<m>>>0?j+1|0:j;f=(l|0)==(e|0)&d>>>0<n>>>0|e>>>0<l>>>0;j=c+p|0;b=b+q|0;j=b>>>0<q>>>0?j+1|0:j;h=b+f|0;i=h>>>0<b>>>0?j+1|0:j;if(!(i&1048576)){break d}d=n&1|((e&1)<<31|d>>>1);e=h<<31|e>>>1;o=o+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}f=0;b=s&-2147483648;m=b;if((o|0)>=32767){h=f;i=b|2147418112;g=0;break a}l=0;e:{if((o|0)>0){l=o;break e}$f(k+16|0,d,e,h,i,o+127|0);cn(k,d,e,h,i,1-o|0);d=x[k>>2]|(x[k+16>>2]|x[k+24>>2]|(x[k+20>>2]|x[k+28>>2]))!=0;e=x[k+4>>2];h=x[k+8>>2];i=x[k+12>>2]}c=(e&7)<<29|d>>>3;b=h<<29|e>>>3;e=f|((i&7)<<29|h>>>3);f=m|(i>>>3&65535|l<<16);f:{g:{d=d&7;if((d|0)!=4){i=f;f=d>>>0>4;g=f;f=c+f|0;g=g>>>0>f>>>0?b+1|0:b;b=(g|0)==(b|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+e|0;i=b>>>0>h>>>0?i+1|0:i;break g}j=f;d=c&1;f=c+d|0;g=d>>>0>f>>>0?b+1|0:b;b=(g|0)==(b|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+e|0;i=b>>>0>h>>>0?j+1|0:j;break f}if(!d){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;fb=k+112|0}function Pz(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-160|0;fb=e;C[e+152>>3]=c;f=x[b+4>>2];a:{if(!f){g=x[b>>2];break a}g=x[b>>2];h=y[zl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Ml(e+128|0,g,f,f-1|0);f=x[e+132>>2];g=x[e+128>>2];x[b>>2]=g;x[b+4>>2]=f}j=e+128|0;ie(j);h=x[e+128>>2];i=e+116|0;ie(i);h=yl(h,x[e+120>>2],b);ie(j);b:{c:{d:{e:{if(x[e+132>>2]==(h|0)){h=pc(e+144|0,22292);a=x[h+4>>2];x[e+8>>2]=x[h>>2];x[e+12>>2]=a;if(Ic(g,f,e+8|0)){b=dc(8);x[31609]=0;O(1008,i|0,e+152|0);a=x[31609];x[31609]=0;f:{g:{h:{if((a|0)!=1){x[31609]=0;S(1011,j|0,18271,i|0);a=x[31609];x[31609]=0;if((a|0)==1){break h}sc(b,j);g=0;x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}f=N()|0;tb(j);break g}f=N()|0;break f}f=N()|0;g=1}tb(e+116|0);if(!g){break c}}lc(b);break c}if(!d){break e}i=dc(8);d=x[b>>2];a=x[b+4>>2];x[31609]=0;h=$h(e+92|0,d,a);a=x[31609];x[31609]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31609]=0;b=e+104|0;S(1011,b|0,18307,h|0);a=x[31609];x[31609]=0;if((a|0)==1){break q}x[31609]=0;d=e+116|0;O(1013,d|0,b|0);b=x[31609];x[31609]=0;a=1;if((b|0)==1){break p}x[31609]=0;b=e+80|0;O(1008,b|0,e+152|0);a=x[31609];x[31609]=0;if((a|0)==1){break o}x[31609]=0;g=e+128|0;S(1015,g|0,d|0,b|0);b=x[31609];x[31609]=0;a=1;if((b|0)==1){break n}sc(i,g);x[31609]=0;S(97,i|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}f=N()|0;tb(g);a=0;break m}f=N()|0;break i}f=N()|0;a=1;break j}f=N()|0;break k}f=N()|0;a=1;break l}f=N()|0}tb(e+80|0)}tb(e+116|0)}tb(e+104|0)}tb(h);if(!a){break c}}lc(i);break c}d=pc(e+72|0,22292);b=x[d+4>>2];x[e+40>>2]=x[d>>2];x[e+44>>2]=b;if(Ic(g,f,e+40|0)){h=dc(8);x[31609]=0;b=e+116|0;O(1008,b|0,e+152|0);a=x[31609];x[31609]=0;r:{s:{t:{if((a|0)!=1){x[31609]=0;d=e+128|0;S(1011,d|0,18271,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break t}sc(h,d);g=0;x[31609]=0;S(97,h|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}f=N()|0;tb(d);break s}f=N()|0;break r}f=N()|0;g=1}tb(e+116|0);if(!g){break c}}lc(h);break c}d=pc(e- -64|0,7759);b=x[d+4>>2];x[e+32>>2]=x[d>>2];x[e+36>>2]=b;if(Ic(g,f,e+32|0)){if(!Id(y[a+28|0])){break e}if(c<=0|c>4){d=dc(8);x[31609]=0;b=P(36,e+128|0,7854)|0;a=x[31609];x[31609]=0;if((a|0)==1){break d}sc(d,b);x[31609]=0;S(97,d|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}a=x[a+24>>2];k=a,l=Te(65536/c),x[k+480244>>2]=l;Cq(a);break e}d=pc(e+56|0,7811);b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;if(Ic(g,f,e+24|0)){if(!Id(y[a+28|0])){break e}if(c<=0|c>4){d=dc(8);x[31609]=0;b=P(36,e+128|0,7875)|0;a=x[31609];x[31609]=0;if((a|0)!=1){sc(d,b);x[31609]=0;S(97,d|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}f=N()|0;lc(d);break c}a=x[a+24>>2];k=a,l=Te(c*65536),x[k+480240>>2]=l;Cq(a);break e}d=pc(e+48|0,7829);b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;if(!Ic(g,f,e+16|0)){break e}k=x[a+24>>2],l=Si(c*65536),x[k+480236>>2]=l}fb=e+160|0;return}f=N()|0;lc(d)}Q(f|0)}p()}function Era(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-368|0;fb=e;g=fb-32|0;fb=g;d=g+12|0;wD(d,b);Mn(g+4|0,d);x[31609]=0;f=e+216|0;S(475,f|0,x[g+4>>2],x[g+8>>2]);b=x[31609];x[31609]=0;a:{if((b|0)!=1){Kc(d);fb=g+32|0;break a}a=N()|0;Kc(g+12|0);Q(a|0);p()}x[31609]=0;b=e+104|0;S(457,b|0,x[e+216>>2],x[e+220>>2]);g=x[31609];x[31609]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((g|0)!=1){x[31609]=0;g=P(103,e+228|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break z}tb(b);fc(f);if(c>>>0<2189){break g}b=Km(b,g);x[31609]=0;c=P(461,f|0,10140)|0;d=x[31609];x[31609]=0;if((d|0)==1){break x}x[31609]=0;x[e+88>>2]=20054022;x[e+92>>2]=0;d=e+88|0;S(462,b|0,c|0,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break w}Eb(c);v[e+103|0]=0;x[31609]=0;c=P(461,d|0,11063)|0;d=x[31609];x[31609]=0;if((d|0)==1){break v}x[31609]=0;S(463,b|0,e+103|0,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break u}Eb(c);d=Fc(e+84|0,y[e+103|0]?0:x[a+1298404>>2]);f=x[a+4>>2];x[31609]=0;c=P(461,e+72|0,15869)|0;h=x[31609];x[31609]=0;if((h|0)==1){break i}h=x[d>>2];x[31609]=0;V(464,b|0,f|0,c|0,h|0);f=x[31609];x[31609]=0;if((f|0)==1){break t}Eb(c);x[31609]=0;c=P(461,e+60|0,15566)|0;f=x[31609];x[31609]=0;if((f|0)==1){break s}d=x[d>>2];x[31609]=0;V(465,b|0,a|0,c|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break r}Eb(c);x[31609]=0;c=P(461,e+48|0,15467)|0;d=x[31609];x[31609]=0;if((d|0)==1){break q}x[31609]=0;d=a+484360|0;S(466,b|0,d|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break p}Eb(c);x[31609]=0;c=P(461,e+36|0,25046)|0;f=x[31609];x[31609]=0;if((f|0)==1){break o}x[31609]=0;S(467,b|0,a+484344|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break n}Eb(c);f=x[a+1298404>>2];x[31609]=0;c=P(461,e+24|0,25052)|0;h=x[31609];x[31609]=0;if((h|0)==1){break m}x[31609]=0;V(468,b|0,d|0,c|0,f|0);d=x[31609];x[31609]=0;if((d|0)==1){break l}Eb(c);if(ql(y[b|0])){x[31609]=0;c=P(1,e+12|0,16343)|0;d=x[31609];x[31609]=0;if((d|0)==1){break k}a=x[a+1298472>>2];x[31609]=0;S(385,a|0,1,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break j}tb(c)}Ch(b);break f}a=N()|0;break y}a=N()|0;tb(e+104|0)}fc(e+216|0);break b}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;tb(c);break h}a=N()|0}Ch(b);break c}b=Fb(e+104|0);d=x[a+1298404>>2];f=x[a+4>>2];x[31609]=0;d=ba(469,f|0,g|0,b|0,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}A:{if((d|0)!=1){x[31609]=0;c=P(1,e+216|0,16649)|0;d=x[31609];x[31609]=0;B:{if((d|0)!=1){a=x[a+1298472>>2];x[31609]=0;S(385,a|0,1,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break B}tb(c);break A}a=N()|0;break d}a=N()|0;tb(c);break d}d=x[a+1298404>>2];x[31609]=0;V(470,g|0,a|0,d|0,(c|0)!=2188|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}}tb(b)}Gf(g);fb=e+368|0;return}a=N()|0}tb(b)}Gf(g)}Q(a|0);p()}function Lta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;e=fb-720|0;fb=e;yc(b);f=fb-16|0;fb=f;h=e+110|0;K$(f+8|0,h);g=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(g|0)){Vb(b,x[f+12>>2])}fb=f+16|0;f=(g|0)==(i|0);if(!f){J$(h)}a:{b:{c:{d:{if(!f){break d}if(!L$(h)){break d}d=1;if((c|0)==64){break d}Dd(a,67108864);eg(a);d=y[e+135|0];w[a+480190>>1]=31;w[a+480188>>1]=d;x[a+480228>>2]=256/(d>>>0);d=uc(e,8179);zb(a+1298344|0,d);tb(d);d=uc(e,10820);zb(a+1298356|0,d);tb(d);f=e+84|0;gg(f,4174);h=y[e+134|0];x[e+64>>2]=h>>>4;d=0;x[31609]=0;x[e+104>>2]=h&15;V(307,e|0,f|0,e- -64|0,e+104|0);h=x[31609];x[31609]=0;if((h|0)==1){break c}zb(a+1298368|0,e);tb(e);Eb(f);r=a,s=x[Fc(e,28)>>2],x[r+1298404>>2]=s;ow(Xb(x[a+484360>>2],y[a+484376|0]),e+158|0,y[e+157|0]+1|0);n=a+484380|0;m=e+689|0;k=e+658|0;j=e+534|0;l=e+410|0;o=e+286|0;while(1){e:{if((d|0)==31){yE(b,a+1298308|0,32);f=a+946304|0;d=1;break e}f=d+1|0;h=D(f,104)+n|0;nd(h,1);i=d<<2;g=i+o|0;r=h,s=$b(y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)),x[r>>2]=s;g=i+l|0;g=$b(y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24));x[h+4>>2]=g;q=g;g=j+i|0;g=$b(y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24));x[h+8>>2]=q+g;if(g){w[h+34>>1]=z[h+34>>1]|2}Uk(h);v[e|0]=y[d+k|0];v[e+84|0]=64;r=h,s=y[Qb(e,e+84|0)|0]<<2,w[r+30>>1]=s;v[h+37|0]=y[d+m|0]<<4;d=f;continue}break}while(1){if((d|0)!=32){I$(b,f+(d<<5)|0,30);d=d+1|0;continue}break}m=c&1;if(m){Tf(a+484344|0,y[e+156|0]+1|0)}i=a+484344|0;h=0;f:{while(1){if(y[e+156|0]<h>>>0){d=1;if(!(c&2)){break d}a=Zc(e,8,1,1,0);break f}g=Yh(e+84|0);g:{h:{if(y[e+136|0]){x[31609]=0;f=R(273,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break g}x[31609]=0;d=e- -64|0;S(185,d|0,b|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break g}break h}f=z[a+480188>>1];x[31609]=0;d=e- -64|0;S(185,d|0,b|0,f<<8);f=x[31609];x[31609]=0;if((f|0)==1){break b}}f=hc(e,d);kd(g,f);ub(f);ub(d);i:{if(!m){break i}x[31609]=0;d=U(196,i|0,h&65535,64)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}if(!d){break i}f=0;if(y[e+136|0]){x[31609]=0;O(308,g|0,e|0);d=x[31609];x[31609]=0;if((d|0)==1){break b}j:while(1){if((f|0)==64){break i}d=Wb(x[i>>2],h);af(e- -64|0,x[d>>2],x[x[d+48>>2]+12>>2],f);r=e,s=wb(x[e+64>>2]),x[r+104>>2]=s;k=e+f|0;d=128;j=nw(x[e+64>>2],x[e+68>>2]);while(1){l=x[e+104>>2];if(!Ib(l,j)){f=f+1|0;continue j}k:{if(!(y[k|0]&d)){break k}x[31609]=0;O(309,g|0,l|0);l=x[31609];x[31609]=0;if((l|0)!=1){break k}break b}d=d>>>1|0;tg(e+104|0);continue}}}l:while(1){d=0;k=f&65535;if(k>>>0>=z[a+480188>>1]){break i}while(1){if((d|0)==64){f=f+1|0;continue l}j=Wb(x[i>>2],h);j=md(x[j>>2],x[x[j+48>>2]+12>>2],d,k);x[31609]=0;O(309,g|0,j|0);j=x[31609];x[31609]=0;if((j|0)!=1){d=d+1|0;continue}break}break}break b}ub(g);h=h+1|0;continue}break}break b}while(1){if((d|0)!=32){dg(a,D(d,104)+n|0,b);d=d+1|0;continue}break}d=1}fb=e+720|0;return d|0}d=N()|0;Eb(e+84|0);break a}d=N()|0;ub(g)}Q(d|0);p()}function ZL(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-48|0;fb=g;a:{b:{if(Vt(c)){h=x[b+484344>>2];if(Je(h,x[b+484348>>2],c&65535)){break b}}c=a;a=Fb(g+36|0);b=Fb(g+24|0);tj(c,a,b);tb(b);tb(a);break a}c=Wb(h,c);if(!(x[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);tj(c,a,b);tb(b);tb(a);break a}if(!(z[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);tj(c,a,b);tb(b);tb(a);break a}if(f>>>0>=6){c=a;a=Fb(g+36|0);b=Fb(g+24|0);tj(c,a,b);tb(b);tb(a);break a}c=md(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);c:{d:{switch(f-1|0){default:e:{f:{g:{h:{i:{d=y[c|0];if(!Tc(d)){if(!Fl(d)){break i}}e=g+24|0;OR(e,b,d,y[c+1|0]);x[31609]=0;O(1059,g+36|0,e|0);b=x[31609];x[31609]=0;d=1;if((b|0)!=1){break h}c=N()|0;break e}d=0;x[31609]=0;P(36,g+36|0,16800)|0;b=x[31609];x[31609]=0;if((b|0)==1){break g}}b=9984;c=y[c|0];if(!Tc(c)){b=Fl(c)?10294:16800}x[31609]=0;b=P(36,g+12|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break f}c=a;a=g+36|0;tj(c,a,b);tb(b);tb(a);if(!d){break a}tb(g+24|0);break a}c=N()|0;break c}c=N()|0;tb(g+36|0);if(!d){break c}}tb(g+24|0);break c;case 0:b=c+1|0;j:{if(y[c+1|0]){Hv(g+36|0,b);break j}Dc(g+36|0,16805)}b=y[b|0];x[31609]=0;b=P(36,g+24|0,(b?10817:16805)|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){c=a;a=g+36|0;tj(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break c;case 1:k:{if(Wg(y[c|0])){Dc(g+36|0,18454);break k}d=y[c+2|0];if(d){rf(g+36|0,1,lR(x[x[b+8>>2]+88>>2],d));break k}Dc(g+36|0,18454)}b=18454;if(!Wg(y[c|0])){b=y[c+2|0]?5505:18454}x[31609]=0;b=P(36,g+24|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){c=a;a=g+36|0;tj(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break c;case 3:b=y[c+2|0];l:{if(Wg(y[c|0])){i=g,j=Cj(b,y[c+4|0])&255,x[i+12>>2]=j;dD(g+36|0,g+12|0);break l}if(b){Hv(g+36|0,c+4|0);break l}Dc(g+36|0,16805)}b=5489;if(!Wg(y[c|0])){b=y[c+2|0]?5489:16805}x[31609]=0;b=P(36,g+24|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){c=a;a=g+36|0;tj(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break c;case 2:d=y[c+3|0];m:{if(Wg(y[c|0])){i=g,j=(Cj(d,y[c+5|0])&3840)!=0,v[i+12|0]=j;b=fb-32|0;fb=b;x[b+12>>2]=-1;x[b+16>>2]=0;x[b+4>>2]=0;Fb(b+20|0);x[31609]=0;x[b+4>>2]=x[b+4>>2]&-1332|1058;x[b+8>>2]=1;d=b+4|0;S(1209,g+36|0,g+12|0,d|0);e=x[31609];x[31609]=0;n:{if((e|0)!=1){Jh(d);fb=b+32|0;break n}a=N()|0;Jh(b+4|0);Q(a|0);p()}break m}if(d){rf(g+36|0,1,kR(x[x[b+8>>2]+84>>2],d));break m}Dc(g+36|0,16806)}b=12391;if(!Wg(y[c|0])){b=y[c+3|0]?12391:16806}x[31609]=0;b=P(36,g+24|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){c=a;a=g+36|0;tj(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break c;case 4:break d}}b=y[c+3|0];o:{if(Wg(y[c|0])){i=g,j=Cj(b,y[c+5|0])&255,x[i+12>>2]=j;dD(g+36|0,g+12|0);break o}if(b){Hv(g+36|0,c+5|0);break o}Dc(g+36|0,16805)}b=11178;if(!Wg(y[c|0])){b=y[c+3|0]?11178:16805}x[31609]=0;b=P(36,g+24|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){c=a;a=g+36|0;tj(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0)}Q(c|0);p()}fb=g+48|0}function Db(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&2)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[31489]){break a}a=a+b|0;c:{d:{if(x[31490]!=(d|0)){c=x[d+12>>2];if(b>>>0<=255){e=b>>>3|0;b=x[d+8>>2];if((b|0)==(c|0)){i=125940,j=x[31485]&Dua(-2,e),x[i>>2]=j;break b}x[b+12>>2]=c;x[c+8>>2]=b;break b}h=x[d+24>>2];if((c|0)!=(d|0)){b=x[d+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break c}e=x[d+20>>2];if(e){b=d+20|0}else{e=x[d+16>>2];if(!e){break d}b=d+16|0}while(1){g=b;c=e;b=c+20|0;e=x[c+20>>2];if(e){continue}b=c+16|0;e=x[c+16>>2];if(e){continue}break}x[g>>2]=0;break c}b=x[f+4>>2];if((b&3)!=3){break b}x[31487]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[f>>2]=a;return}c=0}if(!h){break b}b=x[d+28>>2];e=(b<<2)+126244|0;e:{if(x[e>>2]==(d|0)){x[e>>2]=c;if(c){break e}i=125944,j=x[31486]&Dua(-2,b),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=h;b=x[d+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[d+20>>2];if(!b){break b}x[c+20>>2]=b;x[b+24>>2]=c}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{g:{h:{i:{if(!(b&2)){if((f|0)==x[31491]){x[31491]=d;a=x[31488]+a|0;x[31488]=a;x[d+4>>2]=a|1;if(x[31490]!=(d|0)){break a}x[31487]=0;x[31490]=0;return}if((f|0)==x[31490]){x[31490]=d;a=x[31487]+a|0;x[31487]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;c=x[f+12>>2];if(b>>>0<=255){e=b>>>3|0;b=x[f+8>>2];if((b|0)==(c|0)){i=125940,j=x[31485]&Dua(-2,e),x[i>>2]=j;break g}x[b+12>>2]=c;x[c+8>>2]=b;break g}h=x[f+24>>2];if((c|0)!=(f|0)){b=x[f+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break h}e=x[f+20>>2];if(e){b=f+20|0}else{e=x[f+16>>2];if(!e){break i}b=f+16|0}while(1){g=b;c=e;b=c+20|0;e=x[c+20>>2];if(e){continue}b=c+16|0;e=x[c+16>>2];if(e){continue}break}x[g>>2]=0;break h}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;break f}c=0}if(!h){break g}b=x[f+28>>2];e=(b<<2)+126244|0;j:{if((f|0)==x[e>>2]){x[e>>2]=c;if(c){break j}i=125944,j=x[31486]&Dua(-2,b),x[i>>2]=j;break g}x[h+((f|0)==x[h+16>>2]?16:20)>>2]=c;if(!c){break g}}x[c+24>>2]=h;b=x[f+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[f+20>>2];if(!b){break g}x[c+20>>2]=b;x[b+24>>2]=c}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[31490]!=(d|0)){break f}x[31487]=a;return}if(a>>>0<=255){b=(a&-8)+125980|0;e=x[31485];a=1<<(a>>>3);k:{if(!(e&a)){x[31485]=a|e;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}c=31;if(a>>>0<=16777215){b=G(a>>>8|0);c=((a>>>38-b&1)-(b<<1)|0)+62|0}x[d+28>>2]=c;x[d+16>>2]=0;x[d+20>>2]=0;g=(c<<2)+126244|0;l:{m:{b=x[31486];e=1<<c;n:{if(!(b&e)){x[31486]=b|e;c=24;b=g;break n}c=a<<((c|0)!=31?25-(c>>>1|0)|0:0);b=x[g>>2];while(1){e=b;if((x[b+4>>2]&-8)==(a|0)){break m}b=c>>>29|0;c=c<<1;g=((b&4)+e|0)+16|0;b=x[g>>2];if(b){continue}break}c=24;b=e}e=d;f=d;a=8;break l}b=x[e+8>>2];x[b+12>>2]=d;c=8;g=e+8|0;f=0;a=24}x[g>>2]=d;x[c+d>>2]=b;x[d+12>>2]=e;x[a+d>>2]=f;a=x[31493]-1|0;x[31493]=a?a:-1}}function Ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-112|0;fb=e;g=x[b+4>>2];h=y[b+11|0];a:{if(Ad(g,h)){break a}f=y[yz(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+100|0;zx(f,b,0,_c(g,h)-1|0);zb(b,f);tb(f)}f=e+100|0;ie(f);g=x[e+100>>2];ie(e+88|0);g=TM(g,x[e+92>>2],b);ie(f);b:{c:{d:{e:{if((g|0)==x[e+104>>2]){if(Nd(b,22292)){a=dc(8);x[31609]=0;S(1002,f|0,18271,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}sc(a,f);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(f);break c}if(!d){break e}a=dc(8);x[31609]=0;d=e+76|0;S(1002,d|0,18307,b|0);b=x[31609];x[31609]=0;f:{g:{h:{i:{j:{if((b|0)!=1){x[31609]=0;b=e+88|0;O(1013,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break j}x[31609]=0;f=e+100|0;S(544,f|0,b|0,c|0);b=x[31609];x[31609]=0;d=1;if((b|0)==1){break i}sc(a,f);x[31609]=0;S(97,a|0,48428,1e3);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=N()|0;tb(f);d=0;break h}b=N()|0;break f}b=N()|0;d=1;break g}b=N()|0}tb(e+88|0)}tb(e+76|0);if(!d){break c}}lc(a);break c}k:{switch(x[g+4>>2]){case 0:fe(e+68|0,b);b=fb-176|0;fb=b;g=b+12|0;Uf(g,c);x[31609]=0;f=b+24|0;O(124,f|0,g|0);c=x[31609];x[31609]=0;l:{m:{n:{o:{p:{if((c|0)!=1){x[31609]=0;c=P(103,b+36|0,f|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break p}tb(f);tb(g);g=x[x[c>>2]-12>>2];x[31609]=0;h=ca(104)|0;i=x[31609];x[31609]=0;if((i|0)==1){break n}x[31609]=0;i=b+8|0;S(105,i|0,c+g|0,h|0);g=x[31609];x[31609]=0;if((g|0)==1){break n}_b(i);x[31609]=0;f=P(125,c|0,f|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break n}c=nk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];Gf(f);fb=b+176|0;b=(c^-1)&(g|0)!=0;break l}a=N()|0;break o}a=N()|0;tb(b+24|0)}tb(b+12|0);break m}a=N()|0;Gf(c)}Q(a|0);p()}c=x[e+72>>2];x[e>>2]=x[e+68>>2];x[e+4>>2]=c;Qz(a,e,b,d);break e;case 1:fe(e+60|0,b);b=fb-176|0;fb=b;g=b+12|0;Uf(g,c);x[31609]=0;f=b+24|0;O(124,f|0,g|0);c=x[31609];x[31609]=0;q:{r:{s:{t:{u:{if((c|0)!=1){x[31609]=0;c=P(103,b+36|0,f|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break u}tb(f);tb(g);g=x[x[c>>2]-12>>2];x[31609]=0;h=ca(104)|0;i=x[31609];x[31609]=0;if((i|0)==1){break s}x[31609]=0;i=b+8|0;S(105,i|0,c+g|0,h|0);g=x[31609];x[31609]=0;if((g|0)==1){break s}_b(i);x[31609]=0;x[b+24>>2]=0;x[b+28>>2]=0;f=P(1129,c|0,f|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break s}c=nk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];h=x[b+28>>2];Gf(f);fb=b+176|0;b=c?0:g;c=c?0:h;break q}a=N()|0;break t}a=N()|0;tb(b+24|0)}tb(b+12|0);break r}a=N()|0;Gf(c)}Q(a|0);p()}f=x[e+64>>2];x[e+8>>2]=x[e+60>>2];x[e+12>>2]=f;Oz(a,e+8|0,b,c,d);break e;case 2:fe(e+52|0,b);j=_Z(c);b=x[e+56>>2];x[e+16>>2]=x[e+52>>2];x[e+20>>2]=b;Pz(a,e+16|0,j,d);break e;case 3:break k;default:break e}}fe(e+44|0,b);fe(e+32|0,c);b=x[e+48>>2];x[e+24>>2]=x[e+44>>2];x[e+28>>2]=b;Nz(a,e+24|0,x[e+32>>2],x[e+36>>2],d)}fb=e+112|0;return}b=N()|0;lc(a)}Q(b|0)}p()}function loa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,D=0;h=fb-4128|0;fb=h;i=Bb(y[a+14|0]|y[a+15|0]<<8);if(!(!i|i>>>0>20|z[b+480190>>1]<=y[a+23|0])){nd(d,32);w[d+34>>1]=1;j=h+12|0;g=j;i=a+20|0;x[g>>2]=i;x[g+4>>2]=(i+80|0)-i>>2;dW(h+4120|0,x[h+12>>2],x[h+16>>2],Bb(y[a+14|0]|y[a+15|0]<<8));f=x[h+4120>>2];i=y[yb(f,0)+3|0];x[h+12>>2]=1;g=x[bd(ni(b,i+1|0)+24|0,g)>>2];i=x[h+4124>>2];dW(j,f,i,c?i:1);C=h,D=wb(x[h+12>>2]),x[C+4108>>2]=D;r=1/+(g>>>0);i=fb-16|0;fb=i;o=x[vb(i+12|0,x[h+12>>2]+(x[h+16>>2]<<2)|0)>>2];fb=i+16|0;f=x[d>>2];q=x[h+4120>>2];l=z[b+480190>>1];while(1){g=x[h+4108>>2];if(Ib(g,o)){i=y[g+3|0];a:{if(i>>>0>=l>>>0){break a}j=v[g+1|0];if((j|0)<0){break a}g=ni(b,i+1|0);i=x[g>>2];f=Te(r*(Ai(+((j&255)-v[yb(q,0)+1|0]|0)/-12)*+(i>>>0)*+A[g+24>>2]))+f|0;x[d>>2]=f}Xe(h+4108|0);continue}else{b:{s=Gh(d);if(!s){break b}i=(e<<12>>>0)/1e4|0;g=x[h+4124>>2];f=fb-16|0;fb=f;k=h+4108|0;x[k>>2]=0;x[k+4>>2]=0;tc(k+8|0);Rd(f+8|0,x[vb(f+4|0,k)>>2]);c:{if(!g){break c}x[31609]=0;O(754,k|0,g|0);e=x[31609];x[31609]=0;if((e|0)!=1){x[31609]=0;SV(k,g);e=x[31609];x[31609]=0;if((e|0)!=1){break c}}a=N()|0;wv(f+8|0);Q(a|0);p()}e=f+8|0;Qd(e);wv(e);fb=f+16|0;o=x[k>>2];t=x[h+4120>>2];q=x[h+4124>>2];f=0;while(1){if((f|0)==(q|0)){i=b+24648|0}else{g=yb(t,f);e=cW(o,f);l=y[g+3|0];d:{if(l>>>0>=z[b+480190>>1]){break d}j=v[g+1|0];if((j|0)<0){break d}u=0;g=y[g+2|0];if((g+14&255)>>>0<=5){u=v[g+25182|0]}n=ni(b,l+1|0);g=x[n+24>>2];B=r*(Ai(+(u<<24>>24)/96+ +((j&255)-v[yb(t,0)+1|0]|0)/12)*+(g>>>0));if(B<=0){break d}l=bW(B);x[e+8>>2]=l;j=hb;x[e+12>>2]=j;x[e+16>>2]=x[n+20>>2];g=x[n>>2];x[e+76>>2]=g;x[e+88>>2]=z[n+34>>1]&1023;e:{if(c){x[e+664>>2]=m;m=Te(+(g>>>0)/vC(l,j))+m|0;g=i;break e}g=(i>>>0)/(Bb(y[a+14|0]|y[a+15|0]<<8)>>>0)|0}x[e+20>>2]=g;x[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){f:{a=x[d>>2];if(a>>>0>b>>>0){Rb(h+12|0,0,4096);x[h+8>>2]=512;x[h+4>>2]=a-b;j=x[Hb(h+8|0,h+4|0)>>2];C=h,D=wb(x[k>>2]),x[C+8>>2]=D;c=wb(x[k+4>>2]);while(1){f=x[h+8>>2];if(!Ib(f,c)){break f}g:{h:{if(!x[f+16>>2]){break h}g=x[f+664>>2];if(g>>>0>=j>>>0){x[f+664>>2]=g-j;break h}e=x[f+88>>2];x[h+4>>2]=j-g;C=h,D=Te((+A[f+76>>2]-vC(x[f>>2],x[f+4>>2]))/vC(x[f+8>>2],x[f+12>>2])),x[C>>2]=D;a=x[Hb(h+4|0,h)>>2];x[31609]=0;V(x[((e&1|(e&64?18:16))<<2)+25760>>2],f|0,i|0,(h+12|0)+(g<<3)|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break g}x[f+664>>2]=0;if(A[f+76>>2]>A[f+4>>2]){break h}x[f+16>>2]=0}x[h+8>>2]=x[h+8>>2]+872;continue}break}a=N()|0;xv(k);Q(a|0);p()}xv(k);break b}e=x[d+20>>2]+(b<<1)|0;f=h+12|0;c=fb-16|0;fb=c;x[c+12>>2]=j;xc(c+12|0,512);m=x[c+12>>2];while(1){if(m){a=rd(x[f>>2]+2048|0,12);a=(a|0)>=32767?32767:a;w[e>>1]=(a|0)<=-32768?-32768:a;f=f+8|0;e=e+2|0;m=m-1|0;continue}break}fb=c+16|0;b=b+j|0;continue}}f=(s|0)!=0}break}}fb=h+4128|0;return f|0}function LR(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=E(0),u=0;if(b){MA(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;QR(a)}KR(a+24648|0);p=x[a+24620>>2];f=fb-144|0;fb=f;d=!b;e=a+397456|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}g=D(c,44)+45920|0;if(!((g|0)==x[e+8>>2]&d)){x[e+8>>2]=g;m=E(p>>>0);c=f+12|0;d=x[g+24>>2];x[c>>2]=d;j=x[g+16>>2];x[c+4>>2]=j;x[c+8>>2]=x[g+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){i=j;j=k+600|0;x[c+4>>2]=i-j;x[c>>2]=d-j}h=E(B[g+36>>2]*E(79.30999755859375));a:{if(E(F(h))<E(2147483648)){d=~~h;break a}d=-2147483648}x[c+16>>2]=d- -8192;h=E(E(E(B[g+32>>2]*E(.0036000001709908247))+E(.15000000596046448))*E(32767));b:{if(E(F(h))<E(2147483648)){d=~~h;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;j=0;h=B[g+8>>2];l=B[g+20>>2];l=E((l>E(.10000000149011612)?E(.10000000149011612):l)*m);c:{if(E(F(l))<E(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)<=96?96:d;n=(d|0)>7500?k-7500|0:0;l=E(B[g+28>>2]*m);d:{if(E(F(l))<E(2147483648)){i=~~l;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)<=128?128:d;q=(i|0)>=3800?3800:i;x[c+24>>2]=q;n=(d|0)<128?d-128|0:0;h=E(h*m);e:{if(E(F(h))<E(2147483648)){o=~~h;break e}o=-2147483648}i=(o+n|0)+((d|0)>3800?i-3800|0:0)|0;x[c+32>>2]=i;o=(k|0)>=7500?7500:k;n=c+36|0;while(1){if((j|0)==8){h=E(i|0);l=E(Ee(E(.0010000000474974513),(i|0)<4721?E(1):E(E(4720)/h))*E(32768));f:{if(E(F(l))<E(2147483648)){d=~~l;break f}d=-2147483648}x[c+12>>2]=d;h=E(B[g+12>>2]*h);s=c,t=Ee(E(.0010000000474974513),h<=E(4720)?E(1):E(E(4720)/h)),B[s+28>>2]=t}else{d=D(j,12);k=d+n|0;w[k+6>>1]=z[d+47210>>1];w[k>>1]=z[d+47204>>1];w[k+4>>1]=z[d+47208>>1];w[k+2>>1]=z[d+47206>>1];x[k+8>>2]=o+((D(x[d+47200>>2],q)+50|0)/100|0);j=j+1|0;continue}break}x[e+20>>2]=x[f+44>>2];r=+m;c=DP(EP(x[f+20>>2]),r);w[e+86>>1]=c;w[e+84>>1]=c;c=z[f+28>>1]<<1;w[e+94>>1]=c;w[e+92>>1]=c;j=e+100|0;k=f+48|0;c=0;while(1){if((c|0)==8){x[e+49892>>2]=x[f+36>>2];c=x[f+16>>2];if((c|0)>-9e3){c=CP(c)}else{c=0}x[e+80>>2]=c;c=x[f+12>>2];if((c|0)>=-8999){c=CP(c)}else{c=0}x[e+49948>>2]=c;c=x[f+32>>2];x[e+49932>>2]=268464128;x[e+49936>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+49906>>1]=c;w[e+49904>>1]=c;w[e+49902>>1]=c;w[e+49900>>1]=c;x[f+8>>2]=x[f+24>>2];Ge(f+8|0,0,32752);c=z[f+8>>1];w[e+49914>>1]=c;w[e+49910>>1]=0;w[e+49912>>1]=0;w[e+49908>>1]=c;m=B[f+40>>2];s=f,u=DP(+E(m*m),r),x[s+4>>2]=u;Ge(f+4|0,256,32512);c=z[f+4>>1];w[e+49922>>1]=c;w[e+49918>>1]=0;w[e+49920>>1]=0;w[e+49916>>1]=c}else{d=j+(c<<4)|0;g=k+D(c,12)|0;i=x[g+8>>2];x[d>>2]=i;x[d+4>>2]=i;w[d+8>>1]=z[g>>1];w[d+10>>1]=z[g+6>>1];w[d+12>>1]=z[g+4>>1];w[d+14>>1]=z[g+2>>1];c=c+1|0;continue}break}}if(b){x[e+16>>2]=0;GP(e,a+397448|0,a+397452|0)}b=D(p,5);if(b>>>0>A[e+20>>2]){x[e+20>>2]=b}fb=f+144|0;b=x[a+1298300>>2];if(Ed(b)){CU(b,x[a+24620>>2])}}function wZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-128|0;fb=f;i=og(f+116|0);a:{b:{c:{if(d){x[31609]=0;S(482,a|0,i|0,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){break c}break b}x[31609]=0;S(483,a|0,i|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}}n=b+900380|0;m=Nb(f+104|0);c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{g=c&65535;if(g>>>0<=z[b+480192>>1]){x[31609]=0;w[f+102>>1]=0;O(484,a|0,f+102|0);d=x[31609];x[31609]=0;t:{u:{v:{w:{if((d|0)!=1){h=fb-16|0;fb=h;l=z[f+102>>1];d=de(i);e=gc(i);j=fb-16|0;fb=j;while(1){if(d){k=$o(z[d+16>>1],l);e=k?e:d;d=x[(k?4:0)+d>>2];continue}break}d=x[vb(j+12|0,e)>>2];fb=j+16|0;x:{if(Ib(d,pg(i))){if(!$o(z[f+102>>1],z[ud(d)>>1])){break x}}d=pg(i)}d=vb(h+12|0,d);fb=h+16|0;j=(g<<2)+n|0;if(!x[j>>2]){break d}d=x[d>>2];if(!Zg(d,Pf(i))){break u}x[31609]=0;h=P(3,f+88|0,ud(d)+4|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break t}x[31609]=0;d=P(1,f+76|0,16816)|0;e=x[31609];x[31609]=0;if((e|0)==1){break v}e=ir(h,d);tb(d);if(e){break p}d=x[b+4>>2];x[31609]=0;d=P(485,d|0,h|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break r}x[x[j>>2]+44>>2]=d;if(!x[x[j>>2]+44>>2]){break w}break e}c=N()|0;break f}x[31609]=0;d=P(1,f- -64|0,13559)|0;e=x[31609];x[31609]=0;y:{z:{A:{if((e|0)!=1){B:{if(!ir(h,d)){x[31609]=0;e=P(1,f+52|0,13764)|0;g=x[31609];x[31609]=0;if((g|0)==1){break A}g=ir(h,e);tb(e);tb(d);if(g){break B}break s}tb(d)}x[31609]=0;d=R(486,h|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break z}x[f+36>>2]=d;d=x[b+4>>2];e=f+36|0;g=x[re(f+48|0,e)>>2];x[31609]=0;d=P(487,d|0,g|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break y}mg(e);if(d){break e}break s}c=N()|0;break g}c=N()|0;tb(d);break g}c=N()|0;break g}c=N()|0;mg(f+36|0);break g}c=N()|0;break g}d=x[j>>2];if(!d){break d}x[d+44>>2]=0;break d}c=N()|0;break f}Td(m);uZ(i);fb=f+128|0;return}d=wb(x[m>>2]);g=d;e=wb(x[m+4>>2]);while(1){C:{D:{if((d|0)!=(e|0)){if(!ir(d,h)){break D}}else{d=e}break C}d=d+12|0;continue}break}e=fb-16|0;fb=e;x[e+12>>2]=g;x[e+12>>2]=x[e+12>>2]+D((d-g|0)/12|0,12);fb=e+16|0;if(Ib(x[e+12>>2],wb(x[m+4>>2]))){break p}x[31609]=0;O(488,m|0,h|0);d=x[31609];x[31609]=0;if((d|0)!=1){break q}}c=N()|0;break g}x[31609]=0;d=P(1,f+12|0,17533)|0;e=x[31609];x[31609]=0;if((e|0)==1){break o}x[31609]=0;g=f+24|0;S(489,g|0,d|0,h|0);e=x[31609];x[31609]=0;if((e|0)==1){break n}x[31609]=0;e=P(1,f|0,16392)|0;l=x[31609];x[31609]=0;if((l|0)==1){break m}x[31609]=0;l=f+36|0;S(2,l|0,g|0,e|0);k=x[31609];x[31609]=0;if((k|0)==1){break l}k=x[b+1298472>>2];x[31609]=0;S(385,k|0,2,l|0);k=x[31609];x[31609]=0;if((k|0)==1){break k}tb(l);tb(e);tb(g);tb(d)}x[x[j>>2]+44>>2]=0;break e}c=N()|0;break g}c=N()|0;break h}c=N()|0;break i}c=N()|0;break j}c=N()|0;tb(f+36|0)}tb(e)}tb(f+24|0)}tb(d)}tb(h)}Td(m);break a}tb(h)}c=c+1|0;continue}}c=N()|0}uZ(i);Q(c|0);p()}function Pv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&2)){break a}c=x[a>>2];b=c+b|0;c:{d:{e:{a=a-c|0;if((a|0)!=x[31490]){d=x[a+12>>2];if(c>>>0<=255){e=x[a+8>>2];if((e|0)!=(d|0)){break e}i=125940,j=x[31485]&Dua(-2,c>>>3|0),x[i>>2]=j;break b}g=x[a+24>>2];if((a|0)!=(d|0)){c=x[a+8>>2];x[c+12>>2]=d;x[d+8>>2]=c;break c}e=x[a+20>>2];if(e){c=a+20|0}else{e=x[a+16>>2];if(!e){break d}c=a+16|0}while(1){h=c;d=e;c=d+20|0;e=x[d+20>>2];if(e){continue}c=d+16|0;e=x[d+16>>2];if(e){continue}break}x[h>>2]=0;break c}c=x[f+4>>2];if((c&3)!=3){break b}x[31487]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[e+12>>2]=d;x[d+8>>2]=e;break b}d=0}if(!g){break b}c=x[a+28>>2];e=(c<<2)+126244|0;f:{if(x[e>>2]==(a|0)){x[e>>2]=d;if(d){break f}i=125944,j=x[31486]&Dua(-2,c),x[i>>2]=j;break b}x[g+(x[g+16>>2]==(a|0)?16:20)>>2]=d;if(!d){break b}}x[d+24>>2]=g;c=x[a+16>>2];if(c){x[d+16>>2]=c;x[c+24>>2]=d}c=x[a+20>>2];if(!c){break b}x[d+20>>2]=c;x[c+24>>2]=d}g:{h:{i:{j:{c=x[f+4>>2];if(!(c&2)){if(x[31491]==(f|0)){x[31491]=a;b=x[31488]+b|0;x[31488]=b;x[a+4>>2]=b|1;if(x[31490]!=(a|0)){break a}x[31487]=0;x[31490]=0;return}if(x[31490]==(f|0)){x[31490]=a;b=x[31487]+b|0;x[31487]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;d=x[f+12>>2];if(c>>>0<=255){e=c>>>3|0;c=x[f+8>>2];if((c|0)==(d|0)){i=125940,j=x[31485]&Dua(-2,e),x[i>>2]=j;break h}x[c+12>>2]=d;x[d+8>>2]=c;break h}g=x[f+24>>2];if((d|0)!=(f|0)){c=x[f+8>>2];x[c+12>>2]=d;x[d+8>>2]=c;break i}e=x[f+20>>2];if(e){c=f+20|0}else{e=x[f+16>>2];if(!e){break j}c=f+16|0}while(1){h=c;d=e;c=d+20|0;e=x[d+20>>2];if(e){continue}c=d+16|0;e=x[d+16>>2];if(e){continue}break}x[h>>2]=0;break i}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b;break g}d=0}if(!g){break h}c=x[f+28>>2];e=(c<<2)+126244|0;k:{if(x[e>>2]==(f|0)){x[e>>2]=d;if(d){break k}i=125944,j=x[31486]&Dua(-2,c),x[i>>2]=j;break h}x[g+(x[g+16>>2]==(f|0)?16:20)>>2]=d;if(!d){break h}}x[d+24>>2]=g;c=x[f+16>>2];if(c){x[d+16>>2]=c;x[c+24>>2]=d}c=x[f+20>>2];if(!c){break h}x[d+20>>2]=c;x[c+24>>2]=d}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[31490]!=(a|0)){break g}x[31487]=b;return}if(b>>>0<=255){c=(b&-8)+125980|0;d=x[31485];b=1<<(b>>>3);l:{if(!(d&b)){x[31485]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}d=31;if(b>>>0<=16777215){c=G(b>>>8|0);d=((b>>>38-c&1)-(c<<1)|0)+62|0}x[a+28>>2]=d;x[a+16>>2]=0;x[a+20>>2]=0;c=(d<<2)+126244|0;m:{e=x[31486];h=1<<d;n:{if(!(e&h)){x[31486]=e|h;x[c>>2]=a;x[a+24>>2]=c;break n}d=b<<((d|0)!=31?25-(d>>>1|0)|0:0);c=x[c>>2];while(1){e=c;if((x[c+4>>2]&-8)==(b|0)){break m}c=d>>>29|0;d=d<<1;h=e+(c&4)|0;c=x[h+16>>2];if(c){continue}break}x[h+16>>2]=a;x[a+24>>2]=e}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[e+8>>2];x[b+12>>2]=a;x[e+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=e;x[a+8>>2]=b}}function z1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=fb-32|0;fb=e;a:{if((d|0)<=0){break a}x[e+8>>2]=d;x[e+20>>2]=b;x[e+16>>2]=214748364;u=e,w=D(x[Hb(e+20|0,e+16|0)>>2],20),x[u+24>>2]=w;to(c,x[Hb(e+8|0,e+24|0)>>2]);x[e+12>>2]=b;x[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=Kh(a,b,i);h=Kh(a,b,i+4|0);f=Kh(a,b,i+5|0);u=e,w=Kh(a,b,i+6|0)<<8|Kh(a,b,i+7|0),x[u+28>>2]=w;o=h<<8|f;t=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<o>>>0){i=dc(8);x[31609]=0;a=R(188,i|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(o|0)){u=e,w=Kh(a,b,i+t|0),v[u+24|0]=w;so(c,e+24|0);i=i+1|0;continue}break};s=o;break b;case 1:break g;default:break e}}ui(e+28|0,d);s=x[e+28>>2];q=Kh(a,b,i+10|0);v[e+24|0]=q;so(c,e+24|0);j=i+11|0;o=o+3&65532;i=s-1|0;h=0;l=0;r=0;n=0;while(1){if((i|0)<=0){break c}f=Qg(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;n=8;break l}g=h+1|0;m:{if(!f){m=e+8|0;if(!Qg(j,g,1,m)){break i}k=2;n:{o:{f=h+2|0;if(!Qg(j,f,1,m)){break o}k=3;f=h+3|0;if(!Qg(j,f,1,m)){break o}k=Qg(j,f,3,m);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((n<<3)+k|0)-17|0;s:{if((h|0)<0){a=dc(8);x[31609]=0;b=R(188,a|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=dc(8);x[31609]=0;b=R(188,a|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break q}}b=N()|0;lc(a);Q(b|0);p()}da(b|0,24472,162);p()}da(b|0,24472,162);p()}n=y[h+24512|0];if((n|0)!=8){break k}break m}f=4;if((n|0)!=8){break k}}n=8;f=1;if((r|0)>19){break k}}f=0;break j}r=r+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;m=Kh(x[e+8>>2],x[e+12>>2],h);q=q-rd((Kh(x[e+8>>2],x[e+12>>2],h+1|0)<<8|m<<16|Kh(x[e+8>>2],x[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-n|0)|0;v[e+24|0]=q;so(c,e+24|0);f=f-1|0;i=i-1|0;g=g+n|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!Qg(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!Qg(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!Qg(j,f,1,e+8|0)){h=6;break v}f=g+5|0;h=e+8|0;if(!Qg(j,g+4|0,1,h)){g=g+8|0;f=Qg(j,f,3,h)+8|0;break t}g=g+10|0;h=16;f=Qg(j,f,5,e+8|0);break u}g=f+2|0;f=Qg(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(Qg(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=Qg(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}m=g+1|0;g=Qg(j,m,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)<=1?1:l)-1|0}k=(g^-1)+k|0;g=Xc(x[c>>2],x[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+m|0;while(1){if((f|0)<=0|(i|0)<=0){break h}q=y[xb(x[c>>2],g)|0];v[e+24|0]=q;so(c,e+24|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=dc(8);x[31609]=0;a=R(188,i|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break d}da(a|0,24472,162);p()}r=r-(r>>3)|0;continue}}da(a|0,24472,162);p()}i=mc(x[c>>2],x[c+4>>2])^1;break a}a=N()|0;lc(i);Q(a|0);p()}x[e+28>>2]=i}d=d-s|0;i=o+t|0;continue}}fb=e+32|0;return i|0}function G1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-144|0;fb=d;yc(b);Lp(a);a:{f=d+108|0;if(!cx(b,f)){break a}if(!bG(f)){break a}n=x[b+8>>2];b:{if(!dd(b,y[f+16|0]|y[f+17|0]<<8|(y[f+18|0]<<16|y[f+19|0]<<24))){break b}while(1){if((y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24))>>>0<=j>>>0){break b}if(!Mb(x[b>>2],x[b+8>>2],5)){break b}c:{if((y[f+4|0]|y[f+5|0]<<8)>>>0>=64){if((Ki(b)|0)<=0){break c}}g=0;e=1;while(1){l=Zd(b);if(l){m=g>>>0>4;h=m&e;if(!((e^1)&1|m)){h=(Lq(l<<24>>24)&255)==y[g+13181|0]}e=h;g=g+1|0;continue}break}Vb(b,4);i=(g|0)==5&e|i}j=j+1|0;continue}}dd(b,n);if(!(i&1)){break a}if(!Mb(x[b>>2],x[b+8>>2],aG(f))){break a}if(!c){k=1;break a}h=fb-16|0;fb=h;c=d+108|0;dd(b,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24));j=d+96|0;f=Nb(j);e=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);x[31609]=0;O(176,f|0,e|0);e=x[31609];x[31609]=0;d:{e:{f:{if((e|0)!=1){e=0;g:{h:{while(1){if((y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))>>>0<=e>>>0){break g}g=x[b+8>>2];i=x[b>>2];x[31609]=0;g=U(150,i|0,g|0,5)|0;i=x[31609];x[31609]=0;if((i|0)==1){break f}if(!g){break g}i=y[c+4|0]|y[c+5|0]<<8;x[31609]=0;g=h+4|0;S(177,g|0,b|0,i|0);i=x[31609];x[31609]=0;if((i|0)!=1){x[31609]=0;O(178,f|0,g|0);i=x[31609];x[31609]=0;if((i|0)==1){break h}e=e+1|0;tb(g);continue}break}a=N()|0;break e}a=N()|0;tb(h+4|0);break e}fb=h+16|0;break d}a=N()|0;break e}a=N()|0}Td(f);Q(a|0);p()}x[31609]=0;V(170,d+84|0,b|0,c|0,j|0);c=x[31609];x[31609]=0;i:{if((c|0)!=1){x[31609]=0;P(149,b|0,y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24))|0;c=x[31609];x[31609]=0;j:{if((c|0)!=1){f=d+36|0;k:{l:{m:{n:{while(1){o:{p:{if((y[d+128|0]|y[d+129|0]<<8|(y[d+130|0]<<16|y[d+131|0]<<24))>>>0>k>>>0){c=x[b+8>>2];e=x[b>>2];x[31609]=0;c=U(150,e|0,c|0,8)|0;e=x[31609];x[31609]=0;if((e|0)==1){break p}if(c){break o}}k=mc(x[a>>2],x[a+4>>2])^1;wc(d+84|0);Td(d+96|0);break a}b=N()|0;break j}x[31609]=0;c=d+60|0;aa(171,c|0,b|0,d+108|0,d+84|0,d+96|0);e=x[31609];x[31609]=0;if((e|0)!=1){e=Np(c);x[31609]=0;c=R(172,x[d+60>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break n}if(c){x[31609]=0;c=R(173,d+24|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break m}e=x[e>>2];q:{if((e|0)<0){break q}g=x[d+96>>2];if(Ud(g,x[d+100>>2])>>>0<=e>>>0){break q}x[31609]=0;h=d+12|0;O(174,h|0,Vd(g,e)|0);e=x[31609];x[31609]=0;if((e|0)==1){break l}zb(c,h);tb(h)}ax(f,d+60|0);x[31609]=0;O(175,a|0,c|0);e=x[31609];x[31609]=0;if((e|0)==1){break l}Hp(c)}k=k+1|0;ub(d+60|0);continue}break}b=N()|0;break j}b=N()|0;break k}b=N()|0;break k}b=N()|0;Hp(c)}ub(d+60|0);break j}b=N()|0}wc(d+84|0);break i}b=N()|0}Td(d+96|0);Q(b|0);p()}fb=d+144|0;return k|0}function LG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-144|0;fb=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)<=5){h=d+108|0;vx(h,b);x[31609]=0;e=P(1,d+96|0,18407)|0;b=x[31609];x[31609]=0;if((b|0)==1){break E}x[31609]=0;i=d+120|0;S(2,i|0,h|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break D}x[31609]=0;f=P(3,d+72|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break C}x[31609]=0;g=P(1,d+60|0,20212)|0;b=x[31609];x[31609]=0;if((b|0)==1){break B}x[31609]=0;c=d+84|0;S(4,c|0,f|0,g|0);b=x[31609];x[31609]=0;if((b|0)==1){break A}x[31609]=0;j=d+132|0;S(2,j|0,i|0,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break z}tb(c);tb(g);tb(f);tb(i);tb(e);tb(h);b=x[a>>2];x[31609]=0;O(5,i|0,(b?b:22292)|0);b=x[31609];x[31609]=0;if((b|0)==1){break t}b=x[a+4>>2];x[31609]=0;O(5,h|0,(b?b:22292)|0);b=x[31609];x[31609]=0;if((b|0)==1){break s}a=x[a+8>>2];x[31609]=0;x[d+48>>2]=a;e=d+48|0;O(6,c|0,e|0);a=x[31609];x[31609]=0;if((a|0)==1){break r}x[31609]=0;P(7,497012,18286)|0;a=x[31609];x[31609]=0;if((a|0)==1){break q}x[31609]=0;O(8,e|0,i|0);a=x[31609];x[31609]=0;if((a|0)==1){break p}x[31609]=0;P(9,497012,e|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break o}x[31609]=0;P(7,497012,17493)|0;a=x[31609];x[31609]=0;if((a|0)==1){break o}x[31609]=0;f=d+36|0;O(8,f|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break n}x[31609]=0;P(9,497012,f|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break m}x[31609]=0;P(7,497012,17491)|0;a=x[31609];x[31609]=0;if((a|0)==1){break m}x[31609]=0;P(7,497012,18407)|0;a=x[31609];x[31609]=0;if((a|0)==1){break m}x[31609]=0;g=d+24|0;O(8,g|0,j|0);a=x[31609];x[31609]=0;if((a|0)==1){break l}x[31609]=0;P(9,497012,g|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break k}x[31609]=0;P(7,497012,13585)|0;a=x[31609];x[31609]=0;if((a|0)==1){break k}x[31609]=0;b=d+12|0;O(8,b|0,h|0);a=x[31609];x[31609]=0;if((a|0)==1){break j}x[31609]=0;P(9,497012,b|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break i}x[31609]=0;P(7,497012,13583)|0;a=x[31609];x[31609]=0;if((a|0)==1){break i}x[31609]=0;R(10,497012)|0;a=x[31609];x[31609]=0;if((a|0)==1){break i}tb(b);tb(g);tb(f);tb(e);tb(c);tb(h);tb(i);tb(j)}fb=d+144|0;return}a=N()|0;break u}a=N()|0;break v}a=N()|0;break w}a=N()|0;break x}a=N()|0;break y}a=N()|0;tb(d+84|0)}tb(g)}tb(f)}tb(d+120|0)}tb(e)}tb(d+108|0);break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break e}a=N()|0;break f}a=N()|0;break f}a=N()|0;break g}a=N()|0;break g}a=N()|0;break h}a=N()|0;break h}a=N()|0;tb(d+12|0)}tb(d+24|0)}tb(d+36|0)}tb(d+48|0)}tb(d+84|0)}tb(d+108|0)}tb(d+120|0)}tb(d+132|0)}Q(a|0);p()}function MP(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=E(0),k=0,m=E(0),p=E(0),s=E(0),t=0,u=0,v=E(0),w=E(0);d=a+4208|0;BB(yb(d,0),B[a+4272>>2]);b=E(B[yb(d,0)>>2]*E(15920));s=Ee(E(10),E(E(E(B[yb(d,2)>>2]+E(-.5))*E(30))/E(40)));c=E(E(E(b+E(80))/E(A[x[a+16>>2]+24620>>2]))*E(6.2831854820251465));b=bQ(c);v=uq(c);w=b;f=E(E(c*E(E(E(B[yb(d,1)>>2]*E(35))+E(1))*E(.02888113260269165)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());c=E(F(f));k=(q(c),j(2));a:{if(k>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(q(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((h|0)<0){break b}if(d>>>0<1118925336){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));i=E(c*b);p=E(E(i*E(E(i*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(i*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-i));if(!d){break b}e=E(E(E(c*E(p-e))-e)-i);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}i=(l(2,h^1065353216),r());c=E((d>>>0<=22?E(E(E(1)-i)+E(c-e)):E(E(c-E(e+i))+E(1)))*b)}b=c}if(k>>>0<=1065353215){if(k>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=$y(b)&2047;j:{k:{if($y(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if($y(E(Infinity))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=RG(0);break j}if(!(b<E(-103.97207641601562))){break k}c=zG(0);break j}g=C[165]*+b;t=C[164];u=g+t;g=g-(u-t);g=(C[166]*g+C[167])*(g*g)+(C[168]*g+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;k=x[d>>2];d=x[d+4>>2]+h|0;l(0,k|0);l(1,(k>>>0<k>>>0?d+1|0:d)|0);c=E(g*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/s);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*s);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function N8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-336|0;fb=d;e=fb-16|0;fb=e;x[a+4>>2]=0;v[a|0]=0;f=a+40|0;to(f,32);v[e+15|0]=0;so(f,e+15|0);fb=e+16|0;e=x[a+36>>2];a:{if(x[(x[x[e>>2]-12>>2]+e|0)+16>>2]){Oh(a,2,16777216);break a}ae(d+72|0,e);e=x[d+84>>2];x[a+16>>2]=x[d+80>>2];x[a+20>>2]=e;x[d+72>>2]=3;f=x[a+36>>2];e=0;while(1){if(A[d+72>>2]>e>>>0){Ei(f,d+e|0);e=e+1|0;continue}break}if(jd(d,24376,3)){Oh(a,2,512);break a}v[d+335|0]=0;Ei(x[a+36>>2],d+335|0);f=d+72|0;Rb(f,0,256);e=y[d+335|0];if(e){vj(x[a+36>>2],f,e)}f=b;b=rl(d,d+72|0,e);e=Jy(f,b);Eb(b);if(!e){Oh(a,2,4096)}if(ql(y[a|0])){break a}Ei(x[a+36>>2],d+71|0);b=y[d+71|0];e=b&3;w[a+24>>1]=(e|0)==3?4:e;if(kj(b,6)){Qc(d,a+32|0,9);kf(d,1)}x[d+64>>2]=0;pK(x[a+36>>2],d- -64|0);e=x[d+64>>2];v[d+63|0]=0;if(e>>>0>=2){Ei(x[a+36>>2],d+71|0);f=-1;if(!y[d+71|0]){Ei(x[a+36>>2],d+63|0);f=-2}Om(x[a+36>>2],e+f|0)}x[d+48>>2]=0;x[d+52>>2]=0;b:{if(!kj(b,4)){break b}ol(x[a+36>>2],d+48|0);e=x[d+52>>2];f=x[d+48>>2];x[a+64>>2]=f;x[a+68>>2]=e;g=x[c+4>>2];if((g|0)==(e|0)&A[c>>2]>=f>>>0|e>>>0<g>>>0){break b}Oh(a,1,4)}if(kj(b,5)){Ei(x[a+36>>2],d+71|0);Om(x[a+36>>2],y[d+71|0])}c=y[d+63|0];c:{if(!kj(c,0)){break c}Ei(x[a+36>>2],d+71|0);e=y[d+71|0];e=e&1?-1:e>>>1|0;w[a+24>>1]=e;if(e){break c}Oh(a,1,2)}x[a+8>>2]=0;f=1;if(kj(c,1)){pK(x[a+36>>2],a+8|0)}g=kj(b,2);e=a+32|0;Qc(d,e,6);kf(d,g);g=kj(b,3);Qc(d,e,7);kf(d,g);g=z[a+24>>1];Qc(d,e,5);kf(d,(g|0)!=0);b=kj(b,7);Qc(d,e,8);kf(d,b);Qc(d,e,5);d:{if(Gb(x[x[d>>2]>>2],x[d+4>>2])){break d}Qc(d+40|0,e,6);if(Gb(x[x[d+40>>2]>>2],x[d+44>>2])){break d}Qc(d+32|0,e,7);if(Gb(x[x[d+32>>2]>>2],x[d+36>>2])){break d}Qc(d+24|0,e,8);f=Gb(x[x[d+24>>2]>>2],x[d+28>>2])}b=d+16|0;Qc(b,e,11);kf(b,f);Qc(d,e,11);if(kj(c,2)){w[d+40>>1]=0;By(x[a+36>>2],d+40|0);b=x[a+36>>2];f=z[d+40>>1];Qc(d,e,9);Om(b,f<<Gb(x[x[d>>2]>>2],x[d+4>>2]))}if(kj(c,3)){Om(x[a+36>>2],5)}ol(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(!c&b>>>0>=16001|c){Oh(a,2,8192);break a}x[a+104>>2]=b;if(!b){Oh(a,1,1)}Qc(d,e,11);e:{if(!Gb(x[x[d>>2]>>2],x[d+4>>2])){break e}ol(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(zy(b,c)){break e}Oh(a,2,2048);break a}ae(d,x[a+36>>2]);g=x[d+8>>2];h=x[a+16>>2];c=g-h|0;g=x[d+12>>2]-(x[a+20>>2]+(g>>>0<h>>>0)|0)|0;if((g|0)<0){Oh(a,2,16384);break a}x[a+96>>2]=c;x[a+100>>2]=g;Qc(d,e,11);c=x[a+100>>2];g=b;h=x[a+96>>2];b=Gb(x[x[d>>2]>>2],x[d+4>>2]);x[a+72>>2]=b?g:h;x[a+76>>2]=b?f:c;Qc(d,e,11);if(!Gb(x[x[d>>2]>>2],x[d+4>>2])){b=x[a+100>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+96>>2]|0;x[a+80>>2]=c;x[a+84>>2]=c>>>0<f>>>0?b+1|0:b}Qc(d,e,10);kf(d,1)}fb=d+336|0}function lpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=fb-16|0;fb=g;a:{if(!Mb(x[a>>2],x[a+8>>2],2)){Pg(c+484344|0,b,64);break a}m=c+484344|0;n=Ld(Pk(a),1,1024);if(!Pg(m,b,n)){break a}p=z[c+480188>>1];b:while(1){if((k|0)==(n|0)){break a}e=Wb(x[m>>2],b);af(g+8|0,x[e>>2],x[x[e+48>>2]+12>>2],k);i=0;while(1)if((i|0)==(p|0)){k=k+1|0;continue b}else{e=Yc(x[g+8>>2],i);q=y[e+5|0];l=y[e+3|0];h=g+4|0;lm(h,a);r=_e(h);f=Yi(h);j=y[g+4|0];c:{if((j-1&255)>>>0>35){break c}v[e|0]=j+48;o=y[Jc(h)|0];h=o+1|0;v[e+1|0]=h;j=h;h=h&255;if((j|0)!=(h|0)|h>>>0>z[c+480190>>1]){break c}h=ni(c,h);j=xb(d,i);if(!(!y[j|0]|z[h+30>>1]>255)){v[e+4|0]=64;v[e+2|0]=1}h=x[yb(h+68|0,0)>>2];if(!(y[j|0]|h?y[j|0]?(h|0)==1:0:1)){break c}v[e+1|0]=o+101}d:{e:{switch(y[r|0]-1|0){case 0:if(!y[f|0]){break d}v[e+3|0]=2;v[e+5|0]=y[f|0];break d;case 1:if(!y[f|0]){break d}v[e+3|0]=3;v[e+5|0]=y[f|0];break d;case 9:if(!y[f|0]){break d}v[e+3|0]=1;f=y[f|0];s=e,t=pX(f>>>4|0)<<4|f&15,v[s+5|0]=t;break d;case 10:if(!y[f|0]){break d}v[e+3|0]=1;f=y[f|0];s=e,t=f&240|pX(f&15),v[s+5|0]=t;break d;case 11:if(!y[f|0]){break d}v[e+3|0]=1;v[e+5|0]=y[f|0];break d;case 12:if(!y[f|0]){break d}v[e+3|0]=39;v[g|0]=15;s=e,t=y[Qb(g,f)|0]|16,v[s+5|0]=t;break d;case 29:if(!y[f|0]){break d}v[e+3|0]=38;v[g|0]=15;s=e,t=y[Qb(g,f)|0]|16,v[s+5|0]=t;break d;case 20:if(!y[f|0]){break d}v[e+3|0]=39;v[g|0]=15;s=e,t=y[Qb(g,f)|0]|80,v[s+5|0]=t;break d;case 16:if(!y[f|0]){break d}v[e+3|0]=38;v[g|0]=15;s=e,t=y[Qb(g,f)|0]|80,v[s+5|0]=t;break d;case 14:v[e+3|0]=19;v[e+5|0]=y[f|0]!=0;break d;case 24:v[e+3|0]=12;v[e+5|0]=y[f|0];break d;case 26:Wo(e);v[e|0]=255;break d;case 27:if(y[f|0]>31){break d}v[e+3|0]=16;v[e+5|0]=y[f|0];break d;case 30:break e;default:break d}}h=y[f|0];if(h&15){s=e,t=y[xb(d,i)|0]?22:11,v[s+3|0]=t;v[e+5|0]=y[f|0]&15;h=y[f|0]}f:{g:{switch(h>>>4|0){case 4:if((h|0)!=64){break f}case 0:case 1:case 2:case 3:if(y[xb(d,i)|0]){v[e+3|0]=21;v[e+5|0]=y[f|0];break f}v[e+2|0]=1;f=y[f|0];v[e+3|0]=0;v[e+4|0]=f;break f;case 5:v[e+5|0]=y[e+5|0]<<4;break f;case 6:v[g|0]=y[e+5|0];v[g+3|0]=14;s=e,t=y[Qb(g,g+3|0)|0]|240,v[s+5|0]=t;break f;case 7:v[g|0]=y[e+5|0];v[g+3|0]=14;s=e,t=y[Qb(g,g+3|0)|0]<<4|15,v[s+5|0]=t;break f;default:break g}}v[e+3|0]=0}if((y[e+3|0]-21&255)>>>0>1){break d}f=Yc(x[g+8>>2],v[xb(d,i)|0]+i|0);uw(g,y[f+3|0],y[f+5|0],1);if(y[g|0]){h=z[g>>1];v[f+2|0]=h;v[f+4|0]=h>>>8}v[f+3|0]=y[e+3|0];v[f+5|0]=y[e+5|0]}h:{if(!l){break h}f=y[e+3|0];if((f|0)==(l|0)){break h}em(g,e,f,y[e+5|0],l,q)}i=i+1|0;continue}}}fb=g+16|0}function fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-32|0;fb=c;a:{b:{if(!Ib(x[b>>2],x[b+4>>2])){break b}l=a+16|0;m=x[b+12>>2];k=z[x[x[b+48>>2]+12>>2]+480188>>1];d=k;e=fb-16|0;fb=e;g=c+20|0;x[g>>2]=0;x[g+4>>2]=0;tc(g+8|0);Rd(e+8|0,x[vb(e+4|0,g)>>2]);c:{d:{if(d){x[31609]=0;O(460,g|0,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break d}h=fb-16|0;fb=h;f=Cr(h+4|0,g,d);d=x[f+4>>2];i=x[f+8>>2];while(1){if((d|0)==(i|0)){jc(f);fb=h+16|0}else{v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;Ng(d);d=d+6|0;x[f+4>>2]=d;continue}break}}d=e+8|0;Qd(d);am(d);fb=e+16|0;break c}a=N()|0;am(e+8|0);Q(a|0);p()}while(1){e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!(x[x[x[a>>2]-12>>2]+l>>2]|j>>>0>=m>>>0)){x[31609]=0;v[c+19|0]=0;P(918,a|0,c+19|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}d=v[c+19|0];if(!d){j=j+1|0;continue}v[c+18|0]=0;t:{if((d|0)>=0){break t}x[31609]=0;P(918,a|0,c+18|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break t}break a}v[c+17|0]=0;w[c+12>>1]=0;x[c+8>>2]=0;u:{d=d&127;f=(d?d-1|0:0)&65535;i=f>>>0>=k>>>0;v:{w:{if(!i){h=md(x[b>>2],x[x[b+48>>2]+12>>2],j,f);d=y[c+18|0];if(d&1){break w}e=Yc(x[g>>2],f);break v}h=c+8|0;d=y[c+18|0];if(!(d&1)){break u}}x[31609]=0;P(918,a|0,c+17|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}if(i){break u}e=Yc(x[g>>2],f);v[e|0]=y[c+17|0]}v[h|0]=y[e|0];d=y[c+18|0];if(!(d&2)){break r}break s}if(d&2){break s}break q}Mk(g);break b}x[31609]=0;P(918,a|0,c+17|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}if(i){break q}e=Yc(x[g>>2],f);v[e+1|0]=y[c+17|0]}v[h+1|0]=y[e+1|0];if(d&4){break p}break o}if(!(d&4)){break n}}x[31609]=0;P(918,a|0,c+17|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}if(i){break n}e=Yc(x[g>>2],f);v[e+2|0]=y[c+17|0]}v[h+2|0]=y[e+2|0];if(!(d&8)){break l}break m}if(!(d&8)){break k}}x[31609]=0;P(918,a|0,c+17|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}if(i){break k}e=Yc(x[g>>2],f);v[e+4|0]=y[c+17|0]}v[h+4|0]=y[e+4|0];if(d&16){break j}break i}if(!(d&16)){break h}}x[31609]=0;P(918,a|0,c+17|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}if(i){break h}e=Yc(x[g>>2],f);v[e+3|0]=y[c+17|0]}v[h+3|0]=y[e+3|0];if(!(d&32)){break f}break g}if(!(d&32)){break e}}x[31609]=0;P(918,a|0,c+17|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}if(i){break e}e=Yc(x[g>>2],f);v[e+5|0]=y[c+17|0]}v[h+5|0]=y[e+5|0]}if(!(d&64)){continue}x[31609]=0;P(918,a|0,c+7|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){x[31609]=0;P(919,a|0,y[c+7|0])|0;d=x[31609];x[31609]=0;if((d|0)!=1){continue}}break}break a}fb=c+32|0;return}a=N()|0;Mk(g);Q(a|0);p()}function Oz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-144|0;fb=f;x[f+136>>2]=c;x[f+140>>2]=d;g=x[b+4>>2];a:{if(!g){h=x[b>>2];break a}h=x[b>>2];i=y[zl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Ml(f+112|0,h,g,g-1|0);g=x[f+116>>2];h=x[f+112>>2];x[b>>2]=h;x[b+4>>2]=g}j=f+112|0;ie(j);i=x[f+112>>2];k=f+100|0;ie(k);i=yl(i,x[f+104>>2],b);ie(j);b:{c:{d:{e:{f:{g:{h:{if(x[f+116>>2]==(i|0)){c=pc(f+128|0,22292);a=x[c+4>>2];x[f+8>>2]=x[c>>2];x[f+12>>2]=a;if(Ic(h,g,f+8|0)){g=dc(8);x[31609]=0;O(1006,k|0,f+136|0);a=x[31609];x[31609]=0;if((a|0)==1){break g}x[31609]=0;S(1011,j|0,18271,k|0);a=x[31609];x[31609]=0;if((a|0)==1){break f}sc(g,j);h=0;x[31609]=0;S(97,g|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(j);break e}if(!e){break h}g=dc(8);c=x[b>>2];a=x[b+4>>2];x[31609]=0;e=$h(f+76|0,c,a);a=x[31609];x[31609]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){x[31609]=0;b=f+88|0;S(1011,b|0,18307,e|0);a=x[31609];x[31609]=0;if((a|0)==1){break p}x[31609]=0;c=f+100|0;O(1013,c|0,b|0);b=x[31609];x[31609]=0;a=1;if((b|0)==1){break o}x[31609]=0;b=f- -64|0;O(1006,b|0,f+136|0);a=x[31609];x[31609]=0;if((a|0)==1){break n}x[31609]=0;d=f+112|0;S(1015,d|0,c|0,b|0);b=x[31609];x[31609]=0;a=1;if((b|0)==1){break m}sc(g,d);x[31609]=0;S(97,g|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(d);a=0;break l}b=N()|0;break d}b=N()|0;a=1;break i}b=N()|0;break j}b=N()|0;a=1;break k}b=N()|0}tb(f- -64|0)}tb(f+100|0)}tb(f+88|0)}tb(e);if(a){break d}break c}e=pc(f+56|0,22292);b=x[e+4>>2];x[f+32>>2]=x[e>>2];x[f+36>>2]=b;if(Ic(h,g,f+32|0)){g=dc(8);x[31609]=0;b=f+100|0;O(1006,b|0,f+136|0);a=x[31609];x[31609]=0;q:{r:{if((a|0)!=1){x[31609]=0;c=f+112|0;S(1011,c|0,18271,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break r}sc(g,c);h=0;x[31609]=0;S(97,g|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break q}b=N()|0;break d}b=N()|0;h=1}tb(f+100|0);if(h){break d}break c}e=pc(f+48|0,10990);b=x[e+4>>2];x[f+24>>2]=x[e>>2];x[f+28>>2]=b;if(Ic(h,g,f+24|0)){Lz(a,Gc(c,d));break h}e=pc(f+40|0,8643);b=x[e+4>>2];x[f+16>>2]=x[e>>2];x[f+20>>2]=b;if(!Ic(h,g,f+16|0)){break h}e=x[a+32>>2];a=Tu(c,d);a=a>>>0>=4?1:a;b=fb-16|0;fb=b;s:{if((sk(y[e+140|0])|0)==(a|0)){a=e+120|0;bu(y[a+20|0]);c=fb-16|0;fb=c;x[c+12>>2]=b+15;d=fb-16|0;fb=d;x[d+12>>2]=1146;x[d+8>>2]=1147;x[d+4>>2]=1148;x[d>>2]=1149;ib[x[lq(d,sk(y[a+20|0]))>>2]](c+12|0,a);fb=d+16|0;fb=c+16|0;break s}QM(e,a,RM(e))}fb=b+16|0}fb=f+144|0;return}b=N()|0;break d}b=N()|0;h=1}tb(f+100|0);if(!h){break c}}lc(g)}Q(b|0)}p()}function Aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;e=fb-16|0;fb=e;d=DB(f+8|0);a:{b:{c:{d:{switch(b-850|0){default:e:{f:{if((b|0)!=437){if((b|0)==737){break f}if((b|0)==775){break e}if((b|0)==1252){break c}g:{h:{if((b|0)!=20127){if((b|0)==28591){break h}if((b|0)==28605){break g}if((b|0)!=65001){break b}b=mf(e+8|0,0);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,1);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,2);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,3);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,4);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,5);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,6);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 0:b=mf(e+8|0,7);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 2:b=mf(e+8|0,8);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 5:b=mf(e+8|0,9);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 7:b=mf(e+8|0,10);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 10:b=mf(e+8|0,11);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 11:b=mf(e+8|0,12);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 12:b=mf(e+8|0,13);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 13:b=mf(e+8|0,14);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 14:b=mf(e+8|0,15);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 15:b=mf(e+8|0,16);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 16:b=mf(e+8|0,17);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 19:b=mf(e+8|0,18);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 1:case 3:case 4:case 6:case 8:case 9:case 17:case 18:case 20:case 21:case 22:case 23:break b;case 24:break d}}b=mf(e+8|0,19);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=mf(e+8|0,20);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}if(y[d+4|0]){v[d+4|0]=0}}fb=e+16|0;i:{if(Id(y[f+12|0])){if(!Id(y[f+12|0])){a=dc(4);x[a>>2]=0;a=Dj(a);x[a>>2]=121028;da(a|0,121064,840);p()}b=fb-32|0;fb=b;j:{k:{l:{m:{e=x[f+8>>2];if(!e){Uf(b+20|0,c);c=0;a=Fb(a);d=y[b+31|0];e=x[b+24>>2];x[31609]=0;O(93,a|0,yh(e,d)|0);d=x[31609];x[31609]=0;if((d|0)!=1){while(1){if(yh(x[b+24>>2],y[b+31|0])>>>0<=c>>>0){break m}d=y[ec(b+20|0,c)|0];x[31609]=0;O(95,a|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break k}c=c+1|0;continue}}break k}d=b+8|0;Uf(d,c);x[31609]=0;c=b+20|0;S(11,c|0,e|0,d|0);e=x[31609];x[31609]=0;n:{o:{if((e|0)!=1){x[31609]=0;O(12,a|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break o}Ub(c);tb(d);break l}c=N()|0;break n}c=N()|0;Ub(b+20|0)}tb(b+8|0);break j}tb(b+20|0)}fb=b+32|0;break i}c=N()|0;tb(a);tb(b+20|0)}Q(c|0);p()}s0(a,22,c)}fb=f+16|0}function gI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=fb-48|0;fb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e&2147483647;c:{if(h>>>0<=1074752122){if((e&1048575)==598523){break c}if(h>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(h>>>0<=1075594811){if(h>>>0<=1075183036){if((h|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((h|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(h>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;k=h>>>20|0;e:{if((k-(e>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;if((k-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(h>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;k=1;while(1){m=(i+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=k;k=0;if(m){continue}break}C[i+32>>3]=a;d=2;while(1){k=d;d=d-1|0;m=i+16|0;if(C[m+(k<<3)>>3]==0){continue}break}d=uL(m,i,(h>>>20|0)-1046|0,k+1|0,1);a=C[i>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[i+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[i+8>>3]}fb=i+48|0;return d}function Rpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=fb-560|0;fb=f;a:{if(!dd(b,1464)){break a}d=f+556|0;if(!kr(b,d)){break a}Dd(a,1);Lb(Lb(bg(a+1074312|0,83),84,1),85,1);b:{if(oe(d,25284)){e=f+32|0;d=uc(e,8430);zb(a+1298344|0,d);tb(d);d=uc(e,14917);zb(a+1298356|0,d);tb(d);d=uc(e,14982);zb(a+1298368|0,d);break b}if(!oe(f+556|0,15612)){break a}e=f+32|0;d=uc(e,8620);zb(a+1298344|0,d);tb(d);d=uc(e,12356);zb(a+1298356|0,d);tb(d);d=uc(e,15529);zb(a+1298368|0,d)}tb(d);s=a,t=x[Fc(e,28)>>2],x[s+1298404>>2]=t;e=0;dd(b,0);CZ(b,a+1298308|0,20);w[a+480190>>1]=31;g=a+946304|0;m=a+484380|0;d=1;while(1)if((d|0)==32){if(e>>>0>40){break a}d=f+554|0;Mw(d,b);n=Jc(d);if(y[f+554|0]>128){break a}e=f+32|0;d=fb-16|0;fb=d;c:{if(!Mb(x[b>>2],x[b+8>>2],512)){HX(e);break c}zE(d+8|0,e);sd(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d=0;e=y[n|0];while(1){o=(d|0)==512;if(!o){g=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=y[g|0]){continue}break a}break}if((c|0)==64){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;Uh(a,0);vg(Xb(x[a+484360>>2],y[a+484376|0]),y[f+554|0]);l=a+484344|0;Tf(l,y[f+554|0]);g=0;while(1)if(y[f+554|0]<=g>>>0){if(!(c&2)){break a}dd(b,(y[n|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}a=D(d,104)+m|0;if(x[a>>2]){dg(Zc(f+8|0,8,1,0,0),a,b)}d=d+1|0;continue}}else{s=ac(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],g),t=g,w[s>>1]=t;d:{if(!Pg(l,g&65535,64)){break d}r=g<<2;i=0;e:while(1){if((i|0)==4){s=f,t=wb(x[Wb(x[l>>2],g)>>2]),x[s+24>>2]=t;i=0;while(1){if((i|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{v[f+30|0]=p;v[f+31|0]=q;d=h&255;if(d){break g}h=0;break f}}else{e=x[f+24>>2];h:{if((y[e+3|0]&254)!=16){break h}v[e+3|0]=16;h=0;j=y[e+5|0];if(j>>>0<16){break h}h=j>>>4|0;v[e+5|0]=h;k=h;e=j&15;h=(e|0)!=(h|0)&(e|0)!=0;p=h?k:p;q=h?e:q}d=d+1|0;LC(f+24|0);continue}break}Ae(Wb(x[l>>2],g),We(Oe(f+8|0,16,y[(d+f|0)+29|0]),i));h=h+1|0;h=(h&255)==3?1:h}i=i+1|0;continue}}dd(b,(y[(f+32|0)+(i|r)|0]<<8)+1468|0);e=0;d=Wb(x[l>>2],g);d=md(x[d>>2],x[x[d+48>>2]+12>>2],0,i&65535);while(1)if((e|0)==64){i=i+1|0;continue e}else{k=f+8|0;H$(k,b,d);j=y[f+8|0];k=y[Jc(k)|0];i:{if(!(!(j|k)|(j-5&255)>>>0<5|(j|0)==14&k>>>0>15)){Cf(d,j,k);break i}v[d+3|0]=0}d=d+24|0;e=e+1|0;continue}}}g=g+1|0;continue}}else{i=f+32|0;OC(b,i);e=XC(i,D(d,104)+m|0,g+(d<<5)|0,1)+e|0;d=d+1|0;continue}}fb=f+560|0;return o|0}function Nna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;g=fb-80|0;fb=g;a:{d=x[a+4>>2];b:{if(d>>>0<b>>>0){q=Md(g+72|0);o=b-d|0;c=hv(a);c:{if(!(o>>>0>c>>>0|d>>>0>c-o>>>0)){$q(g+60|0,x[a>>2],d);Zb(q,x[g+60>>2],x[g+64>>2]);x[a+4>>2]=x[a+4>>2]+o;break c}m=To(g+60|0);x[31609]=0;b=P(759,a|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}x[31609]=0;O(760,m|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}x[m+4>>2]=x[a+4>>2]+o;mn(g+44|0,x[a>>2]);$q(g+32|0,x[a>>2],x[a+4>>2]);mn(g+24|0,x[m>>2]);b=x[g+48>>2];x[g+8>>2]=x[g+44>>2];x[g+12>>2]=b;d=g+52|0;b=x[g+32>>2];c=x[g+36>>2];f=x[g+24>>2];r=fb-16|0;fb=r;h=x[g+8>>2];e=x[g+28>>2];i=x[g+12>>2];d:{if((e|0)==(i|0)){f=Zb(r+8|0,f,e);k=fb-16|0;fb=k;b=gv(b,c,h,e);x[k+12>>2]=b;c=x[f>>2];e:{if((b|0)<=0){break e}if(e){i=32-e|0;x[k+8>>2]=i;j=b;b=x[Cd(k+8|0,k+12|0)>>2];x[k+12>>2]=j-b;e=-1<<e&-1>>>i-b;x[c>>2]=x[c>>2]&(e^-1)|e&x[h>>2];b=b+x[f+4>>2]|0;x[f+4>>2]=b&31;c=(b>>>3&536870908)+c|0;x[f>>2]=c;h=h+4|0;b=x[k+12>>2]}e=(b|0)/32|0;_Y(h,e,c);b=b-(e<<5)|0;x[k+12>>2]=b;e=e<<2;c=e+x[f>>2]|0;x[f>>2]=c;if((b|0)<=0){break e}b=-1>>>32-b|0;x[c>>2]=x[c>>2]&(b^-1)|b&x[e+h>>2];x[f+4>>2]=x[k+12>>2]}Zb(d,c,x[f+4>>2]);fb=k+16|0;break d}k=d;e=Zb(r,f,e);f=fb-16|0;fb=f;c=gv(b,c,h,i);x[f+12>>2]=c;f:{if((c|0)<=0){b=x[e+4>>2];d=x[e>>2];break f}g:{if(!i){b=x[e+4>>2];break g}l=32-i|0;x[f+8>>2]=l;b=c;c=f+8|0;d=x[Cd(c,f+12|0)>>2];x[f+12>>2]=b-d;b=x[e+4>>2];n=x[h>>2];x[f+8>>2]=d;s=32-b|0;x[f+4>>2]=s;j=x[e>>2];t=x[j>>2];c=x[Hb(c,f+4|0)>>2];l=n&(-1<<i&-1>>>l-d);x[j>>2]=(-1<<b&-1>>>s-c^-1)&t|(b>>>0>i>>>0?l<<b-i:l>>>i-b|0);n=b+c|0;b=n&31;x[e+4>>2]=b;j=j+(n>>>3&536870908)|0;x[e>>2]=j;d=d-c|0;if((d|0)>0){x[j>>2]=x[j>>2]&(-1>>>32-d^-1)|l>>>c+i;x[e+4>>2]=d;b=d}h=h+4|0;c=x[f+12>>2]}i=32-b|0;j=-1<<b;l=j^-1;while(1){if((c|0)>=32){d=x[e>>2];c=x[h>>2];x[d>>2]=l&x[d>>2]|c<<b;x[e>>2]=d+4;x[d+4>>2]=j&x[d+4>>2]|c>>>i;c=x[f+12>>2]-32|0;x[f+12>>2]=c;h=h+4|0;continue}break}d=x[e>>2];if((c|0)<=0){break f}l=x[h>>2];x[f+8>>2]=i;n=x[d>>2];h=x[Cd(f+12|0,f+8|0)>>2];j=n&(j&-1>>>i-h^-1);i=l&-1>>>32-c;x[d>>2]=j|i<<b;c=b+h|0;b=c&31;x[e+4>>2]=b;d=(c>>>3&536870908)+d|0;x[e>>2]=d;c=x[f+12>>2]-h|0;x[f+12>>2]=c;if((c|0)<=0){break f}x[d>>2]=x[d>>2]&(-1>>>32-c^-1)|i>>>h;b=x[f+12>>2];x[e+4>>2]=b}Zb(k,d,b);fb=f+16|0}fb=r+16|0;Zb(q,x[g+52>>2],x[g+56>>2]);lC(a,m);tf(m)}a=Zb(g+16|0,x[q>>2],x[q+4>>2]);Vw(x[a>>2],x[a+4>>2],o,0);break b}x[a+4>>2]=b}fb=g+80|0;return}a=N()|0;tf(m);Q(a|0);p()}function te(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31609]=0;O(114,b|0,_c(e,d)|0);d=x[31609];x[31609]=0;d:{if((d|0)!=1){e:{while(1){if(_c(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Wd(c,a)>>2];x[31609]=0;O(115,b|0,(d>>>0>=128?63:d)<<24>>24);d=x[31609];x[31609]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31609]=0;O(114,b|0,_c(e,d)|0);d=x[31609];x[31609]=0;f:{if((d|0)!=1){g:{while(1){if(_c(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Wd(c,a)>>2];x[31609]=0;O(115,b|0,(d>>>0>=256?63:d)<<24>>24);d=x[31609];x[31609]=0;if((d|0)==1){break g}a=a+1|0;continue}break}break f}}break a}return;case 3:df(a,c,48864);return;case 4:df(a,c,49888);return;case 5:df(a,c,50912);return;case 6:df(a,c,51936);return;case 7:df(a,c,52960);return;case 8:df(a,c,53984);return;case 9:df(a,c,55008);return;case 10:df(a,c,56032);return;case 11:df(a,c,57056);return;case 12:df(a,c,58080);return;case 13:df(a,c,59104);return;case 14:df(a,c,60128);return;case 15:df(a,c,61152);return;case 16:df(a,c,62176);return;case 17:df(a,c,63200);return;case 18:df(a,c,64224);return;case 19:df(a,c,65248);return;case 20:df(a,c,66272);return;case 21:df(a,c,67296);return;case 22:df(a,c,68320);return;case 23:df(a,c,69344);return;case 24:Dx(a,c,70368);return;case 25:Dx(a,c,48864);return;case 26:Dx(a,c,67296);return;default:a=dc(8);x[31609]=0;b=P(16,a|0,11122)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}b=N()|0;lc(a);Q(b|0);p();case 0:break c}}e=fb-16|0;fb=e;f=Fb(a);h:{while(1){i:{j:{k:{if(_c(x[c+4>>2],y[c+11|0])>>>0>g>>>0){b=x[Wd(c,g)>>2];if(b>>>0>=2097152){x[31609]=0;O(115,f|0,63);a=x[31609];x[31609]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;v[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=y[e+10|0]|64}else{a=y[e+10|0]}x[31609]=0;O(115,f|0,a<<24>>24);a=x[31609];x[31609]=0;if((a|0)!=1){break j}break i}fb=e+16|0;break h}i=(2<<a)+255<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=y[j|0];x[31609]=0;O(115,f|0,(a|i)<<24>>24);h=x[31609];x[31609]=0;a=d;break l}x[31609]=0;a=a-1|0;O(115,f|0,v[a+(e+10|0)|0]|-128);h=x[31609];x[31609]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=N()|0;tb(f);Q(a|0);p()}return}da(b|0,124672,17);p()}a=N()|0;tb(b);Q(a|0);p()}function jn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;h=Nb(a);x[31609]=0;a=R(281,b|0)|0;d=x[31609];x[31609]=0;a:{b:{c:{d:{e:{if((d|0)==1){break e}d=x[b+8>>2];c=x[b>>2];x[31609]=0;d=U(150,c|0,d|0,a|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}if(d){break d}x[31609]=0;a=R(202,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break e}x[31609]=0;P(183,b|0,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break c}}a=N()|0;break a}x[31609]=0;c=e+24|0;S(185,c|0,b|0,a|0);b=x[31609];x[31609]=0;f:{g:{h:{if((b|0)!=1){d=hc(e+44|0,c);ub(c);if(a>>>0<10){break g}x[31609]=0;b=R(736,d|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break b}if(!b){break g}x[31609]=0;b=R(281,d|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break b}x[e+20>>2]=b;a=a-10|0;xc(e+20|0,a>>>0>25264513?-1:D(a,170));x[31609]=0;c=x[e+20>>2];O(287,h|0,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){break h}break b}a=N()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=x[d+8>>2];f=x[d>>2];x[31609]=0;a=P(737,f|0,a|0)|0;f=x[31609];x[31609]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}x[31609]=0;a=R(534,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}f=1;switch(a&255){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}x[31609]=0;a=R(197,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}if(a>>>0>c>>>0){continue}g=x[d+8>>2];i=x[d>>2];x[31609]=0;g=U(150,i|0,g|0,a|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}if(!g){continue}se(e+24|0,x[h>>2],x[h+4>>2]);wr(e+8|0,x[e+24>>2],x[e+28>>2],b,a);x[31609]=0;Yn(471,e,d,x[e+8>>2],x[e+12>>2]);f=x[31609];x[31609]=0;if((f|0)!=1){c=c-a|0;b=a+b|0;continue i}break b}x[31609]=0;a=R(197,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>c>>>0){continue}x[31609]=0;i=P(738,d|0,e+16|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+16|0;i=gc(f);rv(f,i,vf(wb(x[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(c>>>0<8){continue}x[31609]=0;a=e+16|0;g=P(738,d|0,a|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}if(!g){continue}f=gc(a);rv(a,f,vf(wb(x[h>>2]),b));rv(a,f,vf(vf(wb(x[h>>2]),b),4));c=c-8|0;b=b+8|0;continue i}x[31609]=0;a=R(197,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}if(a>>>0>c>>>0){continue}break}c=c-a|0;b=a+b|0;continue}c=c-g|0;continue}break}if(!c){break f}Nb(fc(h));break f}x[31609]=0;S(333,d|0,h|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}}ub(d)}fb=e- -64|0;return}a=N()|0;ub(d)}fc(h);Q(a|0);p()}function jP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-192|0;fb=d;f=x[b+4>>2];a:{if(!f){break a}e=x[b>>2];g=y[zl(e,f)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Ml(d+168|0,e,f,f-1|0);f=x[d+172>>2];e=x[d+168>>2];x[b>>2]=e;x[b+4>>2]=f}e=d+168|0;ie(e);g=x[d+168>>2];ie(d+156|0);g=yl(g,x[d+160>>2],b);ie(e);b:{c:{d:{e:{if((g|0)==x[d+172>>2]){a=x[b>>2];g=pc(d+184|0,22292);h=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=h;if(Ic(a,f,d)){a=dc(8);x[31609]=0;c=P(36,e|0,10498)|0;b=x[31609];x[31609]=0;if((b|0)==1){break d}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;if(!c){break e}a=dc(8);c=x[b+4>>2];b=x[b>>2];x[31609]=0;f=$h(d+156|0,b,c);b=x[31609];x[31609]=0;f:{g:{h:{if((b|0)!=1){x[31609]=0;e=d+168|0;S(1011,e|0,18307,f|0);b=x[31609];x[31609]=0;if((b|0)==1){break h}sc(a,e);c=0;x[31609]=0;S(97,a|0,48428,1e3);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=N()|0;tb(e);break g}b=N()|0;break f}b=N()|0;c=1}tb(f);if(!c){break c}}lc(a);break c}if(x[g+4>>2]){a=dc(8);x[31609]=0;c=P(36,d+168|0,11600)|0;b=x[31609];x[31609]=0;if((b|0)!=1){sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;lc(a);break c}b=x[b>>2];c=pc(d+148|0,22292);e=x[c+4>>2];x[d+72>>2]=x[c>>2];x[d+76>>2]=e;if(Ic(b,f,d+72|0)){a=dc(8);x[31609]=0;c=P(36,d+168|0,10498)|0;b=x[31609];x[31609]=0;if((b|0)!=1){sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;lc(a);break c}c=pc(d+140|0,7462);e=x[c+4>>2];x[d+64>>2]=x[c>>2];x[d+68>>2]=e;i:{if(!Ic(b,f,d- -64|0)){c=pc(d+132|0,7444);e=x[c+4>>2];x[d+56>>2]=x[c>>2];x[d+60>>2]=e;if(!Ic(b,f,d+56|0)){break i}}e=y[a+60|0]!=0;break e}c=pc(d+124|0,6989);e=x[c+4>>2];x[d+48>>2]=x[c>>2];x[d+52>>2]=e;j:{if(!Ic(b,f,d+48|0)){c=pc(d+116|0,6970);e=x[c+4>>2];x[d+40>>2]=x[c>>2];x[d+44>>2]=e;if(!Ic(b,f,d+40|0)){break j}}e=y[a+61|0]!=0;break e}c=pc(d+108|0,7073);e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Ic(b,f,d+32|0)){e=y[a+62|0]!=0;break e}c=pc(d+100|0,6064);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,f,d+24|0)){e=y[a+63|0]!=0;break e}c=pc(d+92|0,7511);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,f,d+16|0)){e=y[a+64|0]!=0;break e}c=pc(d+84|0,13525);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;e=0;if(!Ic(b,f,d+8|0)){break e}e=x[x[a+24>>2]+24668>>2]!=0}fb=d+192|0;return e|0}b=N()|0;lc(a)}Q(b|0)}p()}function ika(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+8>>2]=41968;x[a+4>>2]=0;x[a>>2]=30512;b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;Tq(a+24604|0);qS(a+24648|0,0);x[a+397448>>2]=0;x[a+397452>>2]=0;b=a+397456|0;x[b>>2]=8;x[b+4>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;v[b+12|0]=0;x[b+8>>2]=0;w[b+24>>1]=0;Rb(b+28|0,0,40);Rb(b+68|0,0,49824);Rb(b+49892|0,0,32832);v[a+480224|0]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;f=Nb(a+480248|0);x[a+480272>>2]=0;c=480280;while(1){b=a+c|0;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;kF(b+9|0);c=c+32|0;if((c|0)!=484344){continue}break}d=Nb(a+484344|0);x[d+12>>2]=a;x[31609]=0;g=P(848,a+484360|0,a|0)|0;b=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=484380;while(1){x[31609]=0;R(709,a+c|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break i}c=c+104|0;if((c|0)!=900380){continue}break}x[31609]=0;R(849,a+901404|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break h}e=a+906300|0;c=0;while(1){kS(c+e|0);c=c+160|0;if((c|0)!=4e4){continue}break}x[a+946300>>2]=0;c=946304;while(1){ev(a+c|0);c=c+32|0;if((c|0)!=1074304){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;ds(a+1074312|0);x[31609]=0;X(850);b=x[31609];x[31609]=0;if((b|0)==1){break g}r=a,s=jS(),x[r+1074328>>2]=s;b=a+1074332|0;x[b+12>>2]=1065353216;$R(b,4);x[31609]=0;c=R(851,a+1074376|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break g}x[31609]=0;h=U(604,a+1298264|0,a|0,255)|0;b=x[31609];x[31609]=0;if((b|0)==1){break f}i=tc(a+1298300|0);j=tc(a+1298304|0);k=Fb(a+1298308|0);l=Fb(a+1298320|0);m=Fb(a+1298332|0);n=pS(a+1298344|0);o=Nb(a+1298412|0);v[a+1298424|0]=0;b=a+1298432|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1298472>>2]=0;Dq(a+12|0);VA(a+8204|0);VA(a+12300|0);x[a+1074408>>2]=4;x[a+1074412>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;Rb(a+900380|0,0,1024);iS(a+946304|0);x[31609]=0;b=R(852,12)|0;q=x[31609];x[31609]=0;if((q|0)==1){break e}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;r=a,s=Nb(b),x[r+4>>2]=s;return a|0}a=N()|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;oS(o);YA(n);tb(m);tb(l);tb(k);XA(j);WA(i);Ru(h)}kB(c)}nS(e)}_B(g)}fS(d);wc(f);Q(a|0);p()}function saa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-160|0;fb=d;x[d+156>>2]=c;a:{b:{if(b>=.8){x[31609]=0;c=ca(1194)|0;e=x[31609];x[31609]=0;c:{d:{e:{if((e|0)!=1){x[d+72>>2]=c;x[31609]=0;e=R(1195,x[d+156>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}x[d+152>>2]=e;vo(c,e);a=He(d+132|0,a);x[31609]=0;e=x[a+12>>2];x[d+56>>2]=x[a+8>>2];x[d+60>>2]=e;x[d- -64>>2]=x[a+16>>2];e=x[a+4>>2];x[d+48>>2]=x[a>>2];x[d+52>>2]=e;a=U(1155,c|0,d+48|0,15)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}if(a){x[31609]=0;W(853,x[d+72>>2]);a=x[31609];x[31609]=0;g=1;if((a|0)==1){break e}}vh(d+152|0);wh(d+72|0);break a}c=T(0)|0;break b}c=T(0)|0;vh(d+152|0);break c}c=T(0)|0}wh(d+72|0);break b}if(b>=.6){x[31609]=0;c=ca(1194)|0;e=x[31609];x[31609]=0;f:{g:{h:{if((e|0)!=1){x[d+72>>2]=c;x[31609]=0;e=R(1195,x[d+156>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break g}x[d+152>>2]=e;vo(c,e);a=He(d+112|0,a);x[31609]=0;e=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=e;x[d+40>>2]=x[a+16>>2];e=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=e;a=U(1155,c|0,d+24|0,2)|0;c=x[31609];x[31609]=0;if((c|0)==1){break h}if(a){x[31609]=0;W(853,x[d+72>>2]);a=x[31609];x[31609]=0;g=.8;if((a|0)==1){break h}}vh(d+152|0);wh(d+72|0);break a}c=T(0)|0;break b}c=T(0)|0;vh(d+152|0);break f}c=T(0)|0}wh(d+72|0);break b}g=.2;if(b>=.2){x[31609]=0;c=ca(1194)|0;e=x[31609];x[31609]=0;i:{j:{k:{if((e|0)!=1){x[d+72>>2]=c;x[31609]=0;e=R(1195,x[d+156>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break j}x[d+152>>2]=e;vo(c,e);a=He(d+92|0,a);x[31609]=0;e=x[a+12>>2];x[d+8>>2]=x[a+8>>2];x[d+12>>2]=e;x[d+16>>2]=x[a+16>>2];e=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=e;a=U(1155,c|0,d|0,64)|0;c=x[31609];x[31609]=0;if((c|0)==1){break k}g=0;if(a){x[31609]=0;W(853,x[d+72>>2]);a=x[31609];x[31609]=0;g=.6;if((a|0)==1){break k}}vh(d+152|0);wh(d+72|0);break a}c=T(0)|0;break b}c=T(0)|0;vh(d+152|0);break i}c=T(0)|0}wh(d+72|0);break b}if(!(b>=.1)){break a}x[31609]=0;c=d+72|0;S(186,c|0,a|0,2048);e=x[31609];x[31609]=0;l:{if((e|0)!=1){e=Ze(c);a=x[a>>2];x[31609]=0;f=x[d+72>>2];a=R(154,a|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break l}x[31609]=0;a=aI(1196,3,0,e,f,a,0);e=x[31609];x[31609]=0;if((e|0)==1){break l}g=C[(a<<3)+79272>>3];Kc(c);break a}c=T(0)|0;break b}c=T(0)|0;Kc(d+72|0)}Y(c|0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;g=0;if((a|0)!=1){break a}a=N()|0;Wc(d+156|0);Q(a|0);p()}Wc(d+156|0);fb=d+160|0;return+g}function vS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-48|0;fb=h;j=fb-16|0;fb=j;x[j>>2]=b;x[j+4>>2]=c;g=fb-16|0;fb=g;e=fb-16|0;fb=e;d=vb(e+12|0,Bua(x[j>>2],x[j+4>>2],500654080,20));fb=e+16|0;e=fb-16|0;fb=e;k=x[d>>2];f=sS(e+8|0,k);fb=e+16|0;e=x[j>>2];d=x[f>>2];i=x[j+4>>2];f=x[f+4>>2];if(((d|0)!=(e|0)|(f|0)!=(i|0)?e>>>0>d>>>0&(i|0)>=(f|0)|(f|0)<(i|0)?-1:1:0)<<24>>24>0){d=x[vb(g+12|0,1)>>2];e=fb-16|0;fb=e;k=x[vb(e+12|0,k-d|0)>>2];fb=e+16|0}fb=g+16|0;l=x[vb(j+12|0,k)>>2];fb=j+16|0;k=fb-16|0;fb=k;j=fb-16|0;fb=j;d=l+719468|0;e=(((l|0)>-719469?d:l+573372|0)|0)/146097|0;i=D(e,-146097)+d|0;d=((i>>>0)/36524|0)+i-(((i>>>0)/146096|0)+((i>>>0)/1460|0))|0;f=(d>>>0)/365|0;i=((i-((d>>>0)/1460|0)|0)+((d>>>0)/36500|0)|0)+D(f,-365)|0;d=D(i,5)+2|0;g=(d>>>0)/153|0;d=g+(d>>>0<1530?3:-9)|0;f=Kw(j+14|0,(f+D(e,400)|0)+(d>>>0<3)|0);e=kq(j+13|0,d);d=kq(j+12|0,(i-((D(g,153)+2>>>0)/5|0)|0)+1|0);rS(k+12|0,z[f>>1],e,d);fb=j+16|0;d=x[k+12>>2];w[h+44>>1]=d;w[h+46>>1]=d>>>16;fb=k+16|0;f=fb-16|0;fb=f;e=sS(f,l);d=x[e>>2];c=ye(f+8|0,b-d|0,c-(x[e+4>>2]+(b>>>0<d>>>0)|0)|0);b=x[c>>2];fb=f+16|0;i=fb-16|0;fb=i;c=x[c+4>>2];d=ZA(i+8|0,0);m=h,n=vd(tS(b,c,x[d>>2],x[d+4>>2])),v[m+8|0]=n;f=fb-16|0;fb=f;e=ye(f+8|0,0,0);d=x[e>>2];fb=f+16|0;if(tS(b,c,d,x[e+4>>2])<<24>>24<0){d=fb-16|0;fb=d;c=ye(d+8|0,0-b|0,0-(((b|0)!=0)+c|0)|0);b=x[c>>2];fb=d+16|0;c=x[c+4>>2]}d=fb-16|0;fb=d;e=x[vb(d+12|0,Bua(b,c,-694967296,0))>>2];fb=d+16|0;x[h+12>>2]=e;g=fb-16|0;fb=g;f=fb-16|0;fb=f;d=ye(f+8|0,Aua(e,e>>31,-694967296,0),hb);e=x[d>>2];d=x[d+4>>2];fb=f+16|0;x[g>>2]=e;x[g+4>>2]=d;d=x[g>>2];b=ye(g+8|0,b-d|0,c-(x[g+4>>2]+(b>>>0<d>>>0)|0)|0);f=x[b>>2];b=x[b+4>>2];d=b;fb=g+16|0;c=fb-16|0;fb=c;b=x[vb(c+12|0,Bua(f,b,6e7,0))>>2];fb=c+16|0;x[h+16>>2]=b;g=fb-16|0;fb=g;e=fb-16|0;fb=e;b=ye(e+8|0,Aua(b,b>>31,6e7,0),hb);c=x[b>>2];b=x[b+4>>2];fb=e+16|0;x[g>>2]=c;x[g+4>>2]=b;b=x[g>>2];b=ye(g+8|0,f-b|0,d-(x[g+4>>2]+(b>>>0>f>>>0)|0)|0);f=x[b>>2];b=x[b+4>>2];d=b;fb=g+16|0;c=_A(f,b);x[h+24>>2]=c;b=hb;x[h+28>>2]=b;e=fb-16|0;fb=e;c=Gu(e,c,b);b=x[c>>2];c=ye(e+8|0,f-b|0,d-(x[c+4>>2]+(b>>>0>f>>>0)|0)|0);b=x[c>>2];fb=e+16|0;m=h,n=WQ(b,x[c+4>>2]),x[m+32>>2]=n;x[h+36>>2]=hb;fb=i+16|0;b=uS(a);x[b>>2]=z[h+44>>1]<<16>>16;m=b,n=zf(y[h+46|0]),x[m+4>>2]=n;m=b,n=zf(y[h+47|0]),x[m+8>>2]=n;x[b+12>>2]=x[h+12>>2];x[b+16>>2]=x[h+16>>2];a=x[h+28>>2];x[b+24>>2]=x[h+24>>2];x[b+28>>2]=a;fb=h+48|0}function Cna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb+-64|0;fb=d;w[d+62>>1]=c;Hf(d+62|0,32);j=Nb(a);x[31609]=0;n=z[d+62>>1];O(538,j|0,n|0);a=x[31609];x[31609]=0;a:{b:{if((a|0)!=1){o=b+900380|0;while(1){c:{d:{if((q&65535)>>>0<n>>>0){f=1;c=z[b+480190>>1];a=c+1|0;w[d+60>>1]=a;if((a&65535)>>>0<4e3){break d}e:{while(1){g=f&65535;if(g>>>0>c>>>0){break e}f:{e=ni(b,g);if(!le(x[e>>2],x[e+20>>2])){if(!Ib(NC(wb(x[j>>2]),wb(x[j+4>>2]),f),wb(x[j+4>>2]))){break f}c=z[b+480190>>1]}f=f+1|0;continue}break}w[d+60>>1]=f;a=1;while(1){c=a&65535;if(c>>>0>z[b+480192>>1]){a=f}else{g:{c=x[(c<<2)+o>>2];if(!c){break g}c=c+236|0;e=ur(c);while(1){if((c|0)==(e|0)){break g}if((g|0)==z[c>>1]){w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}}if((a&65535)>>>0<4e3){break d}f=To(d+48|0);x[31609]=0;a=P(777,b|0,f|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break b}if(a){x[31609]=0;O(778,b|0,f|0);c=x[31609];x[31609]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=z[b+480192>>1]){h:{c=x[(c<<2)+o>>2];if(!c){break h}c=c+236|0;g=ur(c);while(1){if((c|0)==(g|0)){break h}e=z[c>>1];i:{if(e>>>0>=A[d+52>>2]){break i}Jb(d+40|0,x[f>>2],e);if(Gb(x[x[d+40>>2]>>2],x[d+44>>2])){break i}w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}mn(d+24|0,x[f>>2]);uV(d+32|0,x[d+24>>2],x[d+28>>2],1);$q(d+16|0,x[f>>2],x[d+52>>2]);l=fb-16|0;fb=l;g=d+40|0;e=Zb(l,x[d+32>>2],x[d+36>>2]);a=gv(x[d+16>>2],x[d+20>>2],x[d+32>>2],x[d+36>>2]);c=fb-16|0;fb=c;x[c+12>>2]=a;h=x[e+4>>2];j:{if(h){i=32-h|0;x[c+8>>2]=i;m=x[Hb(c+8|0,c+12|0)>>2];k=-1<<h&-1>>>i-m;i=x[e>>2];k=k&(x[i>>2]^-1);if(k){Zb(g,i,zua(k));break j}if((a|0)==(m|0)){uV(g,i,h,a);break j}a=a-m|0;x[c+12>>2]=a;x[e>>2]=i+4}while(1){if(a>>>0>=32){h=x[e>>2];i=x[h>>2];if((i|0)!=-1){Zb(g,h,zua(i^-1));break j}else{x[e>>2]=h+4;a=a-32|0;x[c+12>>2]=a;continue}}break}e=x[e>>2];if(!a){Zb(g,e,0);break j}h=(x[e>>2]^-1)&-1>>>32-a;if(!h){Zb(g,e,a);break j}Zb(g,e,zua(h))}fb=c+16|0;fb=l+16|0;mn(d+8|0,x[f>>2]);a=gv(x[d+40>>2],x[d+44>>2],x[d+8>>2],x[d+12>>2]);w[d+60>>1]=a;tf(f);if((a&65535)>>>0<4e3){break d}break c}tf(f)}fb=d- -64|0;return}x[31609]=0;O(257,j|0,d+60|0);c=x[31609];x[31609]=0;if((c|0)!=1){if(z[b+480190>>1]>=(a&65535)>>>0){break c}w[b+480190>>1]=a;break c}c=N()|0;break a}q=q+1|0;continue}}c=N()|0;break a}c=N()|0;tf(f)}od(j);Q(c|0);p()}function rV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-32|0;fb=c;e=y[a+13|0];a:{if(e&227|(e&24)==16){break a}e=y[a+8|0];f=y[a+6|0]|y[a+7|0]<<8;v[c+22|0]=0;v[c+26|0]=e;w[c+24>>1]=f;w[c+20>>1]=0;while(1){if((d|0)!=3){e=xb(c+24|0,d);h=xb(c+20|0,d),i=y[e|0],v[h|0]=i;d=d+1|0;continue}break}e=cg(c+20|0);f=y[a+11|0];g=y[a+9|0]|y[a+10|0]<<8;d=0;v[c+18|0]=0;v[c+26|0]=f;w[c+24>>1]=g;w[c+16>>1]=0;while(1){if((d|0)!=3){f=xb(c+24|0,d);h=xb(c+16|0,d),i=y[f|0],v[h|0]=i;d=d+1|0;continue}break}d=0;if(cg(c+16|0)>>>0<e>>>0){break a}e=a+6|0;d=a+9|0;f=y[d+2|0];g=y[d|0]|y[d+1|0]<<8;d=0;v[c+22|0]=0;v[c+26|0]=f;w[c+24>>1]=g;w[c+20>>1]=0;while(1){if((d|0)!=3){f=xb(c+24|0,d);h=xb(c+20|0,d),i=y[f|0],v[h|0]=i;d=d+1|0;continue}break}f=cg(c+20|0);g=y[e+2|0];e=y[e|0]|y[e+1|0]<<8;d=0;v[c+18|0]=0;v[c+26|0]=g;w[c+24>>1]=e;w[c+16>>1]=0;while(1){if((d|0)!=3){e=xb(c+24|0,d);h=xb(c+16|0,d),i=y[e|0],v[h|0]=i;d=d+1|0;continue}break}e=cg(c+16|0);b:{if(!((b|0)==2|(e|0)==(f|0))){d=0;if((y[a+14|0]|y[a+15|0]<<8)>>>0>=100){break b}break a}if((e|0)==(f|0)|(b|0)!=2){break b}d=0;if((y[a+14|0]|y[a+15|0]<<8)<<16>>16<0){break a}}b=y[a+13|0];e=f-e|0;if(e&1){d=0;if(b&4){break a}}c:{if(b&8){b=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;d=0;v[c+22|0]=0;w[c+24>>1]=f;v[c+26|0]=b;w[c+20>>1]=0;while(1){if((d|0)!=3){b=xb(c+24|0,d);h=xb(c+20|0,d),i=y[b|0],v[h|0]=i;d=d+1|0;continue}break}if(!cg(c+20|0)){break c}}b=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;d=0;v[c+22|0]=0;v[c+26|0]=b;w[c+24>>1]=f;w[c+20>>1]=0;while(1){if((d|0)!=3){b=xb(c+24|0,d);h=xb(c+20|0,d),i=y[b|0],v[h|0]=i;d=d+1|0;continue}break}if(cg(c+20|0)){b=a+3|0;f=y[b+2|0];g=y[b|0]|y[b+1|0]<<8;d=0;v[c+18|0]=0;w[c+24>>1]=g;v[c+26|0]=f;w[c+16>>1]=0;while(1){if((d|0)!=3){f=xb(c+24|0,d);h=xb(c+16|0,d),i=y[f|0],v[h|0]=i;d=d+1|0;continue}break}if(cg(c+16|0)>>>0>=e>>>0){break c}e=y[a+2|0];a=y[a|0]|y[a+1|0]<<8;d=0;v[c+14|0]=0;w[c+24>>1]=a;v[c+26|0]=e;w[c+12>>1]=0;while(1){if((d|0)!=3){a=xb(c+24|0,d);h=xb(c+12|0,d),i=y[a|0],v[h|0]=i;d=d+1|0;continue}break}a=cg(c+12|0);e=y[b+2|0];b=y[b|0]|y[b+1|0]<<8;d=0;v[c+10|0]=0;v[c+26|0]=e;w[c+24>>1]=b;w[c+8>>1]=0;while(1){if((d|0)!=3){b=xb(c+24|0,d);h=xb(c+8|0,d),i=y[b|0],v[h|0]=i;d=d+1|0;continue}break}d=0;if(cg(c+8|0)>>>0<=a>>>0){break a}}d=1;break a}d=0}fb=c+32|0;return d}function n_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-80|0;fb=g;a:{b:{c:{d:{e:{f:{g:{if(Ad(x[b+4>>2],y[b+11|0])){Fb(a);break g}k=Nb(g+68|0);x[g+56>>2]=0;x[g+60>>2]=0;h=x[c>>2];x[31609]=0;n=R(38,h|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break b}h=Kb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Kk(n);f=fb-16|0;fb=f;x[f+12>>2]=j;x[f+8>>2]=0;j=x[Ye(f+8|0,f+12|0)>>2];fb=f+16|0;x[31609]=0;O(39,k|0,D(i,j+1|0)|0);f=x[31609];x[31609]=0;if((f|0)==1){break c}o=(i<<2)+h|0;i=x[k>>2];m=i+Xc(i,x[k+4>>2])|0;q=(d|0)!=2;h:{while(1){i:{j:{k:{l:{if(!q){while(1){x[g+48>>2]=0;x[g+52>>2]=0;x[31609]=0;f=h+4|0;j=za(40,n|0,g+56|0,h|0,f|0,g+52|0,i|0,m|0,g+48|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break f}if((j|0)!=1){break l}if((f|0)!=x[g+52>>2]){l=1;break k}else{i=x[g+48>>2];h=f;continue}}}x[g+48>>2]=0;x[g+52>>2]=0;x[31609]=0;j=za(40,n|0,g+56|0,h|0,o|0,g+52|0,i|0,m|0,g+48|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}l=1;if((j|0)==1){break k}}l=2;f=x[g+48>>2];if((j|0)!=2|(m|0)!=(f|0)){break j}}h=x[k+4>>2];f=x[k>>2];x[31609]=0;O(39,k|0,Xc(f,h)<<1);h=x[31609];x[31609]=0;if((h|0)==1){break d}h=x[k>>2];f=x[g+48>>2];i=h+(f-i|0)|0;m=Xc(h,x[k+4>>2])+h|0;j=l;break i}m:{n:{o:{p:{q:{switch(d|0){case 0:if(x[g+52>>2]!=(h|0)|(f|0)!=(i|0)|(j|0)!=2){break p}x[31609]=0;v[g+47|0]=1;h=P(41,g+8|0,22296)|0;f=x[31609];x[31609]=0;r:{s:{t:{if((f|0)!=1){x[31609]=0;f=g+20|0;S(42,f|0,h|0,b|0);i=x[31609];x[31609]=0;if((i|0)==1){break t}x[31609]=0;i=g+32|0;aa(43,i|0,f|0,c|0,1,g+47|0);l=x[31609];x[31609]=0;if((l|0)==1){break s}tb(i);Ub(f);Ub(h);if(y[g+47|0]){break o}x[31609]=0;aa(43,a|0,b|0,c|0,2,0);a=x[31609];x[31609]=0;if((a|0)!=1){break h}f=N()|0;break a}f=N()|0;break a}f=N()|0;break r}f=N()|0;Ub(g+20|0)}Ub(h);break a;case 1:break q;default:break p}}v[e|0]=(j|0)!=2|x[g+52>>2]!=(h|0)|(f|0)!=(i|0);Fb(a);break h}if((j|0)==2){break n}break m}f=x[g+48>>2]}x[g+52>>2]=x[g+52>>2]+4;v[f|0]=63;f=x[g+48>>2]+1|0;x[g+48>>2]=f}i=f}h=x[g+52>>2];l=o>>>0>h>>>0;if(l&f>>>0<m>>>0&(j|0)==2|l&(d|0)==2){continue}break}b=x[k>>2];x[31609]=0;U(44,a|0,b|0,f|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}}fc(k)}fb=g+80|0;return}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0}fc(k);Q(f|0);p()}function Yu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=fb-16|0;fb=i;g=x[a+24>>2];h=NB(g,y[a+32|0]);k=x[h>>2];a:{if($c(k,x[h+4>>2])>>>0<=b>>>0){break a}if(bU(x[g+484344>>2],x[g+484348>>2],z[ac(k,b)>>1])>>>0<=c>>>0){break a}h=x[a>>2];b:{if(Ud(h,x[a+4>>2])>>>0>b>>>0){if(A[Vd(h,b)+4>>2]>c>>>0){break b}}Mo(a,0);if(Ud(x[a>>2],x[a+4>>2])>>>0<=b>>>0){break a}g=x[a+24>>2]}cc(i,x[d>>2],z[g+480188>>1]);h=i+8|0;l=x[i>>2];d=e?-2046629010:-2078137563;k=e?-1352371636:-873292572;e=x[i+4>>2];while(1){if(!f&(e|0)==(j|0)){x[h>>2]=d;x[h+4>>2]=k}else{g=y[cW(l,j)+841|0];m=g^Aua(d^j,f^k,435,256);g=!g;d=(q=d,r=Aua(m,hb,435,256),s=g,s?q:r);k=g?k:hb;j=j+1|0;f=j?f:f+1|0;continue}break}g=0;d=bn(i,b,c);f=fb-16|0;fb=f;k=a+12|0;e=k;j=ST(z[d>>1],x[d+4>>2],de(e),gc(e));c:{if(Ib(j,pg(e))){m=z[d>>1];l=x[d+4>>2];d=ud(j);if(!Ol(m,l,z[d>>1],x[d+4>>2])){break c}}j=pg(e)}d=x[vb(f+12|0,j)>>2];fb=f+16|0;if(Zg(d,Pf(k))){e=ud(d);g=mc(x[e+8>>2],x[e+12>>2])^1}l=x[h>>2]!=-2078137563|x[h+4>>2]!=-873292572;Jb(i,x[Vd(x[a>>2],b)>>2],c);j=1;o=Gb(x[x[i>>2]>>2],x[i+4>>2])^1;e=g|l;if(!(o|e)){break a}d:{e:{f:{g:{if(g){n=ud(d);d=wb(x[n+8>>2]);m=d;e=wb(x[n+12>>2]);f=x[h>>2];p=x[h+4>>2];while(1){h:{i:{if((d|0)!=(e|0)){if(!bo(x[d>>2],x[d+4>>2],f,p)){break i}}else{d=e}break h}d=d+8|0;continue}break}e=fb-16|0;fb=e;x[e+12>>2]=m;x[e+12>>2]=x[e+12>>2]+(d-m&-8);fb=e+16|0;if(Ib(x[e+12>>2],wb(x[n+12>>2]))){break a}if(!l){break e}break g}if(l){break g}if(!e){break d}break f}x[a+28>>2]=x[a+28>>2]+1}if(g|o){break e}d=QT(k,bn(i,b,c));j:{if(A[d+4>>2]<A[Ab(d)>>2]){e=fb-16|0;fb=e;d=PT(e+4|0,d);NT(x[d+4>>2]);x[d+4>>2]=x[d+4>>2]+8;jc(d);fb=e+16|0;break j}f=fb-32|0;fb=f;e=Ab(d);e=js(f+12|0,ks(d,ih(x[d>>2],x[d+4>>2])+1|0),ih(x[d>>2],x[d+4>>2]),e);NT(x[e+8>>2]);x[e+8>>2]=x[e+8>>2]+8;MB(d,e);is(e);fb=f+32|0}}d=QT(k,bn(i,b,c));k:{if(A[d+4>>2]<A[Ab(d)>>2]){e=fb-16|0;fb=e;d=PT(e+4|0,d);OT(x[d+4>>2],x[h>>2],x[h+4>>2]);x[d+4>>2]=x[d+4>>2]+8;jc(d);fb=e+16|0;break k}f=fb-32|0;fb=f;e=Ab(d);e=js(f+12|0,ks(d,ih(x[d>>2],x[d+4>>2])+1|0),ih(x[d>>2],x[d+4>>2]),e);OT(x[e+8>>2],x[h>>2],x[h+4>>2]);x[e+8>>2]=x[e+8>>2]+8;MB(d,e);is(e);fb=f+32|0}}Jb(i,x[Vd(x[a>>2],b)>>2],c);kf(i,1);j=0}fb=i+16|0;return j|0}function h1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=fb-368|0;fb=e;yc(b);d=fb-16|0;fb=d;g=e+330|0;hF(d+8|0,g);h=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(h|0)){Vb(b,x[d+12>>2])}fb=d+16|0;d=(h|0)==(i|0);if(!d){gF(g)}a:{if(!d){break a}if(!jF(g)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(iF(y[e+365|0]),hb))){break a}f=1;if((c|0)==64){break a}Dd(a,2097152);eg(a);Uh(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[e+362|0];x[a+480204>>2]=D(y[e+363|0],1e4);w[a+480190>>1]=y[e+364|0];d=y[e+367|0];if(d>>>0<y[e+366|0]){$e(Xb(x[a+484360>>2],y[a+484376|0]),d)}d=e- -64|0;f=uc(d,6554);zb(a+1298344|0,f);tb(f);f=uc(d,11164);zb(a+1298356|0,f);tb(f);o=a,p=x[Fc(d,4)>>2],x[o+1298404>>2]=p;Hw(b,d);Qr(Xb(x[a+484360>>2],y[a+484376|0]),d,y[e+366|0],65535,65535);l=a+946304|0;i=a+484380|0;f=1;while(1){j=f&65535;if(j>>>0>z[a+480190>>1]){Vb(b,D(64-y[e+364|0]|0,37));h=a+484344|0;Tf(h,y[e+365|0]);j=c&1;f=0;while(1){b:{c:{if(y[e+365|0]<=f>>>0){if(!(c&2)){break c}c=Zc(e+24|0,8,1,0,0);f=1;while(1){d=f&65535;if(d>>>0>z[a+480190>>1]){break c}dg(c,i+D(d,104)|0,b);f=f+1|0;continue}}d:{if(j){if(Pg(h,f&65535,64)){break d}}Vb(b,2048);break b}d=Wb(x[h>>2],f);o=e,p=wb(x[d>>2]),x[o+24>>2]=p;l=wb(x[d+4>>2]);while(1){d=x[e+24>>2];if(!Ib(d,l)){break b}g=e+12|0;lm(g,b);k=Jc(g);n=_e(g);g=Yi(g);m=y[e+12|0];if((m-1&255)>>>0<=106){v[d|0]=m+13}v[d+1|0]=y[k|0];Cf(d,y[n|0],y[g|0]);tg(e+24|0);continue}}f=1;break a}f=f+1|0;continue}}else{d=e+24|0;fF(b,d);h=fb-16|0;fb=h;g=i+D(j,104)|0;nd(g,0);v[g+37|0]=y[d+22|0]<<4;v[h+15|0]=y[d+23|0];v[h+14|0]=64;o=g,p=y[Qb(h+15|0,h+14|0)|0]<<2,w[o+30>>1]=p;v[g+36|0]=y[d+24|0];x[g>>2]=y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24);k=y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24);if(!(k>>>0<3|k+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))>>>0>(y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24))>>>0)){w[g+34>>1]=z[g+34>>1]|2;x[g+4>>2]=y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24);x[g+8>>2]=(y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24))+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))}fb=h+16|0;Rk(e,2,d);d=e+12|0;Cc(d,e);Ac(l+(j<<5)|0,d);f=f+1|0;tb(d);continue}}}fb=e+368|0;return f|0}function $na(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=fb-16|0;fb=k;e=x[b>>2];d=Mg(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){n=fb-32|0;fb=n;d=c-d|0;f=x[Ab(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){h=fb-16|0;fb=h;e=mC(h+4|0,b,d);d=x[e+4>>2];g=x[e+8>>2];while(1){if((d|0)==(g|0)){jc(e);fb=h+16|0}else{GV(d);d=d+32|0;x[e+4>>2]=d;continue}break}break b}h=Ab(b);h=iv(n+12|0,Wq(b,Mg(x[b>>2],e)+d|0),Mg(x[b>>2],x[b+4>>2]),h);g=fb-16|0;fb=g;d=IV(g+4|0,h+8|0,d);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){GV(e);e=x[d>>2]+32|0;x[d>>2]=e;continue}break}je(d);fb=g+16|0;l=fb-16|0;fb=l;d=vb(l+12|0,x[b+4>>2]);e=vb(l+8|0,x[b>>2]);f=x[vb(l+4|0,x[h+4>>2])>>2];m=fb-16|0;fb=m;o=m+8|0;g=fb-32|0;fb=g;fd(g+24|0,x[d>>2],x[e>>2]);p=g+16|0;d=x[g+24>>2];q=x[g+28>>2];j=fb-16|0;fb=j;x[j+8>>2]=f;x[j+12>>2]=d;while(1){if(Fd(d,q)){d=en(d);e=en(x[j+8>>2]);f=y[d+28|0]|y[d+29|0]<<8|(y[d+30|0]<<16|y[d+31|0]<<24);i=y[d+24|0]|y[d+25|0]<<8|(y[d+26|0]<<16|y[d+27|0]<<24);v[e+24|0]=i;v[e+25|0]=i>>>8;v[e+26|0]=i>>>16;v[e+27|0]=i>>>24;v[e+28|0]=f;v[e+29|0]=f>>>8;v[e+30|0]=f>>>16;v[e+31|0]=f>>>24;f=y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24);i=y[d+16|0]|y[d+17|0]<<8|(y[d+18|0]<<16|y[d+19|0]<<24);v[e+16|0]=i;v[e+17|0]=i>>>8;v[e+18|0]=i>>>16;v[e+19|0]=i>>>24;v[e+20|0]=f;v[e+21|0]=f>>>8;v[e+22|0]=f>>>16;v[e+23|0]=f>>>24;f=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);i=y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24);v[e+8|0]=i;v[e+9|0]=i>>>8;v[e+10|0]=i>>>16;v[e+11|0]=i>>>24;v[e+12|0]=f;v[e+13|0]=f>>>8;v[e+14|0]=f>>>16;v[e+15|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e|0]=d;v[e+1|0]=d>>>8;v[e+2|0]=d>>>16;v[e+3|0]=d>>>24;v[e+4|0]=f;v[e+5|0]=f>>>8;v[e+6|0]=f>>>16;v[e+7|0]=f>>>24;d=Uo(j+12|0);Uo(j+8|0);d=x[d>>2];continue}break}qc(p,d,j+8|0);fb=j+16|0;d=x[g+16>>2];x[g+12>>2]=x[g+20>>2];qc(o,d,g+12|0);fb=g+32|0;fb=m+16|0;x[h+4>>2]=x[m+12>>2];Tb(b,h+4|0);Tb(b+4|0,h+8|0);Tb(Ab(b),nc(h));x[h>>2]=x[h+4>>2];fb=l+16|0;KV(h)}fb=n+32|0;break a}if(c>>>0<d>>>0){Jd(b,e+(c<<5)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<5)){c=x[b>>2];cc(k+8|0,c,Mg(c,x[b+4>>2])<<5);sd(k,a,x[k+8>>2],x[k+12>>2])}fb=k+16|0}function Qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-144|0;fb=d;i=JM(d+128|0);x[i>>2]=48636;Nb(i+4|0);vo(x[a+24>>2],i);e=x[a+24>>2];f=y[a+62|0];g=y[a+61|0];h=y[a+60|0];b=He(d+108|0,b);x[31609]=0;k=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=k;x[d+16>>2]=x[b+16>>2];k=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=k;b=h?13:15;b=g?b&14:b;b=U(1155,e|0,d|0,(f?b&3:b)|0)|0;e=x[31609];x[31609]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=dc(8);x[31609]=0;c=P(36,d+96|0,12026)|0;a=x[31609];x[31609]=0;if((a|0)!=1){sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;lc(b);break b}if(!y[a+63|0]){x[31609]=0;O(1156,a|0,a+36|0);b=x[31609];x[31609]=0;if((b|0)==1){break e}}v[a+28|0]=1;vo(x[a+24>>2],x[a+4>>2]);x[31609]=0;O(1157,d+96|0,i|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}m=d,n=wb(x[d+96>>2]),x[m+92>>2]=n;k=a+68|0;l=wb(x[d+100>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=x[d+92>>2];if(!Ib(b,l)){b=Ti(x[c>>2]);x[d+80>>2]=b;c=Pf(c);while(1){if(!Zg(b,c)){break d}x[31609]=0;e=ud(b);b=P(71,d+20|0,e|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break h}x[31609]=0;V(1012,a|0,b|0,e+12|0,0);e=x[31609];x[31609]=0;if((e|0)==1){break g}tb(b);b=x[ah(d+80|0)>>2];continue}}e=x[a+24>>2];f=x[b>>2];x[31609]=0;j=b+4|0;S(1158,e|0,f|0,j|0);e=x[31609];x[31609]=0;if((e|0)!=1){b=x[b>>2];x[31609]=0;e=d+44|0;O(1159,e|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break r}x[31609]=0;f=d+56|0;O(1059,f|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break q}x[31609]=0;b=P(36,d+32|0,18407)|0;g=x[31609];x[31609]=0;if((g|0)==1){break p}x[31609]=0;g=d+68|0;S(1015,g|0,f|0,b|0);h=x[31609];x[31609]=0;if((h|0)==1){break o}x[31609]=0;h=d+80|0;S(544,h|0,g|0,j|0);j=x[31609];x[31609]=0;if((j|0)==1){break n}x[31609]=0;O(178,k|0,h|0);j=x[31609];x[31609]=0;if((j|0)==1){break m}tb(h);tb(g);tb(b);tb(f);tb(e);Vo(d+92|0);continue}break}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;break j}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+80|0)}tb(d+68|0)}tb(b)}tb(d+56|0)}tb(d+44|0);break f}a=N()|0;break f}a=N()|0;tb(b)}vz(d+96|0);break b}a=N()|0;break b}vz(d+96|0);$t(i);fb=d+144|0;return}a=N()|0}$t(i);Q(a|0)}p()}function eda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;m=fb-32|0;fb=m;j=rf(m+20|0,1,0);a:{b:{while(1){e=Kb(j);i=e+Cb(x[j+4>>2],y[j+11|0])|0;g=x[b>>2];d=x[b+4>>2];if(!((d|0)>=0|(d|0)>0|(e|0)==(i|0))){v[e|0]=45;e=e+1|0;g=VN(g,d);d=hb}k=m+12|0;c:{d:{switch(Dua(c-2|0,31)|0){case 4:ON(k,e,i,g,d);break c;case 0:f=64-eu(g|1,d)|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<17){while(1){e=e-1|0;v[e|0]=y[(g&1)+15515|0];h=!d&g>>>0>1|(d|0)!=0;f=d;d=d>>>1|0;g=(f&1)<<31|g>>>1;if(h){continue}break}}else{e=e-4|0;_m((g<<2&60)+78560|0,4,e);f=d;d=d>>>4|0;g=(f&15)<<28|g>>>4;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 3:f=(66-eu(g|1,d)>>>0)/3|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<65){while(1){e=e-1|0;v[e|0]=y[(g&7)+14812|0];h=!d&g>>>0>7|(d|0)!=0;f=d;d=d>>>3|0;g=(f&7)<<29|g>>>3;if(h){continue}break}}else{e=e-2|0;_m((g<<1&126)+78624|0,2,e);f=d;d=d>>>6|0;g=(f&63)<<26|g>>>6;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 7:f=67-eu(g|1,d)>>>2|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<257){while(1){e=e-1|0;v[e|0]=y[(g&15)+11181|0];h=!d&g>>>0>15|(d|0)!=0;f=d;d=d>>>4|0;g=(f&15)<<28|g>>>4;if(h){continue}break}}else{e=e-2|0;_m((g<<1&510)+78752|0,2,e);f=d;d=d>>>8|0;g=(f&255)<<24|g>>>8;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;default:break d}}f=g;h=d;n=D(c,c);q=D(n,c);r=D(n,n);o=0;e:{while(1){l=o|1;if(!h&c>>>0>f>>>0){break e}l=o|2;if(!h&f>>>0<n>>>0){break e}l=o|3;if(!h&f>>>0<q>>>0){break e}if(!h&f>>>0<r>>>0){l=o+4|0}else{o=o+4|0;f=Cua(f,h,r,0);h=hb;continue}break}}h=l;if((h|0)>(i-e|0)){x[k+4>>2]=61;x[k>>2]=i;break c}q=e+h|0;e=q;while(1){e=e-1|0;h=Cua(g,d,c,0);f=hb;s=e,t=y[(g-Aua(h,f,c,0)|0)+4895|0],v[s|0]=t;n=!d&c>>>0<=g>>>0|(d|0)!=0;g=h;d=f;if(n){continue}break}x[k+4>>2]=0;x[k>>2]=q}if(!x[m+16>>2]){break b}d=ki(Cb(x[j+4>>2],y[j+11|0]));x[31609]=0;O(45,j|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){continue}break}break a}c=x[m+12>>2];b=Kb(j);x[31609]=0;O(46,j|0,c-b|0);b=x[31609];x[31609]=0;f:{if((b|0)!=1){x[31609]=0;O(47,a|0,j|0);a=x[31609];x[31609]=0;if((a|0)!=1){break f}break a}break a}tb(j);fb=m+32|0;return}a=N()|0;tb(j);Q(a|0);p()}function vja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-16|0;fb=h;f=x[a+8>>2];e=x[a>>2];x[31609]=0;f=P(622,e|0,f|0)|0;e=x[31609];x[31609]=0;a:{b:{if((e|0)!=1){if(f){break b}x[31609]=0;f=R(197,a|0)|0;e=x[31609];x[31609]=0;c:{if((e|0)==1){break c}x[31609]=0;j=d+484344|0;k=Ld(f+1|0,1,1024);f=U(196,j|0,b|0,k|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break c}if(!f){break b}d=z[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=x[a+8>>2];e=x[a>>2];x[31609]=0;f=U(150,e|0,f|0,1)|0;e=x[31609];x[31609]=0;d:{if((e|0)!=1){if(!f){break b}x[31609]=0;i=R(197,a|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=x[j>>2];w[h+14>>1]=i&31;w[h+12>>1]=l;e=Wb(e,b);e=md(x[e>>2],x[x[e+48>>2]+12>>2],d,z[Oc(h+14|0,h+12|0)>>1]);if(i>>>0<32){continue}e:{if(i<<24>>24>=0){break e}x[31609]=0;g=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break a}v[e+5|0]=g;x[31609]=0;g=R(197,a|0)|0;f=x[31609];x[31609]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=y[g+41088|0];v[e+3|0]=f;h:{switch(f-1|0){case 0:if(!y[e+5|0]){break f}break e;case 12:if(y[e+2|0]){break e}v[e+2|0]=1;f=y[e+5|0];v[e+5|0]=0;v[e+3|0]=0;m=e,n=Ld(f,0,64),v[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=y[e+5|0]&240;if(!f){break e}v[e+5|0]=f;break e;case 8:f=y[e+5|0];if(f>>>0<=128){m=e,n=Eh(f<<1),v[m+5|0]=n;break e}if((f|0)!=164){break e}v[e+5|0]=145;v[e+3|0]=20;break e;case 13:f=y[e+5|0];v[e+5|0]=D(f>>>4|0,10)+(f&15);break e;case 18:Lr(e);break e;case 16:if(y[e+5|0]>31){break e}v[e+3|0]=16;break e;case 27:break h;default:break e}}g=y[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}v[e+3|0]=f}v[e+5|0]=g&15|224;break e}v[e+3|0]=0}j:{k:{if(!(i&64)){break k}x[31609]=0;g=h+10|0;O(198,g|0,a|0);f=x[31609];x[31609]=0;if((f|0)==1){break j}v[e+1|0]=y[h+10|0];g=y[Jc(g)|0];v[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}v[e|0]=f}if(!(i&32)){continue}v[e+2|0]=1;x[31609]=0;g=R(197,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break a}v[e+4|0]=g;if(!c){continue}v[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}ub(a);fb=h+16|0;return}b=N()|0;ub(a);Q(b|0);p()}function Ala(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;f=fb-48|0;fb=f;A=x[a+16>>2];B=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;r=x[a+128>>2];if(r){k=x[a+8>>2];g=x[a+12>>2];s=Hg(k,g,r);t=hb;h=x[a+76>>2];fg(x[a>>2],x[a+4>>2],uf(k,g,d),hb);q=hb>>>0>h>>>0?d:0}else{q=0}j=a+112|0;w=a+44|0;u=f+24|0;while(1){if((b|0)!=2){g=b<<3;h=g+u|0;g=g+w|0;x[h>>2]=x[g>>2];x[h+4>>2]=x[g+4>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;C=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;q=q-1|0;h=q;s=h?s:0;t=h?t:0;k=(((g&2147483647)<<1|b>>>31)&-2)+A|0;g=r;a:{b:while(1){c:{if((g|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){ce(j,i>>>3<<16>>16);be(j,4);Pb(f+40|0,s,t);g=g-1|0;continue b}else{i=(v[k+(b|h)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b|g)|0]<<8)+i|0;b=b+1|0;continue}break}ce(j,i>>>3<<16>>16);be(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Fg(j,B);x[f+4>>2]=b;x[f>>2]=b;F=x[a+72>>2];i=x[a+68>>2];G=i>>31;k=x[a+64>>2];H=k>>31;h=x[a+60>>2];I=h>>31;b=0;while(1){if((b|0)!=2){y=(b<<2)+f|0;e=x[y>>2];g=(b<<3)+u|0;J=x[g+4>>2];l=x[g>>2];x[g+4>>2]=l;z=e<<8;e=z;e=Aua(e,e>>31,h,I);m=hb;n=e;e=Yb(l,-16777216,16776704);e=Aua(k,H,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Yb(J,-16777216,16776704);m=Aua(i,G,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Sc(m,e,24);x[g>>2]=e-(F&z);x[y>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];p=x[a+28>>2]+p|0;x[c>>2]=x[c>>2]+D(x[f>>2],p>>12);o=b+o|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],o>>12);Pb(f+8|0,C,E);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+w|0;a=a+u|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=f+48|0}function Hda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Fb(a);x[31609]=0;X(84);c=x[31609];x[31609]=0;a:{b:{if((c|0)==1){c=Ua(48428,124540,125124,0)|0;d=gb;c:{d:{e:{if(($(48428)|0)==(d|0)){c=Y(c|0)|0;x[31609]=0;b=P(985,a|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break e}x[31609]=0;b=P(985,b|0,18407)|0;d=x[31609];x[31609]=0;if((d|0)==1){break e}x[31609]=0;d=P(985,b|0,18383)|0;b=x[31609];x[31609]=0;if((b|0)==1){break e}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31609]=0;P(985,d|0,(b?b:22292)|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break e}x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=N()|0;break a}f:{if(($(124540)|0)==(d|0)){c=Y(c|0)|0;x[31609]=0;b=P(985,a|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break f}x[31609]=0;b=P(985,b|0,18407)|0;d=x[31609];x[31609]=0;if((d|0)==1){break f}x[31609]=0;d=P(985,b|0,18358)|0;b=x[31609];x[31609]=0;if((b|0)==1){break f}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31609]=0;P(985,d|0,(b?b:22292)|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break f}x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=N()|0;break a}e=$(125124)|0;c=Y(c|0)|0;g:{if((d|0)==(e|0)){x[31609]=0;b=P(985,a|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break g}x[31609]=0;b=P(985,b|0,18407)|0;d=x[31609];x[31609]=0;if((d|0)==1){break g}x[31609]=0;d=P(985,b|0,18374)|0;b=x[31609];x[31609]=0;if((b|0)==1){break g}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31609]=0;P(985,d|0,(b?b:22292)|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break g}x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=N()|0;break a}x[31609]=0;b=P(985,a|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}x[31609]=0;b=P(985,b|0,18407)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}x[31609]=0;P(985,b|0,13836)|0;b=x[31609];x[31609]=0;if((b|0)==1){break d}x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=N()|0;break a}b=N()|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;if((c|0)==1){break c}break a}b=N()|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;if((c|0)!=1){break a}}T(0)|0;Sb()}p()}return}tb(a);Q(b|0);p()}function N0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=fb-48|0;fb=f;l=f+29|0;m=f+27|0;n=Ng(f+42|0);while(1){a:{if(A[a+12>>2]>j>>>0){af(f+32|0,x[a>>2],x[x[a+48>>2]+12>>2],j);b:while(1){if(!Mb(x[c>>2],x[c+8>>2],1)){break a}e=Zd(c);if((e|0)==255){break a}g=n;k=e<<24>>24;e=k&31;if(e>>>0<z[x[x[a+48>>2]+12>>2]+480188>>1]){g=Yc(x[f+32>>2],e)}d=1;if(!(k&64)){e=Zd(c);i=e<<24>>24;d=255;e=e&127;c:{d:{if((e|0)==1){break d}d=e-1|0;if(b?d>>>0<=120:0){break d}if((e-109&255)>>>0<159|b){break c}d=e+13|0}v[g|0]=d}q=g,r=Zd(c),v[q+1|0]=r;d=(i|0)<0}i=g+3|0;e=g+5|0;while(1){e:{f:{g:{if(d&1){w[f+28>>1]=y[g+4|0]|y[g+5|0]<<8;x[f+24>>2]=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);d=Zd(c);h=d&63;o=d<<24>>24;if(d&64){v[g+4|0]=h;v[g+2|0]=1;break e}d=Zd(c);v[e|0]=d;if(h>>>0<=15){Cf(g,h,d);h:{i:{j:{d=y[g+3|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[i|0]=9;v[e|0]=D(y[e|0]&15,17);break f}v[g+2|0]=1;v[g+3|0]=0;x[f+20>>2]=y[g+5|0]+1>>>1;x[f+16>>2]=64;q=g,r=x[Cd(f+20|0,f+16|0)>>2],v[q+4|0]=r;break f}if((d|0)!=19){break f}if(y[e|0]==128){break g}Lr(g);break f}if(h>>>0>44){break f}v[i|0]=y[h+24624|0];k:{switch(h-16|0){case 0:if(d>>>0>1){break g}v[e|0]=d|158;break f;case 1:case 2:v[f+20|0]=15;q=e,r=y[Qb(f+20|0,e)|0]|224,v[q|0]=r;break f;case 5:case 6:x[f+20>>2]=16;x[f+16>>2]=d+1;q=e,r=x[Cd(f+20|0,f+16|0)>>2]/2|240,v[q|0]=r;break f;case 14:l:{m:{n:{o:{p:{h=d>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[i|0]=2;v[e|0]=d|240;break f}v[i|0]=3;v[e|0]=d|240;break f}v[i|0]=11;v[e|0]=(d<<3&120)+8|15;break f}v[i|0]=11;v[e|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+20>>2]=d+1>>>1;x[f+16>>2]=64;q=e,r=x[Cd(f+20|0,f+16|0)>>2],v[q|0]=r;break f}if((k|0)>=0){continue b}break a}v[i|0]=0}vw(i,e,m,l);d=y[f+27|0];p=ri(d);h=y[i|0];if(p>>>0<=ri(h)>>>0){break e}if(!y[g+2|0]){uw(f+14|0,h,y[g+5|0],1);h=y[f+14|0];v[g+4|0]=y[f+15|0];v[g+2|0]=h}v[i|0]=d;v[e|0]=y[f+29|0]}d=(o|0)<0;continue}}}fb=f+48|0;return}j=j+1|0;continue}}function Tz(a){a=a|0;var b=0,c=0,d=E(0),e=0;Rb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[31609]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}aa(973,e|0,67,5,c|0,b|0);b=x[31609];x[31609]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[31609]=0;aa(973,a+4528|0,62,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[31609]=0;aa(973,a+4552|0,53,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[31609]=0;aa(973,a+4576|0,43,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[31609]=0;aa(973,a+4600|0,32,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[31609]=0;aa(973,a+4624|0,22,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[31609]=0;aa(973,a+4648|0,75,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[31609]=0;aa(973,a+4672|0,69,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[31609]=0;aa(973,a+4696|0,60,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[31609]=0;aa(973,a+4720|0,48,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[31609]=0;aa(973,a+4744|0,36,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[31609]=0;aa(973,a+4768|0,25,5,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}x[31609]=0;aa(973,a+4792|0,0,0,0,0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[31609]=0;aa(973,a+4816|0,3,0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[31609]=0;aa(973,a+4840|0,3,0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}x[31609]=0;aa(973,a+4864|0,407,1,c|0,0);b=x[31609];x[31609]=0;if((b|0)==1){break a}x[31609]=0;aa(973,a+4888|0,400,1,c|0,0);b=x[31609];x[31609]=0;if((b|0)==1){break a}x[31609]=0;aa(973,a+4912|0,10,0,c|0,-1);b=x[31609];x[31609]=0;if((b|0)==1){break a}x[31609]=0;aa(973,a+4936|0,10,0,c|0,-1);c=x[31609];x[31609]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=T(124540)|0;if((gb|0)==($(124540)|0)){Y(c|0)|0;v[a+5045|0]=0;Z();return}Q(c|0);p()}function rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=E(0),l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=E(0),w=0,z=0,A=0,C=0,D=0,G=0,H=E(0),I=0,J=0,K=0,L=0,M=0,N=E(0),O=0,P=E(0);a:{if(!x[a+4316>>2]){break a}if(!ti(a+44|0)){break a}D=a+4300|0;G=a+4288|0;I=a+4264|0;J=a+4276|0;e=x[a+44>>2];r=Hc(e,0);s=Hc(e,1);e=x[a+56>>2];t=Hc(e,0);u=Hc(e,1);K=ib[x[x[a>>2]+196>>2]](a)|0;v=E(E(ib[x[x[a>>2]+204>>2]](a))/E(100));H=E(ib[x[x[a>>2]+192>>2]](a));w=ib[x[x[a>>2]+216>>2]](a)|0;L=w&1;o=x[a+4324>>2];l=x[a+4320>>2];m=x[a+4328>>2];j=x[a+4312>>2];M=x[a+4276>>2];p=x[a+4264>>2];z=x[a+4256>>2];A=y[a+4260|0];C=d;while(1){if(C){h=B[s>>2];k=B[r>>2];i=x[a+4316>>2];e=yo(i,j+z|0);i=yo(i,j);b:{if(A){O=yb(G,m),P=k,B[O>>2]=P;O=yb(D,m),P=h,B[O>>2]=P;q=yb(p,e);O=yb(p,i),P=E(E(B[q>>2]*v)+k),B[O>>2]=P;g=E(E(B[yb(M,e)>>2]*v)+h);e=J;break b}g=E(E(B[yb(p,e)>>2]*v)+E(E(k+h)*E(.5)));e=I}O=yb(x[e>>2],i),P=g,B[O>>2]=P;c:{if(K){f=B[a+4244>>2];g=E(f+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(g>E(1)){g=E(g+E(-2));B[a+4236>>2]=g}if(f>E(1)){f=E(f+E(-2));B[a+4240>>2]=f}g=E(F(g));g=E(E(g+g)+E(-1));f=E(F(f));f=E(E(f+f)+E(-1));break c}f=B[a+4240>>2];n=B[a+4244>>2];g=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f-E(g*n));B[a+4240>>2]=f}if(A){e=(m+2|0)%3|0;k=B[yb(G,e)>>2];h=B[yb(D,e)>>2]}e=x[a+4316>>2];i=yb(p,yo(e,j+l|0));q=e;e=j+4096|0;N=B[yb(p,yo(q,e+l|0))>>2];n=B[i>>2];B[t>>2]=E(E(E(E(E(N-n)*E(E(l&4095)*E(.000244140625)))+n)-k)*H)+k;l=x[(A?4276:4264)+a>>2];i=x[a+4316>>2];q=yb(l,yo(i,j+o|0));n=B[yb(l,yo(i,e+o|0))>>2];k=B[q>>2];B[u>>2]=E(E(E(E(E(n-k)*E(E(o&4095)*E(.000244140625)))+k)-h)*H)+h;m=((m|0)<=0?m+3|0:m)-1|0;x[a+4328>>2]=m;j=(((j|0)<=0?x[a+4316>>2]<<12:0)+j|0)-4096|0;x[a+4312>>2]=j;h=L?f:g;f=B[a+4248>>2];h=E(h*f);d:{if(E(F(h))<E(2147483648)){e=~~h;break d}e=-2147483648}o=(w>>>0>1?e:0-e|0)+z|0;x[a+4324>>2]=o;s=s+4|0;r=r+4|0;g=E(g*f);e:{if(E(F(g))<E(2147483648)){e=~~g;break e}e=-2147483648}l=(w>>>0<4?e:0-e|0)+z|0;x[a+4320>>2]=l;C=C-1|0;u=u+4|0;t=t+4|0;continue}else{e=a;a=x[a+56>>2];Ii(e,b,c,Hc(a,0),Hc(a,1),d)}break}}}function zla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;f=fb-48|0;fb=f;A=x[a+16>>2];B=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;q=x[a+128>>2];if(q){i=x[a+8>>2];g=x[a+12>>2];r=Hg(i,g,q);s=hb;h=x[a+76>>2];fg(x[a>>2],x[a+4>>2],uf(i,g,d),hb);p=hb>>>0>h>>>0?d:0}else{p=0}j=a+112|0;u=a+44|0;t=f+24|0;while(1){if((b|0)!=2){g=b<<3;h=g+t|0;g=g+u|0;x[h>>2]=x[g>>2];x[h+4>>2]=x[g+4>>2];b=b+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;C=x[a+8>>2];E=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;p=p-1|0;h=p;r=h?r:0;s=h?s:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+A|0;b=q;while(1)if((b|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;ce(j,(w[((b&2147483646)<<1)+i>>1]+w[i+(b<<1|2)>>1]|0)/8<<16>>16);be(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Fg(j,B);x[f+4>>2]=b;x[f>>2]=b;F=x[a+72>>2];v=x[a+68>>2];G=v>>31;i=x[a+64>>2];H=i>>31;h=x[a+60>>2];I=h>>31;b=0;while(1){if((b|0)!=2){y=(b<<2)+f|0;e=x[y>>2];g=(b<<3)+t|0;J=x[g+4>>2];k=x[g>>2];x[g+4>>2]=k;z=e<<8;e=z;e=Aua(e,e>>31,h,I);l=hb;m=e;e=Yb(k,-16777216,16776704);e=Aua(i,H,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Yb(J,-16777216,16776704);l=Aua(v,G,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Sc(l,e,24);x[g>>2]=e-(F&z);x[y>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];o=x[a+28>>2]+o|0;x[c>>2]=x[c>>2]+D(x[f>>2],o>>12);n=b+n|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],n>>12);Pb(f+8|0,C,E);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;ce(j,(w[((g&2147483646)<<1)+i>>1]+w[i+(g<<1|2)>>1]|0)/8<<16>>16);be(j,4);Pb(f+40|0,r,s);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+u|0;a=a+t|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=f+48|0}function BR(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;a:{b:{c:{if(!gn(f,g,h,i,0,0,0,0)){break c}k=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|k)?3:2;break d}l=!(f|h|(g|k))}}s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(l){break b}}Xd(j+16|0,b,c,d,e,f,g,h,i);b=x[j+16>>2];d=x[j+20>>2];e=x[j+24>>2];c=x[j+28>>2];yS(j,b,d,e,c,b,d,e,c);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}l=d;p=e&2147483647;k=p;n=h;m=i&2147483647;if((gn(b,c,l,k,f,g,h,m)|0)<=0){if(gn(b,c,l,k,f,g,h,m)){h=b;i=c;break a}Xd(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}q=i>>>16&32767;if(o){i=c;h=b}else{Xd(j+96|0,b,c,l,p,0,0,0,1081540608);l=x[j+104>>2];h=x[j+108>>2];p=h;o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){Xd(j+80|0,f,g,n,m,0,0,0,1081540608);n=x[j+88>>2];f=x[j+92>>2];m=f;q=(f>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}r=n;t=m&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){m=l-r|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-k|0;k=(p-((l>>>0<r>>>0)+t|0)|0)-(k>>>0>m>>>0)|0;f:{if((k|0)>=0|(k|0)>0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|n|(i|k))){Xd(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}k=k<<1|n>>>31;l=n<<1|i>>>31;break f}k=p<<1|l>>>31;l=l<<1|i>>>31}p=k;k=i<<1|h>>>31;h=h<<1;i=k;o=o-1|0;if((o|0)>(q|0)){continue}break}o=q}m=l-r|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-k|0;k=(p-((l>>>0<r>>>0)+t|0)|0)-(k>>>0>m>>>0)|0;m=k;g:{if((k|0)<0){n=l;m=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|n|(i|m)){break g}Xd(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((m|0)==65535|m>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m<<1|n>>>31;n=c|n<<1;m=b;if(b>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){Xd(j- -64|0,h,i,n,m&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=n;e=m&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;fb=j+128|0}function bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=0,i=E(0),j=0,k=0,l=E(0),m=E(0),n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=E(0),A=0,C=0,D=0,F=0,G=E(0),H=0,I=0,J=0,K=0,L=0,M=0,N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0),S=0,T=E(0);if(ti(a+44|0)){f=x[a+44>>2];A=Hc(f,0);C=Hc(f,1);f=x[a+56>>2];D=Hc(f,0);F=Hc(f,1);t=x[a+4296>>2];g=t+1|0;k=a+4304|0;f=a+4272|0;u=g+x[yb(f,0)>>2]&4095;o=k+(u<<4)|0;v=g+x[yb(f,1)>>2]&4095;p=((v<<4)+k|0)+4|0;w=g+x[yb(f,2)>>2]&4095;q=((w<<4)+k|0)+8|0;y=g+x[yb(f,3)>>2]&4095;r=((y<<4)+k|0)+12|0;I=a+78032|0;g=a+4232|0;J=a+69840|0;h=x[yb(f,4)>>2];s=x[a+4300>>2];h=h+s|0;j=x[yb(f,5)>>2]+s|0;f=d;while(1){if(f){N=B[r>>2];O=B[q>>2];P=B[p>>2];Q=B[o>>2];z=B[C>>2];R=B[A>>2];u=u-1&4095;o=(u<<4)+k|0;e=B[o>>2];K=h&1023;h=(K<<3)+J|0;i=B[h+4>>2];r=s<<3;q=r+J|0;v=v-1&4095;p=((v<<4)+k|0)+4|0;l=B[p>>2];m=l;n=E(l*E(.6180340051651001));G=B[h>>2];l=B[yb(g,0)>>2];n=E(n+E(G*l));B[q+4>>2]=m+E(n*E(-.6180340051651001));m=e;e=E(E(i*l)+E(e*E(-.6180340051651001)));B[q>>2]=m+E(e*E(.6180340051651001));B[o>>2]=n;B[p>>2]=e;w=w-1&4095;H=(w<<4)+k|0;q=H+8|0;e=B[q>>2];L=j&1023;j=(L<<3)+I|0;l=B[j+4>>2];M=r+I|0;y=y-1&4095;h=(y<<4)+k|0;r=h+12|0;i=B[r>>2];m=i;G=B[j>>2];n=B[yb(g,1)>>2];i=E(E(i*E(.6180340051651001))+E(G*n));B[M+4>>2]=m+E(i*E(-.6180340051651001));m=e;e=E(E(l*n)+E(e*E(-.6180340051651001)));B[M>>2]=m+E(e*E(.6180340051651001));B[H+8>>2]=i;B[h+12>>2]=e;e=E(R+E(1.0000000031710769e-30));B[D>>2]=i+E(E(e*B[a+4224>>2])+B[o>>2]);i=E(z+E(1.0000000031710769e-30));B[F>>2]=E(E(i*B[a+4224>>2])+B[p>>2])+B[h+12>>2];j=(t<<4)+k|0;l=e;e=B[a+4228>>2];z=E(l*e);S=j,T=E(z+E(E(B[o>>2]*B[yb(g,2)>>2])+E(Q*B[yb(g,3)>>2]))),B[S>>2]=T;e=E(i*e);S=j,T=E(e+E(E(B[p>>2]*B[yb(g,4)>>2])+E(P*B[yb(g,5)>>2]))),B[S+4>>2]=T;S=j,T=E(E(E(B[H+8>>2]*B[yb(g,6)>>2])+E(O*B[yb(g,7)>>2]))-e),B[S+8>>2]=T;S=j,T=E(z+E(E(B[h+12>>2]*B[yb(g,8)>>2])+E(N*B[yb(g,9)>>2]))),B[S+12>>2]=T;f=f-1|0;F=F+4|0;D=D+4|0;C=C+4|0;A=A+4|0;j=L-1|0;h=K-1|0;s=s-1&1023;t=t-1&4095;continue}else{x[a+4300>>2]=s;x[a+4296>>2]=t;f=a;a=x[a+56>>2];Ii(f,b,c,Hc(a,0),Hc(a,1),d)}break}}}function dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=fb-48|0;fb=g;i=x[a+8>>2];r=i;f=x[a+12>>2];m=f;a:{b:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){f=131112;i=m;if((i|0)>-2){e=1}else{e=(i|0)>=-2&r>>>0>=3489660928}if(e){break a}f=262184;if((m|0)==-2&r>>>0<2147483648|m>>>0<4294967294){break a}break b}f=262184;if((m|0)==1&r>>>0>2147483648|m>>>0>1){break a}}f=196648}i=f;B=x[a+16>>2];A=a+44|0;y=g+32|0;while(1){if((h|0)!=2){f=h<<3;n=f+y|0;f=f+A|0;x[n>>2]=x[f>>2];x[n+4>>2]=x[f+4>>2];h=h+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;C=b+i|0;E=x[a+32>>2];F=x[a+28>>2];G=x[a+72>>2];n=x[a+68>>2];H=n>>31;f=x[a+64>>2];I=f>>31;i=x[a+60>>2];J=i>>31;while(1){if(d){b=x[g+16>>2];s=((((x[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+B|0;b=(b>>>16&65520)+C|0;K=w[b+14>>1];l=w[b+12>>1];t=w[b+10>>1];z=w[b+8>>1];j=w[b+6>>1];u=w[b+4>>1];k=w[b+2>>1];e=w[b>>1];h=0;b=0;while(1){if((b|0)!=2){v=b<<1;q=v+s|0;x[(g+8|0)+(b<<2)>>2]=(((((((D(w[s+(v|-8)>>1],k)+D(w[s+(v|-12)>>1],e)|0)+D(w[s+(v|-4)>>1],u)|0)+D(w[q>>1],j)|0)+D(w[q+4>>1],z)|0)+D(w[q+8>>1],t)|0)+D(l,w[q+12>>1])|0)+D(K,w[q+16>>1])|0)/32768;b=b+1|0;continue}break}while(1){if((h|0)!=2){t=(g+8|0)+(h<<2)|0;e=x[t>>2];b=(h<<3)+y|0;z=x[b+4>>2];j=x[b>>2];x[b+4>>2]=j;u=e<<8;e=u;e=Aua(e,e>>31,i,J);k=hb;l=e;e=Yb(j,-16777216,16776704);e=Aua(f,I,e,e>>31);j=l+e|0;l=hb+k|0;l=e>>>0>j>>>0?l+1|0:l;e=Yb(z,-16777216,16776704);k=Aua(n,H,e,e>>31);j=k+j|0;e=hb+l|0;e=j>>>0<k>>>0?e+1|0:e;k=j+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Sc(k,e,24);x[b>>2]=e-(u&G);x[t>>2]=(e|0)/256;h=h+1|0;continue}break}p=p+F|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],p>>12);o=o+E|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],o>>12);Pb(g+16|0,r,m);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;h=0;while(1){if((h|0)!=2){a=h<<3;b=a+A|0;a=a+y|0;x[b>>2]=x[a>>2];x[b+4>>2]=x[a+4>>2];h=h+1|0;continue}break}fb=g+48|0}function Ela(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;p=x[a+128>>2];if(p){k=x[a+8>>2];g=x[a+12>>2];q=Hg(k,g,p);r=hb;h=x[a+76>>2];fg(x[a>>2],x[a+4>>2],uf(k,g,d),hb);o=hb>>>0>h>>>0?d:0}else{o=0}j=a+112|0;t=a+44|0;s=f+24|0;while(1){if((b|0)!=2){g=b<<3;h=g+s|0;g=g+t|0;x[h>>2]=x[g>>2];x[h+4>>2]=x[g+4>>2];b=b+1|0;continue}break}A=x[a+24>>2];B=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;C=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;o=o-1|0;h=o;q=h?q:0;r=h?r:0;k=(((g&2147483647)<<1|b>>>31)&-2)+y|0;g=p;a:{b:while(1){c:{if((g|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){ce(j,i>>>3<<16>>16);be(j,4);Pb(f+40|0,q,r);g=g-1|0;continue b}else{i=(v[k+(b|h)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b|g)|0]<<8)+i|0;b=b+1|0;continue}break}ce(j,i>>>3<<16>>16);be(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Fg(j,z);x[f+4>>2]=b;x[f>>2]=b;F=x[a+72>>2];i=x[a+68>>2];G=i>>31;k=x[a+64>>2];H=k>>31;h=x[a+60>>2];I=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(b<<3)+s|0;J=x[g+4>>2];l=x[g>>2];x[g+4>>2]=l;w=e<<8;e=w;e=Aua(e,e>>31,h,I);m=hb;n=e;e=Yb(l,-16777216,16776704);e=Aua(k,H,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Yb(J,-16777216,16776704);m=Aua(i,G,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Sc(m,e,24);x[g>>2]=e-(F&w);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],B);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],A);Pb(f+8|0,C,E);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+t|0;a=a+s|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=f+48|0}function hP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-112|0;fb=d;f=x[b+4>>2];a:{if(!f){break a}e=x[b>>2];h=y[zl(e,f)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}Ml(d+88|0,e,f,f-1|0);f=x[d+92>>2];e=x[d+88>>2];x[b>>2]=e;x[b+4>>2]=f}e=d+88|0;ie(e);h=x[d+88>>2];ie(d+76|0);h=yl(h,x[d+80>>2],b);ie(e);b:{c:{d:{e:{if((h|0)==x[d+92>>2]){a=x[b>>2];h=pc(d+104|0,22292);i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;if(Ic(a,f,d)){a=dc(8);x[31609]=0;c=P(36,e|0,10498)|0;b=x[31609];x[31609]=0;if((b|0)==1){break d}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}g=0;if(!c){break e}c=dc(8);a=x[b+4>>2];b=x[b>>2];x[31609]=0;f=$h(d+76|0,b,a);a=x[31609];x[31609]=0;f:{g:{h:{if((a|0)!=1){x[31609]=0;e=d+88|0;S(1011,e|0,18307,f|0);a=x[31609];x[31609]=0;if((a|0)==1){break h}sc(c,e);a=0;x[31609]=0;S(97,c|0,48428,1e3);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=N()|0;tb(e);break g}b=N()|0;break f}b=N()|0;a=1}tb(f);if(!a){break c}}lc(c);break c}if(x[h+4>>2]!=2){a=dc(8);x[31609]=0;c=P(36,d+88|0,11600)|0;b=x[31609];x[31609]=0;if((b|0)!=1){sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;lc(a);break c}b=x[b>>2];c=pc(d+68|0,22292);e=x[c+4>>2];x[d+32>>2]=x[c>>2];x[d+36>>2]=e;if(Ic(b,f,d+32|0)){a=dc(8);x[31609]=0;c=P(36,d+88|0,10498)|0;b=x[31609];x[31609]=0;if((b|0)!=1){sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;lc(a);break c}c=pc(d+60|0,7759);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,f,d+24|0)){g=1;if(!Id(y[a+28|0])){break e}g=65536/+A[x[a+24>>2]+480244>>2];break e}c=pc(d+52|0,7811);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,f,d+16|0)){g=1;if(!Id(y[a+28|0])){break e}g=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break e}c=pc(d+44|0,7829);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;g=0;if(!Ic(b,f,d+8|0)){break e}g=+A[x[a+24>>2]+480236>>2]*152587890625e-16}fb=d+112|0;return+g}b=N()|0;lc(a)}Q(b|0)}p()}function $oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(x[a+4>>2]!=x[Ab(a)>>2]){e=fb-16|0;fb=e;c=e+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+56;a=x[c+4>>2];x[31609]=0;O(683,a|0,b|0);a=x[31609];x[31609]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;jc(c);fb=e+16|0;break a}a=N()|0;jc(c);Q(a|0);p()}return}k=fb-32|0;fb=k;i=Ab(a);c=k+12|0;d=Bv(x[a>>2],x[a+4>>2])+1|0;h=fb-16|0;fb=h;x[h+12>>2]=d;f=fb-16|0;fb=f;x[f+12>>2]=76695844;x[f+8>>2]=2147483647;e=x[Hb(f+12|0,f+8|0)>>2];fb=f+16|0;b:{if(e>>>0>=d>>>0){d=dX(a);if(d>>>0<e>>>1>>>0){x[h+8>>2]=d<<1;e=x[bd(h+8|0,h+12|0)>>2]}fb=h+16|0;break b}ed();p()}f=Bv(x[a>>2],x[a+4>>2]);h=fb-16|0;fb=h;Lg(c+12|0,i);c:{if(!e){i=0;e=0;break c}if(e>>>0>=76695845){Sj();p()}d=Ec(D(e,56));x[h+12>>2]=e;x[h+8>>2]=d;i=x[h+12>>2];e=x[h+8>>2]}x[c>>2]=e;d=e+D(f,56)|0;x[c+8>>2]=d;x[c+4>>2]=d;l=nc(c),m=e+D(i,56)|0,x[l>>2]=m;fb=h+16|0;e=x[c+8>>2];x[31609]=0;O(683,e|0,b|0);b=x[31609];x[31609]=0;d:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+56;h=fb-16|0;fb=h;f=Ab(a);d=vb(h+12|0,x[a+4>>2]);e=vb(h+8|0,x[a>>2]);b=vb(h+4|0,x[c+4>>2]);i=x[d>>2];e=x[e>>2];g=fb+-64|0;fb=g;b=x[b>>2];x[g+56>>2]=b;x[g+60>>2]=i;x[g+52>>2]=b;d=Ag(g+24|0,f,g+52|0,g+56|0);x[g+16>>2]=x[d+8>>2];b=x[d+4>>2];x[g+8>>2]=x[d>>2];x[g+12>>2]=b;zg(g+36|0,g+8|0);while(1){if(Fd(i,e)){b=aX(x[g+56>>2]);f=eX(i);d=Tl(b,f);Tl(d+12|0,f+12|0);DC(d+24|0,f+24|0);w[d+52>>1]=z[f+52>>1];b=x[f+48>>2];x[d+44>>2]=x[f+44>>2];x[d+48>>2]=b;b=x[f+40>>2];x[d+36>>2]=x[f+36>>2];x[d+40>>2]=b;b=bX(g+60|0);bX(g+56|0);i=x[b>>2];continue}break}yg(g+36|0);d=x[g+56>>2];if(!y[g+48|0]){i=fb-16|0;fb=i;b=vb(i+12|0,x[x[g+44>>2]>>2]);e=x[vb(i+8|0,x[x[g+40>>2]>>2])>>2];f=fb-16|0;fb=f;b=x[b>>2];x[f+12>>2]=b;while(1){if(wi(b,e)){j=fb-16|0;fb=j;x[j+12>>2]=b;x[j+12>>2]=x[j+12>>2]+56;fb=j+16|0;ar(aX(x[j+12>>2]));b=f+12|0;x[b>>2]=x[b>>2]+56;b=x[b>>2];continue}break}fb=f+16|0;fb=i+16|0}fb=g- -64|0;x[c+4>>2]=d;Tb(a,c+4|0);Tb(a+4|0,c+8|0);Tb(Ab(a),nc(c));x[c>>2]=x[c+4>>2];fb=h+16|0;cX(c);fb=k+32|0;break d}a=N()|0;cX(c);Q(a|0);p()}}function foa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-112|0;fb=d;a:{b:{c:{d:{switch(y[a|0]-23|0){case 0:e=v[a+1|0];i=d,j=JD(c,+y[a+2|0]*1e4/240),v[i+12|0]=j;x[d+88>>2]=127;x[d+76>>2]=(D(y[a+3|0],127)>>>0)/185;i=d,j=x[Cd(d+88|0,d+76|0)>>2],v[i+111|0]=j;e:{switch(((e>>>0)%5|0)-1|0){case 0:a=d+76|0;qw(a,15670);x[31609]=0;c=d- -64|0;O(559,c|0,d+12|0);e=x[31609];x[31609]=0;f:{g:{h:{i:{if((e|0)!=1){x[31609]=0;e=d+52|0;O(559,e|0,d+111|0);f=x[31609];x[31609]=0;if((f|0)==1){break i}x[31609]=0;f=d+88|0;V(560,f|0,a|0,c|0,e|0);g=x[31609];x[31609]=0;if((g|0)==1){break h}fe(d+100|0,f);qf(b,x[d+100>>2],x[d+104>>2]);tb(f);tb(e);tb(c);Eb(a);break b}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;case 1:a=d+76|0;qw(a,15617);x[31609]=0;c=d- -64|0;O(559,c|0,d+12|0);e=x[31609];x[31609]=0;j:{k:{l:{m:{if((e|0)!=1){x[31609]=0;e=d+52|0;O(559,e|0,d+111|0);f=x[31609];x[31609]=0;if((f|0)==1){break m}x[31609]=0;f=d+88|0;V(560,f|0,a|0,c|0,e|0);g=x[31609];x[31609]=0;if((g|0)==1){break l}fe(d+44|0,f);qf(b,x[d+44>>2],x[d+48>>2]);tb(f);tb(e);tb(c);Eb(a);break b}a=N()|0;break j}a=N()|0;break k}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;default:break e}}a=pc(d+36|0,15697);qf(b,x[a>>2],x[a+4>>2]);break b;case 1:break d;default:break a}}c=v[a+1|0];v[d+111|0]=(c|0)<5?c:0;c=v[a+2|0];v[d+35|0]=(c|0)<0?127:c;a=v[a+3|0];v[d+34|0]=(a|0)<0?127:a;a=fb-16|0;fb=a;c=d+76|0;e=Dc(a+4|0,4048);Uc(c,e);tb(e);fb=a+16|0;x[31609]=0;a=d- -64|0;O(559,a|0,d+111|0);e=x[31609];x[31609]=0;n:{o:{p:{q:{r:{s:{if((e|0)!=1){x[31609]=0;e=d+52|0;O(559,e|0,d+35|0);f=x[31609];x[31609]=0;if((f|0)==1){break s}x[31609]=0;f=d+12|0;O(559,f|0,d+34|0);g=x[31609];x[31609]=0;if((g|0)==1){break r}x[31609]=0;g=d+88|0;aa(740,g|0,c|0,a|0,e|0,f|0);h=x[31609];x[31609]=0;if((h|0)==1){break q}fe(d+24|0,g);qf(b,x[d+24>>2],x[d+28>>2]);tb(g);tb(f);tb(e);tb(a);Eb(c);break b}a=N()|0;break n}a=N()|0;break o}a=N()|0;break p}a=N()|0;tb(d+12|0)}tb(d+52|0)}tb(d- -64|0)}}Eb(d+76|0);Q(a|0);p()}e=1}fb=d+112|0;return e|0}function ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=fb-48|0;fb=g;i=x[a+8>>2];s=i;f=x[a+12>>2];m=f;a:{b:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){f=131112;i=m;if((i|0)>-2){e=1}else{e=(i|0)>=-2&s>>>0>=3489660928}if(e){break a}f=262184;if((m|0)==-2&s>>>0<2147483648|m>>>0<4294967294){break a}break b}f=262184;if((m|0)==1&s>>>0>2147483648|m>>>0>1){break a}}f=196648}i=f;B=x[a+16>>2];A=a+44|0;y=g+32|0;while(1){if((h|0)!=2){f=h<<3;o=f+y|0;f=f+A|0;x[o>>2]=x[f>>2];x[o+4>>2]=x[f+4>>2];h=h+1|0;continue}break}p=x[a+40>>2];q=x[a+36>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;C=b+i|0;E=x[a+32>>2];F=x[a+28>>2];G=x[a+72>>2];o=x[a+68>>2];H=o>>31;f=x[a+64>>2];I=f>>31;i=x[a+60>>2];J=i>>31;while(1){if(d){b=x[g+16>>2];K=(((x[g+20>>2]&2147483647)<<1|b>>>31)&-2)+B|0;b=(b>>>16&65520)+C|0;n=w[b+14>>1];t=w[b+12>>1];z=w[b+10>>1];j=w[b+8>>1];u=w[b+6>>1];l=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];h=0;r=0;while(1){if((r|0)!=2){k=r+K|0;x[(g+8|0)+(r<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],l)|0)+D(v[k|0],u)|0)+D(v[k+2|0],j)|0)+D(v[k+4|0],z)|0)+D(t,v[k+6|0])|0)+D(n,v[k+8|0])<<8)/32768;r=r+1|0;continue}break}while(1){if((h|0)!=2){t=(g+8|0)+(h<<2)|0;e=x[t>>2];b=(h<<3)+y|0;z=x[b+4>>2];j=x[b>>2];x[b+4>>2]=j;u=e<<8;e=u;e=Aua(e,e>>31,i,J);l=hb;k=e;e=Yb(j,-16777216,16776704);e=Aua(f,I,e,e>>31);j=k+e|0;n=hb+l|0;n=e>>>0>j>>>0?n+1|0:n;e=Yb(z,-16777216,16776704);l=Aua(o,H,e,e>>31);j=l+j|0;e=hb+n|0;e=j>>>0<l>>>0?e+1|0:e;l=j+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Sc(l,e,24);x[b>>2]=e-(u&G);x[t>>2]=(e|0)/256;h=h+1|0;continue}break}q=q+F|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],q>>12);p=p+E|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],p>>12);Pb(g+16|0,s,m);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=p;x[a+20>>2]=q>>12;x[a+36>>2]=q;x[a+24>>2]=p>>12;h=0;while(1){if((h|0)!=2){a=h<<3;b=a+A|0;a=a+y|0;x[b>>2]=x[a>>2];x[b+4>>2]=x[a+4>>2];h=h+1|0;continue}break}fb=g+48|0}function Cqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-16|0;fb=g;a:{b:{if(!c){break b}n=g,o=Zd(a),v[n+8|0]=o;so(b,g+8|0);j=c-1|0;while(1){d=1;if(!j){break a}c=e<<1&254;c:{if(c){e=(e&65535)>>>0>127;break c}if(!Bf(a,g+8|0)){break b}c=y[g+8|0];e=c>>>7|0;c=c<<1&254|1}if(e){d=1;d:{while(1){e:{e=c<<1&254;f:{if(e){c=(c&65535)>>>0>127;break f}if(!Bf(a,g+8|0)){break e}f=y[g+8|0];c=f>>>7|0;e=f<<1&254|1}d=gr(d,1)+c|0;c=e<<1&254;g:{if(c){e=e>>>0>127;break g}if(!Bf(a,g+8|0)){break e}c=y[g+8|0];e=c>>>7|0;c=c<<1&254|1}if(e){continue}break d}break}c=0}h:{if((d|0)<=2){i=0;f=d-2|0;break h}if(!Bf(a,g+8|0)){break b}f=gr(d-3|0,8)|y[g+8|0];i=((f|0)>1279?2:1)+((f|0)>31999)|0;l=f^-1;f=0}d=c<<1&254;i:{if(d){c=c>>>0>127;break i}if(!Bf(a,g+8|0)){break b}e=y[g+8|0];c=e>>>7|0;d=e<<1&254|1}f=gr(f,1);e=d<<1&254;j:{if(e){h=d>>>0>127;break j}if(!Bf(a,g+8|0)){break b}e=y[g+8|0];h=e>>>7|0;e=e<<1&254|1}d=1;c=gr(c+f|0,1)+h|0;if(!c){k:{while(1){l:{c=e<<1&254;m:{if(c){e=(e&65535)>>>0>127;break m}if(!Bf(a,g+8|0)){break l}c=y[g+8|0];e=c>>>7|0;c=c<<1&254|1}d=gr(d,1)+e|0;e=c<<1&254;n:{if(e){c=c>>>0>127;break n}if(!Bf(a,g+8|0)){break l}f=y[g+8|0];c=f>>>7|0;e=f<<1&254|1}if(c){continue}break k}break}e=0}c=d+2|0}f=c+i|0;d=0;if(f>>>0>j>>>0|(f|0)<=0|(l|0)>=0){break a}c=x[b+4>>2];d=0;if((0-Xc(x[b>>2],c)|0)>(l|0)){break a}c=vb(g+12|0,wb(c));v[g+8|0]=0;i=g+8|0;m=fb-32|0;fb=m;d=x[c>>2];c=x[b>>2];h=zk(d,wb(c))+c|0;c=x[Ab(b)>>2];k=x[b+4>>2];o:{if(f>>>0<=c-k>>>0){c=f;d=k-h|0;if(c>>>0>d>>>0){Ap(b,c-d|0,i);c=d;if(!c){break o}}S_(b,h,k,f+h|0);Sh(h,c,i+(h>>>0<=i>>>0?i>>>0<A[b+4>>2]?f:0:0)|0);break o}c=Ab(b);c=pn(m+12|0,Vl(b,Xc(x[b>>2],k)+f|0),h-x[b>>2]|0,c);dZ(c,f,i);h=R_(b,c,h);on(c)}wb(h);fb=m+32|0;n=g,o=vf(aD(wb(x[b+4>>2]),f),l),x[n+8>>2]=o;n=g,o=aD(wb(x[b+4>>2]),f),x[n+4>>2]=o;c=f;while(1){d=y[hY(g+8|0)|0];n=hY(g+4|0),o=d,v[n|0]=o;d=c>>>0>1;c=c-1|0;if(d){continue}break}j=j-f|0;continue}f=g+8|0;if(!Bf(a,f)){break b}V_(b,f);j=j-1|0;e=c;continue}}d=0}fb=g+16|0;return d|0}
function Yta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-32|0;fb=l;d=b;b=x[a>>2];b=(lp(d,wb(b))<<1)+b|0;e=x[a+4>>2];a:{b:{if(e>>>0<A[Ab(a)>>2]){if((b|0)!=(e|0)){break b}d=fb-16|0;fb=d;a=bj(d+4|0,a,1);$i(x[a+4>>2],y[c|0]|y[c+1|0]<<8);x[a+4>>2]=x[a+4>>2]+2;jc(a);fb=d+16|0;break a}d=Ab(a);g=ek(l+12|0,fk(a,$c(x[a>>2],e)+1|0),b-x[a>>2]>>1,d);x[31609]=0;O(294,g|0,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){h=fb-16|0;fb=h;c=x[g+4>>2];j=Ab(a);d=vb(h+12|0,b);f=vb(h+8|0,x[a>>2]);i=vb(h+4|0,x[g+4>>2]);e=x[d>>2];m=x[f>>2];d=fb+-64|0;fb=d;f=x[i>>2];x[d+56>>2]=f;x[d+60>>2]=e;x[d+52>>2]=f;f=Ag(d+24|0,j,d+52|0,d+56|0);x[d+16>>2]=x[f+8>>2];i=x[f+4>>2];x[d+8>>2]=x[f>>2];x[d+12>>2]=i;zg(d+36|0,d+8|0);while(1){if(Fd(e,m)){f=fb-16|0;fb=f;x[f+12>>2]=x[d+56>>2];T$(f+12|0,-1);fb=f+16|0;k=x[f+12>>2];e=Gn(e);$i(k,y[e|0]|y[e+1|0]<<8);e=Wk(d+60|0);Wk(d+56|0);e=x[e>>2];continue}break}e=d+36|0;yg(e);f=x[d+56>>2];U$(e);fb=d- -64|0;x[g+4>>2]=f;f=x[a+4>>2];d=fb-48|0;fb=d;e=x[g+8>>2];x[d+44>>2]=e;x[d+40>>2]=e;e=Ag(d+12|0,j,d+40|0,d+44|0);x[d+8>>2]=x[e+8>>2];j=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=j;zg(d+24|0,d);while(1){if((b|0)!=(f|0)){$i(x[d+44>>2],y[b|0]|y[b+1|0]<<8);x[d+44>>2]=x[d+44>>2]+2;b=b+2|0;continue}break}b=d+24|0;yg(b);e=x[d+44>>2];U$(b);fb=d+48|0;x[g+8>>2]=e;Tb(a,g+4|0);Tb(a+4|0,g+8|0);Tb(Ab(a),nc(g));x[g>>2]=x[g+4>>2];fb=h+16|0;b=c;aj(g);break a}a=N()|0;aj(g);Q(a|0);p()}j=fb-16|0;fb=j;h=x[a+4>>2];g=(h-(b+2|0)|0)+b|0;i=bj(j+4|0,a,e-g>>1);f=x[i+4>>2];d=g;while(1){if(d>>>0>=e>>>0){jc(i);f=fb-16|0;fb=f;i=f+8|0;d=h;h=fb-32|0;fb=h;fd(h+24|0,b,g);m=h+16|0;n=x[h+24>>2];g=fb-16|0;fb=g;k=x[h+28>>2];e=k;while(1){if((e|0)!=(n|0)){e=e-2|0;d=S$(d-2|0,e);continue}break}x[g+12>>2]=d;qc(m,k,g+12|0);fb=g+16|0;d=x[h+16>>2];x[h+12>>2]=x[h+20>>2];qc(i,d,h+12|0);fb=h+32|0;fb=f+16|0;fb=j+16|0}else{$i(f,y[d|0]|y[d+1|0]<<8);f=f+2|0;x[i+4>>2]=f;d=d+2|0;continue}break}a=(b>>>0<=c>>>0?(A[a+4>>2]>c>>>0)<<1:0)+c|0;c=y[a|0];v[b+1|0]=y[a+1|0];v[b|0]=c}wb(b);fb=l+32|0}function Ae(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;e=x[a>>2];a:{if(mc(e,x[a+4>>2])){break a}f=x[b+4>>2];if(f>>>0>=A[a+12>>2]){break a}i=z[b+8>>1];j=x[x[a+48>>2]+12>>2];c=z[j+480188>>1];if(i>>>0>=c>>>0&(i|0)!=65535){break a}d=c-1|0;c=(i|0)==65535;l=c?d:i;c=c?0:i;e=md(e,j,f,c);g=y[b+12|0];k=g&4;b:{c:{if(g&2){break c}i=y[b+10|0];f=e;d=c;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!k){if((i|0)!=y[f+3|0]){break d}break b}if((i|0)==y[f+2|0]){break b}}f=f+6|0;d=d+1|0;continue}}i=l&65535;d=e;f=c;while(1){if(i>>>0>=(f&65535)>>>0){e:{if(!k){if(y[d+3|0]){break e}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break b}if(y[d+2|0]){break e}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break b}d=d+6|0;f=f+1|0;continue}break}f:{if(!(g&1)){break f}d=x[j+480180>>2]&2;g:{h:{i:{if(!k){while(1){if((c&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(y[e+3|0]-9|0){case 4:if(!$v(x[x[j+8>>2]+88>>2],1)){break j}d=1;v[e+2|0]=1;v[e+4|0]=y[e+5|0];v[e+3|0]=y[b+10|0];v[e+5|0]=y[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){f=y[e+5|0];if(f>>>0>128){break j}v[e+2|0]=2;v[e+3|0]=y[b+10|0];a=1;break l}v[e+2|0]=2;v[e+3|0]=y[b+10|0];f=y[e+5|0];a=2}v[e+4|0]=a+(f&255)>>>a;v[e+5|0]=y[b+11|0];break b}e=e+6|0;c=c+1|0;continue}break}if(!k){break i}}f=y[b+11|0];c=13;m:{switch(y[b+10|0]-1|0){case 1:c=9;f=si(f<<(d?1:2));break;case 0:break m;default:break g}}v[b+11|0]=f;v[b+10|0]=c;g=g&254;break h}v[h+15|0]=0;v[h+14|0]=0;e=b;c=y[b+10|0];n:{if(!(!d|(c|0)!=9)){c=y[b+11|0];if(c>>>0>128){break g}d=2;c=c>>>1|0;break n}f=h+12|0;uw(f,c,y[b+11|0],1);c=h+4|0;ZD(c,h+15|0,h+14|0);YD(c,f);g=y[b+12|0];d=y[h+15|0];if(!d){break g}c=y[h+14|0]}v[e+11|0]=c;v[b+10|0]=d;g=g&254}v[b+12|0]=g}d=1;if(g&1){break f}v[b+12|0]=g^4;if(Ae(a,b)){break a}}d=0;o:{p:{switch(x[b>>2]-1|0){case 0:c=x[b+4>>2]+1|0;if(c>>>0>=A[a+12>>2]){break a}x[b+4>>2]=c;break o;case 1:break p;default:break a}}c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=Ae(a,b);break a}d=1}fb=h+16|0;return d}function lU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=fb-176|0;fb=c;i=1;p=2;d=x[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;v=D(i,3);w=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=x[a+12>>2];continue a}d=x[a>>2];e=Yd(d,h<<1);uR(c+160|0,C[e>>3],C[e+8>>3]);d=Yd(d,h);uR(c+144|0,C[d>>3],C[d+8>>3]);Li(c+128|0,C[c+144>>3],C[c+152>>3],C[c+160>>3],C[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=x[b>>2];e=Yd(f,d);g=e+8|0;j=x[g+4>>2];x[c+120>>2]=x[g>>2];x[c+124>>2]=j;g=x[e+4>>2];x[c+112>>2]=x[e>>2];x[c+116>>2]=g;k=d+i|0;g=Yd(f,k);n=C[g+8>>3];o=C[g>>3];r=d+w|0;g=Yd(f,r);j=x[g+12>>2];x[c+104>>2]=x[g+8>>2];x[c+108>>2]=j;j=x[g+4>>2];x[c+96>>2]=x[g>>2];x[c+100>>2]=j;s=d+v|0;f=Yd(f,s);t=C[f+8>>3];u=C[f>>3];g=c+80|0;f=c+112|0;Dl(g,f,o,n);j=c- -64|0;yj(j,f,o,n);l=c+96|0;Dl(c+48|0,l,u,t);f=c+16|0;yj(f,l,u,t);Li(c+32|0,0,1,C[c+16>>3],C[c+24>>3]);Dl(f,g,C[c+48>>3],C[c+56>>3]);l=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=l;l=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=l;Dl(c,j,C[c+32>>3],C[c+40>>3]);Li(f,C[c+160>>3],C[c+168>>3],C[c>>3],C[c+8>>3]);e=Yd(x[b>>2],k);k=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=k;k=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=k;yj(c,g,C[c+48>>3],C[c+56>>3]);Li(f,C[c+144>>3],C[c+152>>3],C[c>>3],C[c+8>>3]);e=Yd(x[b>>2],r);g=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=g;yj(c,j,C[c+32>>3],C[c+40>>3]);Li(f,C[c+128>>3],C[c+136>>3],C[c>>3],C[c+8>>3]);e=Yd(x[b>>2],s);f=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=f;f=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=x[b>>2];a=Yd(h,d+i|0);m=Yd(h,d);n=C[a>>3];o=C[a+8>>3];yj(c+160|0,m,n,o);h=x[c+172>>2];x[a+8>>2]=x[c+168>>2];x[a+12>>2]=h;h=x[c+164>>2];x[a>>2]=x[c+160>>2];x[a+4>>2]=h;zA(Yd(x[b>>2],d),n,o);d=d+1|0;continue}}fb=c+176|0}function M7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=Ry(x[g>>2]);o=Fy(x[g>>2]);sh(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31609]=0;g=P(1270,k|0,g<<24>>24)|0;i=x[31609];x[31609]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31609]=0;i=P(1270,k|0,48)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;i=v[g+1|0];x[31609]=0;i=P(1270,k|0,i|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;i=g+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Od();if(!$n(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Od();if(!_n(h)){break d}g=g+1|0;continue}}e:{if(Ad(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[31609]=0;V(1263,k|0,i|0,g|0,h|0);h=x[31609];x[31609]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break e}Dm(i,g);x[31609]=0;r=R(1261,o|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){vt((i-a<<2)+d|0,x[f>>2]);break e}f:{if(v[ec(j+4|0,l)|0]<=0){break f}if(v[ec(j+4|0,l)|0]!=(m|0)){break f}m=x[f>>2];x[f>>2]=m+4;x[m>>2]=r;l=(Cb(x[j+8>>2],y[j+15|0])-1>>>0>l>>>0)+l|0;m=0}q=v[h|0];x[31609]=0;q=P(1270,k|0,q|0)|0;n=x[31609];x[31609]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=v[g|0];if((i|0)==46){x[31609]=0;i=R(1264,o|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}l=x[f>>2];h=l+4|0;x[f>>2]=h;x[l>>2]=i;g=g+1|0;break g}x[31609]=0;i=P(1270,k|0,i|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[31609]=0;V(1263,k|0,g|0,c|0,h|0);i=x[31609];x[31609]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;tb(j+4|0);fb=j+16|0;return}a=N()|0;tb(j+4|0);Q(a|0);p()}function Dla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){i=x[a+8>>2];g=x[a+12>>2];p=Hg(i,g,o);q=hb;h=x[a+76>>2];fg(x[a>>2],x[a+4>>2],uf(i,g,d),hb);n=hb>>>0>h>>>0?d:0}else{n=0}j=a+112|0;s=a+44|0;r=f+24|0;while(1){if((b|0)!=2){g=b<<3;h=g+r|0;g=g+s|0;x[h>>2]=x[g>>2];x[h+4>>2]=x[g+4>>2];b=b+1|0;continue}break}A=x[a+24>>2];B=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;C=x[a+8>>2];E=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;n=n-1|0;h=n;p=h?p:0;q=h?q:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=o;while(1)if((b|0)<=0){Pb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;ce(j,(w[((b&2147483646)<<1)+i>>1]+w[i+(b<<1|2)>>1]|0)/8<<16>>16);be(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Fg(j,z);x[f+4>>2]=b;x[f>>2]=b;F=x[a+72>>2];t=x[a+68>>2];G=t>>31;i=x[a+64>>2];H=i>>31;h=x[a+60>>2];I=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(b<<3)+r|0;J=x[g+4>>2];k=x[g>>2];x[g+4>>2]=k;v=e<<8;e=v;e=Aua(e,e>>31,h,I);l=hb;m=e;e=Yb(k,-16777216,16776704);e=Aua(i,H,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Yb(J,-16777216,16776704);l=Aua(t,G,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Sc(l,e,24);x[g>>2]=e-(F&v);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],B);x[c+4>>2]=x[c+4>>2]+D(A,x[f+4>>2]);Pb(f+8|0,C,E);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;ce(j,(w[((g&2147483646)<<1)+i>>1]+w[i+(g<<1|2)>>1]|0)/8<<16>>16);be(j,4);Pb(f+40|0,p,q);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+s|0;a=a+r|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=f+48|0}function cK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=x[d>>2];if(!g){break l}if(!a){d=c;break j}x[d>>2]=0;d=c;break k}m:{if(!x[x[124115]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=v[e|0];if(d){x[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return Ef(e)}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=y[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+2|0;if(!(g&524288)){break n}if((y[f|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=y[e|0];o:{if(e&3|g-1>>>0>126){break o}g=x[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=x[e+4>>2];e=e+4|0;if(!((g-16843009|g)&-2139062144)){continue}break}}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+120704>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=y[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=x[e>>2];if((g|g-16843009)&-2139062144){break s}x[a>>2]=g&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=y[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}x[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=x[(f<<2)+120704>>2];f=1;continue}i=y[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{h=e+1|0;f=i-128|g<<6;v:{if((f|0)>=0){break v}h=y[h|0]-128|0;if(h>>>0>63){break u}i=f<<6;f=h|i;h=e+2|0;if((i|0)>=0){break v}h=y[h|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;x[a>>2]=f;d=d-1|0;a=a+4|0;break t}x[31484]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=y[e|0]}if(g&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-d|0}x[31484]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c}function Kna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;h=fb-32|0;fb=h;a:{b:{if(hv(a)>>>0<b>>>0){if((b|0)<0){break b}j=To(h+20|0);x[31609]=0;O(761,j|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}mn(h+12|0,x[a>>2]);$q(h+4|0,x[a>>2],x[a+4>>2]);g=x[h+12>>2];f=x[h+16>>2];k=fb-48|0;fb=k;b=x[j+4>>2];c=b+x[a+4>>2]|0;x[j+4>>2]=c;c:{d:{if(!b){i=c-1|0;break d}i=c-1|0;if((i^b-1)>>>0<32){break c}}x[x[j>>2]+((c>>>0>=33?i>>>5|0:0)<<2)>>2]=0}c=Zb(k+40|0,g,f);g=Zb(k+32|0,x[h+4>>2],x[h+8>>2]);yp(k+24|0,x[j>>2],b);i=fb-32|0;fb=i;b=Zb(i+24|0,x[c>>2],x[c+4>>2]);c=Zb(i+16|0,x[g>>2],x[g+4>>2]);m=Zb(i+8|0,x[k+24>>2],x[k+28>>2]);g=fb-32|0;fb=g;q=k+8|0;f=Zb(g+24|0,x[b>>2],x[b+4>>2]);c=Zb(g+16|0,x[c>>2],x[c+4>>2]);m=Zb(g+8|0,x[m>>2],x[m+4>>2]);b=fb-128|0;fb=b;e=Zb(b+104|0,x[f>>2],x[f+4>>2]);c=Zb(b+96|0,x[c>>2],x[c+4>>2]);d=fb-16|0;fb=d;e=Zb(d+8|0,x[e>>2],x[e+4>>2]);l=Zb(d,x[c>>2],x[c+4>>2]);c=fb-32|0;fb=c;e=Zb(c+16|0,x[e>>2],x[e+4>>2]);ln(c+24|0,x[e>>2],x[e+4>>2]);e=c+8|0;l=Zb(c,x[l>>2],x[l+4>>2]);ln(e,x[l>>2],x[l+4>>2]);BV(b+112|0,x[c+24>>2],x[c+28>>2],e);fb=c+32|0;fb=d+16|0;e=Zb(b+72|0,x[b+112>>2],x[b+116>>2]);l=Zb(b- -64|0,x[b+120>>2],x[b+124>>2]);d=b+56|0;c=Zb(b+48|0,x[m>>2],x[m+4>>2]);ln(d,x[c>>2],x[c+4>>2]);r=b+80|0;c=fb-16|0;fb=c;while(1){n=x[e>>2];o=x[e+4>>2];if(ZW(n,o,x[l>>2],x[l+4>>2])){Ot(c+8|0,n,o);Ot(c,x[d>>2],x[d+4>>2]);kf(c,Gb(x[x[c+8>>2]>>2],x[c+12>>2]));zv(e);zv(d);continue}break}CV(r,n,o,d);fb=c+16|0;f=Zb(b+32|0,x[f>>2],x[f+4>>2]);d=Zb(b+24|0,x[b+80>>2],x[b+84>>2]);c=fb-16|0;fb=c;e=Zb(c+8|0,x[f>>2],x[f+4>>2]);d=Zb(c,x[d>>2],x[d+4>>2]);f=fb-16|0;fb=f;Zb(f+8|0,x[e>>2],x[e+4>>2]);d=Zb(f,x[d>>2],x[d+4>>2]);ln(b+40|0,x[d>>2],x[d+4>>2]);fb=f+16|0;fb=c+16|0;Zb(b+8|0,x[m>>2],x[m+4>>2]);c=b+16|0;f=Zb(b,x[b+88>>2],x[b+92>>2]);ln(c,x[f>>2],x[f+4>>2]);CV(q,x[b+40>>2],x[b+44>>2],c);fb=b+128|0;fb=g+32|0;fb=i+32|0;fb=k+48|0;lC(a,j);tf(j)}fb=h+32|0;return}ed();p()}a=N()|0;tf(j);Q(a|0);p()}function Ii(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=E(0),q=0,r=E(0);m=ib[x[x[a>>2]+140>>2]](a)|0;g=x[a+20>>2];h=m?h:y[g+25|0];j=B[g+144>>2];k=E(1);if(!(ib[x[x[a>>2]+140>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((ib[x[x[a>>2]+156>>2]](a)|0)<=0){break a}if(!oQ(y[x[a+20>>2]+24|0])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(k*n);j=E(j*n);g=0;l=x[a+44>>2];m=Hc(l,0);l=Hc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;B[i>>2]=B[i>>2]+E(E(B[d+g>>2]*j)+E(k*B[g+m>>2]));i=c+g|0;B[i>>2]=B[i>>2]+E(E(B[e+g>>2]*j)+E(k*B[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[h+m>>2]-E(B[d+h>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]+E(B[h+l>>2]-E(B[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[d+h>>2]-E(B[h+m>>2]*k));i=c+h|0;B[i>>2]=B[i>>2]+E(B[e+h>>2]-E(B[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]-E(B[d+h>>2]-E(B[h+m>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]-E(B[e+h>>2]-E(B[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=B[i>>2];q=i;r=k;n=B[h+m>>2];i=c+h|0;o=B[i>>2];p=B[h+l>>2];k=E(E(E(E(k+n)+o)+p)*E(.5));B[q>>2]=r-E(E(k+E(k-E(B[d+h>>2]*j)))-n);B[i>>2]=o-E(E(k+E(k-E(B[e+h>>2]*j)))-p);g=g+1|0;continue}}g=oQ(y[x[a+20>>2]+24|0]);j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[i>>2]=B[i>>2]+E(E(j*n)+E(k*o));g=c+g|0;B[g>>2]=B[g>>2]+E(E(k*n)+E(j*o));h=h+1|0;continue}}i:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break i}if(ib[x[x[a>>2]+140>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;B[d>>2]=B[a+m>>2]+B[d>>2];d=a+c|0;B[d>>2]=B[a+l>>2]+B[d>>2];g=g+1|0;continue}}}function Dra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,j=E(0);e=fb-96|0;fb=e;d=fb-16|0;fb=d;c=b+16|0;$Y(d+8|0,c);g=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(g|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((f|0)!=(g|0)){Rb(c,0,128)}v[b+79|0]=0;v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;d=e+56|0;he(d,a,Rg(a));g=hc(e+76|0,d);ub(d);x[31609]=0;c=R(202,g|0)|0;f=x[31609];x[31609]=0;a:{b:{if((f|0)==1){break b}x[31609]=0;O(287,b+4|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}se(e+48|0,x[b+4>>2],x[b+8>>2]);x[31609]=0;Yn(471,d,g,x[e+48>>2],x[e+52>>2]);c=x[31609];x[31609]=0;if((c|0)!=1){x[31609]=0;f=R(151,a|0)|0;c=x[31609];x[31609]=0;c:{if((c|0)==1){break c}x[31609]=0;c=e+28|0;S(185,c|0,a|0,f|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}d=hc(d,c);ub(c);a=x[d>>2];x[31609]=0;a=R(172,a|0)|0;c=x[31609];x[31609]=0;d:{if((c|0)!=1){e:{f:{g:{if(!a){break g}while(1){a=x[d+8>>2];c=x[d>>2];x[31609]=0;a=U(150,c|0,a|0,5)|0;c=x[31609];x[31609]=0;if((c|0)==1){break f}if(!a){break g}x[31609]=0;P(472,d|0,e+24|0)|0;a=x[31609];x[31609]=0;h:{if((a|0)!=1){a=4;c=y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24);if((c|0)==1414682436|(c|0)==1196380752){break h}x[31609]=0;a=R(151,d|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break h}a=N()|0;break d}a=N()|0;break d}x[31609]=0;f=e+4|0;S(185,f|0,d|0,a|0);a=x[31609];x[31609]=0;i:{j:{if((a|0)!=1){c=hc(e+28|0,f);ub(f);if((y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24))!=1414682436){break j}x[31609]=0;h=E(xa(473,c|0));a=x[31609];x[31609]=0;if((a|0)==1){break e}i=b,j=Pd(h,E(0)),B[i+144>>2]=j;break i}a=N()|0;break d}if((y[e+24|0]|y[e+25|0]<<8|(y[e+26|0]<<16|y[e+27|0]<<24))!=1196380752){break i}x[31609]=0;a=R(151,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}x[b+148>>2]=a}ub(c);continue}}ub(d);ub(g);fb=e+96|0;return}a=N()|0;break d}a=N()|0;ub(c);break d}a=N()|0}ub(d);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}ub(g);Q(a|0);p()}function hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;g=fb-48|0;fb=g;i=x[a+8>>2];p=i;f=x[a+12>>2];m=f;a:{b:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){f=131112;i=m;if((i|0)>-2){e=1}else{e=(i|0)>=-2&p>>>0>=3489660928}if(e){break a}f=262184;if((m|0)==-2&p>>>0<2147483648|m>>>0<4294967294){break a}break b}f=262184;if((m|0)==1&p>>>0>2147483648|m>>>0>1){break a}}f=196648}i=f;z=x[a+16>>2];y=a+44|0;u=g+32|0;while(1){if((h|0)!=2){f=h<<3;n=f+u|0;f=f+y|0;x[n>>2]=x[f>>2];x[n+4>>2]=x[f+4>>2];h=h+1|0;continue}break}A=x[a+24>>2];B=x[a+20>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;C=b+i|0;E=x[a+72>>2];n=x[a+68>>2];F=n>>31;f=x[a+64>>2];G=f>>31;i=x[a+60>>2];H=i>>31;while(1){if(d){b=x[g+16>>2];q=((((x[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+z|0;b=(b>>>16&65520)+C|0;I=w[b+14>>1];l=w[b+12>>1];r=w[b+10>>1];v=w[b+8>>1];j=w[b+6>>1];s=w[b+4>>1];k=w[b+2>>1];e=w[b>>1];h=0;b=0;while(1){if((b|0)!=2){t=b<<1;o=t+q|0;x[(g+8|0)+(b<<2)>>2]=(((((((D(w[q+(t|-8)>>1],k)+D(w[q+(t|-12)>>1],e)|0)+D(w[q+(t|-4)>>1],s)|0)+D(w[o>>1],j)|0)+D(w[o+4>>1],v)|0)+D(w[o+8>>1],r)|0)+D(l,w[o+12>>1])|0)+D(I,w[o+16>>1])|0)/32768;b=b+1|0;continue}break}while(1){if((h|0)!=2){r=(g+8|0)+(h<<2)|0;e=x[r>>2];b=(h<<3)+u|0;v=x[b+4>>2];j=x[b>>2];x[b+4>>2]=j;s=e<<8;e=s;e=Aua(e,e>>31,i,H);k=hb;l=e;e=Yb(j,-16777216,16776704);e=Aua(f,G,e,e>>31);j=l+e|0;l=hb+k|0;l=e>>>0>j>>>0?l+1|0:l;e=Yb(v,-16777216,16776704);k=Aua(n,F,e,e>>31);j=k+j|0;e=hb+l|0;e=j>>>0<k>>>0?e+1|0:e;k=j+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Sc(k,e,24);x[b>>2]=e-(s&E);x[r>>2]=(e|0)/256;h=h+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],B);x[c+4>>2]=x[c+4>>2]+D(A,x[g+12>>2]);Pb(g+16|0,p,m);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;h=0;while(1){if((h|0)!=2){a=h<<3;b=a+y|0;a=a+u|0;x[b>>2]=x[a>>2];x[b+4>>2]=x[a+4>>2];h=h+1|0;continue}break}fb=g+48|0}function W7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=Fw(x[g>>2]);o=Ly(x[g>>2]);sh(j+4|0,o);x[f>>2]=d;a:{b:{c:{h=a;g=y[h|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31609]=0;g=P(29,k|0,g<<24>>24)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;h=a+1|0}d:{g=h;if(!((c-g|0)<=1|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31609]=0;h=P(29,k|0,48)|0;i=x[31609];x[31609]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[g+1|0];x[31609]=0;h=P(29,k|0,h|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=g+2|0;g=h;while(1){if(c>>>0<=g>>>0){break d}i=v[g|0];Od();if(!$n(i)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}i=v[g|0];Od();if(!_n(i)){break d}g=g+1|0;continue}}e:{if(Ad(x[j+8>>2],y[j+15|0])){i=x[f>>2];x[31609]=0;V(1249,k|0,h|0,g|0,i|0);i=x[31609];x[31609]=0;if((i|0)==1){break a}x[f>>2]=x[f>>2]+(g-h|0);break e}Dm(h,g);x[31609]=0;r=R(1247,o|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break a}i=h;while(1){if(g>>>0<=i>>>0){Dm((h-a|0)+d|0,x[f>>2]);break e}f:{if(v[ec(j+4|0,m)|0]<=0){break f}if(v[ec(j+4|0,m)|0]!=(l|0)){break f}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;m=(Cb(x[j+8>>2],y[j+15|0])-1>>>0>m>>>0)+m|0;l=0}q=v[i|0];x[31609]=0;q=P(29,k|0,q|0)|0;n=x[31609];x[31609]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;i=i+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){h=v[g|0];if((h|0)!=46){break g}x[31609]=0;h=R(1250,o|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;g=g+1|0}h=x[f>>2];x[31609]=0;V(1249,k|0,g|0,c|0,h|0);h=x[31609];x[31609]=0;if((h|0)==1){break a}h=f;f=x[f>>2]+(c-g|0)|0;x[h>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;tb(j+4|0);fb=j+16|0;return}x[31609]=0;h=P(29,k|0,h|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;g=g+1|0;continue}}a=N()|0;tb(j+4|0);Q(a|0);p()}function wfa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{k=hr(1,32);d:{e:{if(!k){a=tn(dc(4));x[31609]=0;S(97,a|0,124540,34);a=x[31609];x[31609]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:977;x[k>>2]=f;c=og(j+68|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31609]=0;e=P(36,j+56|0,e|0)|0;m=x[31609];x[31609]=0;j:{if((m|0)!=1){x[31609]=0;m=P(988,c|0,e|0)|0;n=x[31609];x[31609]=0;if((n|0)==1){break j}x[31609]=0;O(272,m|0,l|0);l=x[31609];x[31609]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31609]=0;e=P(36,j+44|0,e|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break g}iu(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31609]=0;a=R(852,104)|0;m=x[31609];x[31609]=0;k:{l:{m:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31609]=0;b=P(989,f|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break m}x[j+20>>2]=b;d=j+20|0;b=x[re(j+24|0,d)>>2];e=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=e;x[31609]=0;e=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=e;b=ba(1019,a|0,j|0,b|0,c|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break k}i=T(0)|0;Wc(d);break l}i=T(0)|0;break f}i=T(0)|0}Db(a);break f}x[k+28>>2]=b;Wc(j+20|0);x[k+24>>2]=b+8;Nl(c);break d}i=T(0)|0}Nl(c);Y(i|0)|0;x[31609]=0;V(983,11356,k|0,g|0,h|0);a=x[31609];x[31609]=0;if((a|0)!=1){x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)!=1){a=x[k+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);k=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break b}}Y(i|0)|0;k=0;x[31609]=0;V(983,11356,0,g|0,h|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return k|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function J1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-112|0;fb=d;yc(b);Lp(a);f=d+104|0;a:{if(!vi(b,f)){break a}if(!eG(f)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],4)){break a}tx(a);q=d,r=sx(),x[q+84>>2]=r;c=d+84|0;rx(cj(x[a+4>>2])+32|0,c);os(c);l=x[cj(x[a+4>>2])+32>>2];c=Lh(x[b>>2]);if(c&1){break a}e=c-4|0;dd(b,e);f=fb-16|0;fb=f;c=f+13|0;ex(c,b);i=y[xb(c,0)|0];j=y[xb(c,1)|0];c=xb(c,2);fb=f+16|0;i=y[c|0]|(j<<8|i<<16);if(!i){break a}x[31609]=0;O(39,l|0,i|0);c=x[31609];x[31609]=0;c:{if((c|0)==1){b=T(124540)|0;if((gb|0)!=($(124540)|0)){break c}Y(b|0)|0;Z();break a}dd(b,4);k=d+84|0;dG(k,b,e);Mn(d- -64|0,k);lf(d+76|0,x[d+64>>2],x[d+68>>2]);c=x[d+80>>2];j=x[l>>2];e=fb-32|0;fb=e;b=x[d+76>>2];q=e,r=y[xb(b,0)|0],v[q+28|0]=r;q=e,r=y[xb(b,1)|0],v[q+29|0]=r;q=e,r=y[xb(b,2)|0],v[q+30|0]=r;q=e,r=y[xb(b,3)|0],v[q+31|0]=r;f=ds(e+12|0);c=b+c|0;x[f+12>>2]=c-4;x[f+8>>2]=b;ik(f,y[c-1|0]);m=j-1|0;c=i;d:while(1){e:{f:{g:{if(!c){break g}if(ik(f,1)){break f}b=1;while(1){g=ik(f,2);b=g+b|0;if((g|0)==3){continue}break}x[e+8>>2]=b;xc(e+8|0,c);b=0;g=x[e+8>>2];while(1)if((b|0)==(g|0)){if(!c){break g}break f}else{c=c-1|0;q=j+c|0,r=ik(f,8),v[q|0]=r;b=b+1|0;continue}}fb=e+32|0;break e}g=ik(f,2);b=g+2|0;x[e+8>>2]=b;h:{if((g|0)==3){i:{if(!ik(f,1)){b=5;g=7;break i}g=y[xb(e+28|0,3)|0]}g=ik(f,g);while(1){h=ik(f,3);b=h+b|0;if((h|0)==7){continue}break}x[e+8>>2]=b;break h}g=ik(f,y[xb(e+28|0,g)|0])}xc(e+8|0,c);b=0;n=x[e+8>>2];while(1){if((b|0)==(n|0)){continue d}o=c+m|0;h=c+g|0;if(i>>>0>h>>>0){h=y[j+h|0]}else{h=0}v[o|0]=h;b=b+1|0;c=c-1|0;continue}}break}se(d+24|0,x[l>>2],x[l+4>>2]);lf(d+32|0,x[d+24>>2],x[d+28>>2]);b=Md(d+16|0);x[31609]=0;c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;b=hg(160,d+44|0,x[d+32>>2],x[d+36>>2],d+8|0);c=x[31609];x[31609]=0;if((c|0)!=1){kd(cj(x[a+4>>2])+12|0,b);ub(b);Kc(k);break b}b=N()|0;Kc(d+84|0)}Q(b|0);p()}k=1}fb=d+112|0;return k|0}function Vv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Gd(b)}if(b>>>0>=4294967232){x[31484]=48;return 0}f=b>>>0<11?16:b+11&-8;i=a-8|0;j=x[i+4>>2];e=j&-8;a:{if(!(j&3)){if(f>>>0<256){break a}if(e>>>0>=f+4>>>0){c=i;if(e-f>>>0<=x[31605]<<1>>>0){break a}}c=0;break a}g=e+i|0;b:{if(e>>>0>=f>>>0){d=e-f|0;if(d>>>0<16){break b}x[i+4>>2]=j&1|f|2;c=f+i|0;x[c+4>>2]=d|3;x[g+4>>2]=x[g+4>>2]|1;Pv(c,d);break b}if(x[31491]==(g|0)){e=e+x[31488]|0;if(e>>>0<=f>>>0){break a}x[i+4>>2]=j&1|f|2;d=f+i|0;c=e-f|0;x[d+4>>2]=c|1;x[31488]=c;x[31491]=d;break b}if(x[31490]==(g|0)){e=e+x[31487]|0;if(e>>>0<f>>>0){break a}c=e-f|0;c:{if(c>>>0>=16){x[i+4>>2]=j&1|f|2;d=f+i|0;x[d+4>>2]=c|1;e=e+i|0;x[e>>2]=c;x[e+4>>2]=x[e+4>>2]&-2;break c}x[i+4>>2]=e|j&1|2;c=e+i|0;x[c+4>>2]=x[c+4>>2]|1;c=0}x[31490]=d;x[31487]=c;break b}d=x[g+4>>2];if(d&2){break a}k=e+(d&-8)|0;if(k>>>0<f>>>0){break a}m=k-f|0;h=x[g+12>>2];d:{if(d>>>0<=255){c=x[g+8>>2];if((c|0)==(h|0)){n=125940,o=x[31485]&Dua(-2,d>>>3|0),x[n>>2]=o;break d}x[c+12>>2]=h;x[h+8>>2]=c;break d}l=x[g+24>>2];e:{if((g|0)!=(h|0)){c=x[g+8>>2];x[c+12>>2]=h;x[h+8>>2]=c;break e}f:{c=x[g+20>>2];if(c){d=g+20|0}else{c=x[g+16>>2];if(!c){break f}d=g+16|0}while(1){e=d;h=c;d=c+20|0;c=x[c+20>>2];if(c){continue}d=h+16|0;c=x[h+16>>2];if(c){continue}break}x[e>>2]=0;break e}h=0}if(!l){break d}d=x[g+28>>2];c=(d<<2)+126244|0;g:{if(x[c>>2]==(g|0)){x[c>>2]=h;if(h){break g}n=125944,o=x[31486]&Dua(-2,d),x[n>>2]=o;break d}x[(x[l+16>>2]==(g|0)?16:20)+l>>2]=h;if(!h){break d}}x[h+24>>2]=l;c=x[g+16>>2];if(c){x[h+16>>2]=c;x[c+24>>2]=h}c=x[g+20>>2];if(!c){break d}x[h+20>>2]=c;x[c+24>>2]=h}if(m>>>0<=15){x[i+4>>2]=j&1|k|2;c=i+k|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[i+4>>2]=j&1|f|2;d=f+i|0;x[d+4>>2]=m|3;c=i+k|0;x[c+4>>2]=x[c+4>>2]|1;Pv(d,m)}c=i}if(c){return c+8|0}d=Gd(b);if(!d){return 0}c=x[a-4>>2];c=(c&3?-4:-8)+(c&-8)|0;zc(d,a,b>>>0>c>>>0?c:b);Db(a);return d}function ima(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;g=fb-48|0;fb=g;i=x[a+8>>2];q=i;f=x[a+12>>2];m=f;a:{b:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){f=131112;i=m;if((i|0)>-2){e=1}else{e=(i|0)>=-2&q>>>0>=3489660928}if(e){break a}f=262184;if((m|0)==-2&q>>>0<2147483648|m>>>0<4294967294){break a}break b}f=262184;if((m|0)==1&q>>>0>2147483648|m>>>0>1){break a}}f=196648}i=f;z=x[a+16>>2];y=a+44|0;t=g+32|0;while(1){if((h|0)!=2){f=h<<3;o=f+t|0;f=f+y|0;x[o>>2]=x[f>>2];x[o+4>>2]=x[f+4>>2];h=h+1|0;continue}break}A=x[a+24>>2];B=x[a+20>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;C=b+i|0;E=x[a+72>>2];o=x[a+68>>2];F=o>>31;f=x[a+64>>2];G=f>>31;i=x[a+60>>2];H=i>>31;while(1){if(d){b=x[g+16>>2];I=(((x[g+20>>2]&2147483647)<<1|b>>>31)&-2)+z|0;b=(b>>>16&65520)+C|0;n=w[b+14>>1];r=w[b+12>>1];u=w[b+10>>1];j=w[b+8>>1];s=w[b+6>>1];l=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];h=0;p=0;while(1){if((p|0)!=2){k=p+I|0;x[(g+8|0)+(p<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],l)|0)+D(v[k|0],s)|0)+D(v[k+2|0],j)|0)+D(v[k+4|0],u)|0)+D(r,v[k+6|0])|0)+D(n,v[k+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((h|0)!=2){r=(g+8|0)+(h<<2)|0;e=x[r>>2];b=(h<<3)+t|0;u=x[b+4>>2];j=x[b>>2];x[b+4>>2]=j;s=e<<8;e=s;e=Aua(e,e>>31,i,H);l=hb;k=e;e=Yb(j,-16777216,16776704);e=Aua(f,G,e,e>>31);j=k+e|0;n=hb+l|0;n=e>>>0>j>>>0?n+1|0:n;e=Yb(u,-16777216,16776704);l=Aua(o,F,e,e>>31);j=l+j|0;e=hb+n|0;e=j>>>0<l>>>0?e+1|0:e;l=j+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Sc(l,e,24);x[b>>2]=e-(s&E);x[r>>2]=(e|0)/256;h=h+1|0;continue}break}x[c>>2]=x[c>>2]+D(B,x[g+8>>2]);x[c+4>>2]=x[c+4>>2]+D(A,x[g+12>>2]);Pb(g+16|0,q,m);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;h=0;while(1){if((h|0)!=2){a=h<<3;b=a+y|0;a=a+t|0;x[b>>2]=x[a>>2];x[b+4>>2]=x[a+4>>2];h=h+1|0;continue}break}fb=g+48|0}function oP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{d:{e:{f:{k=hr(1,28);if(!k){a=tn(dc(4));x[31609]=0;S(97,a|0,124540,34);a=x[31609];x[31609]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:977;x[k>>2]=f;c=og(j+68|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31609]=0;e=P(36,j+56|0,e|0)|0;m=x[31609];x[31609]=0;k:{if((m|0)!=1){x[31609]=0;m=P(988,c|0,e|0)|0;n=x[31609];x[31609]=0;if((n|0)==1){break k}x[31609]=0;O(272,m|0,l|0);l=x[31609];x[31609]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31609]=0;e=P(36,j+44|0,e|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break h}iu(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31609]=0;a=R(852,80)|0;m=x[31609];x[31609]=0;l:{m:{n:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31609]=0;b=P(989,f|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break n}x[j+20>>2]=b;b=j+20|0;d=x[re(j+24|0,b)>>2];e=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=e;x[31609]=0;e=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=e;d=ba(990,a|0,j|0,d|0,c|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break l}i=T(0)|0;Wc(b);break m}i=T(0)|0;break g}i=T(0)|0}Db(a);break g}x[k+24>>2]=d;Wc(j+20|0);Nl(c);i=k;break d}i=T(0)|0}Nl(c);Y(i|0)|0;x[31609]=0;V(983,15275,k|0,g|0,h|0);a=x[31609];x[31609]=0;if((a|0)!=1){x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){Db(tq(a))}i=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);break d}i=T(0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31609]=0;V(983,15275,0,g|0,h|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return i|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function Zna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=fb-16|0;fb=j;e=x[b>>2];d=Dk(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){n=fb-32|0;fb=n;e=c-d|0;d=x[Ab(b)>>2];f=x[b+4>>2];b:{if(e>>>0<=d-f>>4>>>0){f=fb-16|0;fb=f;e=jv(f+4|0,b,e);d=x[e+4>>2];g=x[e+8>>2];while(1){if((d|0)==(g|0)){jc(e);fb=f+16|0}else{Dr(d);d=d+16|0;x[e+4>>2]=d;continue}break}break b}d=Ab(b);f=MV(n+12|0,NV(b,Dk(x[b>>2],f)+e|0),Dk(x[b>>2],x[b+4>>2]),d);g=fb-16|0;fb=g;h=x[f+8>>2];d=g+4|0;x[d+8>>2]=f+8;x[d>>2]=h;x[d+4>>2]=h+(e<<4);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){Dr(e);e=x[d>>2]+16|0;x[d>>2]=e;continue}break}je(d);fb=g+16|0;k=fb-16|0;fb=k;d=vb(k+12|0,x[b+4>>2]);e=vb(k+8|0,x[b>>2]);i=x[vb(k+4|0,x[f+4>>2])>>2];l=fb-16|0;fb=l;o=l+8|0;g=fb-32|0;fb=g;fd(g+24|0,x[d>>2],x[e>>2]);p=g+16|0;d=x[g+24>>2];q=x[g+28>>2];h=fb-16|0;fb=h;x[h+8>>2]=i;x[h+12>>2]=d;while(1){if(Fd(d,q)){e=nC(d);d=nC(x[h+8>>2]);i=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);m=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);v[d+8|0]=m;v[d+9|0]=m>>>8;v[d+10|0]=m>>>16;v[d+11|0]=m>>>24;v[d+12|0]=i;v[d+13|0]=i>>>8;v[d+14|0]=i>>>16;v[d+15|0]=i>>>24;i=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);v[d|0]=e;v[d+1|0]=e>>>8;v[d+2|0]=e>>>16;v[d+3|0]=e>>>24;v[d+4|0]=i;v[d+5|0]=i>>>8;v[d+6|0]=i>>>16;v[d+7|0]=i>>>24;d=Xq(h+12|0);Xq(h+8|0);d=x[d>>2];continue}break}qc(p,d,h+8|0);fb=h+16|0;d=x[g+16>>2];x[g+12>>2]=x[g+20>>2];qc(o,d,g+12|0);fb=g+32|0;fb=l+16|0;x[f+4>>2]=x[l+12>>2];Tb(b,f+4|0);Tb(b+4|0,f+8|0);Tb(Ab(b),nc(f));x[f>>2]=x[f+4>>2];fb=k+16|0;d=x[f+4>>2];e=x[f+8>>2];while(1){if((d|0)!=(e|0)){e=e-16|0;x[f+8>>2]=e;continue}break}d=x[f>>2];if(d){vs(f);Db(d)}}fb=n+32|0;break a}if(c>>>0<d>>>0){Jd(b,e+(c<<4)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<4)){c=x[b>>2];cc(j+8|0,c,Dk(c,x[b+4>>2])<<4);sd(j,a,x[j+8>>2],x[j+12>>2])}fb=j+16|0}function jla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=fb-16|0;fb=j;c=If(a,c);ae(j,x[a+36>>2]);a:{if(!c){Qc(j,a+32|0,5);f=0;if(Gb(x[x[j>>2]>>2],x[j+4>>2])){break a}}f=fb-240|0;fb=f;h=Km(f+128|0,x[a+36>>2]);x[31609]=0;g=P(461,f+116|0,26168)|0;e=x[31609];x[31609]=0;b:{c:{d:{e:{if((e|0)!=1){x[31609]=0;x[f+96>>2]=20054022;x[f+100>>2]=0;S(462,h|0,g|0,f+96|0);e=x[31609];x[31609]=0;if((e|0)==1){break e}Eb(g);if(!ql(y[h|0])){break d}break b}a=N()|0;break c}a=N()|0;Eb(g);break c}v[f+115|0]=0;x[31609]=0;g=P(461,f+96|0,5505)|0;e=x[31609];x[31609]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((e|0)!=1){x[31609]=0;S(463,h|0,f+115|0,g|0);e=x[31609];x[31609]=0;if((e|0)==1){break p}Eb(g);g=Fb(f+84|0);x[31609]=0;e=P(461,f+72|0,10110)|0;i=x[31609];x[31609]=0;if((i|0)==1){break o}x[31609]=0;S(786,h|0,g|0,e|0);i=x[31609];x[31609]=0;if((i|0)==1){break n}Eb(e);x[31609]=0;e=f+60|0;S(258,e|0,(y[f+115|0]?0:d)|0,g|0);d=x[31609];x[31609]=0;if((d|0)==1){break m}pp(b,e);tb(e);w[f+58>>1]=0;x[31609]=0;d=P(461,f+44|0,10799)|0;e=x[31609];x[31609]=0;if((e|0)==1){break g}x[31609]=0;e=f+58|0;U(491,h|0,e|0,d|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break l}Eb(d);Hf(e,4e3);x[31609]=0;d=P(461,f+32|0,13557)|0;e=x[31609];x[31609]=0;if((e|0)==1){break k}i=z[f+58>>1];e=x[vb(f+28|0,i)>>2];x[31609]=0;V(787,h|0,b|0,d|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break j}Eb(d);w[f+26>>1]=65535;x[31609]=0;d=P(461,f+12|0,8980)|0;e=x[31609];x[31609]=0;if((e|0)==1){break i}x[31609]=0;k=U(491,h|0,f+26|0,d|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break h}e=z[f+26>>1];Eb(d);if(e>>>0<i>>>0&k){$e(b,e)}tb(g);break b}a=N()|0;break c}a=N()|0;Eb(g);break c}a=N()|0;break f}a=N()|0;Eb(e);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0}tb(g)}Ch(h);Q(a|0);p()}Ch(h);fb=f+240|0;f=c}ef(a,f);fb=j+16|0}function nta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-1104|0;fb=d;x[d+1100>>2]=c;i=eE(d+40|0,b);r=Ar(i);f=Nb(a);x[31609]=0;a=R(202,b|0)|0;c=x[31609];x[31609]=0;a:{if((c|0)!=1){x[d+12>>2]=a;x[d+36>>2]=85899345;a=d+12|0;t=d,u=D(x[Hb(a,d+36|0)>>2],50),x[t+24>>2]=u;c=d+24|0;e=x[Hb(d+1100|0,c)>>2];x[31609]=0;O(328,f|0,e|0);e=x[31609];x[31609]=0;if((e|0)!=1){x[31609]=0;h=R(340,c|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){x[31609]=0;g=P(341,a|0,8192)|0;a=x[31609];x[31609]=0;b:{if((a|0)!=1){a=x[h>>2];c=0;while(1){if((c|0)!=256){e=yb(a,c);v[e+2|0]=c;w[e>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){e=0;n=257;while(1){s=m&255;e:{while(1){j=n&65535;while(1){x[31609]=0;o=P(158,i|0,s|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Xc(x[f>>2],x[f+4>>2])>>>0>=A[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:e;a=x[h>>2];l=8192;while(1){c=c&65535;a=yb(a,c);l=l-1|0;q=l&65535;t=xb(x[g>>2],q),u=y[a+2|0],v[t|0]=u;a=x[h>>2];c=z[yb(a,c)>>1];if(c>>>0<8192){continue}break}a=vb(d+8|0,wb(x[f+4>>2]));c=vf(wb(x[g>>2]),q);l=wb(x[g+4>>2]);a=x[a>>2];x[31609]=0;V(329,f|0,a|0,c|0,l|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=x[g>>2];x[31609]=0;O(342,f|0,xb(a,q)|0);a=x[31609];x[31609]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){e=o;continue}if(Xc(x[f>>2],x[f+4>>2])>>>0>=A[d+1100>>2]){continue}break}a=y[xb(x[g>>2],q)|0];c=yb(x[h>>2],j);w[c>>1]=e;v[c+2|0]=a;a=n+1|0;n=8192;e=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<s)+m|0;n=a;continue}break}break}a=Ar(i);x[31609]=0;P(149,b|0,((a-r|0)+3&-4)+r|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}fc(g);wc(h);ub(i);fb=d+1104|0;return}c=N()|0;fc(g);break b}c=N()|0}wc(h);break a}c=N()|0;break a}c=N()|0;break a}c=N()|0}fc(f);ub(i);Q(c|0);p()}function mU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;c=fb-176|0;fb=c;e=x[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=x[a+12>>2]}else{i=x[b>>2];h=Yd(i,e+l|0);d=Yd(i,e);o=C[h>>3];p=C[h+8>>3];yj(c+160|0,d,o,p);i=x[c+172>>2];x[h+8>>2]=x[c+168>>2];x[h+12>>2]=i;i=x[c+164>>2];x[h>>2]=x[c+160>>2];x[h+4>>2]=i;zA(Yd(x[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){w=D(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=x[a>>2];e=Yd(d,j<<1);d=Yd(d,j);o=C[d>>3];p=C[d+8>>3];r=C[e>>3];s=C[e+8>>3];Li(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=x[b>>2];d=Yd(f,e);g=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=g;g=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=g;g=c+128|0;t=e+h|0;k=Yd(f,t);Li(g,r,s,C[k>>3],C[k+8>>3]);u=e+y|0;k=Yd(f,u);Li(c+112|0,o,p,C[k>>3],C[k+8>>3]);m=C[c+160>>3];n=C[c+168>>3];v=e+w|0;f=Yd(f,v);Li(c+96|0,m,n,C[f>>3],C[f+8>>3]);k=c+80|0;f=c+144|0;m=C[c+112>>3];n=C[c+120>>3];Dl(k,f,m,n);q=c- -64|0;yj(q,f,m,n);m=C[c+96>>3];n=C[c+104>>3];Dl(c+48|0,g,m,n);f=c+16|0;Pl(f,-0,-1);yj(c,g,m,n);Li(c+32|0,C[c+16>>3],C[c+24>>3],C[c>>3],C[c+8>>3]);Dl(f,k,C[c+48>>3],C[c+56>>3]);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;yj(f,k,C[c+48>>3],C[c+56>>3]);d=Yd(x[b>>2],t);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Dl(f,q,C[c+32>>3],C[c+40>>3]);d=Yd(x[b>>2],u);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;yj(f,q,C[c+32>>3],C[c+40>>3]);d=Yd(x[b>>2],v);f=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=f;f=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=f;e=e+1|0;continue}}}break}fb=c+176|0}function EO(a,b,c){a=a|0;b=E(b);c=c|0;var d=0,e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=0,n=0,o=0;d=fb-16|0;fb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(q(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=E(E(-1)/E(b*b));if(!((q(b),j(2))&2147483647)){break e}e=E(E(b-b)/E(0));if((a|0)<0){break e}a=(q(E(b*E(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=E((a>>>23|0)+c|0);b=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));f=E(b*E(b*E(.5)));g=E(b/E(b+E(2)));h=E(g*g);i=E(h*h);e=b;b=(l(2,(q(E(b-f)),j(2))&-4096),r());f=E(E(g*E(f+E(E(h*E(E(i*E(.2849878668785095))+E(.6666666269302368)))+E(i*E(E(i*E(.24279078841209412))+E(.40000972151756287))))))+E(E(e-b)-f));b=E(E(k*E(.3010292053222656))+E(E(b*E(.434326171875))+E(E(f*E(.434326171875))+E(E(k*E(7.903415166765626e-7))+E(E(f+b)*E(-3168997136526741e-20))))))}e=b}b=E(e*E(2e3));if(!(E(F(b))<E(2147483648))){break c}a=~~b;break b;case 1:a=(D(x[a+24604>>2],100)|0)/128|0;break b;case 2:c=fb-16|0;fb=c;h:{i:{j:{k:{a=y[a+24648|0];if(a>>>0>=6){a=dc(8);x[31609]=0;c=P(36,c+4|0,5123)|0;d=x[31609];x[31609]=0;if((d|0)==1){break k}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break i}d=N()|0;tb(c);break j}fb=c+16|0;a=x[(a<<2)+79288>>2];break h}d=N()|0;lc(a)}Q(d|0)}p()}break b;case 3:x[d+4>>2]=0;m=x[a+24640>>2];c=fb-80|0;fb=c;a=x[a+24636>>2];x[c+40>>2]=a;x[c>>2]=m;n=c+40|0;o=x[Ye(n,c)>>2];l:{if((a|0)==x[Tq(n)+32>>2]){a=-1;if(x[Tq(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}x[d+4>>2]=a;fb=c+80|0;a=x[d+4>>2];break b;default:break d}}c=dc(8);x[31609]=0;d=P(36,d+4|0,10401)|0;a=x[31609];x[31609]=0;m:{if((a|0)!=1){sc(c,d);x[31609]=0;S(97,c|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break m}a=N()|0;lc(c)}Q(a|0);p()}a=-2147483648}fb=d+16|0;return a|0}p()}function gP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;g=x[b+4>>2];a:{if(!g){break a}e=x[b>>2];f=y[zl(e,g)|0];if((f|0)==33){c=1}else{if((f|0)!=63){break a}c=0}Ml(d+72|0,e,g,g-1|0);g=x[d+76>>2];e=x[d+72>>2];x[b>>2]=e;x[b+4>>2]=g}e=d+72|0;ie(e);f=x[d+72>>2];ie(d+60|0);f=yl(f,x[d+64>>2],b);ie(e);b:{c:{d:{e:{if((f|0)==x[d+76>>2]){a=x[b>>2];f=pc(d+88|0,22292);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;if(Ic(a,g,d)){a=dc(8);x[31609]=0;c=P(36,e|0,10498)|0;b=x[31609];x[31609]=0;if((b|0)==1){break d}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;f=0;if(!c){break e}a=dc(8);c=x[b+4>>2];b=x[b>>2];x[31609]=0;e=$h(d+60|0,b,c);b=x[31609];x[31609]=0;f:{g:{h:{if((b|0)!=1){x[31609]=0;g=d+72|0;S(1011,g|0,18307,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break h}sc(a,g);c=0;x[31609]=0;S(97,a|0,48428,1e3);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=N()|0;tb(g);break g}b=N()|0;break f}b=N()|0;c=1}tb(e);if(!c){break c}}lc(a);break c}if(x[f+4>>2]!=1){a=dc(8);x[31609]=0;c=P(36,d+72|0,11600)|0;b=x[31609];x[31609]=0;if((b|0)!=1){sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;lc(a);break c}b=x[b>>2];c=pc(d+52|0,22292);e=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=e;if(Ic(b,g,d+24|0)){a=dc(8);x[31609]=0;c=P(36,d+72|0,10498)|0;b=x[31609];x[31609]=0;if((b|0)!=1){sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;lc(a);break c}c=pc(d+44|0,10990);e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;if(Ic(b,g,d+16|0)){e=x[a+8>>2];f=e>>31;break e}c=pc(d+36|0,8643);e=x[c+4>>2];x[d+8>>2]=x[c>>2];x[d+12>>2]=e;e=0;f=0;if(!Ic(b,g,d+8|0)){break e}e=sk(y[x[a+32>>2]+140|0]);f=0}fb=d+96|0;hb=f;return e|0}b=N()|0;lc(a)}Q(b|0)}p()}function e7(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-1056|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;k=a+944|0;x[a+940>>2]=k;j=sy(k,100,11198,a+16|0);x[a+48>>2]=1239;l=a+48|0;o=De(a+520|0,0,l);x[a+48>>2]=1239;l=De(a+512|0,0,l);a:{b:{c:{d:{if(j>>>0<100){h=a+528|0;break d}j=Od();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=ij(a+940|0,j,11198,a);if((j|0)!=-1){k=x[a+940>>2];Qe(o,k);Qe(l,Gd(j<<2));h=x[l>>2];if(!Fj(h)){break d}}x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)!=1){break a}j=N()|0;break c}cd(a+508|0,x[d+28>>2]);x[31609]=0;r=R(1252,x[a+508>>2])|0;f=x[31609];x[31609]=0;e:{f:{g:{h:{i:{j:{if((f|0)==1){break j}x[31609]=0;V(1263,r|0,k|0,j+k|0,h|0);f=x[31609];x[31609]=0;if((f|0)==1){break j}q=(j|0)>0?y[x[a+940>>2]]==45:q;i=Fb(a+484|0);f=Fb(a+472|0);g=Fb(a+460|0);x[31609]=0;ka(1292,c|0,q|0,x[a+508>>2],a+504|0,a+500|0,a+496|0,i|0,f|0,g|0,a+456|0);c=x[31609];x[31609]=0;if((c|0)==1){break i}x[a+36>>2]=1239;c=De(a+40|0,0,a+36|0);k=a+48|0;n=x[a+456>>2];k:{if((n|0)<(j|0)){m=((Cb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Cb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}m=(Cb(x[g+4>>2],y[g+11|0])+Cb(x[f+4>>2],y[f+11|0])|0)+2|0}m=m+n|0;if(m>>>0<101){break h}Qe(c,Gd(m<<2));k=x[c>>2];if(k){break h}x[31609]=0;X(1240);b=x[31609];x[31609]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}m=x[d+4>>2];x[31609]=0;ma(1293,k|0,a+36|0,a+32|0,m|0,h|0,(j<<2)+h|0,r|0,q|0,a+504|0,x[a+500>>2],x[a+496>>2],i|0,f|0,g|0,n|0);h=x[31609];x[31609]=0;if((h|0)!=1){x[31609]=0;b=ea(1273,b|0,k|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break b}}}j=N()|0;Lc(c)}Ub(g);Ub(f);tb(i)}_b(a+508|0)}Lc(l);Lc(o);Q(j|0);p()}Lc(c);Ub(g);Ub(f);tb(i);_b(a+508|0);Lc(l);Lc(o);fb=a+1056|0;return b|0}p()}function fP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-96|0;fb=e;f=x[c+4>>2];a:{if(!f){g=x[c>>2];break a}g=x[c>>2];h=y[zl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Ml(e+72|0,g,f,f-1|0);f=x[e+76>>2];g=x[e+72>>2];x[c>>2]=g;x[c+4>>2]=f}i=e+72|0;ie(i);h=x[e+72>>2];ie(e+60|0);h=yl(h,x[e+64>>2],c);ie(i);b:{c:{d:{e:{if(x[e+76>>2]==(h|0)){h=pc(e+88|0,22292);b=x[h+4>>2];x[e>>2]=x[h>>2];x[e+4>>2]=b;if(Ic(g,f,e)){c=dc(8);x[31609]=0;b=P(36,i|0,10498)|0;a=x[31609];x[31609]=0;if((a|0)==1){break d}sc(c,b);x[31609]=0;S(97,c|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}if(d){g=dc(8);b=x[c>>2];a=x[c+4>>2];x[31609]=0;d=$h(e+60|0,b,a);a=x[31609];x[31609]=0;f:{g:{h:{if((a|0)!=1){x[31609]=0;b=e+72|0;S(1011,b|0,18307,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break h}sc(g,b);c=0;x[31609]=0;S(97,g|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break g}f=N()|0;break f}f=N()|0;c=1}tb(d);if(!c){break c}}lc(g);break c}Fb(a);break e}d=pc(e+52|0,22292);c=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=c;if(Ic(g,f,e+24|0)){c=dc(8);x[31609]=0;b=P(36,e+72|0,10498)|0;a=x[31609];x[31609]=0;if((a|0)!=1){sc(c,b);x[31609]=0;S(97,c|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}f=N()|0;tb(b);break c}f=N()|0;lc(c);break c}d=pc(e+44|0,12437);c=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=c;if(Ic(g,f,e+16|0)){i:{switch(x[b+52>>2]){case 0:Dc(a,5601);break e;case 1:Dc(a,11301);break e;case 2:Dc(a,9222);break e;default:break i}}Fb(a);break e}d=pc(e+36|0,11538);c=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=c;if(Ic(g,f,e+8|0)){j:{switch(x[b+56>>2]){case 0:Dc(a,15659);break e;case 1:Dc(a,15664);break e;case 2:Dc(a,12711);break e;case 3:Dc(a,9286);break e;default:break j}}Fb(a);break e}Fb(a)}fb=e+96|0;return}f=N()|0;lc(c)}Q(f|0)}p()}function Pla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=fb-48|0;fb=f;v=a+44|0;A=x[a+16>>2];t=f+32|0;while(1){if((g|0)!=2){i=g<<3;l=i+t|0;i=i+v|0;x[l>>2]=x[i>>2];x[l+4>>2]=x[i+4>>2];g=g+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];i=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=i;B=b+24|0;C=x[a+32>>2];E=x[a+28>>2];F=x[a+72>>2];y=x[a+68>>2];G=y>>31;z=x[a+64>>2];H=z>>31;l=x[a+60>>2];I=l>>31;i=x[a+8>>2];J=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+A|0;b=(((b>>>16|0)+4&131064)<<1)+B|0;K=w[b+14>>1];k=w[b+12>>1];q=w[b+10>>1];u=w[b+8>>1];h=w[b+6>>1];r=w[b+4>>1];j=w[b+2>>1];e=w[b>>1];g=0;b=0;while(1){if((b|0)!=2){s=b<<1;o=s+p|0;x[(f+8|0)+(b<<2)>>2]=(((((D(w[o+8>>1],q)+D(w[o+4>>1],u)|0)+D(w[o+12>>1],k)|0)+D(K,w[o+16>>1])|0)/2|0)+((((D(w[p+(s|-8)>>1],j)+D(w[p+(s|-12)>>1],e)|0)+D(w[p+(s|-4)>>1],r)|0)+D(w[o>>1],h)|0)/2|0)|0)/16384;b=b+1|0;continue}break}while(1){if((g|0)!=2){q=(f+8|0)+(g<<2)|0;e=x[q>>2];b=(g<<3)+t|0;u=x[b+4>>2];h=x[b>>2];x[b+4>>2]=h;r=e<<8;e=r;e=Aua(e,e>>31,l,I);j=hb;k=e;e=Yb(h,-16777216,16776704);e=Aua(z,H,e,e>>31);h=k+e|0;k=hb+j|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(u,-16777216,16776704);j=Aua(y,G,e,e>>31);h=j+h|0;e=hb+k|0;e=h>>>0<j>>>0?e+1|0:e;j=h+8388608|0;e=j>>>0<8388608?e+1|0:e;e=Sc(j,e,24);x[b>>2]=e-(r&F);x[q>>2]=(e|0)/256;g=g+1|0;continue}break}n=n+E|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+C|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Pb(f+16|0,i,J);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;g=0;while(1){if((g|0)!=2){a=g<<3;b=a+v|0;a=a+t|0;x[b>>2]=x[a>>2];x[b+4>>2]=x[a+4>>2];g=g+1|0;continue}break}fb=f+48|0}function Kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-96|0;fb=d;f=1;g=x[c+4>>2];h=y[c+11|0];a:{if(Ad(g,h)){break a}e=y[yz(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+84|0;zx(e,c,0,_c(g,h)-1|0);zb(c,e);tb(e)}e=d+84|0;ie(e);g=x[d+84>>2];ie(d+72|0);g=TM(g,x[d+76>>2],c);ie(e);b:{c:{d:{e:{f:{if((g|0)==x[d+88>>2]){if(Nd(c,22292)){a=dc(8);x[31609]=0;b=P(36,e|0,10498)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}if(!f){break f}a=dc(8);x[31609]=0;b=d+84|0;S(1002,b|0,18307,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}c=N()|0;lc(a);break c}e=Fb(d+84|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:fe(d- -64|0,c);x[31609]=0;c=x[d+68>>2];x[d+8>>2]=x[d+64>>2];x[d+12>>2]=c;b=U(1003,b|0,d+8|0,f|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){x[31609]=0;v[d+72|0]=b;O(1004,a|0,d+72|0);a=x[31609];x[31609]=0;if((a|0)!=1){break g}}break i;case 1:fe(d+56|0,c);x[31609]=0;c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;b=bI(b,d+16|0,f);c=hb;f=x[31609];x[31609]=0;if((f|0)!=1){x[31609]=0;x[d+72>>2]=b;x[d+76>>2]=c;O(1006,a|0,d+72|0);a=x[31609];x[31609]=0;if((a|0)!=1){break g}}break i;case 2:fe(d+48|0,c);x[31609]=0;c=x[d+52>>2];x[d+24>>2]=x[d+48>>2];x[d+28>>2]=c;i=+oa(1007,b|0,d+24|0,f|0);b=x[31609];x[31609]=0;if((b|0)!=1){x[31609]=0;C[d+72>>3]=i;O(1008,a|0,d+72|0);a=x[31609];x[31609]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}fe(d+40|0,c);x[31609]=0;c=x[d+44>>2];x[d+32>>2]=x[d+40>>2];x[d+36>>2]=c;V(1009,a|0,b|0,d+32|0,f|0);a=x[31609];x[31609]=0;if((a|0)!=1){break g}}c=N()|0;tb(e);break c}Uc(a,e)}tb(e);break e}Fb(a)}fb=d+96|0;return}c=N()|0;lc(a)}Q(c|0)}p()}function Vqa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=x[a>>2];b=Ov(e,x[a+4>>2]);if(b>>>0<=63){h=fb-32|0;fb=h;g=64-b|0;b=x[Ab(a)>>2];c=x[a+4>>2];a:{if(g>>>0<=(b-c|0)/33>>>0){e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+D(g,33);c=x[b+4>>2];a=x[b+8>>2];while(1){if((a|0)==(c|0)){jc(b);fb=e+16|0}else{KY(c);c=c+33|0;x[b+4>>2]=c;continue}break}break a}i=Ab(a);e=h+12|0;f=Ov(x[a>>2],c)+g|0;c=fb-16|0;fb=c;x[c+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=130150524;x[d+8>>2]=2147483647;b=x[Hb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(b>>>0>=f>>>0){d=NY(a);if(d>>>0<b>>>1>>>0){x[c+8>>2]=d<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}ed();p()}f=Ov(x[a>>2],x[a+4>>2]);d=fb-16|0;fb=d;Lg(e+12|0,i);c:{if(!b){c=0;b=0;break c}if(b>>>0>=130150525){Sj();p()}c=Ec(D(b,33));x[d+12>>2]=b;x[d+8>>2]=c;c=x[d+12>>2];b=x[d+8>>2]}x[e>>2]=b;f=b+D(f,33)|0;x[e+8>>2]=f;x[e+4>>2]=f;l=nc(e),m=b+D(c,33)|0,x[l>>2]=m;fb=d+16|0;d=fb-16|0;fb=d;c=x[e+8>>2];b=d+4|0;x[b+8>>2]=e+8;x[b>>2]=c;x[b+4>>2]=c+D(g,33);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){KY(c);c=x[b>>2]+33|0;x[b>>2]=c;continue}break}je(b);fb=d+16|0;g=fb-16|0;fb=g;b=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);i=x[vb(g+4|0,x[e+4>>2])>>2];f=fb-16|0;fb=f;c=fb-32|0;fb=c;fd(c+24|0,x[b>>2],x[d>>2]);j=c+16|0;b=x[c+24>>2];k=x[c+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=i;x[d+12>>2]=b;while(1){if(Fd(b,k)){b=MY(b);zc(MY(x[d+8>>2]),b,33);b=LY(d+12|0);LY(d+8|0);b=x[b>>2];continue}break}qc(j,b,d+8|0);fb=d+16|0;b=x[c+16>>2];x[c+12>>2]=x[c+20>>2];qc(f+8|0,b,c+12|0);fb=c+32|0;fb=f+16|0;x[e+4>>2]=x[f+12>>2];Tb(a,e+4|0);Tb(a+4|0,e+8|0);Tb(Ab(a),nc(e));x[e>>2]=x[e+4>>2];fb=g+16|0;b=x[e+4>>2];a=x[e+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;x[e+8>>2]=a;continue}break}a=x[e>>2];if(a){nc(e);Db(a)}}fb=h+32|0;return}if((b|0)!=64){Jd(a,e+2112|0)}}function hW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=x[a>>2];e=Rh(c,x[a+4>>2]);if(e>>>0<b>>>0){h=fb-32|0;fb=h;g=b-e|0;b=x[Ab(a)>>2];c=x[a+4>>2];a:{if(g>>>0<=b-c>>8>>>0){e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(g<<8);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){jc(b);fb=e+16|0}else{OV(a);a=a+256|0;x[b+4>>2]=a;continue}break}break a}i=Ab(a);e=h+12|0;f=Rh(x[a>>2],c)+g|0;c=fb-16|0;fb=c;x[c+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=16777215;x[d+8>>2]=2147483647;b=x[Hb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(b>>>0>=f>>>0){d=oC(a);if(d>>>0<b>>>1>>>0){x[c+8>>2]=d<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}ed();p()}f=Rh(x[a>>2],x[a+4>>2]);d=fb-16|0;fb=d;Lg(e+12|0,i);c:{if(!b){c=0;b=0;break c}if(b>>>0>=16777216){Sj();p()}c=Ec(b<<8);x[d+12>>2]=b;x[d+8>>2]=c;c=x[d+8>>2];b=x[d+12>>2]}x[e>>2]=c;f=c+(f<<8)|0;x[e+8>>2]=f;x[e+4>>2]=f;l=nc(e),m=c+(b<<8)|0,x[l>>2]=m;fb=d+16|0;d=fb-16|0;fb=d;b=x[e+8>>2];c=d+4|0;x[c+8>>2]=e+8;x[c>>2]=b;x[c+4>>2]=b+(g<<8);b=x[c>>2];while(1){if(x[c+4>>2]!=(b|0)){OV(b);b=x[c>>2]+256|0;x[c>>2]=b;continue}break}je(c);fb=d+16|0;g=fb-16|0;fb=g;c=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);i=x[vb(g+4|0,x[e+4>>2])>>2];f=fb-16|0;fb=f;b=fb-32|0;fb=b;fd(b+24|0,x[c>>2],x[d>>2]);j=b+16|0;d=x[b+24>>2];k=x[b+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=i;x[c+12>>2]=d;while(1){if(Fd(d,k)){d=QV(d);zc(QV(x[c+8>>2]),d,256);d=PV(c+12|0);PV(c+8|0);d=x[d>>2];continue}break}qc(j,d,c+8|0);fb=c+16|0;c=x[b+16>>2];x[b+12>>2]=x[b+20>>2];qc(f+8|0,c,b+12|0);fb=b+32|0;fb=f+16|0;x[e+4>>2]=x[f+12>>2];Tb(a,e+4|0);Tb(a+4|0,e+8|0);Tb(Ab(a),nc(e));x[e>>2]=x[e+4>>2];fb=g+16|0;b=x[e+4>>2];a=x[e+8>>2];while(1){if((a|0)!=(b|0)){a=a-256|0;x[e+8>>2]=a;continue}break}a=x[e>>2];if(a){nc(e);Db(a)}}fb=h+32|0;return}if(b>>>0<e>>>0){Jd(a,c+(b<<8)|0)}}function i7(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-448|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;k=a+336|0;x[a+332>>2]=k;j=sy(k,100,11198,a+16|0);x[a+48>>2]=1239;l=a+48|0;o=De(a+216|0,0,l);x[a+48>>2]=1239;l=De(a+208|0,0,l);a:{b:{c:{d:{if(j>>>0<100){h=a+224|0;break d}j=Od();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=ij(a+332|0,j,11198,a);if((j|0)!=-1){k=x[a+332>>2];Qe(o,k);Qe(l,Gd(j));h=x[l>>2];if(!Fj(h)){break d}}x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)!=1){break a}j=N()|0;break c}cd(a+204|0,x[d+28>>2]);x[31609]=0;r=R(28,x[a+204>>2])|0;f=x[31609];x[31609]=0;e:{f:{g:{h:{i:{j:{if((f|0)==1){break j}x[31609]=0;V(1249,r|0,k|0,j+k|0,h|0);f=x[31609];x[31609]=0;if((f|0)==1){break j}q=(j|0)>0?y[x[a+332>>2]]==45:q;i=Fb(a+184|0);f=Fb(a+172|0);g=Fb(a+160|0);x[31609]=0;ka(1290,c|0,q|0,x[a+204>>2],a+200|0,a+199|0,a+198|0,i|0,f|0,g|0,a+156|0);c=x[31609];x[31609]=0;if((c|0)==1){break i}x[a+36>>2]=1239;c=De(a+40|0,0,a+36|0);k=a+48|0;n=x[a+156>>2];k:{if((n|0)<(j|0)){m=((Cb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Cb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}m=(Cb(x[g+4>>2],y[g+11|0])+Cb(x[f+4>>2],y[f+11|0])|0)+2|0}m=m+n|0;if(m>>>0<101){break h}Qe(c,Gd(m));k=x[c>>2];if(k){break h}x[31609]=0;X(1240);b=x[31609];x[31609]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}m=x[d+4>>2];x[31609]=0;ma(1291,k|0,a+36|0,a+32|0,m|0,h|0,h+j|0,r|0,q|0,a+200|0,v[a+199|0],v[a+198|0],i|0,f|0,g|0,n|0);h=x[31609];x[31609]=0;if((h|0)!=1){x[31609]=0;b=ea(23,b|0,k|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break b}}}j=N()|0;Lc(c)}tb(g);tb(f);tb(i)}_b(a+204|0)}Lc(l);Lc(o);Q(j|0);p()}Lc(c);tb(g);tb(f);tb(i);_b(a+204|0);Lc(l);Lc(o);fb=a+448|0;return b|0}p()}function Qla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=fb-48|0;fb=f;u=a+44|0;A=x[a+16>>2];s=f+32|0;while(1){if((g|0)!=2){j=g<<3;m=j+s|0;j=j+u|0;x[m>>2]=x[j>>2];x[m+4>>2]=x[j+4>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;B=b+24|0;C=x[a+32>>2];E=x[a+28>>2];F=x[a+72>>2];y=x[a+68>>2];G=y>>31;z=x[a+64>>2];H=z>>31;m=x[a+60>>2];I=m>>31;j=x[a+8>>2];J=x[a+12>>2];while(1){if(d){b=x[f+16>>2];K=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+A|0;b=(((b>>>16|0)+4&131064)<<1)+B|0;l=w[b+14>>1];q=w[b+12>>1];t=w[b+10>>1];h=w[b+8>>1];r=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=p+K|0;x[(f+8|0)+(p<<2)>>2]=((((D(v[i+4|0],t)+D(v[i+2|0],h)|0)+D(q,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],r)<<8>>1)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){q=(f+8|0)+(g<<2)|0;e=x[q>>2];b=(g<<3)+s|0;t=x[b+4>>2];h=x[b>>2];x[b+4>>2]=h;r=e<<8;e=r;e=Aua(e,e>>31,m,I);k=hb;i=e;e=Yb(h,-16777216,16776704);e=Aua(z,H,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(t,-16777216,16776704);k=Aua(y,G,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Sc(k,e,24);x[b>>2]=e-(r&F);x[q>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+E|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+C|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Pb(f+16|0,j,J);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){a=g<<3;b=a+u|0;a=a+s|0;x[b>>2]=x[a>>2];x[b+4>>2]=x[a+4>>2];g=g+1|0;continue}break}fb=f+48|0}function tfa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{j=hr(1,32);d:{e:{if(!j){a=tn(dc(4));x[31609]=0;S(97,a|0,124540,34);a=x[31609];x[31609]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:977;x[j>>2]=f;c=og(k+36|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31609]=0;e=P(36,k+24|0,e|0)|0;m=x[31609];x[31609]=0;j:{if((m|0)!=1){x[31609]=0;m=P(988,c|0,e|0)|0;n=x[31609];x[31609]=0;if((n|0)==1){break j}x[31609]=0;O(272,m|0,l|0);l=x[31609];x[31609]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31609]=0;e=P(36,k+12|0,e|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break g}iu(c,e)}tb(e);i=i+8|0;continue}}x[31609]=0;e=R(852,104)|0;i=x[31609];x[31609]=0;k:{l:{m:{if((i|0)!=1){x[31609]=0;d=P(989,f|0,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break m}x[k+4>>2]=d;d=k+4|0;f=x[re(k+8|0,d)>>2];x[31609]=0;a=ha(1020,e|0,a|0,b|0,f|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break k}i=T(0)|0;Wc(d);break l}i=T(0)|0;break f}i=T(0)|0}Db(e);break f}x[j+28>>2]=a;Wc(k+4|0);x[j+24>>2]=a+8;Nl(c);break d}i=T(0)|0}Nl(c);Y(i|0)|0;x[31609]=0;V(983,4973,j|0,g|0,h|0);a=x[31609];x[31609]=0;if((a|0)!=1){x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)!=1){a=x[j+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);j=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break b}}Y(i|0)|0;j=0;x[31609]=0;V(983,4973,0,g|0,h|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return j|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function Y6(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;q=fb-16|0;fb=q;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!y[i|0]){break a}i=i+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}k=x[b+4>>2];x[q+8>>2]=x[b>>2];x[q+12>>2]=k;r=fb-16|0;fb=r;u=rh(r+12|0,x[a+8>>2]);o=i-c|0;l=0;n=fb-1040|0;fb=n;k=x[e>>2];x[n+12>>2]=k;p=f?f:n+16|0;m=f?g-f>>2:256;e:{f:{g:{if(!(!k|!m)){while(1){j=o>>>2|0;if(!(o>>>0>131|j>>>0>=m>>>0)){j=k;break f}s=cK(p,n+12|0,j>>>0<m>>>0?j:m,b);j=x[n+12>>2];if((s|0)==-1){m=0;l=-1;break g}t=(n+16|0)!=(p|0)?s:0;m=m-t|0;p=(t<<2)+p|0;o=j?(k+o|0)-j|0:0;l=l+s|0;if(!j){break g}k=j;if(m){continue}break g}}j=k}if(!j){break e}}if(!m|!o){break e}k=l;while(1){h:{l=fq(p,j,o,b);i:{if(l+2>>>0<=2){j:{switch(l+1|0){case 1:x[n+12>>2]=0;break i;case 0:break e;default:break j}}x[b>>2]=0;break i}j=x[n+12>>2]+l|0;x[n+12>>2]=j;k=k+1|0;m=m-1|0;if(m){break h}}l=k;break e}p=p+4|0;o=o-l|0;l=k;if(o){continue}break}}if(f){x[e>>2]=x[n+12>>2]}fb=n+1040|0;qh(u);fb=r+16|0;k:{l:{m:{n:{if((l|0)==-1){while(1){o:{x[h>>2]=f;if(x[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=py(f,c,i-c|0,q+8|0,x[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}x[e>>2]=c;break n}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(l<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break k}c=x[e>>2];if((d|0)==(i|0)){i=d;continue}if(!py(f,c,1,b,x[a+8>>2])){break m}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!y[i|0]){break b}i=i+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}fb=q+16|0;return a|0}f=x[h>>2];continue}}function CX(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];a:{b:{if((c-16&255)>>>0<=128){v[a+2|0]=1;c=c+496>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];d=y[b+5|0];e=y[b+4|0];d:{if(!(c|(d|e))){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[Qb(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d;case 0:Cf(a,c,d);g=y[b+6|0]==15;break d;case 1:v[a+3|0]=2;h=a,i=Eh(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 2:v[a+3|0]=3;h=a,i=Eh(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 3:v[a+3|0]=4;h=a,i=Eh(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 4:v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d;case 12:v[a+3|0]=13;v[a+5|0]=c>>>1;break d;case 15:if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}BD(a,c,d,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];l:{if(!b){break l}m:{if(!y[a+3|0]){v[a+3|0]=9;c=5;break m}if(y[a+2|0]){break l}v[a+2|0]=2;b=b>>>2|0;c=4}v[c+a|0]=b}fb=f+16|0;return g}function Ou(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;c=D(c,872)+b|0;x[c+704>>2]=x[c+704>>2]|524288;c=c+616|0;a:{b:{if(!(y[a+480208|0]&8)){if(Ob(a+1074312|0,15)|x[a+480180>>2]==268435456){break b}break a}if(x[a+480180>>2]!=268435456){break a}}d=d?d:y[c+811|0];v[c+811|0]=d;v[c+812|0]=d}if(d){w[c+768>>1]=d}c:{g=x[c+656>>2];if(Kj(g)){a=z[c+768>>1];if(!a){break c}d=x[b+16>>2];e=d?x[c+856>>2]:e;h=0-a|0;f=a;a=x[c+708>>2];i=(+(d>>>0)+1)*+(((a|0)<0?h:f)|0)/+A[b+40>>2];d:{if(F(i)<2147483648){d=~~i;break d}d=-2147483648}x[c+856>>2]=d;if(y[c+90|0]&16){d=D(x[x[g+44>>2]+36>>2]+1|0,d);x[c+856>>2]=d}b=d-e|0;d=b>>31;e=a>>31;if((e^a)-e>>>0<=(b^d)-d>>>0){if(!a){break c}x[c+708>>2]=0;x[c+852>>2]=a+x[c+852>>2];v[c+851|0]=y[c+851|0]|64;return 0}x[c+708>>2]=a-b;x[c+852>>2]=b+x[c+852>>2];v[c+851|0]=y[c+851|0]|64;break c}g=a+1074312|0;e:{if(!(!Ob(g,118)|!(y[c+89|0]&2))){d=0;if(Tc(y[c+788|0])){break e}}e=1;f:{if(!(v[c+851|0]&1)){break f}d=x[a+480180>>2];if(d&524352){break f}if(x[b+40>>2]==1){if(Ob(g,6)){break f}d=x[a+480180>>2]}e=0;if((d|0)!=8){break f}e=(y[a+480208|0]&2)>>>1|0}d=x[a+480180>>2];b=z[c+768>>1];if(!((d|0)!=268435456|b>>>0<240)){e=v[c+851|0]&1;b=b-240|0}d=b<<((d|0)==64?1:2);g:{if(!x[c+700>>2]|!(x[c+708>>2]!=0&e)){break g}b=c+700|0;f=zj(a)?d:0-d|0;h=x[c+708>>2];j=x[c+700>>2];if(!(!(y[c+851|0]&16)&(h|0)<=(j|0))){wk(a,c,b,f,1);f=x[c+708>>2];if((f|0)>=x[c+700>>2]){break g}x[b>>2]=f;break g}if((h|0)>=(j|0)){break g}wk(a,c,b,0-f|0,1);h=x[c+700>>2];f=x[c+708>>2];h:{if((h|0)<(f|0)){x[b>>2]=f;break h}if((f|0)!=(h|0)){break g}}if(!Ob(g,112)){break g}v[c+851|0]=y[c+851|0]|16}i:{if(x[c+700>>2]!=x[c+708>>2]){break i}if(!Ob(g,25)&x[a+480180>>2]!=1){break i}x[c+708>>2]=0}d=e?d:0}return d}return 0}function mP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{d:{e:{f:{j=hr(1,28);if(!j){a=tn(dc(4));x[31609]=0;S(97,a|0,124540,34);a=x[31609];x[31609]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:977;x[j>>2]=f;c=og(k+36|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31609]=0;e=P(36,k+24|0,e|0)|0;m=x[31609];x[31609]=0;k:{if((m|0)!=1){x[31609]=0;m=P(988,c|0,e|0)|0;n=x[31609];x[31609]=0;if((n|0)==1){break k}x[31609]=0;O(272,m|0,l|0);l=x[31609];x[31609]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31609]=0;e=P(36,k+12|0,e|0)|0;l=x[31609];x[31609]=0;if((l|0)==1){break h}iu(c,e)}tb(e);i=i+8|0;continue}}x[31609]=0;e=R(852,80)|0;i=x[31609];x[31609]=0;l:{m:{n:{if((i|0)!=1){x[31609]=0;d=P(989,f|0,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break n}x[k+4>>2]=d;d=k+4|0;f=x[re(k+8|0,d)>>2];x[31609]=0;a=ha(994,e|0,a|0,b|0,f|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break l}i=T(0)|0;Wc(d);break m}i=T(0)|0;break g}i=T(0)|0}Db(e);break g}x[j+24>>2]=a;Wc(k+4|0);Nl(c);i=j;break d}i=T(0)|0}Nl(c);Y(i|0)|0;x[31609]=0;V(983,15174,j|0,g|0,h|0);a=x[31609];x[31609]=0;if((a|0)!=1){x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){Db(tq(a))}i=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);break d}i=T(0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31609]=0;V(983,15174,0,g|0,h|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return i|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Sb()}p()}function Eg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=i;g=y[a+79|0]?z[x[a>>2]+3836>>1]:g;c=z[a+20>>1];h=z[a+22>>1];k=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=c+(b&z[a+46>>1]?0:z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;b=2;j=z[a+28>>1];if((j|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+58>>1]?0:z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((f>>>z[a+56>>1]&7)<<1)>>1]|0:0)|0;w[a+20>>1]=f;if(f<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;f=z[x[a>>2]+3832>>1];f=c+(f&z[a+34>>1]?0:z[a+24>>1]?D((c^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=j}h=((c+h|0)+k|0)+g<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(i>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:g=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+26768>>1];break e;case 1:g=0;b=z[((b&512?0:b&256?c^255:c)<<1)+26768>>1];break e;case 2:g=0;b=z[((b&256?c^255:c)<<1)+26768>>1];break e;case 3:g=0;b=z[((b&256?0:c)<<1)+26768>>1];break e;case 4:g=0;if(b&512){b=0}else{g=(d&256)>>>8|0;b=(c<<1^b<<24>>31)&254}b=z[(b<<1)+26768>>1];break e;case 5:g=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+26768>>1];break e;case 6:g=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;g=(b&512)>>>9|0;b=g?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+h&65535;a=a>>>0>=8191?8191:a;b=0-(g&1)^z[((a&255)<<1)+26256>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function Tla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;t=a+44|0;y=x[a+16>>2];r=f+32|0;while(1){if((g|0)!=2){i=g<<3;l=i+r|0;i=i+t|0;x[l>>2]=x[i>>2];x[l+4>>2]=x[i+4>>2];g=g+1|0;continue}break}z=x[a+24>>2];A=x[a+20>>2];i=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=i;B=b+24|0;C=x[a+72>>2];u=x[a+68>>2];E=u>>31;v=x[a+64>>2];F=v>>31;l=x[a+60>>2];G=l>>31;i=x[a+8>>2];H=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=(((b>>>16|0)+4&131064)<<1)+B|0;I=w[b+14>>1];k=w[b+12>>1];o=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];p=w[b+4>>1];j=w[b+2>>1];e=w[b>>1];g=0;b=0;while(1){if((b|0)!=2){q=b<<1;m=q+n|0;x[(f+8|0)+(b<<2)>>2]=(((((D(w[m+8>>1],o)+D(w[m+4>>1],s)|0)+D(w[m+12>>1],k)|0)+D(I,w[m+16>>1])|0)/2|0)+((((D(w[n+(q|-8)>>1],j)+D(w[n+(q|-12)>>1],e)|0)+D(w[n+(q|-4)>>1],p)|0)+D(w[m>>1],h)|0)/2|0)|0)/16384;b=b+1|0;continue}break}while(1){if((g|0)!=2){o=(f+8|0)+(g<<2)|0;e=x[o>>2];b=(g<<3)+r|0;s=x[b+4>>2];h=x[b>>2];x[b+4>>2]=h;p=e<<8;e=p;e=Aua(e,e>>31,l,G);j=hb;k=e;e=Yb(h,-16777216,16776704);e=Aua(v,F,e,e>>31);h=k+e|0;k=hb+j|0;k=e>>>0>h>>>0?k+1|0:k;e=Yb(s,-16777216,16776704);j=Aua(u,E,e,e>>31);h=j+h|0;e=hb+k|0;e=h>>>0<j>>>0?e+1|0:e;j=h+8388608|0;e=j>>>0<8388608?e+1|0:e;e=Sc(j,e,24);x[b>>2]=e-(p&C);x[o>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],A);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],z);Pb(f+16|0,i,H);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){a=g<<3;b=a+t|0;a=a+r|0;x[b>>2]=x[a>>2];x[b+4>>2]=x[a+4>>2];g=g+1|0;continue}break}fb=f+48|0}function Ah(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=fb-16|0;fb=c;a:{if((d|0)==189){v[a+3843|0]=e>>>7;v[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}h=a+16|0;a=0;b=1;while(1){if((a|0)==6){break a}d=h+D(a>>>0<3?a:a+6|0,44)|0;f=d+132|0;g=b&e;b:{if(g){Oo(d,f);break b}Oo(d,0)}v[f+40|0]=!g;a=a+1|0;b=b<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=D(d&256?b+9|0:b,44)+a|0;x[c+8>>2]=a+16;b=x[a+52>>2];x[c+12>>2]=b;f=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}h=e&3;g=e>>>2&7;a=0;d=(e&32)!=0;while(1){if((a|0)==(f|0)){break a}b=x[(c+8|0)+(a<<2)>>2];DU(x[b>>2],d);DU(x[b+4>>2],d);w[b+22>>1]=g;VB(b);FU(b);v[b+21|0]=h;VB(b);FU(b);a=a+1|0;continue}}a=0;while(1){if((a|0)==(f|0)){break a}b=x[(c+8|0)+(a<<2)>>2];w[b+20>>1]=z[b+20>>1]&768|e&255;VB(b);a=a+1|0;continue}}v[a+58|0]=(e&32)>>>5;v[a+57|0]=(e&16)>>>4;b=e>>>1&7;w[a+46>>1]=b?9-b|0:0;w[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=v[(d&31)+27360|0];a=(f+D(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:v[a+79|0]=e>>>7;v[a+80|0]=(e&64)>>>6;v[a+78|0]=(e&32)>>>5;v[a+77|0]=(e&16)>>>4;Po(a);b=fb-32|0;x[b+24>>2]=1572888;x[b+28>>2]=1966110;x[b+16>>2]=1179664;x[b+20>>2]=1310740;x[b+8>>2]=655368;x[b+12>>2]=917516;x[b>>2]=131073;x[b+4>>2]=393220;w[a+14>>1]=z[b+((e&15)<<1)>>1];break a;case 1:w[a+68>>1]=y[(e>>>6|0)+22277|0];EU(a);w[a+22>>1]=(e&63)<<2;break a;case 2:w[a+24>>1]=e>>>4;Po(a);w[a+26>>1]=e&15;Po(a);break a;case 3:b=e>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=e&15;Po(a);break a;case 6:break d;default:break a}}w[a+12>>1]=e&7}fb=c+16|0;return}ib[x[x[b>>2]>>2]](b,c,d,e)}function tt(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=xt(c,d);x[i+4>>2]=1239;n=wt(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Gd(k);if(!j){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)!=1){break a}break b}Qe(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31609]=0;h=P(1257,a|0,i+124|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break f}if((!k|h)==1){x[31609]=0;b=P(1257,a|0,i+124|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31609]=0;o=R(1258,b|0)|0;b=x[31609];x[31609]=0;g:{if((b|0)!=1){if(g){break g}x[31609]=0;o=P(1259,e|0,o|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31609]=0;R(1260,a|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Cb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=x[Wd(b,q)>>2];j:{if(g){break j}x[31609]=0;r=P(1259,e|0,r|0)|0;t=x[31609];x[31609]=0;if((t|0)!=1){break j}break b}k:{if((o|0)==(r|0)){s=1;if((Cb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Ad(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Lc(n);fb=i+128|0;return d|0}}a=N()|0;Lc(n);Q(a|0)}p()}function yt(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=xt(c,d);x[i+4>>2]=1239;n=wt(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Gd(k);if(!j){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)!=1){break a}break b}Qe(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31609]=0;h=P(1241,a|0,i+124|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break f}if((!k|h)==1){x[31609]=0;b=P(1241,a|0,i+124|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31609]=0;o=R(1242,b|0)|0;b=x[31609];x[31609]=0;g:{if((b|0)!=1){if(g){break g}x[31609]=0;o=P(1243,e|0,o|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31609]=0;R(1244,a|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Cb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=v[ec(b,q)|0];j:{if(g){break j}x[31609]=0;r=P(1243,e|0,r|0)|0;t=x[31609];x[31609]=0;if((t|0)!=1){break j}break b}k:{if((o|0)==(r|0)){s=1;if((Cb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=Ad(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Lc(n);fb=i+128|0;return d|0}}a=N()|0;Lc(n);Q(a|0)}p()}function Fna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-48|0;fb=h;k=c+484344|0;Tf(k,y[b+70|0]|y[b+71|0]<<8);a:{b:{while(1){if((y[b+70|0]|y[b+71|0]<<8)>>>0<=j>>>0){break b}f=x[a+8>>2];e=Rg(a);Vb(a,1);c:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=Zd(a)+1|0;break c}c=gh(a)}d=gh(a);dd(a,e+f|0);e=h+8|0;he(e,a,d);f=hc(h+28|0,e);ub(e);x[31609]=0;c=U(196,k|0,j&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Wb(x[k>>2],j);m=h,n=wb(x[c>>2]),x[m+8>>2]=n;l=wb(x[c+4>>2]);while(1){c=x[h+8>>2];if(!Ib(c,l)){break d}x[31609]=0;d=R(197,f|0)|0;e=x[31609];x[31609]=0;e:{f:{g:{if((e|0)!=1){e=d<<24>>24;if((e|0)>=0){break g}if(e&1){x[31609]=0;d=R(197,f|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break a}v[c|0]=d}d=e&255;if(e&2){break f}break e}break a}v[c|0]=e;d=255}x[31609]=0;e=R(197,f|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break a}v[c+1|0]=e}i=0;e=0;if(d&4){x[31609]=0;e=R(197,f|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break a}}if(d&8){x[31609]=0;i=R(197,f|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break a}}if(d&16){x[31609]=0;d=R(197,f|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break a}v[c+5|0]=d}h:{i:{d=y[c|0];if(!d){break i}g=255;if((d|0)==97){break h}if(d>>>0>96){break i}g=d+12|0;break h}g=0}v[c|0]=g;d=y[c+5|0];j:{if((d|i)&255){Cf(c,i,d);break j}v[c+3|0]=0}if(y[c+1|0]==255){v[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){v[c+4|0]=d;v[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;v[c+4|0]=d;e=e-96>>>4|0;v[c+2|0]=y[e+25502|0];if((e|0)!=6){break k}v[c+4|0]=d<<2}tg(h+8|0);continue}}ub(f);j=j+1|0;continue}break}break a}fb=h+48|0;return}a=N()|0;ub(f);Q(a|0);p()}function H4(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Cb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(x[Wd(d,b)>>2]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=x[Wd(d,b+1|0)>>2];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=x[Wd(d,a+1|0)>>2];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(x[Wd(d,a+1|0)>>2]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(x[Wd(d,a+1|0)>>2]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(x[Wd(d,a)>>2]==121){break b}if(x[Wd(d,a)>>2]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(x[Wd(d,a+1|0)>>2]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(x[Wd(d,a)>>2]==121){break b}if(x[Wd(d,a)>>2]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(x[Wd(d,b)>>2]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(x[Wd(d,a+1|0)>>2]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function Ula(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;s=a+44|0;y=x[a+16>>2];q=f+32|0;while(1){if((g|0)!=2){j=g<<3;m=j+q|0;j=j+s|0;x[m>>2]=x[j>>2];x[m+4>>2]=x[j+4>>2];g=g+1|0;continue}break}z=x[a+24>>2];A=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;B=b+24|0;C=x[a+72>>2];t=x[a+68>>2];E=t>>31;u=x[a+64>>2];F=u>>31;m=x[a+60>>2];G=m>>31;j=x[a+8>>2];H=x[a+12>>2];while(1){if(d){b=x[f+16>>2];I=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(((b>>>16|0)+4&131064)<<1)+B|0;l=w[b+14>>1];o=w[b+12>>1];r=w[b+10>>1];h=w[b+8>>1];p=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=n+I|0;x[(f+8|0)+(n<<2)>>2]=((((D(v[i+4|0],r)+D(v[i+2|0],h)|0)+D(o,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],p)<<8>>1)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){o=(f+8|0)+(g<<2)|0;e=x[o>>2];b=(g<<3)+q|0;r=x[b+4>>2];h=x[b>>2];x[b+4>>2]=h;p=e<<8;e=p;e=Aua(e,e>>31,m,G);k=hb;i=e;e=Yb(h,-16777216,16776704);e=Aua(u,F,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(r,-16777216,16776704);k=Aua(t,E,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Sc(k,e,24);x[b>>2]=e-(p&C);x[o>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],A);x[c+4>>2]=x[c+4>>2]+D(z,x[f+12>>2]);Pb(f+16|0,j,H);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){a=g<<3;b=a+s|0;a=a+q|0;x[b>>2]=x[a>>2];x[b+4>>2]=x[a+4>>2];g=g+1|0;continue}break}fb=f+48|0}function hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=fb-192|0;fb=c;e=Km(c+80|0,a);x[31609]=0;d=P(461,c+68|0,42207)|0;a=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[31609]=0;x[c+56>>2]=20054022;x[c+60>>2]=0;a=c+56|0;S(462,e|0,d|0,a|0);f=x[31609];x[31609]=0;if((f|0)==1){break n}Eb(d);if(ql(y[e|0])){break e}x[31609]=0;d=P(461,a|0,13450)|0;a=x[31609];x[31609]=0;if((a|0)==1){break m}x[31609]=0;V(493,e|0,b|0,d|0,914);a=x[31609];x[31609]=0;if((a|0)==1){break l}Eb(d);x[c+52>>2]=0;x[c+48>>2]=0;x[31609]=0;d=P(461,c+36|0,16785)|0;a=x[31609];x[31609]=0;if((a|0)==1){break k}x[31609]=0;S(915,e|0,c+52|0,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break j}Eb(d);x[31609]=0;d=P(461,c+24|0,16775)|0;a=x[31609];x[31609]=0;if((a|0)==1){break i}x[31609]=0;S(915,e|0,c+48|0,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break h}Eb(d);a=x[c+52>>2];d=x[c+48>>2];o:{if(!a|d>>>0<a>>>0){break o}f=x[x[x[x[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}x[b+20>>2]=d;x[b+16>>2]=a}d=Nb(c+12|0);x[31609]=0;f=P(461,c|0,14194)|0;a=x[31609];x[31609]=0;if((a|0)==1){break d}x[31609]=0;S(916,e|0,d|0,f|0);a=x[31609];x[31609]=0;if((a|0)==1){break g}Eb(f);if(mc(x[d>>2],x[d+4>>2])){break f}a=x[b+16>>2];x[31609]=0;O(866,d|0,a|0);a=x[31609];x[31609]=0;if((a|0)!=1){break f}break c}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;Eb(f);break b}x[31609]=0;O(917,b|0,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}wc(d)}Ch(e);fb=c+192|0;return}a=N()|0;break b}a=N()|0}wc(d)}Ch(e);Q(a|0);p()}function ED(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;l=fb-16|0;fb=l;a:{if(b&4){break a}e=y[a+14|0];b:{if(e>>>0>=y[a+15|0]){break b}c=y[a+12|0];if(!(c&2)){break b}v[a+12|0]=c&251}if(!(y[a+12|0]&2)|e>>>0<=y[a+13|0]){break a}c=x[a>>2];d=x[a+4>>2];if(Sd(c,d)>>>0<=e>>>0){break a}c=z[Pc(c,d,e)>>1];d=Pc(x[a>>2],x[a+4>>2],y[a+14|0]-1|0);e=y[a+14|0];if(z[d>>1]<(c-1|0)){e=z[Pc(x[a>>2],x[a+4>>2],e)>>1]-1&65535;c=Rq(a,e,64,64);d=vb(l+12|0,Ek(wb(x[a>>2]),y[a+14|0]));h=Yl(l+8|0,e,c&255);n=fb-32|0;fb=n;e=x[a>>2];e=(Lv(x[d>>2],wb(e))<<2)+e|0;f=x[a+4>>2];c:{d:{if(f>>>0<A[Ab(a)>>2]){if((e|0)!=(f|0)){break d}OY(a,h);break c}c=Ab(a);d=Zf(n+12|0,Lf(a,oc(x[a>>2],f)+1|0),e-x[a>>2]>>2,c);x[31609]=0;O(780,d|0,h|0);c=x[31609];x[31609]=0;if((c|0)!=1){f=fb-16|0;fb=f;c=x[d+4>>2];h=vb(f+12|0,e);g=vb(f+8|0,x[a>>2]);j=vb(f+4|0,x[d+4>>2]);o=d,q=MF(x[h>>2],x[g>>2],x[j>>2]),x[o+4>>2]=q;o=d,q=qY(e,x[a+4>>2],x[d+8>>2]),x[o+8>>2]=q;Tb(a,d+4|0);Tb(a+4|0,d+8|0);Tb(Ab(a),nc(d));x[d>>2]=x[d+4>>2];fb=f+16|0;e=c;Yf(d);break c}a=N()|0;Yf(d);Q(a|0);p()}j=fb-16|0;fb=j;k=x[a+4>>2];d=(k-(e+4|0)|0)+e|0;i=xh(j+4|0,a,f-d>>2);g=x[i+4>>2];c=d;while(1){if(c>>>0>=f>>>0){jc(i);f=fb-16|0;fb=f;c=fb-32|0;fb=c;fd(c+24|0,e,d);d=fb-16|0;fb=d;m=k;g=x[c+28>>2];i=x[c+24>>2];k=g-i|0;m=m-k|0;x[d+12>>2]=m;sY(m,i,k>>2);qc(c+16|0,g,d+12|0);fb=d+16|0;d=x[c+16>>2];x[c+12>>2]=x[c+20>>2];qc(f+8|0,d,c+12|0);fb=c+32|0;fb=f+16|0;fb=j+16|0}else{cp(g,z[c>>1]|z[c+2>>1]<<16);g=g+4|0;x[i+4>>2]=g;c=c+4|0;continue}break}v[e+2|0]=y[h+2|0];w[e>>1]=z[h>>1]}wb(e);fb=n+32|0;break a}v[a+14|0]=e-1}if((b|0)!=16777216){v[a+17|0]=255}fb=l+16|0}function uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;r=a+44|0;v=x[a+16>>2];q=f+32|0;b=0;while(1){if((b|0)!=2){g=b<<3;o=g+q|0;g=g+r|0;x[o>>2]=x[g>>2];x[o+4>>2]=x[g+4>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;y=x[a+32>>2];z=x[a+28>>2];A=x[a+72>>2];s=x[a+68>>2];B=s>>31;t=x[a+64>>2];C=t>>31;u=x[a+60>>2];E=u>>31;o=x[a+8>>2];F=x[a+12>>2];while(1){if(d){b=x[f+16>>2];m=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=b>>>21&2040;i=w[b+38086>>1];p=w[b+38084>>1];j=w[b+38082>>1];e=w[b+38080>>1];b=0;h=0;while(1){if((h|0)!=2){g=h<<1;n=m+g|0;x[(f+8|0)+(h<<2)>>2]=(((D(w[n>>1],j)+D(w[m+(g|-4)>>1],e)|0)+D(p,w[n+4>>1])|0)+D(i,w[n+8>>1])|0)/16384;h=h+1|0;continue}break}while(1){if((b|0)!=2){m=(f+8|0)+(b<<2)|0;e=x[m>>2];g=(b<<3)+q|0;n=x[g+4>>2];i=x[g>>2];x[g+4>>2]=i;p=e<<8;e=p;e=Aua(e,e>>31,u,E);j=hb;h=e;e=Yb(i,-16777216,16776704);e=Aua(t,C,e,e>>31);i=h+e|0;h=hb+j|0;h=e>>>0>i>>>0?h+1|0:h;e=Yb(n,-16777216,16776704);j=Aua(s,B,e,e>>31);i=j+i|0;e=hb+h|0;e=i>>>0<j>>>0?e+1|0:e;j=i+8388608|0;e=j>>>0<8388608?e+1|0:e;e=Sc(j,e,24);x[g>>2]=e-(p&A);x[m>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+z|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,o,F);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+r|0;a=a+q|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=f+48|0}function sra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-16|0;fb=g;j=If(a,c);ae(g,x[a+36>>2]);k=a;a:{if(!j){Qc(g,a+32|0,5);c=0;if(Gb(x[x[g>>2]>>2],x[g+4>>2])){break a}}e=fb-192|0;fb=e;f=Km(e+80|0,x[a+36>>2]);x[31609]=0;a=P(461,e+68|0,26175)|0;c=x[31609];x[31609]=0;b:{c:{d:{e:{if((c|0)!=1){x[31609]=0;x[e+8>>2]=20054022;x[e+12>>2]=0;S(462,f|0,a|0,e+8|0);c=x[31609];x[31609]=0;if((c|0)==1){break e}Eb(a);if(!ql(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}v[e+67|0]=0;v[e+66|0]=0;x[31609]=0;a=P(461,e+52|0,10110)|0;c=x[31609];x[31609]=0;f:{g:{h:{i:{if((c|0)!=1){x[31609]=0;c=e+67|0;S(503,f|0,c|0,a|0);h=x[31609];x[31609]=0;if((h|0)==1){break i}Eb(a);if(!y[e+67|0]){break b}Of(c,50);x[31609]=0;a=P(461,e+40|0,13304)|0;c=x[31609];x[31609]=0;if((c|0)==1){break f}x[31609]=0;S(503,f|0,e+66|0,a|0);c=x[31609];x[31609]=0;if((c|0)==1){break g}Eb(a);a=x[b>>2];c=Gj(a,x[b+4>>2]);h=y[e+67|0];if(c>>>0<h>>>0){a=bC(e+8|0,x[b+12>>2]);x[31609]=0;S(504,b|0,h|0,a|0);c=x[31609];x[31609]=0;if((c|0)==1){break h}Ak(a);a=x[b>>2]}l=z[Mj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=y[e+66|0];o=b,q=Gj(x[b>>2],x[b+4>>2])>>>0>a>>>0?a:0,v[o+16|0]=q;break b}$e(Mj(x[b>>2],a),l);m=x[b>>2];x[31609]=0;i=e+8|0;O(505,i|0,c|0);n=x[31609];x[31609]=0;if((n|0)!=1){x[31609]=0;V(506,f|0,Mj(m,a)|0,i|0,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break j}c=c+1|0;Eb(i);continue}break}c=N()|0;break c}c=N()|0;Eb(e+8|0);break c}c=N()|0;break c}c=N()|0;Eb(a);break c}c=N()|0;Ak(a);break c}c=N()|0;Eb(a);break c}c=N()|0}Ch(f);Q(c|0);p()}Ch(f);fb=e+192|0;c=j}ef(k,c);fb=g+16|0}function l4(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Cb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(y[ec(d,b)|0]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=y[ec(d,b+1|0)|0];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(y[ec(d,b)|0]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=y[ec(d,a+1|0)|0];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(y[ec(d,b)|0]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(y[ec(d,a+1|0)|0]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(y[ec(d,b)|0]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(y[ec(d,a+1|0)|0]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(y[ec(d,b)|0]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(y[ec(d,a)|0]==121){break b}if(y[ec(d,a)|0]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(y[ec(d,b)|0]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(y[ec(d,a+1|0)|0]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(y[ec(d,b)|0]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(y[ec(d,a)|0]==121){break b}if(y[ec(d,a)|0]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(y[ec(d,b)|0]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(y[ec(d,a+1|0)|0]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function uw(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{b:{c:{d:{e:{switch(b-2|0){case 11:v[e+14|0]=64;ee(a,1,Qb(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;ee(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;ee(a,13,e+14|0);break a;case 2:if(c>>>0>=240){v[e+14|0]=9;ee(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break b}f=y[b+42144|0];f:{if(d){if(c>>>0>f>>>0){break f}break d}if((c|0)==(f|0)){break d}}b=b+1|0;continue};case 3:g:{if(d){v[e+14|0]=c&15;v[e+13|0]=9;c=y[Qb(e+14|0,e+13|0)|0];break g}if(c>>>0>15|(c&14)>>>0>9){break b}}v[e+14|0]=c&15;ee(a,8,e+14|0);break a;case 24:h:{if(d){v[e+15|0]=0;break h}if(c){break b}}ee(a,8,e+15|0);break a;case 7:v[e+15|0]=(c|0)==255?64:c>>>2|0;ee(a,2,e+15|0);break a;case 9:if(!c){break b}b=c&15;if(!b){v[e+14|0]=c>>>4;ee(a,3,e+14|0);break a}d=c&240;if(!d){ee(a,4,e+15|0);break a}if((b|0)==15){v[e+14|0]=c>>>4;ee(a,5,e+14|0);break a}if((d|0)!=240){break b}v[e+14|0]=c&15;ee(a,6,e+14|0);break a;case 18:if((c&240)!=128){break b}v[e+14|0]=c<<2|2;ee(a,2,e+14|0);break a;case 17:i:{switch((c>>>4|0)-8|0){case 0:v[e+14|0]=c<<2&60|2;ee(a,2,e+14|0);break a;case 2:v[e+14|0]=c&15;ee(a,5,e+14|0);break a;case 3:break i;default:break b}}v[e+14|0]=c&15;ee(a,6,e+14|0);break a;case 4:case 5:case 6:case 8:case 10:case 12:case 13:case 14:case 15:case 16:case 19:case 20:case 21:case 22:case 23:break b;default:break e}}if((b|0)==46){break c}break b}v[e+14|0]=b;ee(a,11,e+14|0);break a}if(d?0:c&3){break b}v[e+14|0]=c+3>>>2;ee(a,1,e+14|0);break a}v[e+14|0]=0;ee(a,0,e+14|0)}fb=e+16|0}function vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;r=a+44|0;y=x[a+16>>2];q=f+32|0;b=0;while(1){if((b|0)!=2){g=b<<3;o=g+q|0;g=g+r|0;x[o>>2]=x[g>>2];x[o+4>>2]=x[g+4>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;z=x[a+32>>2];A=x[a+28>>2];B=x[a+72>>2];s=x[a+68>>2];C=s>>31;t=x[a+64>>2];E=t>>31;u=x[a+60>>2];F=u>>31;o=x[a+8>>2];G=x[a+12>>2];while(1){if(d){b=x[f+16>>2];h=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=b>>>21&2040;p=w[b+38086>>1];i=w[b+38084>>1];e=w[b+38082>>1];g=w[b+38080>>1];b=0;j=0;while(1){if((j|0)!=2){k=h+j|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(p,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){j=(f+8|0)+(b<<2)|0;e=x[j>>2];g=(b<<3)+q|0;k=x[g+4>>2];h=x[g>>2];x[g+4>>2]=h;p=e<<8;e=p;e=Aua(e,e>>31,u,F);i=hb;l=e;e=Yb(h,-16777216,16776704);e=Aua(t,E,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(k,-16777216,16776704);i=Aua(s,C,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Sc(i,e,24);x[g>>2]=e-(p&B);x[j>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+A|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+z|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Pb(f+16|0,o,G);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+r|0;a=a+q|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=f+48|0}function IR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=D(b,872)+a|0;e=f+1074992|0;a:{b:{f=x[f+1075080>>2];if(f&131072){f=x[a+480180>>2];j=1;c:{d:{e:{h=x[a+480208>>2];if(h&4096){if(!(f&16777248)){break e}j=!(h&4)}if((f|0)!=64){break d}break b}if((f|0)==64){break b}h=a+480180|0;j=0;break c}h=a+480180|0;if(!j){break c}Jb(g+8|0,a+1074312|0,21);if(!Gb(x[x[g+8>>2]>>2],x[g+12>>2])){break c}v[e+819|0]=y[e+819|0]+(y[e+823|0]<<2)}f=KA(a,y[e+822|0],y[e+819|0]);f:{if(Kj(x[e+656>>2])){B[d>>2]=B[d>>2]+E(E(E(D(y[e+824|0],f)|0)*E(.05000000074505806))/E(7680));b=y[e+851|0];v[e+851|0]=b&159|64;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break f}v[e+851|0]=b|96;break f}d=x[a+480208>>2];if((d&2101248)==2101248){break a}i=x[h>>2];if(d&4096?i&67633152:0){break a}if(i&5){f=(y[e+822|0]&3)==1?0-f|0:f}k=a+1074312|0;Jb(g+8|0,k,21);i=x[a+480208>>2];g:{if(Gb(x[x[g+8>>2]>>2],x[g+12>>2])){d=i&4;f=d?f:0-f|0;d=d?5:6;break g}d=5;h:{if(i&131072){break h}h=x[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?i&4?6:7:6}Jb(g+8|0,k,80);if(!Gb(x[x[g+8>>2]>>2],x[g+12>>2])){break g}d=y[e+791|0]==26?d+2|0:d}d=0-((D(y[e+824|0],f)|0)/(1<<d)|0)|0;wk(a,e,c,d,0);f=x[e+656>>2];c=Eq(a,x[e+88>>2],f);if(!c){break f}ib[x[x[c>>2]+92>>2]](c,d,(f?y[f+33|0]:2)<<24>>24,b)}if(!j){break a}Jb(g+8|0,a+1074312|0,21);if(Gb(x[x[g+8>>2]>>2],x[g+12>>2])){break a}v[e+819|0]=y[e+819|0]+y[e+823|0];break a}if(!(y[e+670|0]&2)){break a}a=Eq(a,f,x[e+656>>2]);if(!a){break a}ib[x[x[a>>2]+92>>2]](a,0,0,b);break a}a=y[e+819|0];if(a&1){x[c>>2]=x[c>>2]+D(y[e+824|0],167)}v[e+819|0]=a+1}fb=g+16|0}function yQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;a:{if((b|0)==(c|0)){break a}x[l+12>>2]=-1953789045;Zz(b,c,l+12|0);e=c-b|0;c=e>>2;x[l+8>>2]=c;i=oc(x[a>>2],x[a+4>>2]);j=i+1|0;x[l+4>>2]=j;m=x[bd(l+4|0,l+8|0)>>2];f=x[b>>2]^x[(b+e|0)-4>>2];d=11;b:{if(c>>>0>622){break b}d=7;if(c>>>0>67){break b}d=5;if(c>>>0>38){break b}d=3;if(c>>>0>6){break b}d=c-1>>>1|0}e=c-d>>>1|0;h=(e<<2)+b|0;g=x[h>>2];f=D(pu(f^g),1664525);x[h>>2]=f+g;h=d+e|0;d=(h<<2)+b|0;g=d;k=x[d>>2];d=f+i|0;x[g>>2]=k+d;x[b>>2]=d;g=j>>>0<=1?1:j;d=c-1|0;e=(e>>>0)%(c>>>0)|0;f=(h>>>0)%(c>>>0)|0;k=x[a>>2];i=1;a=0;while(1)if((i|0)==(g|0)){while(1)if(j>>>0>=m>>>0){j=c+m|0;i=j>>>0<m>>>0?m:j;while(1){if((i|0)==(m|0)){break a}d=d+1|0;d=(c|0)!=(d|0)?d:0;e=e+1|0;e=(c|0)!=(e|0)?e:0;g=(e<<2)+b|0;k=x[g>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;h=(a<<2)+b|0;j=D(pu(x[(d<<2)+b>>2]+(k+x[h>>2]|0)|0),1566083941);x[g>>2]=j^k;f=f+1|0;f=(c|0)!=(f|0)?f:0;g=(f<<2)+b|0;j=j-a|0;x[g>>2]=j^x[g>>2];x[h>>2]=j;m=m+1|0;continue}}else{e=e+1|0;e=(c|0)!=(e|0)?e:0;g=(e<<2)+b|0;k=x[g>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;h=(a<<2)+b|0;d=d+1|0;d=(c|0)!=(d|0)?d:0;i=D(pu(k^(x[h>>2]^x[(d<<2)+b>>2])),1664525);x[g>>2]=i+k;f=f+1|0;f=(c|0)!=(f|0)?f:0;g=(f<<2)+b|0;i=a+i|0;x[g>>2]=i+x[g>>2];x[h>>2]=i;j=j+1|0;continue}}else{e=e+1|0;e=(c|0)!=(e|0)?e:0;n=(e<<2)+b|0;o=x[n>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;p=(a<<2)+b|0;d=d+1|0;d=(c|0)!=(d|0)?d:0;h=D(pu(o^(x[p>>2]^x[(d<<2)+b>>2])),1664525);x[n>>2]=h+o;h=x[yb(k,i-1|0)>>2]+(a+h|0)|0;f=f+1|0;f=(c|0)!=(f|0)?f:0;n=(f<<2)+b|0;x[n>>2]=h+x[n>>2];x[p>>2]=h;i=i+1|0;continue}}fb=l+16|0}function DS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=fb-16|0;fb=c;d=D(b,872)+a|0;a:{if(x[d+1075080>>2]&67109888){break a}e=d+1074992|0;h=x[e+656>>2];if(!Bj(h)|y[h+15|0]&2){break a}d=om(a,a+1074376|0,b,2,1)-1|0;if((d&255)>>>0>249){break a}i=x[$d(a+906300|0,d)>>2];if(!i){break a}d=y[e+788|0];b:{if(y[e+790|0]==1){v[c+8|0]=64;f=y[Qb(e+792|0,c+8|0)|0];break b}g=y[e+791|0];if((g|0)!=46){f=255;if((g|0)!=13){break b}v[c+8|0]=64;f=y[Qb(e+793|0,c+8|0)|0];break b}f=y[e+793|0]+3>>>2|0}j=a+1074312|0;Jb(c+8|0,j,2);if(Gb(x[x[c+8>>2]>>2],x[c+12>>2])){if(d){if(Tc(d)){d=y[xb(h+108|0,d-1|0)|0]}Xm(a,b,d,z[e+688>>1]);break a}if((f|0)==255){break a}ib[x[x[i>>2]+76>>2]](i,39,f,b);break a}k=x[h+4>>2];c:{if(!d){break c}g=y[h+35|0]?k<<2:x[e+688>>2];l=w[e+776>>1];Jb(c+8|0,j,28);m=c,n=g+(Gb(x[x[c+8>>2]>>2],x[c+12>>2])?l<<2:l)|0,x[m+4>>2]=n;Ge(c+4|0,0,256);g=d;if(Tc(d)){g=y[xb(h+108|0,d-1|0)|0]}Jb(c+8|0,j,117);if(!Gb(x[x[c+8>>2]>>2],x[c+12>>2])){if(Kl(y[e+790|0],y[e+791|0])){break c}}Xm(a,b,g&255,z[c+4>>1])}a=y[h+35|0];Jb(c+8|0,j,101);a=(a|0)==1;g=(f|0)!=255;if(!Gb(x[x[c+8>>2]>>2],x[c+12>>2])){d=Tc(d)}if(((d?a:g)|0)!=1){break a}d:{switch(y[h+36|0]){case 1:a=x[i+20>>2];if((f|0)!=255){Iu(a,E(E(E(f<<1)/E(-127))+E(1)));break a}Iu(a,E(E(E(k<<1>>>0)/E(-127))+E(1)));break a;case 0:break d;default:break a}}if((f|0)!=255){v[c+8|0]=127;v[c+4|0]=f<<1;n=i,o=7,p=y[Qb(c+8|0,c+4|0)|0],q=b,m=x[x[i>>2]+76>>2],ib[m](n|0,o|0,p|0,q|0);break a}x[c+8>>2]=127;x[c+4>>2]=k<<1;q=i,p=7,o=y[Hb(c+8|0,c+4|0)|0],n=b,m=x[x[i>>2]+76>>2],ib[m](q|0,p|0,o|0,n|0)}fb=c+16|0}function _ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=x[a>>2];d=hm(e,x[a+4>>2]);if(d>>>0<b>>>0){i=fb-32|0;fb=i;a:{b:{h=b-d|0;b=x[Ab(a)>>2];e=x[a+4>>2];c:{if(h>>>0<=(b-e|0)/52>>>0){qA(a,h,c);break c}f=Ab(a);d=cR(a,hm(x[a>>2],e)+h|0);g=hm(x[a>>2],x[a+4>>2]);e=fb-16|0;fb=e;b=i+12|0;Lg(b+12|0,f);d:{if(!d){f=0;d=0;break d}bR(e+8|0,d);f=x[e+12>>2];d=x[e+8>>2]}x[b>>2]=d;g=d+D(g,52)|0;x[b+8>>2]=g;x[b+4>>2]=g;l=nc(b),m=d+D(f,52)|0,x[l>>2]=m;fb=e+16|0;x[31609]=0;S(922,b|0,h|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}h=fb-16|0;fb=h;e=Ab(a);c=vb(h+12|0,x[a+4>>2]);d=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);c=x[c>>2];g=x[d>>2];d=fb+-64|0;fb=d;f=x[f>>2];x[d+56>>2]=f;x[d+60>>2]=c;x[d+52>>2]=f;e=Ag(d+24|0,e,d+52|0,d+56|0);x[d+16>>2]=x[e+8>>2];f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;zg(d+36|0,d+8|0);while(1){if(Fd(c,g)){c=c-52|0;e=Tl(ZQ(x[d+56>>2]),c);x[e+20>>2]=x[c+20>>2];f=x[c+16>>2];x[e+12>>2]=x[c+12>>2];x[e+16>>2]=f;kW(e+24|0,c+24|0);Uc(e+36|0,c+36|0);x[e+48>>2]=x[c+48>>2];c=_Q(d+60|0);_Q(d+56|0);c=x[c>>2];continue}break}yg(d+36|0);j=x[d+56>>2];if(!y[d+48|0]){f=fb-16|0;fb=f;c=vb(f+12|0,x[x[d+44>>2]>>2]);k=x[vb(f+8|0,x[x[d+40>>2]>>2])>>2];g=fb-16|0;fb=g;c=x[c>>2];x[g+12>>2]=c;while(1){if(wi(c,k)){e=fb-16|0;fb=e;x[e+12>>2]=c;x[e+12>>2]=x[e+12>>2]+52;fb=e+16|0;vk(ZQ(x[e+12>>2]));c=x[Ul(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=d- -64|0;x[b+4>>2]=j;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0;aR(b)}fb=i+32|0;break a}a=N()|0;aR(b);Q(a|0);p()}return}if(b>>>0<d>>>0){dR(a,e+D(b,52)|0)}}function c7(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;w=h?4:0;z=d&512;while(1){if((u|0)==4){if(Cb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=KJ(Ek(zd(n),1),nl(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(y[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=Bt(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(Ad(x[n+4>>2],y[n+11|0])){break a}h=x[Wd(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(Ad(x[m+4>>2],y[m+11|0])|!z){break a}B=c,C=KJ(zd(m),nl(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}A=x[c>>2];e=e+w|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!oj(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){q=q-1|0;h=h-4|0;s=x[h>>2];r=p+4|0;x[c>>2]=r;x[p>>2]=s;p=r;continue}break}d:{if(!q){s=0;break d}s=Bt(g,48);p=x[c>>2]}while(1){r=p+4|0;if((q|0)>0){x[p>>2]=s;q=q-1|0;p=r;continue}break}x[c>>2]=r;x[p>>2]=j}e:{if((e|0)==(h|0)){p=Bt(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}s=-1;if(!Ad(x[l+4>>2],y[l+11|0])){s=v[ec(l,0)|0]}q=0;t=0;while(1){if((e|0)!=(h|0)){r=x[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;x[c>>2]=p;x[r>>2]=k;r=0;t=t+1|0;if(Cb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){s=q;break f}s=-1;if(y[ec(l,t)|0]==127){break f}s=v[ec(l,t)|0]}h=h-4|0;q=x[h>>2];x[c>>2]=p+4;x[p>>2]=q;q=r+1|0;continue}break}h=x[c>>2]}vt(A,h)}u=u+1|0;continue}break}}function pe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31609]=0;O(53,b|0,_c(e,d)|0);d=x[31609];x[31609]=0;d:{if((d|0)!=1){e:{while(1){if(_c(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=v[ec(c,a)|0];x[31609]=0;O(35,b|0,((d|0)<0?65533:d&255)|0);d=x[31609];x[31609]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31609]=0;O(53,b|0,_c(e,d)|0);d=x[31609];x[31609]=0;f:{if((d|0)!=1){while(1){if(_c(x[c+4>>2],y[c+11|0])>>>0<=a>>>0){break f}d=y[ec(c,a)|0];x[31609]=0;O(35,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){a=a+1|0;continue}break}}break a}return;case 3:gf(a,c,48864);return;case 4:gf(a,c,49888);return;case 5:gf(a,c,50912);return;case 6:gf(a,c,51936);return;case 7:gf(a,c,52960);return;case 8:gf(a,c,53984);return;case 9:gf(a,c,55008);return;case 10:gf(a,c,56032);return;case 11:gf(a,c,57056);return;case 12:gf(a,c,58080);return;case 13:gf(a,c,59104);return;case 14:gf(a,c,60128);return;case 15:gf(a,c,61152);return;case 16:gf(a,c,62176);return;case 17:gf(a,c,63200);return;case 18:gf(a,c,64224);return;case 19:gf(a,c,65248);return;case 20:gf(a,c,66272);return;case 21:gf(a,c,67296);return;case 22:gf(a,c,68320);return;case 23:gf(a,c,69344);return;case 24:cB(a,c,70368);return;case 25:cB(a,c,48864);return;case 26:cB(a,c,67296);return;default:a=dc(8);x[31609]=0;b=P(16,a|0,11122)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}b=N()|0;lc(a);Q(b|0);p();case 0:break c}}t_(a,c);return}da(b|0,124672,17);p()}a=N()|0;Ub(b);Q(a|0);p()}function Tja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-32|0;fb=c;a:{b:{c:{d:{e:{f:{if(Ed(x[a+24>>2])){break f}i=_c(x[a+8>>2],y[a+15|0]);f=fb-16|0;fb=f;h=f+8|0;x[h>>2]=-1;x[h+4>>2]=-1;x[31609]=0;g=$H(65);d=x[31609];x[31609]=0;b=hb;if((d|0)==1){T(0)|0;Sb();p()}e=fb-16|0;fb=e;d=ye(e+8|0,Aua(g,b,1e3,0),hb);b=x[d>>2];fb=e+16|0;j=f,k=pA(b,x[d+4>>2]),x[j>>2]=k;x[f+4>>2]=hb;e=$Q(h,f,Ab(f));x[31609]=0;g=$H(66);d=x[31609];x[31609]=0;b=hb;if((d|0)==1){T(0)|0;Sb();p()}h=a+24|0;j=f,k=pA(WQ(g,b),hb),x[j>>2]=k;x[f+4>>2]=hb;b=$Q(e,f,Ab(f));g=x[b>>2];b=x[b+4>>2];fb=f+16|0;if(i){e=Nb(c+20|0);x[31609]=0;x[c+8>>2]=b;d=c+8|0;O(59,e|0,d|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}x[31609]=0;x[c+8>>2]=g;O(59,e|0,d|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}d=a+4|0;g=0;g:{while(1){if(_c(x[a+8>>2],y[a+15|0])>>>0<=g>>>0){b=wb(x[e>>2]);a=wb(x[e+4>>2]);x[31609]=0;d=U(60,c+8|0,b|0,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break g}a=N()|0;break b}b=y[ec(d,g)|0];x[31609]=0;x[c+8>>2]=b;O(59,e|0,c+8|0);b=x[31609];x[31609]=0;if((b|0)!=1){g=g+1|0;continue}break}a=N()|0;break b}x[31609]=0;b=R(61,d|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){x[c+4>>2]=b;a=c+4|0;vA(h,a);Gl(a);Wm(d);wc(e);break f}a=N()|0;Wm(d);break b}hb=g;x[c+8>>2]=b;x[c+12>>2]=hb;b=Nb(c+20|0);x[31609]=0;S(64,b|0,c+8|0,c+16|0);a=x[31609];x[31609]=0;if((a|0)==1){a=N()|0;wc(b);Q(a|0);p()}x[31609]=0;d=R(61,b|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[c+4>>2]=d;a=c+4|0;vA(h,a);Gl(a);Wm(b)}fb=c+32|0;return}a=N()|0;Wm(b);break a}a=N()|0;break b}a=N()|0}wc(e)}Q(a|0);p()}function bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0;g=fb-32|0;fb=g;e=oU(g+20|0,1<<x[b+12>>2]);f=x[e>>2];while(1){d=x[a>>2];if(ih(d,x[a+4>>2])>>>0>c>>>0){d=Se(d,c);nU(Yd(f,c),C[d>>3]);c=c+1|0;continue}break}mU(b,e);c=wb(x[e>>2]);x[g>>2]=c;q=wb(x[e+4>>2]);while(1){if(Ib(c,q)){h=fb-32|0;fb=h;p=F(C[c+8>>3]);k=F(C[c>>3]);o(+k);n=j(1)|0;f=j(0)|0;o(+p);l=j(1)|0;d=j(0)|0;l=(l|0)==(n|0)&d>>>0>f>>>0|l>>>0>n>>>0;i=l?k:p;o(+i);d=j(1)|0;f=j(0)|0;n=d>>>20|0;a:{if((n|0)==2047){break a}m=l?p:k;b:{if(!(d|f)){break b}o(+m);d=j(1)|0;j(0)|0;d=d>>>20|0;if((d|0)==2047){break b}if((d-n|0)>=65){i=k+p;break a}c:{if(d>>>0>=1534){i=i*190109156629516e-225;m=m*190109156629516e-225;k=5.260135901548374e210;break c}k=1;if(n>>>0>572){break c}i=i*5.260135901548374e210;m=m*5.260135901548374e210;k=190109156629516e-225}zL(h+24|0,h+16|0,m);zL(h+8|0,h,i);i=k*M(C[h>>3]+C[h+16>>3]+C[h+8>>3]+C[h+24>>3]);break a}i=m}fb=h+32|0;nU(c,mq(i));c=x[Vo(g)>>2];continue}break}lU(b,e);kU(e);l=x[e>>2];f=Dk(l,x[e+4>>2])>>>1|0;d=f>>>0<=1?1:f;c=1;while(1){if((c|0)!=(d|0)){PB(Yd(l,c),2);PB(Yd(l,c+f|0),0);c=c+1|0;continue}break}mU(b,e);c=wb(x[e>>2]);x[g+16>>2]=c;f=wb(x[e+4>>2]);while(1){if(Ib(c,f)){jU(g,C[c>>3],C[c+8>>3]);d=x[g+12>>2];x[c+8>>2]=x[g+8>>2];x[c+12>>2]=d;d=x[g+4>>2];x[c>>2]=x[g>>2];x[c+4>>2]=d;c=x[Vo(g+16|0)>>2];continue}break}lU(b,e);kU(e);f=x[a>>2];d=ih(f,x[a+4>>2]);b=x[e>>2];c=0;while(1){if((c|0)==(d|0)){kn(e);fb=g+32|0}else{a=Yd(b,c);r=Se(f,c),s=C[a>>3],C[r>>3]=s;c=c+1|0;continue}break}}function AH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-432|0;fb=d;a:{f=_s(d+428|0,b);e=x[f>>2];b:{if(!Ed(e)){x[31609]=0;b=P(36,d+416|0,b|0)|0;a=x[31609];x[31609]=0;c:{d:{e:{if((a|0)!=1){x[31609]=0;a=d+16|0;S(1011,a|0,17716,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break e}x[31609]=0;W(1367,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break d}break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d+16|0)}tb(b);break b}Zs(e);if(!_p(a+8|0,22292,x[f>>2])){x[a+8>>2]=2147483647}if(!_p(a+12|0,22292,x[f>>2])){x[a+12>>2]=2147483647}x[31609]=0;O(272,a+16|0,22292);b=x[31609];x[31609]=0;f:{g:{if((b|0)!=1){x[d+8>>2]=0;x[d+12>>2]=0;x[d+4>>2]=22292;e=Di(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((e|0)==-1){x[31609]=0;W(1276,12677);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;break b}x[31609]=0;b=d+16|0;e=U(1374,a+28|0,b|0,b+(e<<2)|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break f}x[a+64>>2]=0;x[d+4>>2]=22292;x[d+8>>2]=0;x[d+12>>2]=0;h:{g=d+4|0;i=d+8|0;h=Di(b,g,100,i,x[f>>2]);if((h|0)!=-1){x[31609]=0;U(1374,a+40|0,b|0,b+(h<<2)|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break f}x[d+4>>2]=22292;x[d+8>>2]=0;x[d+12>>2]=0;b=Di(b,g,100,i,x[f>>2]);if((b|0)!=-1){break h}}x[31609]=0;W(1276,12677);a=x[31609];x[31609]=0;if((a|0)!=1){break a}break f}x[31609]=0;g=d+16|0;U(1374,a+52|0,g|0,g+(b<<2)|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break f}x[31609]=0;b=P(1375,d+416|0,e|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){break g}a=N()|0;break b}a=N()|0;break b}bi(a+68|0,c);bi(a+72|0,c);Ub(b);gl(f);fb=d+432|0;return}a=N()|0}gl(f);Q(a|0);p()}p()}function J4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb-576|0;fb=c;Rb(c+532|0,0,44);x[c+24>>2]=0;x[c+28>>2]=0;l=a+4|0;while(1){a:{if((d|0)==7){l=a+172|0;d=0;while(1){b:{if((d|0)==12){x[c+540>>2]=1;d=c+432|0;fa(d|0,100,9278,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=d;e=Di(c+32|0,c+20|0,100,c+24|0,x[a>>2]);if((e|0)!=-1){break b}break a}x[c+548>>2]=d;e=c+432|0;g=c+532|0;fa(e|0,100,14339,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=c+32|0;h=c+8|0;i=c+24|0;j=Di(f,h,100,i,x[a>>2]);if(j+1>>>0<=1){break a}k=l+D(d,12)|0;Cm(k,f,f+(j<<2)|0);fa(e|0,100,13349,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;e=Di(f,h,100,i,x[a>>2]);if(e+1>>>0<=1){break a}Cm(k+144|0,f,(e<<2)+f|0);d=d+1|0;continue}break}d=c+32|0;Cm(a+460|0,d,d+(e<<2)|0);x[c+540>>2]=13;e=c+432|0;fa(e|0,100,9278,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=e;e=Di(d,c+20|0,100,c+24|0,x[a>>2]);if((e|0)!=-1){Cm(a+472|0,d,(e<<2)+d|0);d=c+8|0;bt(d,a,99,b);nh(a+484|0,d);Ub(d);bt(d,a,114,b);nh(a+496|0,d);Ub(d);bt(d,a,120,b);nh(a+508|0,d);Ub(c+8|0);bt(d,a,88,b);nh(a+520|0,d);Ub(c+8|0);fb=c+576|0;return}break a}x[c+556>>2]=d;e=c+432|0;g=c+532|0;fa(e|0,100,14352,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=c+32|0;h=c+8|0;i=c+24|0;j=Di(f,h,100,i,x[a>>2]);if(j+1>>>0>1){k=l+D(d,12)|0;Cm(k,f,f+(j<<2)|0);fa(e|0,100,13556,g|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;e=Di(f,h,100,i,x[a>>2]);if(e+1>>>0<=1){break a}Cm(k+84|0,f,(e<<2)+f|0);d=d+1|0;continue}}break}go(12677);p()}function Kq(a,b,c,d){var e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),p=0;h=fb-16|0;fb=h;x[h+12>>2]=w[b+780>>1]+y[b+837|0];x[h+8>>2]=w[b+782>>1]+(y[b+838|0]&127);Ge(h+12|0,0,127);Ge(h+8|0,0,127);k=a+1074312|0;j=Ob(k,1);i=x[h+8>>2];l=x[h+12>>2];if(!j){v[b+838|0]=i;v[b+837|0]=l;x[b+780>>2]=0}m=D(d+256|0,l);j=(m|0)/256|0;a:{if(!(i|!Ob(k,36)|(m|0)<65024)){j=-1;if(!(y[b+851|0]&2)){break a}x[b+88>>2]=x[b+88>>2]&-32769;break a}x[b+88>>2]=x[b+88>>2]|32768;e=Ee(E(10),E(E(0-i|0)*E(.00937500037252903)));i=fb-16|0;fb=i;g=E(D(d+256|0,l)>>>0);b:{if(x[a+480180>>2]!=33554432){f=E(110);g=E(E(g/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break b}f=E(125);g=E(E(g*E(6))/E(65024))}n=i,o=E(Ee(E(2),g)*f),B[n+12>>2]=o;d=i+12|0;zT(d,E(120),E(2e4));BB(d,E(E(A[a+24620>>2])*E(.5)));fb=i+16|0;g=E(B[i+12>>2]*E(6.2831854820251465));c:{if(!(!Ob(k,36)|y[a+480209|0]&128)){f=E(E(A[a+24620>>2])/g);g=E(E(E(e*f)+e)+E(-1));e=E(f*f);break c}f=E(e+e);e=E(g/E(A[a+24620>>2]));B[h+4>>2]=E(E(1)-f)*e;BB(h+4|0,E(2));g=E(E(f-B[h+4>>2])/e);e=E(E(1)/E(e*e))}f=E(e+E(g+E(1)));g=E(E(e+E(e+g))/f);e=E(E(-e)/f);f=E(E(1)/f);d:{if(y[b+845|0]==1){n=b,p=Ll(E(E(E(1)-f)*E(16777216))),x[n+60>>2]=p;n=b,p=Ll(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Ll(E(e*E(16777216))),x[n+68>>2]=p;a=-1;break d}d=Ll(E(f*E(16777216)));x[b+60>>2]=d;n=b,p=Ll(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Ll(E(e*E(16777216))),x[n+68>>2]=p;a=0;if(d){break d}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break a}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}fb=h+16|0;return j}function g7(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;z=d&512;while(1){if((u|0)==4){if(Cb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=LJ(vf(zd(n),1),Df(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(y[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];p=km(g,32);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 3:if(Ad(x[n+4>>2],y[n+11|0])){break a}p=y[ec(n,0)|0];q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 2:if(Ad(x[m+4>>2],y[m+11|0])|!z){break a}B=c,C=LJ(zd(m),Df(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}p=x[g+8>>2];A=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Jf(p,64,v[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){p=p-1|0;r=r-1|0;q=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=q;continue}break}if(p){q=km(g,48)}else{q=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((p|0)>0){v[s|0]=q;p=p-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){p=km(g,48);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break d}q=-1;if(!Ad(x[l+4>>2],y[l+11|0])){q=v[ec(l,0)|0]}p=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=x[c>>2];x[c>>2]=q+1;v[q|0]=k;s=0;t=t+1|0;if(Cb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){q=p;break e}q=-1;if(y[ec(l,t)|0]==127){break e}q=v[ec(l,t)|0]}r=r-1|0;p=y[r|0];w=x[c>>2];x[c>>2]=w+1;v[w|0]=p;p=s+1|0;continue}}Dm(A,x[c>>2])}u=u+1|0;continue}break}}function Kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;g=fb-48|0;fb=g;p=a+44|0;u=x[a+16>>2];o=g+32|0;b=0;while(1){if((b|0)!=2){f=b<<3;n=f+o|0;f=f+p|0;x[n>>2]=x[f>>2];x[n+4>>2]=x[f+4>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;v=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];q=x[a+68>>2];A=q>>31;r=x[a+64>>2];B=r>>31;s=x[a+60>>2];C=s>>31;n=x[a+8>>2];E=x[a+12>>2];while(1){if(d){f=x[g+16>>2];i=f>>>18|0;e=((((x[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+u|0;b=0;h=0;while(1){if((h|0)!=2){f=e+(h<<1)|0;m=w[f>>1];x[(g+8|0)+(h<<2)>>2]=m+((D(i,w[f+4>>1]-m|0)|0)/16384|0);h=h+1|0;continue}break}while(1){if((b|0)!=2){t=(g+8|0)+(b<<2)|0;e=x[t>>2];f=(b<<3)+o|0;F=x[f+4>>2];h=x[f>>2];x[f+4>>2]=h;m=e<<8;e=m;e=Aua(e,e>>31,s,C);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Aua(r,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(F,-16777216,16776704);i=Aua(q,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Sc(i,e,24);x[f>>2]=e-(m&z);x[t>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],l>>12);k=k+v|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],k>>12);Pb(g+16|0,n,E);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+p|0;a=a+o|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=g+48|0}function hoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;k=f,l=Qj(b),x[k+4>>2]=l;e=fb-16|0;fb=e;h=a;c=de(a);a:{if(c){g=gc(a);while(1){a=c;c=a+14|0;if(mv(b,c)){g=a;c=x[a>>2];if(c){continue}break a}if(!mv(c,b)){break a}g=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(h);g=a}x[e+12>>2]=a;b=x[g>>2];if(!b){i=fb-16|0;fb=i;a=gc(h);j=Dh(e,Ec(48),Og(i+8|0,a));a=x[j>>2];b=x[f+4>>2];c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+14|0]=d;v[a+15|0]=d>>>8;v[a+16|0]=d>>>16;v[a+17|0]=d>>>24;v[a+18|0]=c;v[a+19|0]=c>>>8;v[a+20|0]=c>>>16;v[a+21|0]=c>>>24;c=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);d=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[a+38|0]=d;v[a+39|0]=d>>>8;v[a+40|0]=d>>>16;v[a+41|0]=d>>>24;v[a+42|0]=c;v[a+43|0]=c>>>8;v[a+44|0]=c>>>16;v[a+45|0]=c>>>24;c=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);d=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[a+30|0]=d;v[a+31|0]=d>>>8;v[a+32|0]=d>>>16;v[a+33|0]=d>>>24;v[a+34|0]=c;v[a+35|0]=c>>>8;v[a+36|0]=c>>>16;v[a+37|0]=c>>>24;c=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a+22|0]=b;v[a+23|0]=b>>>8;v[a+24|0]=b>>>16;v[a+25|0]=b>>>24;v[a+26|0]=c;v[a+27|0]=c>>>8;v[a+28|0]=c>>>16;v[a+29|0]=c>>>24;w[a+46>>1]=0;k=gc(j),l=1,v[k+4|0]=l;fb=i+16|0;$g(h,x[e+12>>2],g,x[e>>2]);b=ne(e);Ik(e);d=1}_g(f+8|0,x[vb(e,b)>>2],d);fb=e+16|0;a=dp(x[f+8>>2]);fb=f+16|0;return a+32|0}function fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;f=x[a+8>>2];m=f;e=x[a+12>>2];j=e;a:{b:{if((e|0)<=1&f>>>0<=805306368|(e|0)<=0){i=131112;f=e;if((e|0)>-2){e=1}else{e=(f|0)>=-2&m>>>0>=3489660928}if(e){break a}i=262184;if((j|0)==-2&m>>>0<2147483648|j>>>0<4294967294){break a}break b}i=262184;if((j|0)==1&m>>>0>2147483648|j>>>0>1){break a}}i=196648}s=x[a+16>>2];k=x[a+40>>2];l=x[a+36>>2];f=x[a+48>>2];e=x[a+44>>2];n=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=n;t=b+i|0;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];r=x[a+68>>2];z=r>>31;i=x[a+64>>2];A=i>>31;n=x[a+60>>2];B=n>>31;while(1){b=e;if(d){e=Yb(e,-16777216,16776704);o=Aua(i,A,e,e>>31);p=hb;e=x[h+8>>2];g=(x[h+12>>2]<<1)+s|0;e=(e>>>16&65520)+t|0;g=(((((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+4>>1],w[e+10>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/32768<<8;e=g;e=Aua(e,e>>31,n,B);o=e+o|0;q=hb+p|0;q=e>>>0>o>>>0?q+1|0:q;f=Yb(f,-16777216,16776704);e=Aua(r,z,f,f>>31);p=e+o|0;f=hb+q|0;f=e>>>0>p>>>0?f+1|0:f;e=p+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Sc(e,f,24);f=(e|0)/256|0;l=l+v|0;x[c>>2]=D(f,l>>12)+x[c>>2];k=k+u|0;x[c+4>>2]=x[c+4>>2]+D(f,k>>12);Pb(h+8|0,m,j);e=e-(g&y)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=k>>12;fb=h+16|0}function $ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;v=x[a+16>>2];o=kg(1,2);b=hb;y=b;Pb(a,o,b);p=a+44|0;n=f+32|0;b=0;while(1){if((b|0)!=2){g=b<<3;m=g+n|0;g=g+p|0;x[m>>2]=x[g>>2];x[m+4>>2]=x[g+4>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;z=x[a+32>>2];A=x[a+28>>2];B=x[a+72>>2];q=x[a+68>>2];C=q>>31;r=x[a+64>>2];E=r>>31;s=x[a+60>>2];F=s>>31;m=x[a+8>>2];G=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){t=(f+8|0)+(b<<2)|0;e=x[t>>2];g=(b<<3)+n|0;H=x[g+4>>2];h=x[g>>2];x[g+4>>2]=h;u=e<<8;e=u;e=Aua(e,e>>31,s,F);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Aua(r,E,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(H,-16777216,16776704);i=Aua(q,C,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Sc(i,e,24);x[g>>2]=e-(B&u);x[t>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+A|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+z|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,m,G);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+p|0;c=c+n|0;x[d>>2]=x[c>>2];x[d+4>>2]=x[c+4>>2];b=b+1|0;continue}break}Ig(a,o,y);fb=f+48|0}function Lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;g=fb-48|0;fb=g;p=a+44|0;u=x[a+16>>2];o=g+32|0;b=0;while(1){if((b|0)!=2){f=b<<3;n=f+o|0;f=f+p|0;x[n>>2]=x[f>>2];x[n+4>>2]=x[f+4>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;w=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];q=x[a+68>>2];A=q>>31;r=x[a+64>>2];B=r>>31;s=x[a+60>>2];C=s>>31;n=x[a+8>>2];E=x[a+12>>2];while(1){if(d){f=x[g+16>>2];i=f>>>10&4194048;e=(((x[g+20>>2]&2147483647)<<1|f>>>31)&-2)+u|0;b=0;h=0;while(1){if((h|0)!=2){f=e+h|0;m=v[f|0];x[(g+8|0)+(h<<2)>>2]=((D(i,v[f+2|0]-m|0)|0)/16384|0)+(m<<8);h=h+1|0;continue}break}while(1){if((b|0)!=2){t=(g+8|0)+(b<<2)|0;e=x[t>>2];f=(b<<3)+o|0;F=x[f+4>>2];h=x[f>>2];x[f+4>>2]=h;m=e<<8;e=m;e=Aua(e,e>>31,s,C);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Aua(r,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(F,-16777216,16776704);i=Aua(q,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Sc(i,e,24);x[f>>2]=e-(m&z);x[t>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],l>>12);k=k+w|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],k>>12);Pb(g+16|0,n,E);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+p|0;a=a+o|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=g+48|0}function E1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;g=Ki(b)^-1;a:{if(oc(x[d>>2],x[d+4>>2])>>>0<=g>>>0){xu(a);break a}Ki(b);if((y[c+4|0]|y[c+5|0]<<8)>>>0>=60){Vb(b,4)}j=f,k=Ki(b),x[j+44>>2]=k;Vb(b,4);h=Ki(b);i=Ki(b);if(!((h|0)>0&(i|0)>36)){xu(a);break a}if(!Nd(Vd(x[e>>2],x[yb(x[d>>2],g)>>2]),13181)){xu(a);break a}e=f+4|0;uF(e,b,i,h);d=hc(f+24|0,e);ub(e);b=x[d>>2];x[31609]=0;b=R(172,b|0)|0;e=x[31609];x[31609]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){x[31609]=0;R(182,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break d}break b}b=y[c+4|0]|y[c+5|0]<<8;if(b>>>0<=39){x[31609]=0;P(183,d|0,8)|0;b=x[31609];x[31609]=0;if((b|0)==1){break b}b=y[c+4|0]|y[c+5|0]<<8}if((b&65535)>>>0<=59){x[31609]=0;P(183,d|0,16)|0;b=x[31609];x[31609]=0;if((b|0)==1){break b}}x[31609]=0;R(184,d|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break b}e:{f:{b=y[c+4|0]|y[c+5|0]<<8;g:{if(b>>>0>=120){x[31609]=0;R(184,d|0)|0;c=x[31609];x[31609]=0;b=8;break g}h:{if(b>>>0>=100){x[31609]=0;P(183,d|0,4)|0;b=x[31609];x[31609]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}x[31609]=0;R(184,d|0)|0;c=x[31609];x[31609]=0;b=4}if((c|0)==1){break b}x[31609]=0;P(183,d|0,b|0)|0;break e}x[31609]=0;R(184,d|0)|0}b=x[31609];x[31609]=0;if((b|0)==1){break b}x[31609]=0;c=R(184,d|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break c}x[31609]=0;b=f+4|0;S(185,b|0,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}j=hc(a,b),k=x[f+44>>2],x[j+20>>2]=k;ub(b)}ub(d);break a}}a=N()|0;ub(d);Q(a|0);p()}fb=f+48|0}function yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;p=a+44|0;t=x[a+16>>2];o=f+32|0;b=0;while(1){if((b|0)!=2){g=b<<3;m=g+o|0;g=g+p|0;x[m>>2]=x[g>>2];x[m+4>>2]=x[g+4>>2];b=b+1|0;continue}break}u=x[a+24>>2];v=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;m=x[a+8>>2];C=x[a+12>>2];while(1){if(d){b=x[f+16>>2];k=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=b>>>21&2040;i=w[b+38086>>1];n=w[b+38084>>1];j=w[b+38082>>1];e=w[b+38080>>1];b=0;h=0;while(1){if((h|0)!=2){g=h<<1;l=k+g|0;x[(f+8|0)+(h<<2)>>2]=(((D(w[l>>1],j)+D(w[k+(g|-4)>>1],e)|0)+D(n,w[l+4>>1])|0)+D(i,w[l+8>>1])|0)/16384;h=h+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(b<<3)+o|0;l=x[g+4>>2];i=x[g>>2];x[g+4>>2]=i;n=e<<8;e=n;e=Aua(e,e>>31,s,B);j=hb;h=e;e=Yb(i,-16777216,16776704);e=Aua(r,A,e,e>>31);i=h+e|0;h=hb+j|0;h=e>>>0>i>>>0?h+1|0:h;e=Yb(l,-16777216,16776704);j=Aua(q,z,e,e>>31);i=j+i|0;e=hb+h|0;e=i>>>0<j>>>0?e+1|0:e;j=i+8388608|0;e=j>>>0<8388608?e+1|0:e;e=Sc(j,e,24);x[g>>2]=e-(n&y);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],v);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],u);Pb(f+16|0,m,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+p|0;a=a+o|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=f+48|0}function XP(a){var b=E(0),c=E(0),d=0,e=0,f=0,g=0,h=0,i=0,k=E(0),l=0,m=E(0);d=fb-16|0;fb=d;f=a+4208|0;c=Vz(B[yb(f,2)>>2]);b=E(A[x[a+16>>2]+24620>>2]);B[d+12>>2]=c/b;x[d+8>>2]=1056964608;c=uq(E(B[Rm(d+12|0,d+8|0)>>2]*E(6.2831854820251465)));c=E(M(E(E(E(c+c)+E(3))/E(5))));B[a+4236>>2]=c;B[a+4240>>2]=M(E(E(1)-E(c*c)));c=E(E(B[yb(f,1)>>2]*E(29))+E(2));a:{if(c<E(4294967296)&c>=E(0)){i=~~c>>>0;break a}i=0}v[a+4272|0]=i;e=i;while(1){if(e&255){g=g+1|0;e=(e&254)>>>1|0;continue}break}v[a+4273|0]=g;k=Ee(E(10),E(E(E(B[a+4208>>2]*E(60))+E(-60))/E(20)));l=d,m=E(Vz(B[yb(f,3)>>2])/b),B[l+12>>2]=m;x[d+8>>2]=1056964608;c=B[Rm(d+12|0,d+8|0)>>2];l=d,m=E(Vz(B[yb(f,4)>>2])/b),B[l+12>>2]=m;x[d+8>>2]=1056964608;b=E(E(B[Rm(d+12|0,d+8|0)>>2]*E(6.2831854820251465))*E(.5));g=fb-16|0;fb=g;f=(q(b),j(2));e=f&2147483647;b:{if(e>>>0<=1061752794){if(e>>>0<964689920){break b}b=mo(+b,0);break b}if(e>>>0<=1081824209){h=+b;if(e>>>0<=1075235811){b=mo(((f|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=mo(((f|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(e>>>0<=1088565717){h=+b;if(e>>>0<=1085271519){b=mo(((f|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=mo(((f|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(e>>>0>=2139095040){b=E(b-b);break b}e=Zy(b,g+8|0);b=mo(C[g+8>>3],e&1)}fb=g+16|0;b=E(E(E(1)-b)/E(b+E(1)));B[a+4268>>2]=b;c=uq(E(c*E(6.2831854820251465)));B[a+4264>>2]=-c;B[a+4260>>2]=E(E(k*E(M(E(E(1)-E(c*c)))))*E(M(E(E(1)-E(b*b)))))*B[(i<<2)+44e3>>2];fb=d+16|0}function o7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;a=fb-624|0;fb=a;x[a+616>>2]=c;x[a+620>>2]=b;x[a+16>>2]=1274;b=a+16|0;h=De(a+200|0,a+208|0,b);i=a+192|0;cd(i,x[e+28>>2]);x[31609]=0;j=R(1252,x[a+192>>2])|0;k=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{if((k|0)!=1){v[a+191|0]=0;e=x[e+4>>2];x[31609]=0;c=na(1283,a+620|0,c|0,d|0,i|0,e|0,f|0,a+191|0,j|0,h|0,a+196|0,a+608|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break d}if(!c){break e}v[a+190|0]=0;v[a+188|0]=56;v[a+189|0]=57;v[a+180|0]=48;v[a+181|0]=49;v[a+182|0]=50;v[a+183|0]=51;v[a+184|0]=52;v[a+185|0]=53;v[a+186|0]=54;v[a+187|0]=55;x[31609]=0;V(1263,j|0,a+180|0,a+190|0,a+128|0);c=x[31609];x[31609]=0;if((c|0)==1){break g}x[a+4>>2]=1239;d=De(a+8|0,0,a+4|0);e=b;b=x[a+196>>2];c=b-x[h>>2]|0;if((c|0)<393){break f}Qe(d,Gd((c>>>2|0)+2|0));e=x[d>>2];if(e){break f}x[31609]=0;X(1240);b=x[31609];x[31609]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((SJ(a+16|0,a)|0)!=1){x[31609]=0;W(1276,8e3);b=x[31609];x[31609]=0;if((b|0)!=1){break a}break c}Lc(d)}else{b=a+128|0;l=e,m=y[(a+180|0)+(Ey(b,b+40|0,x[c>>2])-b>>2)|0],v[l|0]=m;e=e+1|0;c=c+4|0;b=x[a+196>>2];continue}break}}x[31609]=0;b=P(1257,a+620|0,a+616|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+620>>2];_b(a+192|0);Lc(h);fb=a+624|0;return b|0}c=N()|0;break b}c=N()|0;Lc(d)}_b(a+192|0);Lc(h);Q(c|0);p()}p()}function gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;e=x[a+8>>2];m=e;f=x[a+12>>2];j=f;a:{b:{if((f|0)<=1&e>>>0<=805306368|(f|0)<=0){i=131112;e=f;if((e|0)>-2){e=1}else{e=(e|0)>=-2&m>>>0>=3489660928}if(e){break a}i=262184;if((j|0)==-2&m>>>0<2147483648|j>>>0<4294967294){break a}break b}i=262184;if((j|0)==1&m>>>0>2147483648|j>>>0>1){break a}}i=196648}r=x[a+16>>2];k=x[a+40>>2];l=x[a+36>>2];e=x[a+48>>2];f=x[a+44>>2];n=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=n;s=b+i|0;t=x[a+32>>2];u=x[a+28>>2];y=x[a+72>>2];p=x[a+68>>2];z=p>>31;i=x[a+64>>2];A=i>>31;n=x[a+60>>2];B=n>>31;while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Aua(i,A,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Aua(p,z,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];o=g;g=x[h+12>>2]+r|0;e=(e>>>16&65520)+s|0;q=(((((((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])|0)+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+2|0],w[e+10>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8)/32768<<8;e=q;g=Aua(e,e>>31,n,B);o=o+g|0;e=hb+f|0;e=g>>>0>o>>>0?e+1|0:e;f=o+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Sc(f,e,24);e=(f|0)/256|0;l=l+u|0;x[c>>2]=D(e,l>>12)+x[c>>2];k=k+t|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,e);Pb(h+8|0,m,j);f=f-(y&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=k>>12;fb=h+16|0}function Au(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-128|0;fb=f;a:{b:{c:{d:{e:{f:{g:{if(!c){break g}d=x[c+4>>2];if(!d&A[c>>2]>=A[b+4>>2]|d){break g}a=dc(8);x[31609]=0;b=P(51,a|0,22292)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break f}e=N()|0;lc(a);break a}if(!x[b>>2]){a=dc(8);x[31609]=0;b=R(855,a|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break e}e=N()|0;lc(a);break a}d=x[b>>2];k=x[b+4>>2];b=fb-16|0;fb=b;lf(b+8|0,d,k);h=x[b+8>>2];d=f+108|0;AG(d,h,x[b+12>>2]);x[d+12>>2]=0;fb=b+16|0;h:{i:{if(a&2){b=Ln(f+88|0,d);x[31609]=0;g=R(856,b|0)|0;i=x[31609];x[31609]=0;b=1;if((i|0)==1){break h}if((g|0)==1){break i}b=Ln(f+68|0,d);x[31609]=0;i=R(857,b|0)|0;h=x[31609];x[31609]=0;b=1;if((h|0)==1){break d}if((i|0)==1){break i}b=Ln(f+48|0,d);x[31609]=0;h=P(858,b|0,c|0)|0;j=x[31609];x[31609]=0;b=1;if((j|0)==1){break c}if((h|0)==1){break i}b=Ln(f+28|0,d);x[31609]=0;j=P(859,b|0,c|0)|0;l=x[31609];x[31609]=0;b=1;if((l|0)==1){break b}if((j|0)==1){break i}g=0-((g|0)==-1|(i|0)==-1|(h|0)==-1|(j|0)==-1)|0}j:{if(!(a&1)){break j}while(1){if((e|0)==576){break j}a=x[e+29888>>2];if(a){b=Ln(f+8|0,d);x[31609]=0;a=P(a|0,b|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){e=N()|0;break a}b=1;if((a|0)==1){break i}g=(a|0)==-1?-1:g}e=e+12|0;continue}}a=k;if(c){b=0;if((g|0)!=-1){break i}b=Bc(x[c>>2],x[c+4>>2])>>>0>a>>>0?-1:0;break i}b=0;if((g|0)!=-1){break i}b=a>>>0>2047?1:-1}fb=f+128|0;return b}e=N()|0;break a}da(b|0,124832,17);p()}da(b|0,124728,17);p()}e=N()|0;break a}e=N()|0;break a}e=N()|0}Q(e|0);p()}function L7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=fb-416|0;fb=i;v[i+412|0]=0;v[i+413|0]=0;v[i+414|0]=0;v[i+415|0]=0;v[i+409|0]=0;v[i+410|0]=0;v[i+411|0]=0;v[i+412|0]=0;v[i+408|0]=37;l=qt(i+409|0,13966,x[c+4>>2]);b=i+368|0;x[i+364>>2]=b;a=Od();a:{if(l){j=x[c+8>>2];k=i- -64|0;x[k>>2]=g;x[k+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=j;j=ph(b,30,a,i+408|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=ph(i+368|0,30,a,i+408|0,i+80|0)}x[i+128>>2]=1239;k=De(i+356|0,0,i+128|0);b=i+368|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Od();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=ij(i+364|0,a,i+408|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=ij(i+364|0,a,i+408|0,i+32|0)}if((j|0)==-1){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)==1){break d}break e}a=x[i+364>>2];Qe(k,a)}f=a+j|0;g=jj(a,f,x[c+4>>2]);x[i+116>>2]=1239;e=De(i+120|0,0,i+116|0);g:{h:{if((i+368|0)==(a|0)){j=i+128|0;break h}j=Gd(j<<3);if(!j){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)!=1){break e}a=N()|0;break g}Qe(e,j);b=a}a=i+108|0;cd(a,x[c+28>>2]);x[31609]=0;ga(1272,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);b=x[31609];x[31609]=0;i:{if((b|0)!=1){_b(a);x[31609]=0;a=ea(1273,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break i}Lc(e);Lc(k);fb=i+416|0;break b}a=N()|0;_b(i+108|0);break g}a=N()|0}Lc(e);break c}p()}a=N()|0}Lc(k);Q(a|0);p()}return a|0}function ana(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;w=x[a+16>>2];o=kg(1,2);b=hb;y=b;Pb(a,o,b);p=a+44|0;n=f+32|0;b=0;while(1){if((b|0)!=2){g=b<<3;m=g+n|0;g=g+p|0;x[m>>2]=x[g>>2];x[m+4>>2]=x[g+4>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;z=x[a+32>>2];A=x[a+28>>2];B=x[a+72>>2];q=x[a+68>>2];C=q>>31;r=x[a+64>>2];E=r>>31;s=x[a+60>>2];F=s>>31;m=x[a+8>>2];G=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+w|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){t=(f+8|0)+(b<<2)|0;e=x[t>>2];g=(b<<3)+n|0;H=x[g+4>>2];h=x[g>>2];x[g+4>>2]=h;u=e<<8;e=u;e=Aua(e,e>>31,s,F);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Aua(r,E,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(H,-16777216,16776704);i=Aua(q,C,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Sc(i,e,24);x[g>>2]=e-(B&u);x[t>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+A|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+z|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Pb(f+16|0,m,G);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+p|0;c=c+n|0;x[d>>2]=x[c>>2];x[d+4>>2]=x[c+4>>2];b=b+1|0;continue}break}Ig(a,o,y);fb=f+48|0}function V7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=fb-256|0;fb=i;v[i+252|0]=0;v[i+253|0]=0;v[i+254|0]=0;v[i+255|0]=0;v[i+249|0]=0;v[i+250|0]=0;v[i+251|0]=0;v[i+252|0]=0;v[i+248|0]=37;l=qt(i+249|0,13966,x[c+4>>2]);b=i+208|0;x[i+204>>2]=b;a=Od();a:{if(l){j=x[c+8>>2];k=i- -64|0;x[k>>2]=g;x[k+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=j;j=ph(b,30,a,i+248|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=ph(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=1239;k=De(i+196|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Od();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=ij(i+204|0,a,i+248|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=ij(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)==1){break d}break e}a=x[i+204>>2];Qe(k,a)}f=a+j|0;g=jj(a,f,x[c+4>>2]);x[i+116>>2]=1239;e=De(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Gd(j<<1);if(!j){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)!=1){break e}a=N()|0;break g}Qe(e,j);b=a}a=i+108|0;cd(a,x[c+28>>2]);x[31609]=0;ga(1267,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);b=x[31609];x[31609]=0;i:{if((b|0)!=1){_b(a);x[31609]=0;a=ea(23,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break i}Lc(e);Lc(k);fb=i+256|0;break b}a=N()|0;_b(i+108|0);break g}a=N()|0}Lc(e);break c}p()}a=N()|0}Lc(k);Q(a|0);p()}return a|0}function v7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;x[a+16>>2]=1274;b=a+16|0;h=De(a+152|0,a+160|0,b);j=a+144|0;cd(j,x[e+28>>2]);x[31609]=0;i=R(28,x[a+144>>2])|0;k=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{if((k|0)!=1){v[a+143|0]=0;e=x[e+4>>2];x[31609]=0;c=na(1275,a+268|0,c|0,d|0,j|0,e|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break d}if(!c){break e}v[a+142|0]=0;v[a+140|0]=56;v[a+141|0]=57;v[a+132|0]=48;v[a+133|0]=49;v[a+134|0]=50;v[a+135|0]=51;v[a+136|0]=52;v[a+137|0]=53;v[a+138|0]=54;v[a+139|0]=55;x[31609]=0;V(1249,i|0,a+132|0,a+142|0,a+122|0);c=x[31609];x[31609]=0;if((c|0)==1){break g}x[a+4>>2]=1239;d=De(a+8|0,0,a+4|0);e=b;b=x[a+148>>2];c=b-x[h>>2]|0;if((c|0)<99){break f}Qe(d,Gd(c+2|0));e=x[d>>2];if(e){break f}x[31609]=0;X(1240);b=x[31609];x[31609]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((SJ(a+16|0,a)|0)!=1){x[31609]=0;W(1276,8e3);b=x[31609];x[31609]=0;if((b|0)!=1){break a}break c}Lc(d)}else{b=a+122|0;i=a_(b);l=e,m=y[((Fi(b,i,y[c|0])-a|0)+a|0)+10|0],v[l|0]=m;e=e+1|0;c=c+1|0;b=x[a+148>>2];continue}break}}x[31609]=0;b=P(1241,a+268|0,a+264|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+268>>2];_b(a+144|0);Lc(h);fb=a+272|0;return b|0}c=N()|0;break b}c=N()|0;Lc(d)}_b(a+144|0);Lc(h);Q(c|0);p()}p()}function Kz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);e=fb-48|0;fb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=x[a+24>>2];if((b|0)==x[d+24604>>2]){break d}a=e+8|0;zc(a,d+24604|0,40);x[e+8>>2]=b;NA(d,a);break d;case 2:f=x[a+24>>2];d=f+24664|0;b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;d=f+24656|0;b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;b=x[f+24652>>2];x[e+8>>2]=x[f+24648>>2];x[e+12>>2]=b;d=fb-16|0;fb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=dc(8);x[31609]=0;b=P(36,d+4|0,10846)|0;a=x[31609];x[31609]=0;i:{if((a|0)!=1){sc(c,b);x[31609]=0;S(97,c|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break g}a=N()|0;tb(b);break i}a=N()|0;lc(c)}Q(a|0);p()}fb=d+16|0;break f}p()}v[e+8|0]=b;b=e+8|0;a=x[a+24>>2];if(!zz(b,a+24648|0)){break d}LA(a,b);break d;case 3:f=e+8|0;d=x[a+24>>2];zc(f,d+24604|0,40);b=fb-48|0;fb=b;j:{if((c|0)==-1){cu(f,x[Tq(b+8|0)+32>>2]);Oo(f,x[Tq(b+8|0)+36>>2]);break j}if((c|0)<=0){cu(f,0);Oo(f,0);break j}a=D(c,1e3);cu(f,a);Oo(f,a)}fb=b+48|0;if(x[d+24636>>2]==x[e+40>>2]&x[d+24640>>2]==x[e+44>>2]){break d}NA(d,e+8|0);break d;default:d=dc(8);x[31609]=0;c=P(36,e+8|0,10401)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(d,c);x[31609]=0;S(97,d|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b;case 0:break e}}g=a,h=Ee(E(10),E(E(E(c|0)*E(.0010000000474974513))*E(.5))),B[g+48>>2]=h}fb=e+48|0;return}b=N()|0;lc(d)}Q(b|0)}p()}function wk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;a:{if(!d){break a}g=x[c>>2];if(!g){break a}b:{c:{d:{e:{f=x[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=D(d,20)+g|0;break d}f=((D(d,36318)|0)/1024|0)+g|0;break d}f:{g:{if(y[a+480208|0]&16){if((f|0)==4){break g}f=d>>31;x[i+12>>2]=(f^d)-f;xc(i+12|0,1020);h=x[i+12>>2];f=c;h:{if((d|0)>0){if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?35376:35440)>>2];break h}h=x[(h&-4)+(Ob(a+1074312|0,7)?35504:36528)>>2];break h}if(h>>>0<=15){h=x[(h<<2)+(Ob(a+1074312|0,7)?35440:35376)>>2];break h}h=x[(h&-4)+(Ob(a+1074312|0,7)?36528:35504)>>2]}j=Aua(h,h>>31,g,g>>31);h=hb;j=j+32768|0;h=j>>>0<32768?h+1|0:h;k=f;f=Gc(Bua(j,h,65536,0),hb);x[k>>2]=f;if((g|0)!=(f|0)){break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!((d|0)>0^f)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}f=Ob(a+1074312|0,7);g=x[c>>2];if(!f){break g}if((d|0)<0){f=Aua(g,0,14317456,0);h=hb;g=Aua(g,0,0-d|0,0);d=hb;g=g+14317456|0;d=g>>>0<14317456?d+1|0:d;f=OS(Cua(f,h,g,d),hb);break d}d=Aua(g,g>>31,d,0);f=hb;if((f|0)>=0&d>>>0>=14317456|(f|0)>0){if(e){x[c>>2]=2147483647;break a}x[c>>2]=0;x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248;break a}d=OS(Cua(Aua(g,0,14317456,0),hb,14317456-d|0,0-(f+(d>>>0>14317456)|0)|0),hb);x[c>>2]=d;if((d|0)<=0){break b}break a}f=g-d|0;break d}f=d+g|0}x[c>>2]=f}if((f|0)>0){break a}}x[c>>2]=1;if(x[a+480180>>2]!=2|e){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}fb=i+16|0}function zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0;f=fb-48|0;fb=f;p=a+44|0;t=x[a+16>>2];o=f+32|0;b=0;while(1){if((b|0)!=2){g=b<<3;m=g+o|0;g=g+p|0;x[m>>2]=x[g>>2];x[m+4>>2]=x[g+4>>2];b=b+1|0;continue}break}u=x[a+24>>2];y=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;z=x[a+72>>2];q=x[a+68>>2];A=q>>31;r=x[a+64>>2];B=r>>31;s=x[a+60>>2];C=s>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];h=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=b>>>21&2040;n=w[b+38086>>1];i=w[b+38084>>1];e=w[b+38082>>1];g=w[b+38080>>1];b=0;j=0;while(1){if((j|0)!=2){k=h+j|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(n,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){j=(f+8|0)+(b<<2)|0;e=x[j>>2];g=(b<<3)+o|0;k=x[g+4>>2];h=x[g>>2];x[g+4>>2]=h;n=e<<8;e=n;e=Aua(e,e>>31,s,C);i=hb;l=e;e=Yb(h,-16777216,16776704);e=Aua(r,B,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Yb(k,-16777216,16776704);i=Aua(q,A,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Sc(i,e,24);x[g>>2]=e-(n&z);x[j>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],y);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],u);Pb(f+16|0,m,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+p|0;a=a+o|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=f+48|0}function I0(){var a=0,b=0,c=0;if(!y[497532]){a=fb-16|0;fb=a;Pt(497180);x[124307]=-1;x[124305]=497236;x[124303]=125632;x[124295]=94380;v[497232]=0;b=a+12|0;cd(b,x[124296]);c=x[x[124295]+8>>2];x[31609]=0;O(c|0,497180,b|0);c=x[31609];x[31609]=0;a:{if((c|0)!=1){_b(b);fb=a+16|0;break a}b=N()|0;_b(a+12|0);ho(497180);Q(b|0);p()}Ut(496508);x[124127]=94512;x[124125]=94492;x[124126]=0;po(496508,497180);SK(497244,125776,497292);Oy(496676,497244);SK(497300,125480,497348);Oy(496844,497300);Oy(497012,x[x[x[124211]-12>>2]+496868>>2]);RK(x[x[124125]-12>>2]+496500|0);OK(x[x[124211]-12>>2]+496844|0);RK(x[x[124211]-12>>2]+496844|0);a=fb-16|0;fb=a;aL(497356);x[124351]=-1;x[124349]=497412;x[124347]=125632;x[124339]=94772;v[497408]=0;b=a+12|0;cd(b,x[124340]);c=x[x[124339]+8>>2];x[31609]=0;O(c|0,497356,b|0);c=x[31609];x[31609]=0;b:{if((c|0)!=1){_b(b);fb=a+16|0;break b}b=N()|0;_b(a+12|0);Dt(497356);Q(b|0);p()}NK(496596);x[124149]=94904;x[124147]=94884;x[124148]=0;po(496596,497356);QK(497420,125776,497468);Ny(496760,497420);QK(497476,125480,497524);Ny(496928,497476);Ny(497096,x[x[x[124232]-12>>2]+496952>>2]);PK(x[x[124147]-12>>2]+496588|0);OK(x[x[124232]-12>>2]+496928|0);PK(x[x[124232]-12>>2]+496928|0);v[497532]=1}a=fb-16|0;fb=a;c:{if(bb(a+12|0,a+8|0)|0){break c}b=Gd((x[a+12>>2]<<2)+4|0);x[125414]=b;if(!b){break c}b=Gd(x[a+8>>2]);if(b){c=x[125414];x[c+(x[a+12>>2]<<2)>>2]=0;if(!(ab(c|0,b|0)|0)){break c}}x[125414]=0}fb=a+16|0;x[124097]=42;x[124115]=501692}function aV(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}d=YZ(b);e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;g=1;break a}x[e+8>>2]=x[d+8>>2];g=0}c=x[d+8>>2];c:{d:{if(mi(d)){x[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break c}c=c+4|0;break d}x[c+4>>2]=e}c=x[c>>2]}h=!y[d+12|0];if((b|0)!=(d|0)){f=x[b+8>>2];x[d+8>>2]=f;i=f+(mi(b)?0:4)|0,j=d,x[i>>2]=j;f=x[b>>2];x[d>>2]=f;wn(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){wn(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=y[c+12|0];e:{f:{if(!mi(c)){if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;or(b);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}b=x[c>>2];g:{if(!(y[b+12|0]?0:b)){b=x[c+4>>2];if(y[b+12|0]?0:b){break g}v[c+12|0]=0;b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break f}a=b}v[a+12|0]=1;return}a=x[c+4>>2];if(y[a+12|0]?0:a){break g}v[b+12|0]=1;v[c+12|0]=0;nr(c);c=x[c+8>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[x[c+4>>2]+12|0]=1;or(a);return}if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;nr(b);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];h:{if(y[d+12|0]?0:d){break h}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;return}b=x[b+8>>2]+(mi(b)?4:0)|0;break e}if(y[d+12|0]?0:d){break h}v[b+12|0]=1;v[c+12|0]=0;or(c);c=x[c+8>>2];d=x[c>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[d+12|0]=1;nr(a);return}b=x[b+8>>2]+(mi(b)?4:0)|0}c=x[b>>2];continue}}v[e+12|0]=1}}function d8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-384|0;fb=a;x[a+376>>2]=c;x[a+380>>2]=b;Dy(a+220|0,d,a+240|0,a+236|0,a+232|0);d=Fb(a+208|0);b=Mc(d);x[31609]=0;O(46,d|0,b|0);b=x[31609];x[31609]=0;a:{b:{c:{if((b|0)!=1){c=ec(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=x[a+232>>2];i=x[a+236>>2];while(1){d:{x[31609]=0;b=P(1257,a+380|0,a+376|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(b){break c}g=x[a+204>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31609]=0;O(46,d|0,b<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+204>>2]=b+c}x[31609]=0;b=R(1258,x[a+380>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(Cy(b,a+23|0,a+22|0,c,a+204|0,i,h,a+220|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[31609]=0;R(1260,a+380|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+224>>2],y[a+231|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}sK(a,c,x[a+204>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Vf(a+220|0,a+32|0,x[a+28>>2],e);x[31609]=0;b=P(1257,a+380|0,a+376|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+380>>2];tb(d);tb(a+220|0);fb=a+384|0;break a}}b=N()|0;tb(d);tb(a+220|0);Q(b|0);p()}return b|0}function Rka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0;f=fb-48|0;fb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}t=l-4|0;o=D(b,e);u=o-8|0;h:while(1){b=x[c+8>>2];g=x[c>>2];x[31609]=0;b=U(150,g|0,b|0,l|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}if(!(n>>>0<o>>>0&b)){break g}x[31609]=0;b=f+8|0;S(185,b|0,c|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break c}g=hc(f+28|0,b);ub(b);x[31609]=0;O(575,b|0,g|0);j=x[31609];x[31609]=0;if((j|0)==1){break e}z=Ze(b);q=x[f+8>>2];A=q-4|0;j=0;while(1){if((e|0)==(j|0)){Kc(f+8|0);ub(g);n=(q-l<<1)+n|0;continue h}x[31609]=0;h=R(568,g|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){x[31609]=0;b=R(197,g|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break f}x[f>>2]=b;Ge(f,0,89);x[31609]=0;P(183,g|0,1)|0;b=x[31609];x[31609]=0;if((b|0)==1){break f}k=j+n|0;b=e+j<<2;i:while(1){j:{if(k>>>0>u>>>0){break j}m=0;if(b>>>0>A>>>0){break j}while(1)if((m|0)==8){b=b+t|0;continue i}else{r=x[f>>2];i=y[b+z|0];s=m&1;i=s?i>>>4|0:i&15;x[f>>2]=r+v[(i&7)+28600|0];B=h;h=w[(r<<1)+28608>>1];h=(((0-(i&1)&h>>2)+(h>>3)|0)+(i<<30>>31&h>>1)|0)+(h&i<<29>>31)|0;x[f+4>>2]=B+(i>>>0<8?h:0-h|0);Ge(f,0,88);Ge(f+4|0,-32768,32767);h=x[f+4>>2];w[(k<<1)+a>>1]=h;m=m+1|0;k=e+k|0;b=b+s|0;continue}}break}j=j+1|0;continue}break}break}break f}ub(c);fb=f+48|0;return}b=N()|0;Kc(f+8|0);break d}b=N()|0}ub(g);break a}b=N()|0;break a}b=N()|0}ub(c);Q(b|0);p()}function m8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;Hy(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Fb(a+196|0);b=Mc(d);x[31609]=0;O(46,d|0,b|0);b=x[31609];x[31609]=0;a:{b:{c:{if((b|0)!=1){c=ec(d,0);x[a+192>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=v[a+222|0];i=v[a+223|0];while(1){d:{x[31609]=0;b=P(1241,a+268|0,a+264|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(b){break c}g=x[a+192>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31609]=0;O(46,d|0,b<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+192>>2]=b+c}x[31609]=0;b=R(1242,x[a+268>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(Gy(b,a+23|0,a+22|0,c,a+192|0,i,h,a+208|0,a+32|0,a+28|0,a+24|0,a+224|0)){break c}x[31609]=0;R(1244,a+268|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+212>>2],y[a+219|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}sK(a,c,x[a+192>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Vf(a+208|0,a+32|0,x[a+28>>2],e);x[31609]=0;b=P(1241,a+268|0,a+264|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+268>>2];tb(d);tb(a+208|0);fb=a+272|0;break a}}b=N()|0;tb(d);tb(a+208|0);Q(b|0);p()}return b|0}function yoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=Ud(c,x[a+4>>2]);if(d>>>0<b>>>0){i=fb-32|0;fb=i;b=b-d|0;d=x[Ab(a)>>2];c=x[a+4>>2];a:{if(b>>>0<=(d-c|0)/12>>>0){d=fb-16|0;fb=d;b=uv(d+4|0,a,b);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){jc(b);fb=d+16|0}else{mW(a);a=a+12|0;x[b+4>>2]=a;continue}break}break a}d=Ab(a);d=ym(i+12|0,Qp(a,Ud(x[a>>2],c)+b|0),Ud(x[a>>2],x[a+4>>2]),d);f=fb-16|0;fb=f;b=lW(f+4|0,d+8|0,b);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){mW(c);c=x[b>>2]+12|0;x[b>>2]=c;continue}break}je(b);fb=f+16|0;f=fb-16|0;fb=f;e=Ab(a);b=vb(f+12|0,x[a+4>>2]);g=vb(f+8|0,x[a>>2]);h=vb(f+4|0,x[d+4>>2]);c=x[b>>2];g=x[g>>2];b=fb+-64|0;fb=b;h=x[h>>2];x[b+56>>2]=h;x[b+60>>2]=c;x[b+52>>2]=h;e=Ag(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];h=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=h;zg(b+36|0,b+8|0);while(1){if(Fd(c,g)){kW(Pp(x[b+56>>2]),bl(c));c=jk(b+60|0);jk(b+56|0);c=x[c>>2];continue}break}yg(b+36|0);h=x[b+56>>2];if(!y[b+48|0]){e=fb-16|0;fb=e;c=vb(e+12|0,x[x[b+44>>2]>>2]);j=x[vb(e+8|0,x[x[b+40>>2]>>2])>>2];g=fb-16|0;fb=g;c=x[c>>2];x[g+12>>2]=c;while(1){if(wi(c,j)){yC(Ax(c));c=x[xm(g+12|0)>>2];continue}break}fb=g+16|0;fb=e+16|0}fb=b- -64|0;x[d+4>>2]=h;Tb(a,d+4|0);Tb(a+4|0,d+8|0);Tb(Ab(a),nc(d));x[d>>2]=x[d+4>>2];fb=f+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-12|0;x[d+8>>2]=b;yC(b);continue}break}a=x[d>>2];if(a){vs(d);Db(a)}}fb=i+32|0;return}if(b>>>0<d>>>0){nW(a,c+D(b,12)|0)}}function Kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;Tj(c+76|0,b,1413829443);x[31609]=0;b=R(172,x[c+76>>2])|0;d=x[31609];x[31609]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){x[31609]=0;d=c+56|0;S(808,d|0,a+140|0,1413894985);a=x[31609];x[31609]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){x[31609]=0;a=P(891,d|0,13752)|0;b=x[31609];x[31609]=0;if((b|0)==1){break e}b=28591;if(a){b=Fb(c+44|0);x[31609]=0;a=R(202,d|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break m}x[31609]=0;S(270,d|0,b|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break m}x[31609]=0;d=P(71,c+20|0,b|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break l}x[31609]=0;e=c+8|0;W(892,e|0);a=x[31609];x[31609]=0;if((a|0)==1){break k}x[31609]=0;a=c+32|0;S(893,a|0,d|0,e|0);f=x[31609];x[31609]=0;if((f|0)==1){break j}f=zb(b,a);tb(a);tb(e);tb(d);x[31609]=0;S(258,a|0,2,f|0);d=x[31609];x[31609]=0;if((d|0)==1){break h}x[31609]=0;d=R(773,a|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break g}tb(a);tb(f);b=d-1>>>0<19398657?1252:28591}ub(c+56|0);break a}a=N()|0;break b}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;tb(c+8|0)}tb(d);break f}a=N()|0;break f}a=N()|0;tb(c+32|0)}tb(b);break d}a=N()|0}ub(c+56|0);break b}x[31609]=0;a=U(150,x[c+76>>2],x[c+84>>2],2)|0;b=x[31609];x[31609]=0;if((b|0)==1){break c}b=28591;if(!a){break a}x[31609]=0;b=R(189,c+76|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0}ub(c+76|0);Q(a|0);p()}ub(c+76|0);fb=c+96|0;return b|0}function vna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;w[e+30>>1]=254;d=Hj(a);c=fb-16|0;fb=c;f=e+16|0;x[f>>2]=0;x[f+4>>2]=0;tc(f+8|0);Rd(c+8|0,x[vb(c+4|0,f)>>2]);a:{b:{if(d){x[31609]=0;O(641,f|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break b}QE(f,d)}g=c+8|0;Qd(g);Rj(g);fb=c+16|0;break a}a=N()|0;Rj(c+8|0);Q(a|0);p()}c=x[a>>2];g=x[f>>2];while(1){if((b|0)==(d|0)){c:{if(!(h&65535)){break c}c=wb(c);d=wb(x[a+4>>2]);b=fb-16|0;fb=b;c=NC(c,d,z[e+30>>1]);x[b+12>>2]=c;if(Ib(c,d)){x[b+8>>2]=c;while(1){c=x[ge(b+8|0)>>2];if(Ib(c,d)){c=z[c>>1];if((c|0)==z[e+30>>1]){continue}w[x[b+12>>2]>>1]=c;ge(b+12|0);continue}break}c=x[b+12>>2]}fb=b+16|0;b=vb(e+12|0,c);c=x[vb(e+8|0,wb(x[a+4>>2]))>>2];d=x[b>>2];b=x[a>>2];b=(lp(d,wb(b))<<1)+b|0;if(Ib(d,c)){Jd(a,aC(b+(lp(c,d)<<1)|0,x[a+4>>2],b))}wb(b);b=wb(x[a>>2]);x[e+4>>2]=b;d=wb(x[a+4>>2]);while(1){if(Ib(b,d)){d:{c=x[a+24>>2];h=x[c+484344>>2];b=z[b>>1];if(!Je(h,x[c+484348>>2],b)){break d}b=Wb(h,b);k=e,l=wb(x[b>>2]),x[k>>2]=l;h=wb(x[b+4>>2]);g=x[f+4>>2];c=x[f>>2];while(1){b=x[e>>2];if(!Ib(b,h)){break d}e:{if(y[b+3|0]!=12){break e}j=$c(c,g);i=y[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=y[ac(c,i)|0],v[k+5|0]=l}tg(e);continue}}b=x[ge(e+4|0)>>2];continue}else{b=x[f>>2];d=$c(b,x[f+4>>2]);c=z[a+28>>1];if(d>>>0<=c>>>0){break c}k=a,l=z[ac(b,c)>>1],w[k+28>>1]=l}break}}}else{k=ac(g,b),l=b-h|0,w[k>>1]=l;h=(z[ac(c,b)>>1]==254)+h|0;b=b+1|0;continue}break}od(f);fb=e+32|0}function Bla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];o=x[a+128>>2];if(o){p=Hg(m,n,o);q=hb;b=x[a+76>>2];fg(h,e,uf(m,n,d),hb);r=hb>>>0>b>>>0?d:0}i=a+112|0;k=x[a+40>>2];l=x[a+36>>2];f=x[a+48>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{s=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;r=r-1|0;b=r;p=b?p:0;q=b?q:0;h=(e<<1)+t|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){ce(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);be(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}v=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=Fg(i,u)<<8;b=h;j=b>>31;b=x[a+60>>2];b=Aua(h,j,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(s,-16777216,16776704);j=Aua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Aua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Sc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Pb(g,m,n);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue a}else{ce(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);be(i,4);Pb(g+8|0,p,q);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function BO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;g=Nb(a);a:{b:{c:{a=x[b+36>>2];c=x[b+40>>2];d:{if(Ib(a,c)){tc(d+28|0);break d}x[31609]=0;a=d+16|0;O(1072,a|0,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}x[31609]=0;c=R(1056,a|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break c}x[d+28>>2]=c;nf(a);c=x[b+40>>2];a=x[b+36>>2]}e:{if(Ib(a,c)){c=b+36|0;break e}c=x[d+28>>2];a=x[c>>2]}e=x[c+4>>2];x[31609]=0;O(176,g|0,fj(a,e)|0);a=x[31609];x[31609]=0;f:{if((a|0)!=1){a=wb(x[c>>2]);x[d+12>>2]=a;h=wb(x[c+4>>2]);g:{h:{i:{j:{k:{while(1){if(!Ib(a,h)){xl(d+28|0);fb=d+32|0;return}c=y[a+16|0];e=x[x[b+24>>2]+484360>>2];x[31609]=0;e=Mj(e,c);O(1073,d|0,e|0);c=x[31609];x[31609]=0;if((c|0)==1){break g}x[31609]=0;c=d+16|0;O(1059,c|0,d|0);f=x[31609];x[31609]=0;if((f|0)!=1){x[31609]=0;O(178,g|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break k}tb(c);tb(d);f=bl(x[g+4>>2]);l:{if(!Ad(x[f+4>>2],y[f+11|0])){break l}a=x[a+12>>2];if(!Wi(e,a&255)){break l}f=x[b+24>>2];i=x[f+1298404>>2];a=z[ac(x[e>>2],a)>>1];e=x[f+484344>>2];x[31609]=0;O(1066,d|0,Wb(e,a)|0);a=x[31609];x[31609]=0;if((a|0)==1){break i}x[31609]=0;S(1074,c|0,i|0,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break h}zb(bl(x[g+4>>2]),c);tb(c);tb(d)}a=x[fA(d+12|0)>>2];continue}break}a=N()|0;break j}a=N()|0;tb(d+16|0)}tb(d);break f}a=N()|0;break f}a=N()|0;tb(d);break f}a=N()|0;break f}a=N()|0}xl(d+28|0);break a}a=N()|0;nf(d+16|0);break a}a=N()|0}Td(g);Q(a|0);p()}function c8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-320|0;fb=a;x[a+312>>2]=c;x[a+316>>2]=b;h=Fb(a+196|0);g=a+16|0;cd(g,x[d+28>>2]);x[31609]=0;b=R(1252,x[a+16>>2])|0;c=x[31609];x[31609]=0;a:{b:{if((c|0)==1){break b}x[31609]=0;V(1263,b|0,95168,95194,a+208|0);b=x[31609];x[31609]=0;if((b|0)==1){break b}_b(g);c=Fb(a+184|0);b=Mc(c);x[31609]=0;O(46,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){c:{b=ec(c,0);x[a+180>>2]=b;x[a+12>>2]=g;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1257,a+316|0,a+312|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break d}d=x[a+180>>2];e:{if(!g){g=d;d=Cb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31609]=0;O(46,c|0,d<<1);b=x[31609];x[31609]=0;if((b|0)==1){break c}b=Mc(c);x[31609]=0;O(46,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}b=ec(c,0);x[a+180>>2]=d+b}x[31609]=0;d=R(1258,x[a+316>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(!co(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break e}d=x[a+180>>2]}x[31609]=0;O(46,c|0,d-b|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}b=Kb(c);d=Od();x[a>>2]=f;if((rK(b,d,a)|0)!=1){x[e>>2]=4}x[31609]=0;b=P(1257,a+316|0,a+312|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break d}if(b){x[e>>2]=x[e>>2]|2}b=x[a+316>>2];tb(c);tb(h);fb=a+320|0;return b|0}x[31609]=0;R(1260,a+316|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){continue}}break}}}b=N()|0;tb(c);break a}b=N()|0;_b(a+16|0)}tb(h);Q(b|0);p()}function l8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;h=Fb(a+196|0);g=a+16|0;cd(g,x[d+28>>2]);x[31609]=0;b=R(28,x[a+16>>2])|0;c=x[31609];x[31609]=0;a:{b:{if((c|0)==1){break b}x[31609]=0;V(1249,b|0,95168,95194,a+208|0);b=x[31609];x[31609]=0;if((b|0)==1){break b}_b(g);c=Fb(a+184|0);b=Mc(c);x[31609]=0;O(46,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){c:{b=ec(c,0);x[a+180>>2]=b;x[a+12>>2]=g;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1241,a+252|0,a+248|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break d}d=x[a+180>>2];e:{if(!g){g=d;d=Cb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31609]=0;O(46,c|0,d<<1);b=x[31609];x[31609]=0;if((b|0)==1){break c}b=Mc(c);x[31609]=0;O(46,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}b=ec(c,0);x[a+180>>2]=d+b}x[31609]=0;d=R(1242,x[a+252>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(!eo(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break e}d=x[a+180>>2]}x[31609]=0;O(46,c|0,d-b|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}b=Kb(c);d=Od();x[a>>2]=f;if((rK(b,d,a)|0)!=1){x[e>>2]=4}x[31609]=0;b=P(1241,a+252|0,a+248|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break d}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(c);tb(h);fb=a+256|0;return b|0}x[31609]=0;R(1244,a+252|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){continue}}break}}}b=N()|0;tb(c);break a}b=N()|0;_b(a+16|0)}tb(h);Q(b|0);p()}function Cla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];o=x[a+128>>2];if(o){p=Hg(m,n,o);q=hb;b=x[a+76>>2];fg(h,e,uf(m,n,d),hb);r=hb>>>0>b>>>0?d:0}i=a+112|0;k=x[a+40>>2];l=x[a+36>>2];f=x[a+48>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{s=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;r=r-1|0;b=r;p=b?p:0;q=b?q:0;h=e+t|0;b=o;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){ce(i,v[h+x[g+12>>2]|0]<<6);be(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}w=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=Fg(i,u)<<8;b=h;j=b>>31;b=x[a+60>>2];b=Aua(h,j,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(s,-16777216,16776704);j=Aua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Aua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Sc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Pb(g,m,n);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue a}else{ce(i,v[h+x[g+12>>2]|0]<<6);be(i,4);Pb(g+8|0,p,q);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function Oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=fb-48|0;fb=g;n=a+44|0;s=x[a+16>>2];m=g+32|0;b=0;while(1){if((b|0)!=2){f=b<<3;l=f+m|0;f=f+n|0;x[l>>2]=x[f>>2];x[l+4>>2]=x[f+4>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;v=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;l=x[a+8>>2];B=x[a+12>>2];while(1){if(d){f=x[g+16>>2];i=f>>>18|0;e=((((x[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+s|0;b=0;h=0;while(1){if((h|0)!=2){f=e+(h<<1)|0;k=w[f>>1];x[(g+8|0)+(h<<2)>>2]=k+((D(i,w[f+4>>1]-k|0)|0)/16384|0);h=h+1|0;continue}break}while(1){if((b|0)!=2){r=(g+8|0)+(b<<2)|0;e=x[r>>2];f=(b<<3)+m|0;C=x[f+4>>2];h=x[f>>2];x[f+4>>2]=h;k=e<<8;e=k;e=Aua(e,e>>31,q,A);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Aua(p,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=Aua(o,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Sc(i,e,24);x[f>>2]=e-(k&v);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[g+12>>2]);Pb(g+16|0,l,B);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+n|0;a=a+m|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=g+48|0}function RA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=92;j=91;k=85;l=84;m=83;n=5;o=118;p=113;q=111;r=107;s=106;t=96;c=88;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;a=ds(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1),119,1),120,1);if(!c){break a}d=111;e=105;f=99;break b;case 3:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1);o=112;p=98;q=93;r=90;s=89;t=88;c=86;u=76;v=75;w=74;x=73;y=72;z=71;A=70;d=69;e=68;g=67;case 1:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1),v,1);n=u;m=c;l=t;k=s;j=r;i=q;c=p;h=o;break;case 2:break c;case 0:break d}}Lb(Lb(Lb(Lb(a,n,1),m,1),l,1),k,1);g=j;f=i;e=c;d=h}Lb(a,g,1)}Lb(Lb(Lb(a,f,1),e,1),d,1)}}function jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=fb-16|0;fb=h;f=x[a+8>>2];k=f;e=x[a+12>>2];j=e;a:{b:{if((e|0)<=1&f>>>0<=805306368|(e|0)<=0){i=131112;f=e;if((e|0)>-2){e=1}else{e=(f|0)>=-2&k>>>0>=3489660928}if(e){break a}i=262184;if((j|0)==-2&k>>>0<2147483648|j>>>0<4294967294){break a}break b}i=262184;if((j|0)==1&k>>>0>2147483648|j>>>0>1){break a}}i=196648}q=x[a+16>>2];r=x[a+24>>2];s=x[a+20>>2];f=x[a+48>>2];e=x[a+44>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;t=b+i|0;u=x[a+72>>2];p=x[a+68>>2];v=p>>31;i=x[a+64>>2];y=i>>31;l=x[a+60>>2];z=l>>31;while(1){b=e;if(d){e=Yb(e,-16777216,16776704);m=Aua(i,y,e,e>>31);n=hb;e=x[h+8>>2];g=(x[h+12>>2]<<1)+q|0;e=(e>>>16&65520)+t|0;g=(((((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+4>>1],w[e+10>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/32768<<8;e=g;e=Aua(e,e>>31,l,z);m=e+m|0;o=hb+n|0;o=e>>>0>m>>>0?o+1|0:o;f=Yb(f,-16777216,16776704);e=Aua(p,v,f,f>>31);n=e+m|0;f=hb+o|0;f=e>>>0>n>>>0?f+1|0:f;e=n+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Sc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(h+8|0,k,j);e=e-(g&u)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;fb=h+16|0}function dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];m=kg(1,2);b=hb;u=b;Pb(a,m,b);n=a+44|0;l=f+32|0;b=0;while(1){if((b|0)!=2){g=b<<3;k=g+l|0;g=g+n|0;x[k>>2]=x[g>>2];x[k+4>>2]=x[g+4>>2];b=b+1|0;continue}break}v=x[a+24>>2];y=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;k=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(b<<3)+l|0;F=x[g+4>>2];h=x[g>>2];x[g+4>>2]=h;s=e<<8;e=s;e=Aua(e,e>>31,q,C);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Aua(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(F,-16777216,16776704);i=Aua(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Sc(i,e,24);x[g>>2]=e-(z&s);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],y);x[c+4>>2]=x[c+4>>2]+D(v,x[f+12>>2]);Pb(f+16|0,k,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+n|0;c=c+l|0;x[d>>2]=x[c>>2];x[d+4>>2]=x[c+4>>2];b=b+1|0;continue}break}Ig(a,m,u);fb=f+48|0}function hz(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;Ke(x[a+80>>2],x[a+20>>2]);while(1){c=x[a+28>>2];if((b|0)<x[a+24>>2]){Ke(x[a+80>>2],x[c+(b<<2)>>2]);b=b+1|0;continue}break}Ke(x[a+80>>2],c);a:{if(!x[a+396>>2]){break a}while(1){if(x[a+264>>2]<=(e|0)){break a}d=x[a+396>>2]+D(e,24)|0;c=x[d+16>>2];if(c){b=0;while(1){if((b|0)<x[(x[a+124>>2]+D(y[d+13|0],2096)|0)+4>>2]){Ke(x[a+80>>2],x[(b<<2)+c>>2]);b=b+1|0;c=x[d+16>>2];continue}break}Ke(x[a+80>>2],c)}Ke(x[a+80>>2],x[d+20>>2]);e=e+1|0;continue}}b=x[a+124>>2];if(b){c=0;while(1){if((c|0)<x[a+120>>2]){b=D(c,2096)+b|0;Ke(x[a+80>>2],x[b+8>>2]);Ke(x[a+80>>2],x[b+28>>2]);Ke(x[a+80>>2],x[b+32>>2]);Ke(x[a+80>>2],x[b+2084>>2]);b=x[b+2088>>2];Ke(x[a+80>>2],b?b-4|0:0);c=c+1|0;b=x[a+124>>2];continue}break}Ke(x[a+80>>2],b)}Ke(x[a+80>>2],x[a+260>>2]);Ke(x[a+80>>2],x[a+396>>2]);c=x[a+404>>2];if(c){b=0;while(1){if((b|0)<x[a+400>>2]){Ke(x[a+80>>2],x[(D(b,40)+c|0)+4>>2]);b=b+1|0;c=x[a+404>>2];continue}break}Ke(x[a+80>>2],c)}e=a+996|0;d=a+928|0;f=a+800|0;b=0;while(1){if(b>>>0<=15&x[a+4>>2]>(b|0)){c=b<<2;Ke(x[a+80>>2],x[c+f>>2]);Ke(x[a+80>>2],x[c+d>>2]);Ke(x[a+80>>2],x[c+e>>2]);b=b+1|0;continue}else{e=a+1100|0;d=a+1092|0;f=a+1084|0;g=a+1076|0;h=a+1068|0;c=0;while(1){if((c|0)!=2){b=c<<2;Ke(x[a+80>>2],x[b+h>>2]);Ke(x[a+80>>2],x[b+g>>2]);Ke(x[a+80>>2],x[b+f>>2]);Ke(x[a+80>>2],x[b+d>>2]);Ke(x[a+80>>2],x[b+e>>2]);c=c+1|0;continue}break}}break}}function Pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=fb-48|0;fb=g;n=a+44|0;s=x[a+16>>2];m=g+32|0;b=0;while(1){if((b|0)!=2){f=b<<3;l=f+m|0;f=f+n|0;x[l>>2]=x[f>>2];x[l+4>>2]=x[f+4>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;w=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;l=x[a+8>>2];B=x[a+12>>2];while(1){if(d){f=x[g+16>>2];i=f>>>10&4194048;e=(((x[g+20>>2]&2147483647)<<1|f>>>31)&-2)+s|0;b=0;h=0;while(1){if((h|0)!=2){f=e+h|0;k=v[f|0];x[(g+8|0)+(h<<2)>>2]=((D(i,v[f+2|0]-k|0)|0)/16384|0)+(k<<8);h=h+1|0;continue}break}while(1){if((b|0)!=2){r=(g+8|0)+(b<<2)|0;e=x[r>>2];f=(b<<3)+m|0;C=x[f+4>>2];h=x[f>>2];x[f+4>>2]=h;k=e<<8;e=k;e=Aua(e,e>>31,q,A);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Aua(p,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(C,-16777216,16776704);i=Aua(o,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Sc(i,e,24);x[f>>2]=e-(k&w);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[g+12>>2]);Pb(g+16|0,l,B);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){a=b<<3;c=a+n|0;a=a+m|0;x[c>>2]=x[a>>2];x[c+4>>2]=x[a+4>>2];b=b+1|0;continue}break}fb=g+48|0}function xS(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;f=fb-48|0;fb=f;b=Kw(f+30|0,x[a>>2]);c=kq(f+29|0,x[a+4>>2]);uY(f+32|0,z[b>>1],c);c=kq(f+28|0,x[a+8>>2]);d=z[f+32>>1];b=fb-16|0;fb=b;v[b+15|0]=y[f+34|0];rS(f+36|0,d,b+15|0,c);fb=b+16|0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;h=z[f+36>>1]<<16>>16;g=y[f+38|0];b=zf(g);e=zf(2);g=zf(g);b=h-(((b|0)!=(e|0)?b>>>0<e>>>0?-1:1:0)<<24>>24<=0)|0;e=(((b|0)<0?b-399|0:b)|0)/400|0;b=D(e,-400)+b|0;b=x[vb(d+12|0,((((zf(y[f+39|0])+D(e,146097)|0)+((D(g+(g>>>0>2?-3:9)|0,153)+2>>>0)/5|0)+(b>>>2)|0)+D(b,365)|0)-((b>>>0)/100|0)|0)-719469|0)>>2];fb=d+16|0;e=x[vb(c+12|0,b)>>2];fb=c+16|0;g=vb(f+24|0,x[a+12>>2]);c=fb-16|0;fb=c;b=fb-16|0;fb=b;d=fb-16|0;fb=d;e=x[vb(d+12|0,D(e,24))>>2];fb=d+16|0;x[b+8>>2]=e;d=x[vb(b+12|0,x[g>>2]+x[b+8>>2]|0)>>2];fb=b+16|0;e=x[vb(c+12|0,d)>>2];fb=c+16|0;g=vb(f+20|0,x[a+16>>2]);c=fb-16|0;fb=c;b=fb-16|0;fb=b;d=fb-16|0;fb=d;e=x[vb(d+12|0,D(e,60))>>2];fb=d+16|0;x[b+8>>2]=e;d=x[vb(b+12|0,x[g>>2]+x[b+8>>2]|0)>>2];fb=b+16|0;b=x[vb(c+12|0,d)>>2];fb=c+16|0;c=ye(f+8|0,x[a+24>>2],x[a+28>>2]);d=fb-16|0;fb=d;a=fb-16|0;fb=a;e=fb-16|0;fb=e;b=ye(e+8|0,Aua(b,b>>31,60,0),hb);g=x[b>>2];b=x[b+4>>2];fb=e+16|0;x[a>>2]=g;x[a+4>>2]=b;b=x[a>>2];e=b+x[c>>2]|0;c=x[c+4>>2]+x[a+4>>2]|0;b=ye(a+8|0,e,b>>>0>e>>>0?c+1|0:c);c=x[b>>2];fb=a+16|0;a=ye(d+8|0,c,x[b+4>>2]);b=x[a>>2];fb=d+16|0;a=Gu(f+40|0,b,x[a+4>>2]);b=x[a>>2];fb=f+48|0;hb=x[a+4>>2];return b}function JO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb+-64|0;fb=e;g=Nb(a);a=0;c=x[b+24>>2];h=Hj(Xb(x[c+484360>>2],y[c+484376|0]));x[31609]=0;O(176,g|0,h|0);c=x[31609];x[31609]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(h|0)){c=x[b+24>>2];f=x[c+484344>>2];d=x[c+484348>>2];c=z[ac(x[Xb(x[c+484360>>2],y[c+484376|0])>>2],a)>>1];if(Bn(f,d,c)){x[31609]=0;d=e+40|0;O(1066,d|0,Wb(f,c)|0);c=x[31609];x[31609]=0;c:{d:{e:{if((c|0)!=1){f=x[b+24>>2];x[31609]=0;c=e+52|0;S(1053,c|0,f|0,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}x[31609]=0;O(178,g|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break d}tb(c);tb(d);break b}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+52|0)}tb(e+40|0);break a}f:{switch(c-65534|0){case 0:x[31609]=0;c=P(36,e+28|0,9256)|0;d=x[31609];x[31609]=0;g:{if((d|0)!=1){x[31609]=0;O(178,g|0,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break g}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;case 1:x[31609]=0;c=P(36,e+16|0,9218)|0;d=x[31609];x[31609]=0;h:{if((d|0)!=1){x[31609]=0;O(178,g|0,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break h}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;default:break f}}x[31609]=0;c=P(36,e+4|0,14661)|0;d=x[31609];x[31609]=0;i:{if((d|0)!=1){x[31609]=0;O(178,g|0,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break i}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a}fb=e- -64|0;return}a=a+1|0;continue}}a=N()|0}Td(g);Q(a|0);p()}function kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+8>>2];k=e;f=x[a+12>>2];j=f;a:{b:{if((f|0)<=1&e>>>0<=805306368|(f|0)<=0){i=131112;e=f;if((e|0)>-2){e=1}else{e=(e|0)>=-2&k>>>0>=3489660928}if(e){break a}i=262184;if((j|0)==-2&k>>>0<2147483648|j>>>0<4294967294){break a}break b}i=262184;if((j|0)==1&k>>>0>2147483648|j>>>0>1){break a}}i=196648}p=x[a+16>>2];q=x[a+24>>2];r=x[a+20>>2];e=x[a+48>>2];f=x[a+44>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;s=b+i|0;t=x[a+72>>2];n=x[a+68>>2];u=n>>31;i=x[a+64>>2];y=i>>31;l=x[a+60>>2];z=l>>31;while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Aua(i,y,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Aua(n,u,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];m=g;g=x[h+12>>2]+p|0;e=(e>>>16&65520)+s|0;o=(((((((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])|0)+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+2|0],w[e+10>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8)/32768<<8;e=o;g=Aua(e,e>>31,l,z);m=m+g|0;e=hb+f|0;e=g>>>0>m>>>0?e+1|0:e;f=m+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Sc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,r)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,q);Pb(h+8|0,k,j);f=f-(t&o)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;yc(c);while(1){a:{if(!Mb(x[c>>2],x[c+8>>2],3)){break a}e=f+13|0;Tr(e,c);h=Jc(e);e=_e(e);d=y[f+13|0];if(d>>>0>=A[a+12>>2]){break a}g=md(x[a>>2],x[x[a+48>>2]+12>>2],d,b);d=y[h|0];if(d>>>0<=126){if(!(d|y[e|0])){v[g|0]=254;continue}v[g|0]=d+1;if(y[e|0]==255){continue}v[g+2|0]=1;v[g+4|0]=y[e|0];continue}b:{switch(d-127|0){case 1:v[g+1|0]=y[e|0]+1;continue;case 0:continue;default:break b}}d=v[e|0];v[f+12|0]=d;e=0;i=y[h|0];j=i&127;if(j>>>0<=23){e=y[j+24608|0]}c:{d:{e:{f:{g:{switch(j-2|0){case 0:case 8:case 9:if((d|0)>=0){break f}d=0-d&15;break e;case 1:v[f+8|0]=64;d=y[Qb(f+12|0,f+8|0)|0];if(y[g+2|0]>1){break e}v[g+2|0]=1;e=4;break c;case 2:h=3;if((d|0)>=0){break d}d=0-d&127;break e;case 15:if(!d){continue}if((d|0)<0){d=0-d|-16;break e}d=d<<4|15;break e;case 16:case 20:if(!d){continue}e=(d|0)>=0;if(!e){d=0-d&15;v[f+12|0]=d;i=y[h|0]}h=e?3:2;d=((i|0)==22?-32:-16)|d;v[f+12|0]=d;break d;case 17:d=d&15|-48;break e;case 18:d=d&15|-64;break e;case 21:break g;default:break e}}if((d|0)==100){d=164;v[f+12|0]=164;break e}x[f+8>>2]=d- -64;x[f+4>>2]=0;x[f>>2]=128;d=x[Zj(f+8|0,f+4|0,f)>>2];if(!y[g+3|0]){break e}h:{switch(y[g+2|0]){case 0:case 2:break h;default:continue}}v[g+2|0]=2;d=(d&254)>>>1|0;e=4;break c}d=d<<4}h=e;if(!e){continue}}v[g+3|0]=h;e=5}v[e+g|0]=d;continue}break}fb=f+16|0}function f8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;Dy(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Mc(d);x[31609]=0;O(46,d|0,b|0);b=x[31609];x[31609]=0;a:{b:{c:{if((b|0)!=1){c=ec(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31609]=0;b=P(1257,a+364|0,a+360|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31609]=0;O(46,d|0,b<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+188>>2]=b+c}x[31609]=0;b=R(1258,x[a+364>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(Cy(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31609]=0;R(1260,a+364|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=vK(c,x[a+188>>2],e),B[j>>2]=k;Vf(a+204|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1257,a+364|0,a+360|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];m=kg(1,2);b=hb;u=b;Pb(a,m,b);n=a+44|0;l=f+32|0;b=0;while(1){if((b|0)!=2){g=b<<3;k=g+l|0;g=g+n|0;x[k>>2]=x[g>>2];x[k+4>>2]=x[g+4>>2];b=b+1|0;continue}break}w=x[a+24>>2];y=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;k=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(b<<3)+l|0;F=x[g+4>>2];h=x[g>>2];x[g+4>>2]=h;s=e<<8;e=s;e=Aua(e,e>>31,q,C);i=hb;j=e;e=Yb(h,-16777216,16776704);e=Aua(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Yb(F,-16777216,16776704);i=Aua(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Sc(i,e,24);x[g>>2]=e-(z&s);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],y);x[c+4>>2]=x[c+4>>2]+D(w,x[f+12>>2]);Pb(f+16|0,k,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+n|0;c=c+l|0;x[d>>2]=x[c>>2];x[d+4>>2]=x[c+4>>2];b=b+1|0;continue}break}Ig(a,m,u);fb=f+48|0}function RB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=a;b:{c:{h=a+62|0;f=xb(h,b);a=v[f|0];if((a|0)==-1){break c}if((a|0)>=0){break b}a=a&127;d=ac(e+26|0,a);g=z[d>>1];if((g|0)!=65535&(b|0)!=(g|0)){break c}w[d>>1]=b;v[f|0]=a;break b}l=e+8|0;i=e+26|0;d=255;a=0;g=255;d:{while(1){if((a|0)==18){break d}j=ac(i,a);k=z[j>>1];if((k|0)!=65535){if(!(y[xb(l,a)|0]&32)){g=v[xb(h,k)|0]<0?a:g;d=a}a=a+1|0;continue}break}w[j>>1]=b;v[f|0]=a;break b}if((d&255)!=255){a=(g&255)==255?d:g;d=ac(i,a&255);m=xb(h,z[d>>1]),n=255,v[m|0]=n;w[d>>1]=b;v[f|0]=a}a=Ql(e,b)}g=a&255;if((g|0)==255){break a}if(Fj(x[e>>2])){break a}d=Vd(e+318|0,g);a=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[d+8|0]=a;v[d+9|0]=a>>>8;v[d+10|0]=a>>>16;v[d+11|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[d|0]=f;v[d+1|0]=f>>>8;v[d+2|0]=f>>>16;v[d+3|0]=f>>>24;v[d+4|0]=a;v[d+5|0]=a>>>8;v[d+6|0]=a>>>16;v[d+7|0]=a>>>24;f=AU(g);h=f+3|0;a=0;while(1){if((a|0)==2){Ah(x[e>>2],x[e+4>>2],b,bv(g)|192,y[xb(c,10)|0])}else{d=a?h:f;Ah(x[e>>2],x[e+4>>2],b,(d|32)&65535,y[xb(c,a)|0]);Ah(x[e>>2],x[e+4>>2],b,(d|64)&65535,y[xb(c,a|2)|0]);Ah(x[e>>2],x[e+4>>2],b,(d|96)&65535,y[xb(c,a|4)|0]);Ah(x[e>>2],x[e+4>>2],b,(d|128)&65535,y[xb(c,a|6)|0]);Ah(x[e>>2],x[e+4>>2],b,(d|224)&65535,y[xb(c,a|8)|0]);a=a+1|0;continue}break}}}function o8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;Hy(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Mc(d);x[31609]=0;O(46,d|0,b|0);b=x[31609];x[31609]=0;a:{b:{c:{if((b|0)!=1){c=ec(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[31609]=0;b=P(1241,a+252|0,a+248|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31609]=0;O(46,d|0,b<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+176>>2]=b+c}x[31609]=0;b=R(1242,x[a+252>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(Gy(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31609]=0;R(1244,a+252|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=vK(c,x[a+176>>2],e),B[j>>2]=k;Vf(a+192|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1241,a+252|0,a+248|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function $W(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);d=x[b+4>>2];if(d){Xr(a,d);mn(f+8|0,x[b>>2]);$q(f,x[b>>2],x[b+4>>2]);d=x[f+8>>2];k=x[f+12>>2];e=x[f>>2];l=x[f+4>>2];j=fb-32|0;fb=j;c=x[b+4>>2];b=x[a+4>>2];c=c+b|0;x[a+4>>2]=c;a:{b:{if(!b){g=c-1|0;break b}g=c-1|0;if((g^b-1)>>>0>31){break b}h=x[a>>2];break a}h=x[a>>2];x[h+((c>>>0>=33?g>>>5|0:0)<<2)>>2]=0}yp(j+24|0,h,b);h=fb-16|0;fb=h;b=Zb(h+8|0,x[j+24>>2],x[j+28>>2]);m=fb-16|0;fb=m;n=j+8|0;g=Zb(m+8|0,x[b>>2],x[b+4>>2]);b=fb-96|0;fb=b;c=fb-16|0;fb=c;mr(c+8|0,d,k);mr(c,e,l);d=x[c+12>>2];x[b+80>>2]=x[c+8>>2];x[b+84>>2]=d;d=x[c+4>>2];x[b+88>>2]=x[c>>2];x[b+92>>2]=d;fb=c+16|0;d=x[b+84>>2];x[b+56>>2]=x[b+80>>2];x[b+60>>2]=d;k=x[b+88>>2];l=x[b+92>>2];d=b+48|0;e=Zb(b+40|0,x[g>>2],x[g+4>>2]);ln(d,x[e>>2],x[e+4>>2]);e=x[b+60>>2];x[b>>2]=x[b+56>>2];x[b+4>>2]=e;o=b- -64|0;e=fb-16|0;fb=e;while(1){i=x[b+4>>2];if(ZW(x[b>>2],i,k,l)){c=fb-16|0;fb=c;i=Zb(c+8|0,x[b>>2],1<<i);i=Gb(x[x[i>>2]>>2],x[i+4>>2]);fb=c+16|0;c=e+8|0;Ot(c,x[d>>2],x[d+4>>2]);kf(c,i);zv(b);zv(d);continue}break}_W(o,x[b>>2],x[b+4>>2],d);fb=e+16|0;mr(b+32|0,x[b+64>>2],x[b+68>>2]);Zb(b+16|0,x[g>>2],x[g+4>>2]);d=b+24|0;e=Zb(b+8|0,x[b+72>>2],x[b+76>>2]);ln(d,x[e>>2],x[e+4>>2]);_W(n,x[b+32>>2],x[b+36>>2],d);fb=b+96|0;fb=m+16|0;fb=h+16|0;fb=j+32|0}fb=f+16|0;return a|0}function e8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;Dy(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Mc(d);x[31609]=0;O(46,d|0,b|0);b=x[31609];x[31609]=0;a:{b:{c:{if((b|0)!=1){c=ec(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31609]=0;b=P(1257,a+364|0,a+360|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31609]=0;O(46,d|0,b<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+188>>2]=b+c}x[31609]=0;b=R(1258,x[a+364>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(Cy(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31609]=0;R(1260,a+364|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=tK(c,x[a+188>>2],e),C[j>>3]=k;Vf(a+204|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1257,a+364|0,a+360|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function n8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;Hy(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Mc(d);x[31609]=0;O(46,d|0,b|0);b=x[31609];x[31609]=0;a:{b:{c:{if((b|0)!=1){c=ec(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+206|0];i=v[a+207|0];while(1){d:{x[31609]=0;b=P(1241,a+252|0,a+248|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Cb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31609]=0;O(46,d|0,b<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+176>>2]=b+c}x[31609]=0;b=R(1242,x[a+252>>2])|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}if(Gy(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31609]=0;R(1244,a+252|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=tK(c,x[a+176>>2],e),C[j>>3]=k;Vf(a+192|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1241,a+252|0,a+248|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function b7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-480|0;fb=a;cd(a+476|0,x[d+28>>2]);x[31609]=0;n=R(1252,x[a+476>>2])|0;g=x[31609];x[31609]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Cb(x[f+4>>2],y[f+11|0])){g=x[Wd(f,0)>>2];x[31609]=0;h=P(1270,n|0,45)|0;j=x[31609];x[31609]=0;if((j|0)==1){break e}o=(g|0)==(h|0)}j=Fb(a+452|0);g=Fb(a+440|0);h=Fb(a+428|0);x[31609]=0;ka(1292,c|0,o|0,x[a+476>>2],a+472|0,a+468|0,a+464|0,j|0,g|0,h|0,a+424|0);c=x[31609];x[31609]=0;if((c|0)==1){break d}x[a+4>>2]=1239;c=De(a+8|0,0,a+4|0);k=a+16|0;l=Cb(x[f+4>>2],y[f+11|0]);m=x[a+424>>2];f:{if((l|0)>(m|0)){i=((Cb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Cb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Cb(x[h+4>>2],y[h+11|0])+Cb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Qe(c,Gd(i<<2));k=x[c>>2];if(!k){break g}l=Cb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Kb(f);x[31609]=0;ma(1293,k|0,a+4|0,a|0,i|0,f|0,f+(l<<2)|0,n|0,o|0,a+472|0,x[a+468>>2],x[a+464>>2],j|0,g|0,h|0,m|0);f=x[31609];x[31609]=0;if((f|0)==1){break c}x[31609]=0;b=ea(1273,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}Lc(c);Ub(h);Ub(g);tb(j);_b(a+476|0);fb=a+480|0;return b|0}x[31609]=0;X(1240);b=x[31609];x[31609]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Lc(c)}Ub(h);Ub(g);tb(j)}_b(a+476|0);Q(f|0);p()}function Z6(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=fb-16|0;fb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!x[b>>2]){break a}b=b+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=fb-16|0;fb=r;s=rh(r+12|0,x[a+8>>2]);i=f;j=g-f|0;m=0;o=fb-16|0;fb=o;k=x[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=f?j:0;while(1){l=It(j>>>0<4?o+12|0:i,x[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}zc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!x[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){x[e>>2]=k}fb=o+16|0;qh(s);fb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=qy(f,x[c>>2],x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=x[h>>2]+m|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=x[e>>2];b=d;continue}b=qy(n+12|0,0,x[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-x[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=y[c|0];i=x[h>>2];x[h>>2]=i+1;v[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!x[b>>2]){break b}b=b+4|0;continue}}c=x[e>>2]}q=(c|0)!=(d|0)}fb=n+16|0;return q|0}f=x[h>>2];continue}}function sG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=x[a>>2];e=ih(c,x[a+4>>2]);if(e>>>0<b>>>0){j=fb-32|0;fb=j;c=b-e|0;b=x[Ab(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=b-d>>3>>>0){e=fb-16|0;fb=e;b=hs(e+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){jc(b);fb=e+16|0}else{$k(a);a=a+8|0;x[b+4>>2]=a;continue}break}break a}b=Ab(a);e=js(j+12|0,ks(a,ih(x[a>>2],d)+c|0),ih(x[a>>2],x[a+4>>2]),b);d=fb-16|0;fb=d;f=x[e+8>>2];b=d+4|0;x[b+8>>2]=e+8;x[b>>2]=f;x[b+4>>2]=f+(c<<3);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){$k(c);c=x[b>>2]+8|0;x[b>>2]=c;continue}break}je(b);fb=d+16|0;h=fb-16|0;fb=h;b=vb(h+12|0,x[a+4>>2]);d=vb(h+8|0,x[a>>2]);g=x[vb(h+4|0,x[e+4>>2])>>2];i=fb-16|0;fb=i;c=fb-32|0;fb=c;fd(c+24|0,x[b>>2],x[d>>2]);k=c+16|0;b=x[c+24>>2];l=x[c+28>>2];f=fb-16|0;fb=f;x[f+8>>2]=g;x[f+12>>2]=b;while(1){if(Fd(b,l)){d=Ip(b);g=Ip(x[f+8>>2]);b=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;v[g+4|0]=b;v[g+5|0]=b>>>8;v[g+6|0]=b>>>16;v[g+7|0]=b>>>24;b=gs(f+12|0);gs(f+8|0);b=x[b>>2];continue}break}qc(k,b,f+8|0);fb=f+16|0;b=x[c+16>>2];x[c+12>>2]=x[c+20>>2];qc(i+8|0,b,c+12|0);fb=c+32|0;fb=i+16|0;x[e+4>>2]=x[i+12>>2];Tb(a,e+4|0);Tb(a+4|0,e+8|0);Tb(Ab(a),nc(e));x[e>>2]=x[e+4>>2];fb=h+16|0;is(e)}fb=j+32|0;return}if(b>>>0<e>>>0){Jd(a,c+(b<<3)|0)}}function uqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;h=a+4|0;a:{if((c|0)!=4){g=b+236|0;i=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+h|0;j=xb(i,d),k=y[f|0]+1|0,v[j|0]=k;j=ac(g,d),k=(y[f+2|0]|y[f+3|0]<<8)+1|0,w[j>>1]=k;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+h|0;j=ac(f,d+12|0),k=(y[g+2|0]|y[g+3|0]<<8)+1|0,w[j>>1]=k;d=d+1|0;continue}}$C(a+484|0,b+48|0,0,c);$C(a+590|0,b+68|0,0,c);$C(a+696|0,b+88|0,5,c);x[b>>2]=y[a+806|0]|y[a+807|0]<<8;d=v[a+808|0];b:{if((d|0)<0){v[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(v[a|0]&1){v[b+31|0]=d+1;break b}if(!d){break b}v[b+31|0]=d+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=y[a+810|0];break d}d=v[a+809|0];if((d|0)>=0){w[b+28>>1]=d+1&255}d=v[a+810|0];if((d|0)<0){break c}}v[b+30|0]=d+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;j=b,k=y[Qb(e+15|0,e+14|0)|0]>>>1|0,x[j+4>>2]=k}c=y[a+813|0]|y[a+814|0]<<8;if(c>>>0<=256){x[b+8>>2]=c;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];w[e+12>>1]=y[a+820|0]|y[a+821|0]<<8;w[e+10>>1]=100;j=b,k=y[Oc(e+12|0,e+10|0)|0],v[j+20|0]=k;w[e+8>>1]=y[a+822|0]|y[a+823|0]<<8;w[e+6>>1]=256;j=b,k=z[Oc(e+8|0,e+6|0)>>1]>>>2|0,v[j+19|0]=k;c=y[a+824|0];ck(b,c&127,c>>>7|0);a=y[a+825|0];bk(b,a&127,a>>>7|0);fb=e+16|0}function koa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=fb-16|0;fb=i;nd(d,32);h=i+8|0;$V(h,y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24),y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24),x[b>>2]);h=gc(h);$V(i,y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24),y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24),x[c>>2]);a=0;a:{h=x[h>>2];if(h-838861>>>0<4294128436){break a}e=x[gc(i)>>2];x[d>>2]=D(h,320);w[d+34>>1]=1;if(!Gh(d)){break a}k=h<<2;f=+(k>>>0);o=+(e>>>0)/f;p=+(h>>>0)/f;q=1/+A[d>>2];r=+A[i>>2];s=+A[i+8>>2];h=0;b:while(1){if((h|0)==(k|0)){a=1;break a}l=+(h>>>0);m=0;n=0;e=x[b+20>>2];if(le(x[b>>2],e)){f=l*p+s;c:{if(f<4294967296&f>=0){g=~~f>>>0;break c}g=0}a=g;f=f-+(a>>>0);j=z[b+34>>1];a=_d(j);g=D(g,a);d:{if(j&1){e=e+(g<<1)|0;a=z[e+(a<<1)>>1];e=z[e>>1];break d}g=e+g|0;e=y[g|0]<<8;a=y[a+g|0]<<8}n=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}e=x[c+20>>2];if(le(x[c>>2],e)){f=l*o+r;e:{if(f<4294967296&f>=0){g=~~f>>>0;break e}g=0}a=g;f=f-+(a>>>0);j=z[c+34>>1];a=_d(j);g=D(g,a);f:{if(j&1){e=e+(g<<1)|0;a=z[e+(a<<1)>>1];e=z[e>>1];break f}g=e+g|0;e=y[g|0]<<8;a=y[a+g|0]<<8}m=+(e<<16>>16)*(1-f)+f*+(a<<16>>16)}e=0;a=h;while(1)if((e|0)==80){h=h+1|0;continue b}else{f=q*+(a>>>0);t=x[d+20>>2]+(a<<1)|0,u=uC(n*(1-f)+m*f),w[t>>1]=u;a=a+k|0;e=e+1|0;continue}}}fb=i+16|0;return a|0}function i8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=nj(x[d+4>>2]);i=cq(x[d+28>>2],a+208|0);bq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=ec(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1257,a+332|0,a+328|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31609]=0;O(46,d|0,g<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+180>>2]=g+c}x[31609]=0;g=R(1258,x[a+332>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(co(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31609]=0;R(1260,a+332|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=AK(c,x[a+180>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Vf(a+196|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1257,a+332|0,a+328|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function g8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=nj(x[d+4>>2]);i=cq(x[d+28>>2],a+208|0);bq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=ec(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1257,a+332|0,a+328|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31609]=0;O(46,d|0,g<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+180>>2]=g+c}x[31609]=0;g=R(1258,x[a+332>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(co(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31609]=0;R(1260,a+332|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=wK(c,x[a+180>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Vf(a+196|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1257,a+332|0,a+328|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function f7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-176|0;fb=a;cd(a+172|0,x[d+28>>2]);x[31609]=0;n=R(28,x[a+172>>2])|0;g=x[31609];x[31609]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Cb(x[f+4>>2],y[f+11|0])){g=y[ec(f,0)|0];x[31609]=0;h=P(29,n|0,45)|0;j=x[31609];x[31609]=0;if((j|0)==1){break e}o=(h&255)==(g|0)}j=Fb(a+152|0);g=Fb(a+140|0);h=Fb(a+128|0);x[31609]=0;ka(1290,c|0,o|0,x[a+172>>2],a+168|0,a+167|0,a+166|0,j|0,g|0,h|0,a+124|0);c=x[31609];x[31609]=0;if((c|0)==1){break d}x[a+4>>2]=1239;c=De(a+8|0,0,a+4|0);k=a+16|0;l=Cb(x[f+4>>2],y[f+11|0]);m=x[a+124>>2];f:{if((l|0)>(m|0)){i=((Cb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Cb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Cb(x[h+4>>2],y[h+11|0])+Cb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Qe(c,Gd(i));k=x[c>>2];if(!k){break g}l=Cb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Kb(f);x[31609]=0;ma(1291,k|0,a+4|0,a|0,i|0,f|0,f+l|0,n|0,o|0,a+168|0,v[a+167|0],v[a+166|0],j|0,g|0,h|0,m|0);f=x[31609];x[31609]=0;if((f|0)==1){break c}x[31609]=0;b=ea(23,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}Lc(c);tb(h);tb(g);tb(j);_b(a+172|0);fb=a+176|0;return b|0}x[31609]=0;X(1240);b=x[31609];x[31609]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Lc(c)}tb(h);tb(g);tb(j)}_b(a+172|0);Q(f|0);p()}function _X(a,b){var c=0;a:{b:{c:{if(oe(a,16780)){break c}if(oe(a,17547)){break c}if(oe(a,13697)){break c}if(oe(a,13822)){break c}if(!oe(a,14304)){break b}}w[b+10>>1]=4;x[b>>2]=12052;break a}d:{e:{if(oe(a,17542)){break e}if(oe(a,13702)){break e}if(!oe(a,16770)){break d}}v[b+15|0]=1;v[b+12|0]=1;x[b>>2]=8391;w[b+10>>1]=4;break a}f:{if(!oe(a,14342)){if(!oe(a,14347)){break f}}w[b+10>>1]=8;x[b>>2]=8169;break a}g:{if(!oe(a,15474)){if(!oe(a,15479)){break g}}x[b>>2]=17134;w[b+10>>1]=v[a+2|0]-48;break a}h:{if(!oe(a,25274)){if(!oe(a,25279)){break h}}x[b+4>>2]=1;x[b>>2]=16940;w[b+10>>1]=y[a|0]==56?8:4;break a}if(!(jd(a,15573,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=8509;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break a}i:{j:{if(jd(a,13760,3)){if(jd(a,13879,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=8268;break i}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!jd(a+1|0,13900,3)){v[b+14|0]=1;x[b>>2]=8589;w[b+10>>1]=v[a|0]-48;break a}c=y[a+2|0]|y[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(y[a+1|0]-48&255)>>>0>9){break k}v[b+14|0]=1;x[b>>2]=8589;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;break a}if(!(jd(a,13588,3)|(y[a+3|0]-49&255)>>>0>8)){x[b>>2]=8418;break i}if(oe(a,13972)){v[b+16|0]=1;w[b+10>>1]=4;break a}if(oe(a,14299)){v[b+14|0]=1;x[b>>2]=8589;w[b+10>>1]=8;a=1}else{a=0}return a}w[b+10>>1]=v[a+3|0]-48}return 1}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;m=fb-32|0;fb=m;e=b;b=x[a>>2];h=D(wu(e,wb(b)),6)+b|0;a:{if(!c){break a}b=x[Ab(a)>>2];i=x[a+4>>2];if((b-i|0)/6>>>0>=c>>>0){b=c;e=(i-h|0)/6|0;if(e>>>0<c>>>0){xD(a,c-e|0,d);b=e;if((h|0)==(i|0)){break a}}n=fb-16|0;fb=n;o=x[a+4>>2];g=(o-(D(c,6)+h|0)|0)+h|0;f=Cr(n+4|0,a,(i-g|0)/6|0);k=x[f+4>>2];e=g;while(1){if(e>>>0>=i>>>0){jc(f);i=fb-16|0;fb=i;j=fb-32|0;fb=j;fd(j+24|0,h,g);l=fb-16|0;fb=l;k=x[j+28>>2];f=x[j+24>>2];g=(k-f|0)/6|0;e=o+D(g,-6)|0;x[l+12>>2]=e;iR(e,f,g);qc(j+16|0,k,l+12|0);fb=l+16|0;e=x[j+16>>2];x[j+12>>2]=x[j+20>>2];qc(i+8|0,e,j+12|0);fb=j+32|0;fb=i+16|0;fb=n+16|0}else{sD(k,e);k=k+6|0;x[f+4>>2]=k;e=e+6|0;continue}break}e=h;c=D(e>>>0<=d>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=a;v[e+1|0]=a>>>8;v[e+2|0]=a>>>16;v[e+3|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[e+4|0]=a;v[e+5|0]=a>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Ab(a);f=kZ(m+12|0,tD(a,Hk(x[a>>2],i)+c|0),(h-x[a>>2]|0)/6|0,b);jZ(f,c,d);g=fb-16|0;fb=g;b=x[f+4>>2];e=vb(g+12|0,h);d=vb(g+8|0,x[a>>2]);c=vb(g+4|0,x[f+4>>2]);p=f,q=gZ(x[e>>2],x[d>>2],x[c>>2]),x[p+4>>2]=q;p=f,q=hR(h,x[a+4>>2],x[f+8>>2]),x[p+8>>2]=q;Tb(a,f+4|0);Tb(a+4|0,f+8|0);Tb(Ab(a),nc(f));x[f>>2]=x[f+4>>2];fb=g+16|0;h=b;iZ(f)}wb(h);fb=m+32|0}function Joa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;nd(b,2);f=e+24|0;Lk(f,2,a+1|0);d=e+36|0;Cc(d,f);Be(b+43|0,d);tb(d);a:{b:{c:{d:{switch(y[a|0]){case 0:f=x[b+4>>2];d=x[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b>>2]=d;x[e+36>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[e+24>>2]=d-1;d=e+36|0;f=x[Hb(d,e+24|0)>>2];x[b+4>>2]=f;x[e+36>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);d=x[Hb(d,b)>>2];x[b+8>>2]=d;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}f=e+24|0;mh(f,a+16|0);d=x[e+24>>2];x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);mh(f,a+20|0);d=x[e+24>>2];x[e+40>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);mh(f,a+24|0);d=x[e+24>>2];d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+44>>2]=d;x[e+16>>2]=d;d=x[e+40>>2];x[e+8>>2]=x[e+36>>2];x[e+12>>2]=d;Sk(b,1,e+8|0)}v[e+36|0]=y[a+28|0];v[e+24|0]=64;g=b,h=y[Qb(e+36|0,e+24|0)|0]<<2,w[g+30>>1]=h;d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(y[a|0]==2){d=d&65535;x[b>>2]=d;break e}if(A[b>>2]>=65536){x[b>>2]=65535}d=x[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}x[b>>2]=a}fb=e+48|0}function mK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=nj(x[d+4>>2]);i=cq(x[d+28>>2],a+208|0);bq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=ec(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1257,a+332|0,a+328|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31609]=0;O(46,d|0,g<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+180>>2]=g+c}x[31609]=0;g=R(1258,x[a+332>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(co(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31609]=0;R(1260,a+332|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=xK(c,x[a+180>>2],e,b),x[j>>2]=k;Vf(a+196|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1257,a+332|0,a+328|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function j8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=nj(x[d+4>>2]);i=cq(x[d+28>>2],a+208|0);bq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=ec(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1257,a+332|0,a+328|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31609]=0;O(46,d|0,g<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+180>>2]=g+c}x[31609]=0;g=R(1258,x[a+332>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(co(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31609]=0;R(1260,a+332|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=DK(c,x[a+180>>2],e,b),x[j>>2]=k;Vf(a+196|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1257,a+332|0,a+328|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function h8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=nj(x[d+4>>2]);i=cq(x[d+28>>2],a+208|0);bq(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=ec(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1257,a+332|0,a+328|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31609]=0;O(46,d|0,g<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+180>>2]=g+c}x[31609]=0;g=R(1258,x[a+332>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(co(g,b,c,a+180|0,a+8|0,x[a+324>>2],x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31609]=0;R(1260,a+332|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=zK(c,x[a+180>>2],e,b),w[j>>1]=k;Vf(a+196|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1257,a+332|0,a+328|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function aJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){c=x[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[c|0];j=i&255;d:{if((i|0)>=0){w[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;w[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;x[a+8>>2]=f+2;w[f+2>>1]=i<<6&960|k&63|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;f=x[a+8>>2]+2|0;x[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return b|0}function r8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=nj(g);dq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=ec(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1241,a+220|0,a+216|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31609]=0;O(46,d|0,g<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+184>>2]=g+c}x[31609]=0;g=R(1242,x[a+220>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(eo(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,95168)){break c}x[31609]=0;R(1244,a+220|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=AK(c,x[a+184>>2],e,b),x[i>>2]=j;x[f+4>>2]=hb;Vf(a+200|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1241,a+220|0,a+216|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function p8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=nj(g);dq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=ec(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1241,a+220|0,a+216|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31609]=0;O(46,d|0,g<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+184>>2]=g+c}x[31609]=0;g=R(1242,x[a+220>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(eo(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,95168)){break c}x[31609]=0;R(1244,a+220|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=wK(c,x[a+184>>2],e,b),x[i>>2]=j;x[f+4>>2]=hb;Vf(a+200|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1241,a+220|0,a+216|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function Fla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];m=x[a+128>>2];if(m){n=Hg(k,l,m);o=hb;b=x[a+76>>2];fg(h,e,uf(k,l,d),hb);p=hb>>>0>b>>>0?d:0}i=a+112|0;t=x[a+24>>2];u=x[a+20>>2];f=x[a+48>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{q=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;p=p-1|0;b=p;n=b?n:0;o=b?o:0;h=(e<<1)+r|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){ce(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);be(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}v=x[a+72>>2];y=x[c>>2];h=Fg(i,s)<<8;b=h;j=b>>31;b=x[a+60>>2];b=Aua(h,j,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(q,-16777216,16776704);j=Aua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Aua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Sc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+y;x[c+4>>2]=x[c+4>>2]+D(f,t);Pb(g,k,l);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue a}else{ce(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);be(i,4);Pb(g+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function CU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;c=x[a>>2];a:{if(Fj(c)){i=fb-16|0;fb=i;f=Ec(3848);c=16;while(1){d=c+f|0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+36>>2]=0;v[d+42|0]=1;w[d+40>>1]=257;x[d+24>>2]=0;x[d+28>>2]=0;w[d+32>>1]=0;d=808;c=c+44|0;if((c|0)!=808){continue}break}while(1){c=d+f|0;x[c>>2]=0;x[c+4>>2]=0;x[c+68>>2]=0;x[c+72>>2]=0;x[c+24>>2]=0;x[c+28>>2]=0;w[c+20>>1]=511;x[c+16>>2]=-1;w[c+14>>1]=1;w[c+6>>1]=0;w[c+8>>1]=0;w[c+10>>1]=0;w[c+12>>1]=0;v[c+73|0]=0;v[c+74|0]=0;v[c+75|0]=0;v[c+76|0]=0;v[c+77|0]=0;v[c+78|0]=0;v[c+79|0]=0;v[c+80|0]=0;d=d+84|0;if((d|0)!=3832){continue}break}d=0;c=0;x[f+3832>>2]=0;x[f+3836>>2]=0;e=f+3837|0;v[e|0]=0;v[e+1|0]=0;v[e+2|0]=0;v[e+3|0]=0;v[e+4|0]=0;v[e+5|0]=0;v[e+6|0]=0;v[e+7|0]=0;e=f+808|0;while(1){if((d|0)==36){k=f+16|0;d=0;while(1){if((c|0)==18){b:{c=0;while(1)if((d|0)==18){while(1){if((c|0)==36){break b}Po(D(c,84)+e|0);c=c+1|0;continue}}else{g=D(d,44)+k|0;l=x[(d<<2)+27280>>2];c:{if(!(!(1<<d&3591)|d>>>0>11)){j=g;g=D(l,84)+e|0;HU(j,g,g+252|0,g+504|0,g+756|0);break c}j=g;g=D(l,84)+e|0;HU(j,g,g+252|0,0,0)}d=d+1|0;continue}}}else{x[(D(c,44)+k|0)+16>>2]=f;c=c+1|0;continue}break}GU(f,b)}else{yd(D(d,84)+e|0,f);d=d+1|0;continue}break}b=x[yf(i+12|0,f)>>2];fb=i+16|0;x[h+12>>2]=b;b=h+12|0;vA(a,b);Gl(b);break a}GU(c,b)}BU(a);fb=h+16|0}function R7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=Ry(x[g>>2]);g=Fy(x[g>>2]);sh(k+4|0,g);a:{b:{if(Ad(x[k+8>>2],y[k+15|0])){x[31609]=0;V(1263,l|0,a|0,c|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31609]=0;j=P(1270,l|0,h<<24>>24)|0;h=x[31609];x[31609]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31609]=0;h=P(1270,l|0,48)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[31609]=0;h=P(1270,l|0,h|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}Dm(j,c);i=0;x[31609]=0;o=R(1261,g|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){vt((j-a<<2)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[ec(k+4|0,h)|0]){break e}if(v[ec(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Cb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31609]=0;n=P(1270,l|0,n|0)|0;m=x[31609];x[31609]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;tb(k+4|0);fb=k+16|0}function fsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb+-64|0;fb=d;b=b&4095;w[d+62>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=((b|0)==4095?c:b-80|0)+734016|0;c=Aua(e,e>>31,1e4,0);b=hb;c=c+14780|0;b=c>>>0<14780?b+1|0:b;b=Bua(c,b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=fb-16|0;fb=e;h=d+48|0;f=uc(e+4|0,4451);Uc(h,f);tb(f);fb=e+16|0;x[31609]=0;f=(D(c,100)+52|0)/3060|0;e=f+2|0;g=(e|0)/12|0;x[d+32>>2]=g+b;b=d+36|0;O(73,b|0,d+32|0);i=x[31609];x[31609]=0;e:{f:{g:{h:{i:{j:{if((i|0)!=1){x[31609]=0;x[d+16>>2]=(e+D(g,-12)|0)+1;e=d+20|0;O(76,e|0,d+16|0);g=x[31609];x[31609]=0;if((g|0)==1){break j}x[31609]=0;x[d>>2]=(((D(f,306)+5|0)/-10|0)+c|0)+1;c=d+4|0;O(76,c|0,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break i}x[31609]=0;aa(413,a|0,h|0,b|0,e|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break h}tb(c);tb(e);tb(b);Eb(h);break d}b=N()|0;break e}b=N()|0;break f}b=N()|0;break g}b=N()|0;tb(d+4|0)}tb(d+20|0)}tb(d+36|0)}break a}b=d+48|0;gg(b,4431);x[31609]=0;c=d+36|0;O(414,c|0,d+62|0);e=x[31609];x[31609]=0;if((e|0)==1){break c}x[31609]=0;S(139,a|0,b|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}tb(c);Eb(b)}fb=d- -64|0;return}b=N()|0;break a}b=N()|0;tb(d+36|0)}Eb(d+48|0);Q(b|0);p()}function YE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-16|0;fb=h;d=x[b>>2];e=$c(d,x[b+4>>2]);a:{if(e>>>0<c>>>0){l=fb-32|0;fb=l;d=c-e|0;e=x[Ab(b)>>2];f=x[b+4>>2];b:{if(d>>>0<=e-f>>1>>>0){f=fb-16|0;fb=f;d=bj(f+4|0,b,d);e=x[d+4>>2];g=x[d+8>>2];while(1){if((e|0)==(g|0)){jc(d);fb=f+16|0}else{rp(e);e=e+2|0;x[d+4>>2]=e;continue}break}break b}e=Ab(b);e=ek(l+12|0,fk(b,$c(x[b>>2],f)+d|0),$c(x[b>>2],x[b+4>>2]),e);g=fb-16|0;fb=g;d=Bp(g+4|0,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){rp(f);f=x[d>>2]+2|0;x[d>>2]=f;continue}break}je(d);fb=g+16|0;i=fb-16|0;fb=i;f=vb(i+12|0,x[b+4>>2]);g=vb(i+8|0,x[b>>2]);j=x[vb(i+4|0,x[e+4>>2])>>2];k=fb-16|0;fb=k;m=k+8|0;d=fb-32|0;fb=d;fd(d+24|0,x[f>>2],x[g>>2]);n=d+16|0;g=x[d+24>>2];o=x[d+28>>2];f=fb-16|0;fb=f;x[f+8>>2]=j;x[f+12>>2]=g;while(1){if(Fd(g,o)){g=Gn(g);j=Gn(x[f+8>>2]);g=y[g|0]|y[g+1|0]<<8;v[j|0]=g;v[j+1|0]=g>>>8;g=Wk(f+12|0);Wk(f+8|0);g=x[g>>2];continue}break}qc(n,g,f+8|0);fb=f+16|0;f=x[d+16>>2];x[d+12>>2]=x[d+20>>2];qc(m,f,d+12|0);fb=d+32|0;fb=k+16|0;x[e+4>>2]=x[k+12>>2];Tb(b,e+4|0);Tb(b+4|0,e+8|0);Tb(Ab(b),nc(e));x[e>>2]=x[e+4>>2];fb=i+16|0;aj(e)}fb=l+32|0;break a}if(c>>>0<e>>>0){Jd(b,d+(c<<1)|0)}}c=Mb(x[a>>2],x[a+8>>2],c<<1);if(c){e=x[b>>2];cc(h+8|0,e,$c(e,x[b+4>>2])<<1);sd(h,a,x[h+8>>2],x[h+12>>2])}fb=h+16|0;return c|0}function _sa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;h=fb-288|0;fb=h;sf(b);a:{if(!Mb(x[a>>2],x[a+8>>2],1)){break a}while(1){i=h+32|0;wl(h+8|0,i,ur(i));kc(h+20|0,x[a>>2],x[a+8>>2],x[h+8>>2],x[h+12>>2]);x[h+28>>2]=x[h+24>>2];o=h,q=c-_c(x[b+4>>2],y[b+11|0])|0,x[o+4>>2]=q;d=x[Hb(h+28|0,h+4|0)>>2];if(!d){break a}m=d+i|0;k=Fi(i,m,0);d=x[vb(h,Df(b))>>2];f=Pj(i,k);l=fb-16|0;fb=l;j=zk(d,zd(b));b:{c:{d:{if(!f){zd(b);break d}if(!I_(b,i)){d=i;e=Cb(x[b+4>>2],y[b+11|0]);g=Mc(b);e:{if(g-e>>>0>=f>>>0){g=Kb(b);if((e|0)==(j|0)){break e}n=g+j|0;Ni(n+f|0,n,e-j|0);break e}an(b,g,(e+f|0)-g|0,e,j,0,f);g=x[b>>2]}f=e+f|0;lg(b,f);hd(f+g|0,0);f=g+j|0;while(1){if((d|0)!=(k|0)){hd(f,y[d|0]);d=d+1|0;f=f+1|0;continue}break}vf(zd(b),j);break d}d=i;e=l+4|0;xx(e);f:{while(1){if((d|0)==(k|0)){break f}g=v[d|0];x[31609]=0;O(115,e|0,g|0);g=x[31609];x[31609]=0;if((g|0)!=1){d=d+1|0;continue}break}Y(T(0)|0)|0;if(vd(y[e+11|0])){Db(x[e>>2])}x[31609]=0;X(84);a=x[31609];x[31609]=0;g:{if((a|0)==1){a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break g}T(0)|0;Sb()}p()}Q(a|0);p()}d=zd(e);g=Df(e);x[31609]=0;ha(364,b|0,f|0,j|0,d|0,g|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}tb(e)}fb=l+16|0;break b}a=N()|0;tb(e);Q(a|0);p()}Vb(a,k-i|0);if(k>>>0>=m>>>0){continue}break}Vb(a,1)}fb=h+288|0}function JP(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-240|0;fb=e;if(!y[126600]){if(!y[126472]){b=fb-16|0;fb=b;Fb(126448);x[31615]=0;v[126464]=0;x[31617]=0;x[31609]=0;a=ca(55)|0;c=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){x[b+12>>2]=a;a=b+12|0;JA(126460,ne(a));Gl(a);v[126464]=0;break f}a=ta(124540,125124)|0;c=gb;if(($(124540)|0)==(c|0)){Y(a|0)|0;x[31609]=0;X(56);b=x[31609];x[31609]=0;if((b|0)==1){break d}p()}if(($(125124)|0)!=(c|0)){break c}Y(a|0)|0;x[31609]=0;v[126464]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){a=N()|0;break c}if(y[126464]){break e}}x[31609]=0;W(57,126444);a=x[31609];x[31609]=0;if((a|0)!=1){break e}a=N()|0;break c}fb=b+16|0;break a}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break b}}Gl(126468);Gl(126460);tb(126448);Q(a|0);p()}T(0)|0;Sb();p()}v[126472]=1}c=fb+-64|0;fb=c;b=c+16|0;g=fb-16|0;fb=g;h=nP(g+8|0);j=e+120|0;l=c+4|0;while(1){if((i|0)==12){fb=g+16|0}else{f=fb-48|0;fb=f;a=x[h+4>>2];d=x[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=eP(iP(f+12|0,32));break g}d=G(a);d=iP(f+12|0,(a<<d&2147483647?32:31)-d|0);while(1){k=eP(d);if(a>>>0<=k>>>0){continue}break}a=x[h>>2]+k|0}fb=f+48|0;m=yb(b,i),n=a,x[m>>2]=n;i=i+1|0;continue}break}b=wP(l,b,zP(b));qP(j,b);Wm(b);fb=c- -64|0;zc(126480,zc(e,j,120),116);v[126600]=1}fb=e+240|0}function yK(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=nj(g);dq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=ec(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1241,a+220|0,a+216|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31609]=0;O(46,d|0,g<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+184>>2]=g+c}x[31609]=0;g=R(1242,x[a+220>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(eo(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,95168)){break c}x[31609]=0;R(1244,a+220|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=xK(c,x[a+184>>2],e,b),x[i>>2]=j;Vf(a+200|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1241,a+220|0,a+216|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function tU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{b:{switch(Dua(e-2|0,31)|0){case 4:EB(a,b,c,d);return;case 0:e=32-G(d|1)|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<17){while(1){b=b-1|0;v[b|0]=y[(d&1)+15515|0];e=d>>>0>1;d=d>>>1|0;if(e){continue}break}}else{b=b-4|0;_m((d<<2&60)+78560|0,4,b);d=d>>>4|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 3:e=(34-G(d|1)>>>0)/3|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<65){while(1){b=b-1|0;v[b|0]=y[(d&7)+14812|0];e=d>>>0>7;d=d>>>3|0;if(e){continue}break}}else{b=b-2|0;_m((d<<1&126)+78624|0,2,b);d=d>>>6|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 7:e=35-G(d|1)>>>2|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<257){while(1){b=b-1|0;v[b|0]=y[(d&15)+11181|0];e=d>>>0>15;d=d>>>4|0;if(e){continue}break}}else{b=b-2|0;_m((d<<1&510)+78752|0,2,b);d=d>>>8|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;default:break b}}g=d;i=D(e,e);k=D(i,e);j=D(i,i);c:{while(1){h=f|1;if(e>>>0>g>>>0){break c}h=f|2;if(g>>>0<i>>>0){break c}h=f|3;if(g>>>0<k>>>0){break c}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){x[a+4>>2]=61;break a}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;v[c|0]=y[(d-D(b,e)|0)+4895|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}x[a+4>>2]=0;x[a>>2]=f;return}x[a>>2]=c}function s8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=nj(g);dq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=ec(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1241,a+220|0,a+216|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31609]=0;O(46,d|0,g<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+184>>2]=g+c}x[31609]=0;g=R(1242,x[a+220>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(eo(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,95168)){break c}x[31609]=0;R(1244,a+220|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=DK(c,x[a+184>>2],e,b),x[i>>2]=j;Vf(a+200|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1241,a+220|0,a+216|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function q8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=nj(g);dq(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){c=ec(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){d:{x[31609]=0;g=P(1241,a+220|0,a+216|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Cb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31609]=0;O(46,d|0,g<<1);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=Mc(d);x[31609]=0;O(46,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}c=ec(d,0);x[a+184>>2]=g+c}x[31609]=0;g=R(1242,x[a+220>>2])|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}if(eo(g,b,c,a+184|0,a+8|0,v[a+215|0],x[a+204>>2],y[a+211|0],a+16|0,a+12|0,95168)){break c}x[31609]=0;R(1244,a+220|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Cb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}i=f,j=zK(c,x[a+184>>2],e,b),w[i>>1]=j;Vf(a+200|0,a+16|0,x[a+12>>2],e);x[31609]=0;b=P(1241,a+220|0,a+216|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function TI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-80|0;fb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){uc(a,9766);break j}f=b>>>24|0;if(!(b&65535)){d=fb-16|0;fb=d;g=c+68|0;e=uc(d+4|0,4399);Uc(g,e);tb(e);fb=d+16|0;x[31609]=0;x[c+24>>2]=f;f=c+56|0;O(87,f|0,c+24|0);d=x[31609];x[31609]=0;k:{l:{m:{n:{if((d|0)!=1){x[31609]=0;x[c+8>>2]=b>>>16&255;b=c+44|0;O(88,b|0,c+8|0);d=x[31609];x[31609]=0;if((d|0)==1){break n}x[31609]=0;V(89,a|0,g|0,f|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break m}tb(b);tb(f);Eb(g);break j}b=N()|0;break k}b=N()|0;break l}b=N()|0;tb(c+44|0)}tb(c+56|0)}break a}d=fb-16|0;fb=d;g=c+68|0;e=uc(d+4|0,4123);Uc(g,e);tb(e);fb=d+16|0;x[31609]=0;x[c+40>>2]=f;f=c+56|0;O(87,f|0,c+40|0);d=x[31609];x[31609]=0;if((d|0)==1){break i}x[31609]=0;x[c+36>>2]=b>>>16&255;d=c+44|0;O(88,d|0,c+36|0);e=x[31609];x[31609]=0;if((e|0)==1){break h}x[31609]=0;x[c+20>>2]=b>>>8&255;e=c+24|0;O(88,e|0,c+20|0);h=x[31609];x[31609]=0;if((h|0)==1){break g}x[31609]=0;x[c+4>>2]=b&255;b=c+8|0;O(88,b|0,c+4|0);h=x[31609];x[31609]=0;if((h|0)==1){break f}x[31609]=0;ja(90,a|0,g|0,f|0,d|0,e|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}tb(b);tb(e);tb(d);tb(f);Eb(g)}fb=c+80|0;return}b=N()|0;break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;tb(c+8|0)}tb(c+24|0)}tb(c+44|0)}tb(c+56|0)}Eb(c+68|0);Q(b|0);p()}function $7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=Fw(x[g>>2]);g=Ly(x[g>>2]);sh(k+4|0,g);a:{b:{if(Ad(x[k+8>>2],y[k+15|0])){x[31609]=0;V(1249,l|0,a|0,c|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31609]=0;j=P(29,l|0,h<<24>>24)|0;h=x[31609];x[31609]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31609]=0;h=P(29,l|0,48)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[31609]=0;h=P(29,l|0,h|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}Dm(j,c);i=0;x[31609]=0;o=R(1247,g|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Dm((j-a|0)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[ec(k+4|0,h)|0]){break e}if(v[ec(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Cb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31609]=0;n=P(29,l|0,n|0)|0;m=x[31609];x[31609]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;tb(k+4|0);fb=k+16|0}function yB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;f=x[c+656>>2];a:{if(!Kj(f)){i=x[c+704>>2];f=fb-16|0;fb=f;x[f+12>>2]=d;g=0;b:{if(!d){break b}j=x[b+480180>>2];if(j&20){e=b+1074312|0;d=Ob(e,73)?d&65535:d;if(y[b+480208|0]&16){e=Ob(e,73)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=x[((d>>>0)%768<<2)+32304>>2]<<6>>>e|0;break b}g=229079296/((d>>>0<=1?1:d)>>>0)|0;break b}g=227001280/(d>>>0)|0;if(xn(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}xc(f+12|0,16777215);if(j&17408){g=Bc(Cua(Aua(i?i:8363,0,3506176,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}if(zj(b)){d=x[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(y[b+480208|0]&16){g=Bc(Cua(Aua(i?i:8363,0,7012352,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}g=Bc(Cua(-1485242368,13,(x[f+12>>2]<<8)+e|0,0),hb)}e=g;fb=f+16|0;f=x[c+656>>2];break a}e=x[c+700>>2]}x[h+12>>2]=e;c=w[c+774>>1];c:{if(!c){break c}c=f?D(v[f+33|0],c):c;if(!c){break c}e=Te(Ai(+(c|0)/393216)*+(e>>>0));x[h+12>>2]=e}d:{if(!f){break d}c=x[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=x[b+1074420>>2];e=Aua(f,f>>31,e,e>>31);f=d+e|0;d=hb+(d>>31)|0;k=h,l=Gc(Bua(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),hb),x[k+12>>2]=l}xc(h+12|0,2147483647);c=x[h+12>>2];b=kg(c,x[b+24620>>2]<<4);x[a+8>>2]=c;x[a>>2]=b;x[a+4>>2]=hb;fb=h+16|0}function N7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-368|0;fb=f;v[f+364|0]=0;v[f+365|0]=0;v[f+366|0]=0;v[f+367|0]=0;v[f+361|0]=0;v[f+362|0]=0;v[f+363|0]=0;v[f+364|0]=0;v[f+360|0]=37;h=qt(f+361|0,22292,x[c+4>>2]);b=f+320|0;x[f+316>>2]=b;a=Od();a:{if(h){g=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=g;g=ph(b,30,a,f+360|0,f+32|0);break a}C[f+48>>3]=e;g=ph(f+320|0,30,a,f+360|0,f+48|0)}x[f+80>>2]=1239;i=De(f+308|0,0,f+80|0);b=f+320|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Od();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=ij(f+316|0,a,f+360|0,f);break f}C[f+16>>3]=e;g=ij(f+316|0,a,f+360|0,f+16|0)}if((g|0)==-1){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)==1){break d}break e}a=x[f+316>>2];Qe(i,a)}j=a+g|0;l=jj(a,j,x[c+4>>2]);x[f+68>>2]=1239;h=De(f+72|0,0,f+68|0);g:{h:{if((f+320|0)==(a|0)){g=f+80|0;break h}g=Gd(g<<3);if(!g){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)!=1){break e}a=N()|0;break g}Qe(h,g);b=a}a=f+60|0;cd(a,x[c+28>>2]);x[31609]=0;ga(1272,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);b=x[31609];x[31609]=0;i:{if((b|0)!=1){_b(a);x[31609]=0;a=ea(1273,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break i}Lc(h);Lc(i);fb=f+368|0;break b}a=N()|0;_b(f+60|0);break g}a=N()|0}Lc(h);break c}p()}a=N()|0}Lc(i);Q(a|0);p()}return a|0}function IA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=HR(b,c);a:{if(!x[b+656>>2]|!(v[i+6|0]&1)){break a}e=x[i>>2];j=a+1074312|0;f=Ob(j,31);d=Nw(x[b+656>>2],c);if(mc(x[d>>2],x[d+4>>2])){break a}f=(f^1)+e|0;g=Ob(j,31);e=y[d+12|0];b:{c:{if(!g){d:{if(!(e&2)){break d}h=y[d+14|0];k=!(x[a+480180>>2]&1048580)+z[yb(x[d>>2],h)>>1]|0;g=0;if(!(!(y[b+89|0]&8)|(!(e&4)|(h|0)!=y[d+16|0]))){g=Ob(j,70)}if(g|(f|0)!=(k|0)){break d}f=z[yb(x[d>>2],y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){a=x[d>>2];if((z[yb(a,y[d+16|0])>>1]+1|0)!=(f|0)){break b}f=z[yb(a,y[d+15|0])>>1];if(!Ob(j,93)|(c|0)!=1|y[b+89|0]&8){break b}v[i+6|0]=y[i+6|0]&254;break b}h=0;e=z[xf(x[d+4>>2])>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|y[b+669|0]&8)){if(z[i+4>>1]==65535){break f}if(Ob(j,97)){break f}e=y[d+12|0]}if(e&2){g=x[d>>2];e=z[yb(g,y[d+13|0])>>1];h=1;g=z[yb(g,y[d+14|0])>>1]+1|0;break e}e=z[xf(x[d+4>>2])>>1];h=f>>>0<=e>>>0;g=e;break e}g=x[d>>2];e=z[yb(g,y[d+15|0])>>1];h=1;g=z[yb(g,y[d+16|0])>>1]+1|0}e=f>>>0<g>>>0?f:e}g:{if(c|h){break g}f=x[a+480180>>2];c=x[b+88>>2];if(!(!(f&16777248)&(!(c&2048)|(f|0)==16384))){c=c|4096;x[b+88>>2]=c}if(y[xf(x[d+4>>2])+2|0]|!(z[b+786>>1]|x[a+480180>>2]&16777248)){break g}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=c|4096}f=e}l=i,m=Ob(j,31)+f|0,x[l>>2]=m}}function Gla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];m=x[a+128>>2];if(m){n=Hg(k,l,m);o=hb;b=x[a+76>>2];fg(h,e,uf(k,l,d),hb);p=hb>>>0>b>>>0?d:0}i=a+112|0;t=x[a+24>>2];u=x[a+20>>2];f=x[a+48>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;a:while(1){b:{q=b;if(!d){break b}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;p=p-1|0;b=p;n=b?n:0;o=b?o:0;h=e+r|0;b=m;while(1)if((b|0)<=0){Pb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){ce(i,v[h+x[g+12>>2]|0]<<6);be(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}w=x[a+72>>2];y=x[c>>2];h=Fg(i,s)<<8;b=h;j=b>>31;b=x[a+60>>2];b=Aua(h,j,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Yb(q,-16777216,16776704);j=Aua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Yb(f,-16777216,16776704);e=Aua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Sc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+y;x[c+4>>2]=x[c+4>>2]+D(f,t);Pb(g,k,l);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue a}else{ce(i,v[h+x[g+12>>2]|0]<<6);be(i,4);Pb(g+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function X7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-208|0;fb=f;v[f+204|0]=0;v[f+205|0]=0;v[f+206|0]=0;v[f+207|0]=0;v[f+201|0]=0;v[f+202|0]=0;v[f+203|0]=0;v[f+204|0]=0;v[f+200|0]=37;h=qt(f+201|0,22292,x[c+4>>2]);b=f+160|0;x[f+156>>2]=b;a=Od();a:{if(h){g=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=g;g=ph(b,30,a,f+200|0,f+32|0);break a}C[f+48>>3]=e;g=ph(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=1239;i=De(f+148|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Od();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=ij(f+156|0,a,f+200|0,f);break f}C[f+16>>3]=e;g=ij(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)==1){break d}break e}a=x[f+156>>2];Qe(i,a)}j=a+g|0;l=jj(a,j,x[c+4>>2]);x[f+68>>2]=1239;h=De(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Gd(g<<1);if(!g){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)!=1){break e}a=N()|0;break g}Qe(h,g);b=a}a=f+60|0;cd(a,x[c+28>>2]);x[31609]=0;ga(1267,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);b=x[31609];x[31609]=0;i:{if((b|0)!=1){_b(a);x[31609]=0;a=ea(23,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break i}Lc(h);Lc(i);fb=f+208|0;break b}a=N()|0;_b(f+60|0);break g}a=N()|0}Lc(h);break c}p()}a=N()|0}Lc(i);Q(a|0);p()}return a|0}function Sta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31609]=0;k=yh(g,a);O(110,h|0,k|0);a=x[31609];x[31609]=0;a:{b:{if((a|0)!=1){g=0;a=0;c:{while(1){d:{if((a|0)==(k|0)){if(l&m|f){break d}return}e=y[ec(b,a)|0];e:{f:{g:{switch(f|0){case 0:f=1;h:{switch(e-123|0){case 2:break h;case 0:break e;default:break f}}f=3;break e;case 1:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break e}x[31609]=0;O(302,h|0,Vd(c,g)|0);j=x[31609];x[31609]=0;g=e;if((j|0)!=1){break e}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48&255;if(e>>>0>9){break e}l=1;f=2;i=e;break e;case 2:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break e}x[31609]=0;O(302,h|0,Vd(c,i)|0);e=x[31609];x[31609]=0;if((e|0)!=1){break e}a=N()|0;break b;case 0:break e;default:break j}}e=e-48&255;if(e>>>0>9){break e}i=e+D(i,10)|0;l=1;f=2;break e;case 3:break g;default:break e}}j=(e|0)!=125;f=-1;e=125;if(j){break e}}f=0;x[31609]=0;O(111,h|0,e<<24>>24);e=x[31609];x[31609]=0;if((e|0)==1){break c}}a=a+1|0;continue}break}b=dc(8);x[31609]=0;a=R(96,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){x[31609]=0;S(97,a|0,40180,17);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;lc(b);break b}a=N()|0;break b}a=N()|0}tb(h);Q(a|0)}p()}function X3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31609]=0;k=yh(g,a);O(93,h|0,k|0);a=x[31609];x[31609]=0;a:{b:{if((a|0)!=1){g=0;a=0;c:{while(1){d:{if((a|0)==(k|0)){if(l&m|f){break d}return}e=y[ec(b,a)|0];e:{f:{g:{switch(f|0){case 0:f=1;h:{switch(e-123|0){case 2:break h;case 0:break e;default:break f}}f=3;break e;case 1:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break e}x[31609]=0;O(94,h|0,Vd(c,g)|0);j=x[31609];x[31609]=0;g=e;if((j|0)!=1){break e}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break e}l=1;f=2;i=e;break e;case 2:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break e}x[31609]=0;O(94,h|0,Vd(c,i)|0);e=x[31609];x[31609]=0;if((e|0)!=1){break e}a=N()|0;break b;case 0:break e;default:break j}}if((e-48&255)>>>0>9){break e}i=(D(i,10)+e|0)-48|0;l=1;f=2;break e;case 3:break g;default:break e}}j=(e|0)!=125;f=-1;e=125;if(j){break e}}f=0;x[31609]=0;O(95,h|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break c}}a=a+1|0;continue}break}b=dc(8);x[31609]=0;a=R(96,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){x[31609]=0;S(97,a|0,40180,17);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;lc(b);break b}a=N()|0;break b}a=N()|0}tb(h);Q(a|0)}p()}function una(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-32|0;fb=e;c=z[a+480190>>1];v[e+20|0]=0;j=c+1|0;c=e+20|0;aU(b,j,c);if(z[a+480192>>1]){g=Nb(c);n=e,o=wb(x[a+484344>>2]),x[n+16>>2]=o;m=a+900380|0;j=wb(x[a+484348>>2]);while(1){h=x[e+16>>2];if(Ib(h,j)){a:{if(!Ib(x[h>>2],x[h+4>>2])){break a}c=z[a+480188>>1];x[31609]=0;v[e+4|0]=0;S(779,g|0,c|0,e+4|0);c=x[31609];x[31609]=0;if((c|0)!=1){n=e,o=wb(x[h>>2]),x[n+12>>2]=o;k=0;b:while(1){f=0;if(A[h+12>>2]<=k>>>0){break a}while(1)if(z[a+480188>>1]<=f>>>0){k=k+1|0;continue b}else{c:{c=x[e+12>>2];if(!Tc(y[c|0])){break c}d:{e:{c=y[c+1|0];if(c){d=z[a+480192>>1];break e}d=z[a+480192>>1];c=y[xb(x[g>>2],f)|0];if(c){break e}c=1;break d}n=xb(x[g>>2],f),o=c,v[n|0]=o;d=d&65535;i=d>>>0<c>>>0;d=i?d:c;c=i?1:c}i=d&65535;while(1){d=c&65535;if(d>>>0>i>>>0){break c}d=x[(d<<2)+m>>2];f:{if(!d){break f}d=z[ac(d+236|0,y[x[e+12>>2]]-1|0)>>1];if(d>>>0>z[a+480190>>1]){break f}l=e+4|0;Jb(l,x[b>>2],d);kf(l,1)}c=c+1|0;continue}}f=f+1|0;LC(e+12|0);continue}}}a=N()|0;fc(g);Q(a|0);p()}Ul(e+16|0);continue}else{f=a+484380|0;c=z[a+480190>>1];d=0;while(1){if(c){Jb(e+4|0,x[b>>2],c);if(!Gb(x[x[e+4>>2]>>2],x[e+8>>2])){a=f+D(c,104)|0;d=le(x[a>>2],x[a+20>>2])+d|0}c=c-1|0;continue}else{fc(g)}break}}break}}fb=e+32|0;return d&65535}function dc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=HY(a+24|0);a=h;i=a>>>0<=1?1:a;a=i;f=fb-16|0;fb=f;c=a+15&-16;a=a>>>0<c>>>0?c:a;if(!(a&15)){if(a>>>0>4294967216){a=48}else{a:{if(a>>>0>=4294967216){x[31484]=48;b=0;break a}c=a>>>0<11?16:a+11&-8;a=Gd(c+28|0);b=0;if(!a){break a}b=a-8|0;b:{if(!(a&15)){a=b;break b}g=a-4|0;j=x[g>>2];a=(a+15&-16)-8|0;a=(a-b>>>0<=15?16:0)+a|0;d=a-b|0;e=(j&-8)-d|0;if(!(j&3)){b=x[b>>2];x[a+4>>2]=e;x[a>>2]=b+d;break b}x[a+4>>2]=e|x[a+4>>2]&1|2;e=a+e|0;x[e+4>>2]=x[e+4>>2]|1;x[g>>2]=d|x[g>>2]&1|2;e=b+d|0;x[e+4>>2]=x[e+4>>2]|1;Pv(b,d)}b=x[a+4>>2];c:{if(!(b&3)){break c}d=b&-8;if(d>>>0<=c+16>>>0){break c}x[a+4>>2]=c|b&1|2;b=a+c|0;c=d-c|0;x[b+4>>2]=c|3;d=a+d|0;x[d+4>>2]=x[d+4>>2]|1;Pv(b,c)}b=a+8|0}if(b){x[f+12>>2]=b;a=0}else{a=48}}b=a?0:x[f+12>>2]}fb=f+16|0;a=b;if(!a){d:{b=0;a=x[125432];if(!a){x[125432]=501756;w[250879]=125;k=501756,l=Xx(502256),w[k>>1]=l;a=x[125432]}c=(i+3>>>2|0)+1|0;while(1){e:{if(!a|(a|0)==502256){a=0}else{d=z[a+2>>1];f=c+(c>>>0<d>>>0?d-c&3:0)|0;if(d>>>0>f>>>0){b=d-f|0;w[a+2>>1]=b;a=((b&65535)<<2)+a|0;w[a+2>>1]=f;w[a>>1]=0;a=a+4|0;break d}if(c>>>0>d>>>0){break e}c=z[a>>1];f:{if(!b){k=501728,l=Yx(c),x[k>>2]=l;break f}w[b>>1]=c}w[a>>1]=0;a=a+4|0}break d}b=a;a=Yx(z[a>>1]);continue}}}if(!a){Sb();p()}return MR(Rb(a,0,h))}function r4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=xt(c,d);x[k+4>>2]=1239;n=wt(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Gd(j);if(!i){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break a}Qe(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(h){x[f>>2]=x[f>>2]|2}break b}g=x[g>>2];x[31609]=0;s=P(1259,e|0,g|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+4;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Cb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=x[Wd(g,o)>>2];x[31609]=0;q=P(1259,e|0,q|0)|0;t=x[31609];x[31609]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Cb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=Ad(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Lc(n);fb=k+128|0;return d|0}a=N()|0;Lc(n);Q(a|0);p()}function g4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=xt(c,d);x[k+4>>2]=1239;n=wt(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Gd(j);if(!i){x[31609]=0;X(1240);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break a}Qe(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(h){x[f>>2]=x[f>>2]|2}break b}g=v[g|0];x[31609]=0;s=P(1243,e|0,g|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+1;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Cb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=v[ec(g,o)|0];x[31609]=0;q=P(1243,e|0,q|0)|0;t=x[31609];x[31609]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Cb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=Ad(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Lc(n);fb=k+128|0;return d|0}a=N()|0;Lc(n);Q(a|0);p()}function NO(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-160|0;fb=e;d=Dc(e+4|0,11616);x[31609]=0;b=d+12|0;P(36,b|0,11021)|0;c=x[31609];x[31609]=0;a:{if((c|0)==1){break a}x[31609]=0;b=d+24|0;P(36,b|0,11446)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=d+36|0;P(36,b|0,11013)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=d+48|0;P(36,b|0,8243)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=d+60|0;P(36,b|0,10998)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=d+72|0;P(36,b|0,8309)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=d+84|0;P(36,b|0,5620)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=d+96|0;P(36,b|0,12020)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=d+108|0;P(36,b|0,11389)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=d+120|0;P(36,b|0,12289)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=d+132|0;P(36,b|0,5472)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;b=d+144|0;P(36,b|0,7335)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;U(1063,a|0,d|0,13)|0;a=x[31609];x[31609]=0;if((a|0)!=1){b=d+156|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}fb=e+160|0;return}b=d+156|0}a=N()|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}Q(a|0);p()}function tra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;i=If(a,c);ae(e,x[a+36>>2]);j=a;a:{if(!i){Qc(e,a+32|0,5);c=0;if(Gb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=fb-160|0;fb=d;f=Km(d+48|0,x[a+36>>2]);x[31609]=0;a=P(461,d+36|0,42212)|0;c=x[31609];x[31609]=0;b:{c:{d:{e:{if((c|0)!=1){x[31609]=0;x[d+16>>2]=20054022;x[d+20>>2]=0;S(462,f|0,a|0,d+16|0);c=x[31609];x[31609]=0;if((c|0)==1){break e}Eb(a);if(!ql(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}l=d,m=Xj(x[b>>2],x[b+4>>2]),w[l+34>>1]=m;w[d+32>>1]=65535;x[31609]=0;a=P(461,d+16|0,10121)|0;c=x[31609];x[31609]=0;f:{if((c|0)!=1){x[31609]=0;c=U(491,f|0,d+32|0,a|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break f}Eb(a);if(c){w[d+34>>1]=z[d+32>>1]}Hf(d+34|0,4e3);a=z[d+34>>1];g:{if(Xj(x[b>>2],x[b+4>>2])>>>0>=a>>>0){break g}x[31609]=0;O(223,b|0,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){break g}c=N()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}h=x[b>>2];x[31609]=0;g=d+4|0;O(492,g|0,c|0);k=x[31609];x[31609]=0;if((k|0)!=1){x[31609]=0;V(493,f|0,Wb(h,c)|0,g|0,494);h=x[31609];x[31609]=0;if((h|0)==1){break h}c=c+1|0;Eb(g);continue}break}c=N()|0;break c}c=N()|0;Eb(d+4|0);break c}c=N()|0;break c}c=N()|0;Eb(a)}Ch(f);Q(c|0);p()}Ch(f);fb=d+160|0;c=i}ef(j,c);fb=e+16|0}function vI(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{c=x[a+4>>2];g:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break g}c=td(a)}switch(c-43|0){case 0:case 2:break f;default:break e}}d=(c|0)==45;f=!b;c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=td(a)}b=c-58|0;if(f|b>>>0>4294967285){break d}b=x[a+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){break c}break a}b=c-58|0}f=d;if(b>>>0<=4294967285){if(x[a+116>>2]<0){break a}break b}i:{if(c-48>>>0>=10){break i}while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];j:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break j}c=td(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}g=e>>31;if(b>>>0>=10){break i}while(1){b=c;c=Aua(e,g,10,0);d=b+c|0;b=hb;e=d-48|0;d=(c>>>0>d>>>0?b+1|0:b)-(d>>>0<48)|0;g=d;d=e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836;c=x[a+4>>2];k:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break k}c=td(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}if(b>>>0>=10){break i}while(1){b=x[a+4>>2];l:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break l}b=td(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0){b=1}else{b=(b|0)>=0}if(b){x[a+4>>2]=x[a+4>>2]-1}hb=f?0-(((e|0)!=0)+g|0)|0:g;return f?0-e|0:e}x[a+4>>2]=x[a+4>>2]-1}x[a+4>>2]=x[a+4>>2]-1}hb=-2147483648;return 0}function bJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=z[c>>1];c:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break e}if((g-x[a+8>>2]|0)<4){break a}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;v[f|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&191;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return f|0}function Ee(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,k=0;d=(q(b),j(2));c=fI(d);a:{b:{c:{d:{e=(q(a),j(2));e:{if(e-2139095040>>>0>=2164260864){if(c){break e}break c}if(!c){break d}}h=E(1);if((e|0)==1065353216){break b}c=d<<1;if(!c){break b}i=c>>>0<4278190081;c=e<<1;a=E(a+b);if(!(i&c>>>0<=4278190080)){break a}if((c|0)==2130706432){break b}a=(d|0)<0^c>>>0<2130706432?E(0):E(b*b);break a}if(fI(e)){h=E(a*a);if((e|0)<0){h=(eI(d)|0)==1?E(-h):h}if((d|0)>=0){break b}a=Lx(E(E(1)/h));break a}if((e|0)<0){c=eI(d);if(!c){a=YI(a);break a}e=(q(a),j(2))&2147483647;i=((c|0)==1)<<16}if(e>>>0>8388607){break c}e=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}d=e-1060306944|0;c=d>>>15&240;f=+(l(2,e-(d&-8388608)|0),r())*C[c+125168>>3]+-1;g=f*f;f=((f*.288457581109214+-.36092606229713164)*(g*g)+((f*.480898481472577+-.7213474675006291)*g+(f*1.4426950408774342+(C[c+125176>>3]+ +(d>>23)))))*+b;o(+f);c=j(1)|0;j(0)|0;f:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break f}if(f>127.99999995700433){a=RG(i);break a}if(!(f<=-150)){break f}a=zG(i);break a}k=f;g=C[160];f=g+f;g=k-(f-g);g=(C[161]*g+C[162])*(g*g)+(C[163]*g+1);o(+f);j(1)|0;e=j(0)|0;d=i+e|0;i=d<<15;d=((e&31)<<3)+1024|0;c=x[d>>2];d=x[d+4>>2]+i|0;l(0,c|0);l(1,(c>>>0>c>>>0?d+1|0:d)|0);h=E(g*+n())}a=h}return a}function wM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Xf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){l=x[c+20>>2];if(l>>>0<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}m=x[c+28>>2];if(f>>>0>x[c+24>>2]-m>>>0){break b}n=b+12|0;o=x[c+16>>2];q=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}r=(D(h,k)<<3)+q|0;s=(D(h+m|0,l)<<1)+o|0;d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=yb(x[b>>2],d);i=Fe(Jg(C[(d<<3)+r>>3])*134217728);j=e;e=(x[e>>2]>>1)+vn(i)|0;t=e;e=Zt(n)+e&-4096;x[j>>2]=t-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d<<1)+s|0;i=Fe(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}u=j,v=gd(e),w[u>>1]=v;d=d+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=c- -64|0}function Rla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;h=fb-16|0;fb=h;i=x[a+40>>2];j=x[a+36>>2];e=x[a+48>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Aua(n,y,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Aua(m,v,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=p;g=Aua(e,e>>31,o,z);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Sc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,l,A);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function EL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=ue(a,k),x[p>>2]=q;g=d+1076|0;p=g,q=ue(a,k),x[p>>2]=q;i=ue(a,c&-4);x[d+1084>>2]=i;a:{h=x[h>>2];if(!h){break a}g=x[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=E(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+E(E(E(g<<1)*E(3.1415927410125732))/j);p=i+(e<<2)|0,r=E(hf(f)),B[p>>2]=r;p=i+(g<<2)|0,r=E(-E(Pi(f))),B[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+E(E(E(e<<2)*E(3.1415927410125732))/j);p=h+l|0,r=E(hf(f)),B[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=E(-E(Pi(f))),B[p>>2]=r;f=+E(E(E(E(m|0)*E(3.1415927410125732))/j)*E(.5));p=g+l|0,r=E(E(hf(f))*E(.5)),B[p>>2]=r;p=g+n|0,r=E(E(Pi(f))*E(.5)),B[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=ue(a,k);x[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=E(Pi((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=E(Pi(+E(j*j)*1.5707963705062866)),B[p>>2]=r;b=b+1|0;continue}break}b=ue(a,c>>2&-2);x[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Jm(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Hm(a)>>>c<<2,w[p>>1]=q;a=a+1|0;continue}break}return 1}bc(a,3);return 0}function Ij(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!le(x[a>>2],x[a+20>>2])){break a}Uk(a);b:{switch(Jn(z[a+34>>1])-1|0){case 1:h=fb-48|0;fb=h;g=x[a+20>>2];d=x[a>>2];c=_d(z[a+34>>1]);e=g+(D(d,c)<<1)|0;while(1){c:{d:{if((f|0)!=16){j=e+(D(c,f)<<1)|0;k=g+(D(c,f^-1)<<1)|0;d=0;break d}f=e+(c<<5)|0;d=z[a+34>>1];if(d&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;$U(h+28|0,f,g+(D(c,e)<<1)|0,i,c,(d&4)>>>2|0,Ob(b+1074312|0,33));d=z[a+34>>1]}if(d&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;$U(h+8|0,f+(c<<7)|0,g+(D(a,c)<<1)|0,e,c,(d&16)>>>4|0,Ob(b+1074312|0,33))}fb=h+48|0;break c}while(1){if((c|0)!=(d|0)){i=d<<1;w[i+j>>1]=z[e+(d-c<<1)>>1];w[i+k>>1]=z[g+i>>1];d=d+1|0;continue}break}f=f+1|0;continue}break};return;case 0:break b;default:break a}}h=fb-48|0;fb=h;g=x[a+20>>2];c=x[a>>2];d=_d(z[a+34>>1]);e=g+D(c,d)|0;while(1){e:{f:{if((f|0)!=16){i=e+D(d,f)|0;j=g+D(d,f^-1)|0;c=0;break f}f=e+(d<<4)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;_U(h+28|0,f,g+D(d,e)|0,i,d,(c&4)>>>2|0,Ob(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;_U(h+8|0,f+(d<<6)|0,g+D(a,d)|0,e,d,(c&16)>>>4|0,Ob(b+1074312|0,33))}fb=h+48|0;break e}while(1){if((c|0)!=(d|0)){v[c+i|0]=y[e+(c-d|0)|0];v[c+j|0]=y[c+g|0];c=c+1|0;continue}break}f=f+1|0;continue}break}}}function x1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-1088|0;fb=g;e=Yh(a);Rb(e+20|0,0,1040);x[e+1064>>2]=0;x[e+1068>>2]=0;x[e+1060>>2]=c;v[e+1084|0]=d;a=e+1072|0;x[a>>2]=0;x[a+4>>2]=0;x[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(_d(z[a+34>>1])>>>0<=d>>>0){break a}x[e+1064>>2]=0;x[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(A[c>>2]<=a>>>0){break j}a=x[b+8>>2];f=x[b>>2];x[31609]=0;a=U(150,f|0,a|0,2)|0;f=x[31609];x[31609]=0;if((f|0)==1){break i}if(!a){break j}x[31609]=0;a=R(189,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break h}if(!a){break e}x[31609]=0;f=g+8|0;S(185,f|0,b|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break g}a=ns(g+28|0,f);h=kd(e,a);zc(h+20|0,a+20|0,1040);ub(a);ub(f);x[e+1076>>2]=0;x[e+1080>>2]=0;f=x[e+1060>>2];a=x[f+20>>2];if(Jn(z[f+34>>1])>>>0>=2){x[31609]=0;O(190,h|0,a+(d<<1)|0);a=x[31609];x[31609]=0;if((a|0)!=1){break e}break f}x[31609]=0;O(191,h|0,a+d|0);a=x[31609];x[31609]=0;if((a|0)==1){break f}break e}d=d+1|0;a=x[e+1060>>2];continue c}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=T(28816)|0;if((gb|0)!=($(28816)|0)){break b}Y(a|0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break d}}a=x[i>>2];continue}break}break}a=N()|0}ub(e);Q(a|0);p()}fb=g+1088|0;return e|0}function lN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;g=x[a+32>>2];f=qq(g);if(!f){f=pq(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=dc(8);x[31609]=0;c=P(36,i+4|0,6e3)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}if(c>>>0>=120){b=dc(8);x[31609]=0;c=P(36,i+4|0,11334)|0;a=x[31609];x[31609]=0;if((a|0)!=1){sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;lc(b);break b}f=eB(g,65535);j=(f|0)==65535?255:f;w[i+4>>1]=j;f=g+D(j,872)|0;h=f+1074992|0;Qo(h,g,65535,1024);c=c+1|0;v[f+1075794|0]=c;v[f+1075791|0]=c;w[f+1075778>>1]=0;Ym(h);Lo(x[a+32>>2],h,b+1|0,0,1,1);x[f+1075688>>2]=65536;Su(x[a+32>>2],h,c,0,1,1,65535);l=f+1075684|0,m=Si(Zv(e*128,-128,128)+128),x[l>>2]=m;l=f+1075680|0,m=Si(Zv(d*256,0,256)),x[l>>2]=m;d:{b=x[a+32>>2];h=b+1074478|0;c=h;c=c+(z[b+480212>>1]<<1)|0;g=z[i+4>>1];b=MX(h,c,g);if((b|0)==(c|0)){break d}f=b;while(1){while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break d}k=z[f>>1];if((k|0)==(g|0)){continue}break}w[b>>1]=k;b=b+2|0;g=z[i+4>>1];continue}}l=x[a+32>>2],m=LT(h,c),w[l+480212>>1]=m;fb=i+16|0;return j|0}a=N()|0;lc(b)}Q(a|0)}p()}function Ila(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=fb-16|0;fb=f;s=x[a+16>>2];t=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+8>>2];l=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];m=x[a+128>>2];if(m){n=Hg(k,l,m);o=hb;h=x[a+76>>2];fg(b,g,uf(k,l,d),hb);p=hb>>>0>h>>>0?d:0}h=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[f>>2]=b;x[f+4>>2]=g;while(1){if(d){d=d-1|0;x[f+8>>2]=b;x[f+12>>2]=0;p=p-1|0;e=p;n=e?n:0;o=e?o:0;r=(((g&2147483647)<<1|b>>>31)&-2)+s|0;g=m;a:{b:while(1){c:{if((g|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break a}e=x[f+8>>2];q=((x[f+12>>2]&2147483647)<<1|e>>>31)&-2;e=0;b=0;break c}e=x[f+8>>2];q=((x[f+12>>2]&2147483647)<<1|e>>>31)&-2;b=0;e=0;while(1)if((b|0)==2){ce(h,e>>>3<<16>>16);be(h,4);Pb(f+8|0,n,o);g=g-1|0;continue b}else{e=(v[(b|q)+r|0]<<8)+e|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){e=(v[(b|q)+r|0]<<8)+e|0;b=b+1|0;continue}break}ce(h,e>>>3<<16>>16);be(h,g);x[h>>2]=x[h>>2];x[h+4>>2]=0}g=x[a+32>>2];e=x[c>>2];b=Fg(h,t);j=x[a+28>>2]+j|0;x[c>>2]=D(b,j>>12)+e;i=g+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(f,k,l);c=c+8|0;b=x[f>>2];g=x[f+4>>2];continue}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=f+16|0}function CM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Xf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}l=x[c+28>>2];if(f>>>0>x[c+24>>2]-l>>>0){break b}m=b+12|0;n=x[c+16>>2];o=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}q=(D(h,k)<<3)+o|0;d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=yb(x[b>>2],d);i=Fe(Jg(C[(d<<3)+q>>3])*134217728);j=e;e=(x[e>>2]>>1)+vn(i)|0;r=e;e=Zt(m)+e&-4096;x[j>>2]=r-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d<<2)+n|0;i=Fe(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}s=(x[j>>2]+(l<<1)|0)+(h<<1)|0,t=gd(e),w[s>>1]=t;d=d+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=c- -64|0}function zh(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=x[a+480180>>2];if(!xn(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((D(a,-12)+e&255)<<1)+31616>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(zj(a)){a=((e&255)>>>0)/12|0;b=Aua(x[(D(a,-12)+e<<6&960)+35504>>2]<<a,0,d,0);a=hb;c=a>>>21|0;h=f,i=Bc((a&2097151)<<11|b>>>21,c),x[h+8>>2]=i;xc(f+8|0,2147483647);e=x[f+8>>2];break a}if(y[a+480208|0]&16){a=e&255;e=z[((a>>>0)%12<<1)+31616>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;xc(f+12|0,-1>>>a|0);e=Bc(Cua(Aua(z[((D(a,-12)+e&255)<<1)+31616>>1],0,267616,0),hb,x[f+12>>2]<<a,0),hb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{b=Ob(a+1074312|0,76)?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=((b|0)/-2|0)-(c<<6)|0;e=((a|0)<=-8447?-8447:a)+8448|0;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(D(c,-12)+a<<3&248)|0;x[f+4>>2]=d+8;Ge(f+4|0,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)<=-8?-8:a;e=D(b,z[(((a|0)>=95?95:a)<<1)+32112>>1])+D(z[(x[f+4>>2]<<1)+32096>>1],16-b|0)<<1>>>c|0;break a}if(!(!(c&240|e>>>0<24)&e>>>0<108)){a=((e&255)>>>0)/12|0;e=z[(D(c>>>4&15,12)+(D(a,-12)+e&255)<<1)+31216>>1]<<5>>>a|0;break a}e=z[(b<<1)+30990>>1]<<2}fb=f+16|0;return e}function gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=jv(c+4|0,a,1);Az(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+16;jc(a);fb=c+16|0;return}i=fb-32|0;fb=i;c=Ab(a);d=MV(i+12|0,NV(a,Dk(x[a>>2],x[a+4>>2])+1|0),Dk(x[a>>2],x[a+4>>2]),c);Az(x[d+8>>2],b);x[d+8>>2]=x[d+8>>2]+16;h=fb-16|0;fb=h;e=Ab(a);b=vb(h+12|0,x[a+4>>2]);c=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[d+4>>2]);b=x[b>>2];g=x[c>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=b;x[c+52>>2]=f;e=Ag(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;zg(c+36|0,c+8|0);while(1){if(Fd(b,g)){Az(Bz(x[c+56>>2]),nC(b));b=Xq(c+60|0);Xq(c+56|0);b=x[b>>2];continue}break}yg(c+36|0);j=x[c+56>>2];if(!y[c+48|0]){f=fb-16|0;fb=f;b=vb(f+12|0,x[x[c+44>>2]>>2]);k=x[vb(f+8|0,x[x[c+40>>2]>>2])>>2];g=fb-16|0;fb=g;b=x[b>>2];x[g+12>>2]=b;while(1){if(wi(b,k)){e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+12>>2]=x[e+12>>2]+16;fb=e+16|0;Oj(Bz(x[e+12>>2]));b=x[Vo(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=c- -64|0;x[d+4>>2]=j;Tb(a,d+4|0);Tb(a+4|0,d+8|0);Tb(Ab(a),nc(d));x[d>>2]=x[d+4>>2];fb=h+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-16|0;x[d+8>>2]=b;Oj(b);continue}break}a=x[d>>2];if(a){vs(d);Db(a)}fb=i+32|0}function Sla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;i=x[a+40>>2];j=x[a+36>>2];e=x[a+48>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;l=x[a+8>>2];B=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Aua(n,z,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Aua(m,y,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=p;g=Aua(e,e>>31,o,A);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Sc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,l,B);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function $P(a){var b=0,c=E(0),d=0,e=0,f=0,g=E(0),h=0,i=0,k=E(0),m=0,n=0,o=E(0);d=fb-16|0;fb=d;b=x[x[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=Ee(E(10),E(E(E(B[yb(e,0)>>2]*E(120))+E(-60))/E(20))),B[n+4232>>2]=o;k=E(E(b>>>0)/E(1e3));n=a,o=Ee(E(10),E(E(-1)/E(k*E(E(B[yb(e,1)>>2]*E(499.989990234375))+E(.009999999776482582))))),B[n+4236>>2]=o;n=a,o=Ee(E(10),E(E(-1)/E(k*E(E(B[yb(e,2)>>2]*E(2950))+E(50))))),B[n+4240>>2]=o;x[d+12>>2]=1325400064;c=E(Ee(E(10),E(E(E(B[yb(e,3)>>2]*E(60))+E(-60))/E(20)))*E(2147483648));b=(q(c),j(2));g=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){g=E(Lx(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=YI(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),r())*C[h+3568>>3]+-1;m=i*i;c=E((C[479]*m+(C[480]*i+C[481]))*m+(+(f>>23)*C[478]+C[h+3576>>3]+i))}g=c}B[d+8>>2]=E(E(g*E(67108864))/E(.6931471824645996))+E(67108864);n=a,o=E(B[Rm(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[n+4244>>2]=o;n=a,o=E(E(E(-1)/E(E(B[yb(e,4)>>2]*E(99))+E(1)))+E(1)),B[n+4248>>2]=o;c=E(E(E(B[yb(e,5)>>2]*E(4))*k)+E(2));c:{if(E(F(c))<E(2147483648)){h=~~c;break c}h=-2147483648}x[a+4252>>2]=h;fb=d+16|0}function Yka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;j=fb-32|0;fb=j;f=j+28|0;e=j+24|0;k=c;g=fb-16|0;fb=g;a:{b:{c=b;if(!mc(b,x[vb(g+12|0,pg(a))>>2])){b=z[k>>1];h=x[k+4>>2];i=ud(c);m=z[i>>1];i=x[i+4>>2];if(!Ol(b,h,m,i)){break b}}x[g+12>>2]=c;c:{if(!mc(c,x[vb(g+8|0,wb(x[a>>2]))>>2])){b=x[LB(g+12|0)>>2];e=ud(b);i=z[e>>1];m=x[e+4>>2];e=z[k>>1];h=x[k+4>>2];if(Ol(i,m,e,h)){break c}c=KB(a,f,e,h);break a}b=c}if(!x[c>>2]){x[f>>2]=c;break a}x[f>>2]=b;c=b+4|0;break a}if(Ol(m,i,b,h)){d:{b=JB(c);if(!mc(b,x[vb(g+12|0,pg(a))>>2])){e=z[k>>1];h=x[k+4>>2];i=ud(b);if(!Ol(e,h,z[i>>1],x[i+4>>2])){break d}}if(!x[c+4>>2]){x[f>>2]=c;c=c+4|0;break a}x[f>>2]=b;c=b;break a}c=KB(a,f,e,h);break a}x[f>>2]=c;x[e>>2]=c;c=e}fb=g+16|0;b=x[c>>2];if(!b){b=fb-16|0;fb=b;f=gc(a);e=j+12|0;g=Dh(e,Ec(36),Og(b+8|0,f));f=x[g>>2]+16|0;h=x[k+4>>2];x[f>>2]=x[k>>2];x[f+4>>2]=h;Tl(f+8|0,d);o=gc(g),p=1,v[o+4|0]=p;fb=b+16|0;$g(a,x[j+28>>2],c,x[j+12>>2]);b=ne(e);WT(e);n=1}a=l+4|0;_g(a,x[vb(j+12|0,b)>>2],n);fb=j+32|0;if(!y[gc(a)|0]){a=ud(x[l+4>>2])+8|0;VT(a);x[a>>2]=x[d>>2];x[a+4>>2]=x[d+4>>2];b=Ab(d);o=Ab(a),p=x[b>>2],x[o>>2]=p;x[b>>2]=0;x[d>>2]=0;x[d+4>>2]=0}a=vb(l+12|0,x[l+4>>2]);fb=l+16|0;return x[a>>2]}function Dia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=kC(c+4|0,a);eA(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+4;jc(a);fb=c+16|0;return}i=fb-32|0;fb=i;c=Ab(a);d=Zf(i+12|0,Lf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);eA(x[d+8>>2],b);x[d+8>>2]=x[d+8>>2]+4;h=fb-16|0;fb=h;e=Ab(a);b=vb(h+12|0,x[a+4>>2]);c=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[d+4>>2]);b=x[b>>2];g=x[c>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=b;x[c+52>>2]=f;e=Ag(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;zg(c+36|0,c+8|0);while(1){if(Fd(b,g)){eA(KQ(x[c+56>>2]),xf(b));b=wj(c+60|0);wj(c+56|0);b=x[b>>2];continue}break}yg(c+36|0);j=x[c+56>>2];if(!y[c+48|0]){f=fb-16|0;fb=f;b=vb(f+12|0,x[x[c+44>>2]>>2]);k=x[vb(f+8|0,x[x[c+40>>2]>>2])>>2];g=fb-16|0;fb=g;b=x[b>>2];x[g+12>>2]=b;while(1){if(wi(b,k)){e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+12>>2]=x[e+12>>2]+4;fb=e+16|0;mg(KQ(x[e+12>>2]));b=x[Xe(g+12|0)>>2];continue}break}fb=g+16|0;fb=f+16|0}fb=c- -64|0;x[d+4>>2]=j;Tb(a,d+4|0);Tb(a+4|0,d+8|0);Tb(Ab(a),nc(d));x[d>>2]=x[d+4>>2];fb=h+16|0;a=x[d+4>>2];while(1){b=x[d+8>>2];if((b|0)!=(a|0)){b=b-4|0;x[d+8>>2]=b;mg(b);continue}break}a=x[d>>2];if(a){Uz(d);Db(a)}fb=i+32|0}function Dd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-80|0;fb=e;x[a+480180>>2]=b;c=tr(a);sr(e+12|0,c);f=x[e+24>>2];d=a+1074320|0;x[d>>2]=x[e+20>>2];x[d+4>>2]=f;d=x[e+16>>2];x[a+1074312>>2]=x[e+12>>2];x[a+1074316>>2]=d;if(!((b|0)==32|(c|0)!=32)){bg(a+1074312|0,120)}Bu(a+8|0,c);c=a+900380|0;b=1;while(1){d=b&65535;if(d>>>0>z[a+480192>>1]){x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;SA(a,4);d=fb+-64|0;fb=d;b=a+484344|0;Du(b);f=hm(x[b>>2],x[b+4>>2]);c=rA(d+12|0,b);x[31609]=0;S(854,b|0,f|0,c|0);b=x[31609];x[31609]=0;a:{if((b|0)!=1){vk(c);fb=d- -64|0;break a}a=N()|0;vk(c);Q(a|0);p()}OU(a+484360|0);sf(a+1298308|0);sf(a+1298320|0);sf(a+1298332|0);b=e+12|0;Rb(b,0,68);b=pS(b);c=zb(a+1298344|0,b);zb(c+12|0,b+12|0);zb(c+24|0,b+24|0);zb(c+36|0,b+36|0);zb(c+48|0,b+48|0);d=x[b+64>>2];x[c+60>>2]=x[b+60>>2];x[c+64>>2]=d;YA(b);Nc(a+1298412|0);Nc(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}fb=e+80|0;return}d=c+(d<<2)|0;f=x[d>>2];if(f){Db(Mv(f))}x[d>>2]=0;b=b+1|0;continue}}function w3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(lh(a,x[b+8>>2],e)){Vx(b,c,d);return}a:{if(lh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;Sx(x[f>>2],x[f+4>>2],b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){if(x[b+24>>2]!=1){d=1;g=1;if(y[a+8|0]&2){break e}}x[b+44>>2]=3;return}d=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}x[b+44>>2]=d?3:4;if(!g){break b}break a}x[b+44>>2]=3;if(g){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}f=x[a+12>>2];g=a+16|0;Ps(x[g>>2],x[a+20>>2],b,c,d,e);if((f|0)<2){break a}g=g+(f<<3)|0;f=a+24|0;a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}Ps(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}Ps(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}Ps(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function r1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1397771593){nd(b,32);xp(b);c=d+8|0;dk(c,1,a+4|0);e=d+20|0;Cc(e,c);Be(b+43|0,e);tb(e);w[b+30>>1]=y[a+19|0]<<2;Hf(b+30|0,256);w[b+32>>1]=y[a+17|0];Hf(b+32|0,64);w[b+28>>1]=(y[a+47|0]&127)<<2;Hf(b+28|0,256);if(v[a+47|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=y[a+18|0];if(c&16){w[b+34>>1]=z[b+34>>1]|2;c=y[a+18|0]}if(c&32){w[b+34>>1]=z[b+34>>1]|8;c=y[a+18|0]}if(c&64){w[b+34>>1]=z[b+34>>1]|4;c=y[a+18|0]}if(c<<24>>24<0){w[b+34>>1]=z[b+34>>1]|16}c=y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+12>>2]=y[a+64|0]|y[a+65|0]<<8|(y[a+66|0]<<16|y[a+67|0]<<24);x[b+16>>2]=y[a+68|0]|y[a+69|0]<<8|(y[a+70|0]<<16|y[a+71|0]<<24);Uk(b);v[b+38|0]=y[(y[a+79|0]&7)+38064|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=y[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}w[b+34>>1]=c|z[b+34>>1]}c=y[a+72|0]|y[a+73|0]<<8|(y[a+74|0]<<16|y[a+75|0]<<24)}fb=d+32|0;return c|0}function lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+12>>2];i=x[a+8>>2];a:{b:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){f=131112;if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break a}f=262184;if((g|0)==-2&i>>>0<2147483648|g>>>0<4294967294){break a}break b}f=262184;if((g|0)==1&i>>>0>2147483648|g>>>0>1){break a}}f=196648}m=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;n=b+f|0;o=x[a+32>>2];p=x[a+28>>2];while(1){if(d){b=x[e+8>>2];h=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;b=(b>>>16&65520)+n|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];v=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];b=0;while(1){if((b|0)!=2){l=b<<1;f=l+h|0;x[(b<<2)+e>>2]=(((((((D(w[(l|-8)+h>>1],y)+D(w[(l|-12)+h>>1],z)|0)+D(w[(l|-4)+h>>1],v)|0)+D(w[f>>1],u)|0)+D(w[f+4>>1],t)|0)+D(w[f+8>>1],s)|0)+D(w[f+12>>1],r)|0)+D(w[f+16>>1],q)|0)/32768;b=b+1|0;continue}break}k=k+p|0;x[c>>2]=x[c>>2]+D(x[e>>2],k>>12);j=j+o|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],j>>12);Pb(e+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function nO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb+-64|0;fb=e;a:{b:{c:{d:{g=x[a+36>>2];c=x[a+40>>2];e:{if(Ib(g,c)){tc(e+60|0);break e}f=e+24|0;wo(f,a);x[31609]=0;c=R(1056,f|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break d}x[e+60>>2]=c;nf(f);c=x[a+40>>2];g=x[a+36>>2]}f=(k=a+36|0,l=x[e+60>>2],m=Ib(g,c),m?k:l);d=x[a+8>>2];if((d|0)==-1){c=x[f+4>>2];d=il(c);g=0;h=x[f>>2];f=fj(h,c);while(1){if((f|0)==(g|0)){c=d;break c}c=wf(h,g);j=i+C[c>>3];if(j>b){break c}g=g+1|0;i=j;continue}}c=wf(x[f>>2],d);break b}g=N()|0;nf(e+24|0);break a}b=b-i}f=z[c+12>>1];d=x[a+24>>2];x[31609]=0;O(1090,d|0,f|0);d=x[31609];x[31609]=0;if((d|0)!=1){f:{h=x[a+24>>2];f=y[a+64|0];c=NR(UX(e+24|0,b),y[c+16|0],z[c+12>>1],x[c+8>>2]);x[31609]=0;d=x[c+12>>2];x[e+8>>2]=x[c+8>>2];x[e+12>>2]=d;d=x[c+20>>2];x[e+16>>2]=x[c+16>>2];x[e+20>>2]=d;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;c=e+48|0;V(1091,c|0,h|0,(f?7:1)|0,e|0);d=x[31609];x[31609]=0;if((d|0)==1){break f}h=en(x[e+52>>2]);f=v[h+26|0]&1;d=x[(f?h+8|0:h+12|0)>>2];f=z[(f?h+20|0:h+22|0)>>1];b=C[h>>3];Qi(c);c=x[a+24>>2];w[c+1074450>>1]=f;w[c+1074448>>1]=f;x[c+1074428>>2]=d;x[c+1074392>>2]=-2;b=i+b;C[a+16>>3]=b;xl(e+60|0);fb=e- -64|0;return+b}}g=N()|0;xl(e+60|0)}Q(g|0);p()}function Tra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=fb-48|0;fb=d;l=b+8|0;m=b+906300|0;while(1){a:{b:{c:{if(Mb(x[c>>2],x[c+8>>2],9)){kr(c,d+43|0);f=Rg(c);d:{e=y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24);if(!((e|0)==1229999433|(e|0)==1397771593|((e|0)==1297110104|(e|0)==1297110099))){if(Mb(x[c>>2],x[c+8>>2],f)){break d}}v[d+47|0]=j;Ih(c,8);break c}he(d,c,f);f=hc(d+20|0,d);ub(d);e:{if((y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24))==1481001027){g=480280;while(1){if((g|0)==484344){g=1;break a}x[31609]=0;e=R(151,f|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break e}v[g+l|0]=e;g=g+32|0;continue}}if(y[d+43|0]!=70){break b}h=y[d+44|0];k=(h|0)==88;f:{if(!k){if((h-48&255)>>>0>9){break b}e=v[d+45|0];if((e|0)>47){break f}break b}e=v[d+45|0];if((e|0)<48){break b}}if(e>>>0>57){break b}i=v[d+46|0];if((i|0)<48|(i|0)>57){break b}g=1;e=((i&255)+(k?-528:D(h,100)-5328|0)|0)+D(e&255,10)&65535;if(e>>>0>249){break a}x[31609]=0;O(450,f|0,$d(m,e)|0);e=x[31609];x[31609]=0;if((e|0)!=1){break a}}a=N()|0;ub(f);Q(a|0);p()}v[d+47|0]=j}zD(a,g,d+47|0);fb=d+48|0;return}if((y[d+43|0]|y[d+44|0]<<8|(y[d+45|0]<<16|y[d+46|0]<<24))!=1430540109){break a}x[b+1074308>>2]=0;j=1}ub(f);continue}}function Baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Xf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){h=x[c+20>>2];if(h>>>0<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(e>>>0>x[c+24>>2]-i>>>0){break b}l=b+12|0;m=x[c+16>>2];n=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}o=(D(b,g)<<3)+n|0;q=(D(b+i|0,h)<<1)+m|0;d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{s=a,t=+(vn(Fe(Jg(C[(d<<3)+o>>3])*134217728))+rd(Yt(l),21)|0)*7.450580596923828e-9,C[s+24>>3]=t;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;r=(d<<1)+q|0;j=Fe(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}s=r,u=gd(k),w[s>>1]=u;d=d+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=c- -64|0}function Via(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0);g=w[d>>1];h=w[d+2>>1];a:{if((g|0)>(h|0)){break a}k=x[b>>2];i=oc(k,x[b+4>>2]);if(!i){break a}j=w[e>>1];if((g|0)>(j|0)|(h|0)<(j|0)|(i-1&65535)>>>0>(h-j&65535)>>>0|A[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(i|0)){break b}j=yb(k,f);f=f+1|0;if(!(B[j>>2]<E(0))){continue}break}return 0}f=0;l=B[c>>2];if(l<=E(0)){break a}w[a+28>>1]=g;w[a>>1]=1;m=a,n=XQ(i),w[m+30>>1]=n;B[a+32>>2]=F(l);Cl(a+4|0,(h-g|0)+1|0);c=wb(x[b>>2]);h=wb(x[b+4>>2]);f=Ek(wb(x[a+4>>2]),w[e>>1]-w[d>>1]|0);g=fb-16|0;fb=g;b=fb-32|0;fb=b;fd(b+24|0,c,h);cD(b+16|0,x[b+24>>2],x[b+28>>2],f);c=lA(c,x[b+16>>2]);m=b,n=VQ(f,x[b+20>>2]),x[m+12>>2]=n;qc(g+8|0,c,b+12|0);fb=b+32|0;fb=g+16|0;c=x[a+4>>2];g=w[a+30>>1];h=w[a+28>>1];b=w[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;i=yb(c,b+g|0);m=yb(c,b),o=E(B[i>>2]/B[a+32>>2]),B[m>>2]=o;b=w[e>>1];continue}else{c=w[a+30>>1];e=w[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=x[a+4>>2];d=w[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=yb(b,f-h|0);m=yb(b,f-e|0),o=E(B[a+32>>2]*B[g>>2]),B[m>>2]=o;f=f+1|0;continue}else{xq(a)}break}}break}f=1}return f|0}function Kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Xf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[c+20>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(e>>>0>x[c+24>>2]-h>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}n=(D(b,g)<<3)+m|0;d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{q=a,r=+(vn(Fe(Jg(C[(d<<3)+n>>3])*134217728))+rd(Yt(k),21)|0)*7.450580596923828e-9,C[q+24>>3]=r;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;o=(d<<2)+l|0;i=Fe(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}q=(x[o>>2]+(h<<1)|0)+(b<<1)|0,s=gd(j),w[q>>1]=s;d=d+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=c- -64|0}function Ona(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;c=wb(x[a>>2]);x[g+44>>2]=c;k=wb(x[a+4>>2]);while(1){if(Ib(c,k)){i=g+24|0;a=wb(x[c>>2]);l=wb(x[c+4>>2]);c=$W(g+4|0,b);v[c+16|0]=y[b+16|0];x[c+12>>2]=x[b+12>>2];h=fb-16|0;fb=h;x[h+12>>2]=a;while(1){if(Ib(a,l)){f=fb-16|0;fb=f;if(!(y[a+5|0]|y[a+3|0]!=4)){e=f+8|0;Jb(e,x[c>>2],z[c+14>>1]);kf(e,0);v[a+3|0]=0}e=y[a+2|0];if(!(y[a+4|0]|(e|0)!=11)){d=f+8|0;Jb(d,x[c>>2],z[c+14>>1]);kf(d,0);v[a+2|0]=0;e=0}a:{b:{if(!y[a|0]){Jb(f+8|0,x[c>>2],z[c+14>>1]);e=y[a+2|0];d=y[a+3|0];if(!Gb(x[x[f+8>>2]>>2],x[f+12>>2])){break b}if(!((e|0)==11|d)){v[a+5|0]=0;d=4;v[a+3|0]=4;break a}if((d|0)==4|e){break a}v[a+4|0]=0;v[a+2|0]=11;break a}d=y[a+3|0]}j=f+8|0;Jb(j,x[c>>2],z[c+14>>1]);kf(j,(d|0)==4|(e|0)==11);d=y[a+3|0]}c:{d:{e:{if(!(!y[c+16|0]|d)){v[a+3|0]=17;d=125;e=0;break e}e=0;f:{switch(d-16|0){case 1:break d;case 0:break f;default:break c}}if(y[a+5|0]){break c}d=6;e=1}v[a+5|0]=d}v[c+16|0]=e}a=z[c+14>>1]+1|0;w[c+14>>1]=z[c+12>>1]>(a&65535)>>>0?a:0;fb=f+16|0;a=x[tg(h+12|0)>>2];continue}break}a=DC(i,c);v[a+16|0]=y[c+16|0];x[a+12>>2]=x[c+12>>2];fb=h+16|0;tf(i);tf(c);c=x[Ul(g+44|0)>>2];continue}else{fb=g+48|0}break}}function $ja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=fb-16|0;fb=i;d=x[b+1298304>>2];if(!Ed(d)){c=fb-16|0;fb=c;d=Ec(12);x[31609]=0;g=R(951,d|0)|0;e=x[31609];x[31609]=0;a:{if((e|0)!=1){d=yf(c+12|0,g);fb=c+16|0;c=x[d>>2];break a}a=N()|0;Db(d);Q(a|0);p()}x[i+12>>2]=c;c=b+1298304|0;d=i+12|0;hS(c,ne(d));XA(d);d=x[c>>2]}g=fb-32|0;fb=g;c=g+8|0;XR(c,a);x[31609]=0;O(952,g+20|0,c|0);e=x[31609];x[31609]=0;b:{c:{if((e|0)!=1){tb(c);e=wb(x[d>>2]);x[g+4>>2]=e;l=wb(x[d+4>>2]);d=0;while(1){d:{if(!Ib(e,l)){e:{if(!d){break e}f=x[d+4>>2];if(!f){break e}x[31609]=0;b=U(f|0,d|0,b|0,a|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}if(b){f=x[d>>2];x[b+4>>2]=f;if(f){x[f+8>>2]=b}x[d>>2]=b}x[a>>2]=b}tb(g+20|0);fb=g+32|0;break b}j=0;c=x[e>>2];if(x[c+32>>2]==x[a+16>>2]){j=x[c+36>>2]==x[a+20>>2]}x[31609]=0;k=g+8|0;O(953,k|0,c+8|0);c=x[31609];x[31609]=0;if((c|0)!=1){h=fb-16|0;fb=h;fe(h+8|0,k);fe(h,g+20|0);c=zR(x[h+8>>2],x[h+12>>2],x[h>>2],x[h+4>>2]);fb=h+16|0;tb(k);f:{if(!(!j|(c|0)!=0)){d=x[e>>2];f=3;break f}if((f|0)<2&j){d=x[e>>2];f=2;break f}c=!c&(f|0)<=0;d=c?x[e>>2]:d;f=c?1:f}e=x[Xe(g+4|0)>>2];continue}}break}e=N()|0;tb(g+20|0);break c}e=N()|0;tb(g+8|0)}Q(e|0);p()}fb=i+16|0}
function dJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){b=x[a+12>>2];if(!(d>>>0<=b>>>0|f>>>0>=g>>>0)){i=v[b|0];c=i&255;c:{if((i|0)>=0){i=1;break c}k=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-b|0)<2){break b}i=y[b+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-b|0)<3){break b}j=y[b+2|0];i=y[b+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((j&192)!=128){break a}c=j&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-b|0)<4){break b}l=y[b+3|0];m=y[b+2|0];j=y[b+1|0];f:{g:{switch(c-240|0){case 0:if((j+112&255)>>>0<48){break f}break a;case 4:if((j&240)==128){break f}break a;default:break g}}if((j&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(j&63)<<12));if(c>>>0>1114111){break a}}x[f>>2]=c;x[a+12>>2]=b+i;f=x[a+8>>2]+4|0;x[a+8>>2]=f;continue}break}k=b>>>0<d>>>0;break a}k=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return k|0}function rqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;nd(b,0);xp(b);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=Te(Ai(+(f+1408|0)/1536)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[Qb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=y[a+6|0]|y[a+7|0]<<8;if(d>>>0<=256){w[b+28>>1]=d;w[b+34>>1]=z[b+34>>1]|32}x[b>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+4>>2]=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);x[b+8>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);d=y[a+20|0]|y[a+21|0]<<8;if(d&16){w[b+34>>1]=z[b+34>>1]|2;d=y[a+20|0]|y[a+21|0]<<8}if(d&32){w[b+34>>1]=z[b+34>>1]|4;d=y[a+20|0]|y[a+21|0]<<8}if(d&256){w[b+34>>1]=z[b+34>>1]|8;d=y[a+20|0]|y[a+21|0]<<8}if(d&512){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+38064|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[Qb(e+13|0,e+12|0)|0],w[g+32>>1]=h}x[b+12>>2]=y[a+27|0]|y[a+28|0]<<8|(y[a+29|0]<<16|y[a+30|0]<<24);x[b+16>>2]=y[a+31|0]|y[a+32|0]<<8|(y[a+33|0]<<16|y[a+34|0]<<24);fb=e+16|0}function lka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=fb-16|0;fb=l;x[l+12>>2]=b;q=Pf(a);while(1){if(Zg(b,c)){e=x[vb(l+8|0,q)>>2];j=ud(b);o=fb-16|0;fb=o;p=0;m=fb-16|0;fb=m;h=fb-32|0;fb=h;f=h+28|0;d=h+24|0;k=fb-16|0;fb=k;a:{b:{b=e;if(!mc(b,x[vb(k+12|0,pg(a))>>2])){e=y[j|0];i=x[j+4>>2];g=ud(b);n=y[g|0];g=x[g+4>>2];if(!Bo(e,i,n,g)){break b}}x[k+12>>2]=b;c:{if(!mc(b,x[vb(k+8|0,wb(x[a>>2]))>>2])){d=x[LB(k+12|0)>>2];e=ud(d);g=y[e|0];n=x[e+4>>2];e=y[j|0];i=x[j+4>>2];if(Bo(g,n,e,i)){break c}b=fB(a,f,e,i);break a}d=b}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}if(Bo(n,g,e,i)){d:{d=JB(b);if(!mc(d,x[vb(k+12|0,pg(a))>>2])){e=y[j|0];i=x[j+4>>2];g=ud(d);if(!Bo(e,i,y[g|0],x[g+4>>2])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=fB(a,f,e,i);break a}x[f>>2]=b;x[d>>2]=b;b=d}fb=k+16|0;d=x[b>>2];if(!d){d=fb-16|0;fb=d;f=gc(a);e=h+12|0;f=Dh(e,Ec(28),Og(d+8|0,f));xC(x[f>>2]+16|0,j);r=gc(f),s=1,v[r+4|0]=s;fb=d+16|0;$g(a,x[h+28>>2],b,x[h+12>>2]);d=ne(e);Ik(e);p=1}_g(m+8|0,x[vb(h+12|0,d)>>2],p);fb=h+32|0;fb=m+16|0;vb(o+12|0,x[m+8>>2]);fb=o+16|0;b=x[ah(l+12|0)>>2];continue}else{fb=l+16|0}break}}function mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;f=fb-16|0;fb=f;g=x[a+12>>2];h=x[a+8>>2];a:{b:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){e=131112;if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break a}e=262184;if((g|0)==-2&h>>>0<2147483648|g>>>0<4294967294){break a}break b}e=262184;if((g|0)==1&h>>>0>2147483648|g>>>0>1){break a}}e=196648}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];k=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=k;k=b+e|0;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[f+8>>2];o=(((x[f+12>>2]&2147483647)<<1|b>>>31)&-2)+l|0;b=(b>>>16&65520)+k|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];b=0;while(1){if((b|0)!=2){e=b+o|0;x[(b<<2)+f>>2]=(((((((D(v[e-4|0],y)+D(v[e-6|0],z)|0)+D(v[e-2|0],u)|0)+D(v[e|0],t)|0)+D(v[e+2|0],s)|0)+D(v[e+4|0],r)|0)+D(v[e+6|0],q)|0)+D(v[e+8|0],p)<<8)/32768;b=b+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[f>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],i>>12);Pb(f+8|0,h,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=f+16|0}function Cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=0;i=fb-16|0;fb=i;if(ti(a+44|0)){n=x[a+44>>2];j=Hc(n,0);k=Hc(n,1);n=x[a+56>>2];t=Hc(n,0);n=Hc(n,1);u=B[yb(a+4208|0,1)>>2];x[i+12>>2]=d;s=x[a+4220>>2];q=E(E(1)/E(s>>>0));v=x[a+4216>>2];o=d;f=n;g=t;while(1){if(o){h=x[a+4224>>2];a:{if(s>>>0>h>>>0){x[i+8>>2]=s-h;r=x[Hb(i+12|0,i+8|0)>>2];m=0;b:{if(u<E(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break b}p=E(h>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){B[g>>2]=B[j>>2];B[f>>2]=B[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;x[i+12>>2]=o;break a}m=v-h|0;x[i+4>>2]=m;l=x[Hb(i+12|0,i+4|0)>>2];e=0;c:{if(u<E(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break c}p=E(m>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){x[g>>2]=0;x[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;x[i+12>>2]=o;e=h+l|0;l=e>>>0<v>>>0?e:0}x[a+4224>>2]=l;continue}else{Ii(a,b,c,t,n,d)}break}}fb=i+16|0}function lqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;x[g+44>>2]=0;d=g+44|0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){qD(d);break a}mh(c+8|0,d);sd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0;b:{if(!kV(d)){break b}e=y[g+46|0];f=y[g+47|0];d=y[g+45|0];v[a+4|0]=1;h=d>>>3&3;c=(h|0)!=3;d=(d^-1)>>>1&3;f=f>>>0<192;w[a+2>>1]=z[(D(c,6)+(d<<1)|0)+25736>>1]<<f;i=D(D(y[(d+D(c,3)|0)+25512|0],z[((D(c,90)+D(d,30)|0)+(e>>>3&30)|0)+25520>>1]),1e3);e=e>>>1|0;e=((i>>>0)/z[(D(h,6)+(e&6)|0)+25712>>1]|0)+(e&1)<<(!d<<1);w[a>>1]=e;d=y[(f|c<<1)+25748|0];if(d+8>>>0>(e&65535)>>>0){break b}e=Rb(g,0,36);c=fb-32|0;fb=c;x[c+28>>2]=d+4;x[c+8>>2]=36;h=x[b>>2];i=x[b+8>>2];f=x[Hb(c+28|0,c+8|0)>>2];if(!Mb(h,i,f)){f=jf(b)}h=c+8|0;bs(h,e);i=Zb(c+16|0,x[c+8>>2],f);kc(c,x[b>>2],x[b+8>>2],x[i>>2],x[i+4>>2]);bs(h,e);Rb(x[c+8>>2]+f|0,0,36-f|0);Vb(b,x[c+28>>2]);fb=c+32|0;b=2;c=d>>>0<=2?2:d;while(1){if((b|0)!=(c|0)){f=b+e|0;b=b+1|0;if(!y[f|0]){continue}break b}break}b=d+e|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1868983881){b=1}else{b=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))==1735289176}v[a+5|0]=b}fb=g+48|0;return a|0}function f3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-2096|0;fb=d;vu(d+48|0);a:{b:{c:{if(Ep(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){a=dc(8);x[31609]=0;c=P(36,d+36|0,10469)|0;b=x[31609];x[31609]=0;if((b|0)!=1){sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;lc(a);break c}g=iM(c);if(g){b=fM(c)}else{b=0}x[d+24>>2]=b;x[d+28>>2]=0;h=c+16|0;b=2048;d:{while(1){e:{if(!b){break e}if(!hM(x[x[x[c>>2]-12>>2]+h>>2])){break e}e=x[x[x[vj(c,(d+48|0)+f|0,b)>>2]-12>>2]+h>>2];if(Ep(e)){a=dc(8);x[31609]=0;c=P(36,d+36|0,10469)|0;b=x[31609];x[31609]=0;if((b|0)==1){break d}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}f:{if(TF(e)){break f}if(!nk(e)){break f}a=dc(8);x[31609]=0;c=P(36,d+36|0,10469)|0;b=x[31609];x[31609]=0;if((b|0)!=1){sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;lc(a);break c}e=x[c+4>>2];b=b-e|0;f=e+f|0;continue}break}b=Zb(d+16|0,d+48|0,f);c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;a=Au(a,d+8|0,g?d+24|0:0);fb=d+2096|0;break a}b=N()|0;lc(a)}Q(b|0)}p()}return a|0}function UR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;c=Xb(x[a+484360>>2],y[a+484376|0]);d=$c(x[c>>2],x[c+4>>2]);a:{while(1){f=b&65535;if(f>>>0>=d>>>0){break a}if(!Wi(c,f)){b=b+1|0;continue}break}f=a+1074312|0;d=1074992;b:{while(1){c:{if((d|0)==1298224){TR(a);if(b&65535){break c}b=0;c=a+1074992|0;while(1){if((b|0)==256){Mo(a+1298264|0,1);x[a+1074456>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;sB(a+1074376|0);w[a+1074450>>1]=0;x[a+1074392>>2]=-2;x[a+1074428>>2]=0;x[a+1074432>>2]=0;x[a+1074396>>2]=0;x[a+1074400>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0}else{Qo(c+D(b,872)|0,a,b&65535,67108864);b=b+1|0;continue}break}break b}c=a+d|0;v[c+797|0]=0;x[c+700>>2]=0;v[c+841|0]=0;v[c+805|0]=0;x[c+708>>2]=0;v[c+821|0]=0;x[c+764>>2]=0;v[c+819|0]=0;v[c+820|0]=0;Jb(e+8|0,f,23);if(Gb(x[x[e+8>>2]>>2],x[e+12>>2])){v[c+807|0]=1;v[c+808|0]=0}v[c+839|0]=0;d=d+872|0;continue}break}w[a+1074450>>1]=b;w[a+1074446>>1]=0;x[a+1074424>>2]=0;x[a+1074428>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;x[a+1074396>>2]=0;x[a+1074400>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}fb=e+16|0}function Mla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Hg(i,j,k);m=hb;h=x[a+76>>2];fg(b,g,uf(i,j,d),hb);n=hb>>>0>h>>>0?d:0}h=a+112|0;s=x[a+24>>2];t=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;while(1){if(d){g=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;n=n-1|0;f=n;l=f?l:0;m=f?m:0;d=d-1|0;p=(((g&2147483647)<<1|b>>>31)&-2)+q|0;g=k;a:{b:while(1){c:{if((g|0)<=0){Pb(h,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break a}f=x[e+8>>2];o=((x[e+12>>2]&2147483647)<<1|f>>>31)&-2;f=0;b=0;break c}f=x[e+8>>2];o=((x[e+12>>2]&2147483647)<<1|f>>>31)&-2;b=0;f=0;while(1)if((b|0)==2){ce(h,f>>>3<<16>>16);be(h,4);Pb(e+8|0,l,m);g=g-1|0;continue b}else{f=(v[(b|o)+p|0]<<8)+f|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){f=(v[(b|o)+p|0]<<8)+f|0;b=b+1|0;continue}break}ce(h,f>>>3<<16>>16);be(h,g);x[h>>2]=x[h>>2];x[h+4>>2]=0}f=x[c>>2];b=Fg(h,r);x[c>>2]=f+D(b,t);x[c+4>>2]=x[c+4>>2]+D(b,s);Pb(e,i,j);c=c+8|0;continue}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function Hla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];n=x[a+128>>2];if(n){o=Hg(l,m,n);p=hb;g=x[a+76>>2];fg(b,f,uf(l,m,d),hb);k=hb>>>0>g>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;k=k-1|0;o=k?o:0;p=k?p:0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;ce(g,(w[((h&2147483646)<<1)+f>>1]+w[f+(h<<1|2)>>1]|0)/8<<16>>16);be(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}f=x[a+32>>2];h=x[c>>2];b=Fg(g,r);j=x[a+28>>2]+j|0;x[c>>2]=D(b,j>>12)+h;i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(e,l,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue a}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;ce(g,(w[((h&2147483646)<<1)+f>>1]+w[f+(h<<1|2)>>1]|0)/8<<16>>16);be(g,4);Pb(e+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function iM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=f+8|0;xz(d,a);b=fb-96|0;fb=b;a=x[d+4>>2];ig(x[x[a>>2]-12>>2]+a|0,0);ae(b+80|0,x[d+4>>2]);a:{b:{e=x[d+4>>2];a=x[x[e>>2]-12>>2]+e|0;if(!nk(x[a+16>>2])){c=ai(b- -64|0,-1,-1);if(!bo(x[b+88>>2],x[b+92>>2],x[c+8>>2],x[c+12>>2])){break b}}ig(a,0);break a}Ci(e,0,0,0);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(nk(x[a+16>>2])){ig(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+8>>2]=x[b+88>>2];x[b+12>>2]=a;a=x[b+84>>2];x[b>>2]=x[b+80>>2];x[b+4>>2]=a;Tm(c,b);a=x[d+4>>2];ig(x[x[a>>2]-12>>2]+a|0,0);break a}Ci(c,0,0,2);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(nk(x[a+16>>2])){ig(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+24>>2]=x[b+88>>2];x[b+28>>2]=a;a=x[b+84>>2];x[b+16>>2]=x[b+80>>2];x[b+20>>2]=a;Tm(c,b+16|0);a=x[d+4>>2];ig(x[x[a>>2]-12>>2]+a|0,0);break a}ae(b- -64|0,c);e=x[d+4>>2];a=e+x[x[e>>2]-12>>2]|0;c:{if(!nk(x[a+16>>2])){c=ai(b+48|0,-1,-1);g=1;if(!bo(x[b+72>>2],x[b+76>>2],x[c+8>>2],x[c+12>>2])){break c}}ig(a,0);e=x[d+4>>2];g=0}a=x[b+92>>2];x[b+40>>2]=x[b+88>>2];x[b+44>>2]=a;a=x[b+84>>2];x[b+32>>2]=x[b+80>>2];x[b+36>>2]=a;Tm(e,b+32|0);a=x[d+4>>2];ig(x[x[a>>2]-12>>2]+a|0,0)}fb=b+96|0;fb=f+16|0;return g|0}function wsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;nd(b,32);fp(b);f=b,g=ze((y[a+50|0]|y[a+51|0]<<8)<<16>>16)>>>2|0,w[f+32>>1]=g;if((ze((y[a+32|0]|y[a+33|0]<<8)<<16>>16)|0)>0){w[b+34>>1]=z[b+34>>1]|32;c=ze((y[a+32|0]|y[a+33|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;f=b,g=Bc(Cua(d,d>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}c=$b(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24));x[b>>2]=c;d=$b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24));x[b+4>>2]=d;e=$b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))+$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))|0;x[b+8>>2]=e;if((Bb(y[a+34|0]|y[a+35|0]<<8)|0)==16){x[b+8>>2]=e>>>1;x[b+4>>2]=d>>>1;x[b>>2]=c>>>1}a:{b:{c:{if($b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))){c=z[b+34>>1];break c}c=z[b+34>>1];if($b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))>>>0<3){break b}}c=c|2;break a}c=c&65533}w[b+34>>1]=c;f=b,g=c&65531|Bb(y[a+30|0]|y[a+31|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=Bb(y[a+36|0]|y[a+37|0]<<8)<<1,x[f+24>>2]=g;c=ze((y[a+52|0]|y[a+53|0]<<8)<<16>>16);if(c){_l(b,+(c|0)/96);c=ze((y[a+52|0]|y[a+53|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function Vla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;h=fb-16|0;fb=h;o=x[a+24>>2];p=x[a+20>>2];e=x[a+48>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];v=m>>31;j=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Aua(l,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Aua(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=n;g=Aua(e,e>>31,m,v);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Sc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(h+8|0,j,y);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(x[a+4>>2]!=x[Ab(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+32;HS(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+32;jc(c);fb=d+16|0;return}j=fb-32|0;fb=j;c=Ab(a);c=iv(j+12|0,Wq(a,Mg(x[a>>2],x[a+4>>2])+1|0),Mg(x[a>>2],x[a+4>>2]),c);HS(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;h=fb-16|0;fb=h;b=vb(h+12|0,x[a+4>>2]);e=vb(h+8|0,x[a>>2]);f=x[vb(h+4|0,x[c+4>>2])>>2];i=fb-16|0;fb=i;d=fb-32|0;fb=d;fd(d+24|0,x[b>>2],x[e>>2]);k=d+16|0;b=x[d+24>>2];l=x[d+28>>2];g=fb-16|0;fb=g;x[g+8>>2]=f;x[g+12>>2]=b;while(1){if(Fd(b,l)){b=en(b);e=en(x[g+8>>2]);f=y[b+23|0]|y[b+24|0]<<8|(y[b+25|0]<<16|y[b+26|0]<<24);v[e+23|0]=f;v[e+24|0]=f>>>8;v[e+25|0]=f>>>16;v[e+26|0]=f>>>24;f=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=f;f=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;b=Uo(g+12|0);Uo(g+8|0);b=x[b>>2];continue}break}qc(k,b,g+8|0);fb=g+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];qc(i+8|0,b,d+12|0);fb=d+32|0;fb=i+16|0;x[c+4>>2]=x[i+12>>2];Tb(a,c+4|0);Tb(a+4|0,c+8|0);Tb(Ab(a),nc(c));x[c>>2]=x[c+4>>2];fb=h+16|0;KV(c);fb=j+32|0}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;if(!y[a+4242|0]){_z(a);a:{if(!y[a+4240|0]){break a}e=PA(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;qu(a)}f=a+4256|0;b:{if(y[a+4244|0]){if(C[f>>3]>1){x[f>>2]=0;x[f+4>>2]=1072693248}break b}i=(x[a+4232>>2]&-2)!=4;e=C[f>>3];c:{if(F(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Yz(a);e=C[a+4256>>3]}C[f>>3]=e-+(g|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=Pi(C[f>>3]*6.283185307179586);break d;case 1:e=F(C[f>>3]+-.5)*-4+1;break d;case 2:e=C[f>>3];e=e+e+-1;break d;case 3:e=C[f>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=C[a+4280>>3]*e+C[a+4272>>3]*(1-e)}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];AT(h+8|0,1);g=xj(a);f:{if(!g){break f}f=x[a+4236>>2];if(y[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|Zl(C[h+8>>3]*127)<<16,j=x[x[g>>2]+68>>2],ib[j](k|0,l|0)|0;break f}ib[x[x[g>>2]+44>>2]](g,f,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4264>>3]*+(d>>>0)+C[a+4256>>3]}g=a;a=x[a+44>>2];Ii(g,b,c,Hc(a,0),Hc(a,1),d);fb=h+16|0}function RY(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;a:{if(b>>>0>=22){v[d+14|0]=0;ee(a,0,d+14|0);break a}e=y[b+25072|0];b:{c:{switch(b-8|0){case 0:v[d+15|0]=c<<1;break b;case 4:v[d+15|0]=c+1>>>1;break b;case 5:v[d+15|0]=D(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:v[d+13|0]=c&15;v[d+12|0]=14;f=d,g=y[Qb(d+13|0,d+12|0)|0]<<4|15,v[f+15|0]=g;e=29;break b;case 1:v[d+11|0]=c&15;v[d+10|0]=14;f=d,g=y[Qb(d+11|0,d+10|0)|0]|240,v[f+15|0]=g;e=29;break b;case 3:v[d+15|0]=c&15|48;break b;case 4:v[d+15|0]=c<<4^128;e=35;break b;case 5:v[d+15|0]=c&15|176;break b;case 6:v[d+15|0]=c&15|64;break b;case 8:e=15;v[d+15|0]=c&15;break b;case 9:v[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:v[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=(b>>>0>=15?15:b)<<4;break b}if(c>>>0<=239){v[d+15|0]=c<<2&48|15;break b}v[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=b>>>0>=15?15:b;break b}if(c>>>0>239){break b}v[d+15|0]=c>>>2&3|240}ee(a,e,d+15|0)}fb=d+16|0}function k7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-448|0;fb=a;x[a+440>>2]=c;x[a+444>>2]=b;x[a+20>>2]=1274;i=a+20|0;b=De(a+24|0,a+32|0,i);j=a+16|0;cd(j,x[e+28>>2]);x[31609]=0;h=R(1252,x[a+16>>2])|0;k=x[31609];x[31609]=0;if((k|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31609]=0;c=na(1283,a+444|0,c|0,d|0,j|0,e|0,f|0,a+15|0,h|0,b|0,i|0,a+432|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(vd(y[g+11|0])){yd(x[g>>2],0);Bd(g,0);break d}yd(g,0);Ne(g,0)}if(y[a+15|0]){x[31609]=0;c=P(1270,h|0,45)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}x[31609]=0;O(35,g|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}}x[31609]=0;d=P(1270,h|0,48)|0;c=x[31609];x[31609]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-4|0;c=x[b>>2];while(1){if(!((d|0)!=x[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}x[31609]=0;U(1288,g|0,c|0,e|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break c}break a}x[31609]=0;c=P(1257,a+444|0,a+440|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+444>>2];_b(a+16|0);Lc(b);fb=a+448|0;return c|0}}}c=N()|0;_b(a+16|0);Lc(b);Q(c|0);p()}function Wla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=fb-16|0;fb=h;o=x[a+24>>2];p=x[a+20>>2];e=x[a+48>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];y=m>>31;j=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Aua(l,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Aua(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=n;g=Aua(e,e>>31,m,y);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Sc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Pb(h+8|0,j,z);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;i=x[a+40>>2];j=x[a+36>>2];f=x[a+48>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];n=x[a+68>>2];u=n>>31;o=x[a+64>>2];v=o>>31;p=x[a+60>>2];y=p>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Yb(e,-16777216,16776704);k=Aua(o,v,e,e>>31);l=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38082>>1])+D(w[h-2>>1],w[e+38080>>1])|0)+D(w[h+2>>1],w[e+38084>>1])|0)+D(w[h+4>>1],w[e+38086>>1])|0)/16384<<8;e=h;e=Aua(e,e>>31,p,y);k=e+k|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;f=Yb(f,-16777216,16776704);e=Aua(n,u,f,f>>31);l=e+k|0;f=hb+m|0;f=e>>>0>l>>>0?f+1|0:f;e=l+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Sc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Pb(g+8|0,z,A);e=e-(h&t)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=g+16|0}function Aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Xf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){h=x[b+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}i=x[b+28>>2];if(d>>>0>x[b+24>>2]-i>>>0){break b}l=x[b+16>>2];m=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}n=(D(f,g)<<3)+m|0;o=(D(f+i|0,h)<<1)+l|0;c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c<<3)+n>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=(c<<1)+o|0;j=Fe(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}r=q,s=gd(k),w[r>>1]=s;c=c+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=b- -64|0}function xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;h=fb-16|0;fb=h;i=x[a+40>>2];j=x[a+36>>2];e=x[a+48>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];l=x[a+68>>2];t=l>>31;m=x[a+64>>2];u=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Aua(m,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Aua(l,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;o=(((D(v[g|0],w[e+38082>>1])+D(v[g-1|0],w[e+38080>>1])|0)+D(v[g+1|0],w[e+38084>>1])|0)+D(v[g+2|0],w[e+38086>>1])<<8)/16384<<8;e=o;g=Aua(e,e>>31,n,y);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Sc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,z,A);f=f-(s&o)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=fb-16|0;fb=e;g=x[a+12>>2];i=x[a+8>>2];a:{b:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){f=131112;if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break a}f=262184;if((g|0)==-2&i>>>0<2147483648|g>>>0<4294967294){break a}break b}f=262184;if((g|0)==1&i>>>0>2147483648|g>>>0>1){break a}}f=196648}k=x[a+16>>2];l=x[a+24>>2];m=x[a+20>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;n=b+f|0;while(1){if(d){b=x[e+8>>2];h=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(b>>>16&65520)+n|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];v=w[b>>1];b=0;while(1){if((b|0)!=2){j=b<<1;f=j+h|0;x[(b<<2)+e>>2]=(((((((D(w[(j|-8)+h>>1],u)+D(w[(j|-12)+h>>1],v)|0)+D(w[(j|-4)+h>>1],t)|0)+D(w[f>>1],s)|0)+D(w[f+4>>1],r)|0)+D(w[f+8>>1],q)|0)+D(w[f+12>>1],p)|0)+D(w[f+16>>1],o)|0)/32768;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],m);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],l);Pb(e+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function lT(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=x[b+64>>2];a:{b:{g=x[b+60>>2];f=z[b+68>>1];if(!((g|0)==-1&(f|0)==65535)){c:{d:{if((e|0)==-1){break d}e=a+1074312|0;if(Ob(e,68)){break d}f=(f|0)!=65535;if(h=Ob(e,103),i=0,j=f,j?h:i){break c}if(h=Ob(e,49),i=0,j=f,j?h:i){break c}e=x[b+64>>2];break b}if((f|0)!=65535){break c}w[b+68>>1]=z[b+72>>1]+1}if((g|0)==-1){x[b+60>>2]=0}f=$c(x[c>>2],x[c+4>>2]);e=z[b+68>>1];if(f>>>0<=e>>>0){e=z[c+28>>1];w[b+68>>1]=e}e:{if(z[b+72>>1]==(e&65535)){break e}c=a+1074312|0;if(Ob(c,26)){break e}if(Ob(c,68)|x[a+480180>>2]==1){break e}c=b+616|0;f=z[a+480188>>1];e=0;while(1){if((e|0)==(f|0)){break e}v[(c+D(e,872)|0)+841|0]=0;e=e+1|0;continue}}x[b+52>>2]=x[b+60>>2];if(d){e=1;if(y[a+480208|0]&32){break a}}w[b+74>>1]=z[b+68>>1];return 1}if((e|0)!=-1){break b}e=0;break a}x[b+52>>2]=e;w[b+74>>1]=z[b+72>>1];f:{if(!x[b+20>>2]){break f}c=x[a+480180>>2];if((c|0)==32){if(Ob(a+1074312|0,103)){break f}c=x[a+480180>>2]}if((c|0)==2){break f}x[b+52>>2]=x[b+52>>2]+1}e=0;if(A[b+64>>2]<A[Wb(x[a+484344>>2],z[b+70>>1])+12>>2]){break a}x[b+52>>2]=0;w[b+74>>1]=z[b+74>>1]+1;return 0}return e}function oI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;g=y[a|0];a:{if(!g){f=a;break a}f=a;b:{while(1){if(!fl(g<<24>>24)){break b}g=y[f+1|0];f=f+1|0;if(g){continue}break}break a}c:{h=g&255;switch(h-43|0){case 0:case 2:break c;default:break a}}j=(h|0)==45?-1:0;f=f+1|0}d:{if(!((c|16)!=16|y[f|0]!=48)){n=1;if((y[f+1|0]&223)==88){f=f+2|0;m=16;break d}f=f+1|0;m=c?c:8;break d}m=c?c:10}c=0;while(1){e:{h=y[f|0];g=h-48|0;f:{if((g&255)>>>0<10){break f}if((h-97&255)>>>0<=25){g=h-87|0;break f}if((h-65&255)>>>0>25){break e}g=h-55|0}g=g&255;if((g|0)>=(m|0)){break e}Mf(l,m,0,0,0,k,i,0,0);h=1;g:{if(x[l+8>>2]|x[l+12>>2]){break g}o=Aua(k,i,m,0);p=hb;if((p|0)==-1&(g^-1)>>>0<o>>>0){break g}i=p;k=g+o|0;i=k>>>0<g>>>0?i+1|0:i;n=1;h=c}f=f+1|0;c=h;continue}break}if(b){x[b>>2]=n?f:a}h:{i:{j:{if(c){x[31484]=68;a=d&1;j=a?0:j;k=d;i=e;break j}if((e|0)==(i|0)&d>>>0>k>>>0|e>>>0>i>>>0){break i}a=d&1}if(!(a|j)){x[31484]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(i|0)&d>>>0>=k>>>0|e>>>0>i>>>0){break i}x[31484]=68;break h}a=j^k;d=a-j|0;b=j>>31;e=(b^i)-((a>>>0<j>>>0)+b|0)|0}fb=l+16|0;hb=e;return d}function Jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Xf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){if(A[b+20>>2]<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}h=x[b+28>>2];if(d>>>0>x[b+24>>2]-h>>>0){break b}k=x[b+16>>2];l=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}m=(D(f,g)<<3)+l|0;c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c<<3)+m>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;n=(c<<2)+k|0;i=Fe(C[Yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}o=(x[n>>2]+(h<<1)|0)+(f<<1)|0,q=gd(j),w[o>>1]=q;c=c+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=a+32|0;fb=b- -64|0}function Ko(a,b,c){var d=0,e=0,f=0,g=0;f=a+1074312|0;d=Ob(f,96);x[b+660>>2]=(d?0:x[b+660>>2])+c;e=x[a+480180>>2];d=x[b+84>>2];if(!(!(e&18)|d>>>0>c>>>0|(!(y[b+88|0]&2)|!d))){g=c;c=x[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&(e|0)==16384)|0;a:{b:{if(!Tc(y[b+788|0])){if(!Ob(f,114)){break b}}d=x[b+656>>2];c:{if(!d){break c}e=y[b+788|0];if(!Tc(e)){break c}if((z[ac(d+236|0,e-1|0)>>1]-1&65535)>>>0>=z[a+480190>>1]){break a}}if(y[a+480210|0]&32){d=c;c=x[b+660>>2];x[b+660>>2]=d+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break a}d:{if(!Ob(f,57)){c=x[a+480180>>2];if((c|0)!=16){break d}}x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;return}if(!(c&1048581)){if(Ob(f,27)){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;return}x[b>>2]=0;x[b+4>>2]=0;return}c=x[b+80>>2];d=0;x[b>>2]=d;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break a}a=x[b+76>>2];if(a>>>0<5){break a}x[b>>2]=d;x[b+4>>2]=a-2;return}if(!(y[b+88|0]&2)|(c|0)!=1){break a}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;return}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break a}x[b>>2]=0;x[b+4>>2]=c}}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=fb-16|0;fb=i;x[i+12>>2]=b;o=Pf(a);while(1){if(Zg(b,c)){e=x[vb(i+8|0,o)>>2];j=ud(b);m=fb-16|0;fb=m;n=0;k=fb-16|0;fb=k;g=fb-32|0;fb=g;f=g+28|0;d=g+24|0;h=fb-16|0;fb=h;a:{b:{b=e;if(!mc(b,x[vb(h+12|0,pg(a))>>2])){e=y[j|0];l=y[ud(b)|0];if(!Co(e,l)){break b}}x[h+12>>2]=b;c:{if(!mc(b,x[vb(h+8|0,wb(x[a>>2]))>>2])){d=x[LB(h+12|0)>>2];l=y[ud(d)|0];e=y[j|0];if(Co(l,e)){break c}b=gB(a,f,e);break a}d=b}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}if(Co(l,e)){d:{d=JB(b);if(!mc(d,x[vb(h+12|0,pg(a))>>2])){e=y[j|0];if(!Co(e,y[ud(d)|0])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=gB(a,f,e);break a}x[f>>2]=b;x[d>>2]=b;b=d}fb=h+16|0;d=x[b>>2];if(!d){d=fb-16|0;fb=d;f=gc(a);e=g+12|0;f=Dh(e,Ec(24),Og(d+8|0,f));IS(x[f>>2]+16|0,x[j>>2],x[j+4>>2]);p=gc(f),q=1,v[p+4|0]=q;fb=d+16|0;$g(a,x[g+28>>2],b,x[g+12>>2]);d=ne(e);Ik(e);n=1}_g(k+8|0,x[vb(g+12|0,d)>>2],n);fb=g+32|0;fb=k+16|0;vb(m+12|0,x[k+8>>2]);fb=m+16|0;b=x[ah(i+12|0)>>2];continue}else{fb=i+16|0}break}}function mua(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-32|0;fb=g;v[g+16|0]=0;m=r0(g+20|0,d,g+16|0);f=x[m>>2];x[g+16>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=y[a|0];if(!(!i|(k|0)!=(e&255))){x[g+12>>2]=y[a+1|0];i=a+2|0;j=Hb(g+12|0,g+16|0);b:{k=b-2|0;if(!k){break b}j=x[j>>2];if(!(j&255)){break b}i=y[i|0];while(1){if(!(j&255)){break a}v[f|0]=i;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;j=j-1|0;continue}}v[f|0]=e;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;v[f|0]=k;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=x[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=v[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;v[c|0]=k;e=e-1|0;c=c+1|0;continue}break}fc(m);fb=g+32|0;return}n=y[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;v[l|0]=y[l|0]|D(f&n,257)>>>(h-j&7);b=b+1|0;l=b>>>0>=d>>>0;b=l?0:b;j=j+1|0;h=h+l|0;f=(f<<8|f)>>>1&255;continue}}}function eC(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;w[a+34>>1]=z[a+34>>1]&65407;if(b&5){if((b|0)==1){e=Aua(x[a+24>>2],0,8363,0);c=hb;e=e+4143|0;c=e>>>0<4143?c+1|0:c;f=a,g=Bc(Cua(e,c,8287,0),hb),x[f+24>>2]=g}pV(a)}if(b&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(b&7){w[a+32>>1]=64;c=z[a+34>>1];if(c&8){e=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=e;c=c&16?c|6:c&65513|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=c&65511}a:{if(!(b&4)){break a}c=z[a+34>>1];if(!(c&32)){w[a+28>>1]=128;w[a+34>>1]=c|32}Of(a+40|0,15);Of(a+41|0,63);if(!y[a+41|0]){break a}e=y[a+40|0];if(!e){break a}c=y[a+39|0];if(c){c=si(Bc(((e<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}v[a+39|0]=c}b:{c:{if((b|0)!=4){if((b|0)==16777216){break b}if((b|0)!=32|y[a+38|0]!=2){break c}v[a+38|0]=3;break c}if(y[a+38|0]!=4){break c}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}d:{if(!(!(y[a+35|0]&2)|b&16777218)){x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;Sk(a,0,d);break d}if(!(y[a+35|0]&2)|(b|0)!=2){break d}a=a+68|0;b=xb(a,8);v[b|0]=y[b|0]&3;a=xb(a,9);v[a|0]=y[a|0]&3}fb=d+32|0}function mta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-1072|0;fb=d;x[d+1068>>2]=c;o=d,q=Zd(b),v[o+8|0]=q;v[d+4|0]=1;c=d+8|0;e=d+4|0;h=y[cf(c,e)|0];f=eE(c,b);l=Ar(f);x[31609]=0;c=R(202,b|0)|0;g=x[31609];x[31609]=0;a:{if((g|0)!=1){x[d+4>>2]=c;x[d>>2]=536870911;xc(d+1068|0,x[Hb(e,d)>>2]<<3);x[31609]=0;m=x[d+1068>>2];k=P(341,a|0,m|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){x[31609]=0;c=8;i=P(158,f|0,8)|0;a=x[31609];x[31609]=0;b:{if((a|0)!=1){c:{o=xb(x[k>>2],0),q=i,v[o|0]=q;g=1;a=h;while(1){c=c&255;n=c>>>0<=9?9:c;e=a;d:{e:{while(1){if(g>>>0>=m>>>0){break d}x[31609]=0;j=P(158,f|0,c|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=h;continue}break}break c}a=j>>>1|0;i=(j&1?0-a|0:a)+i|0;o=xb(x[k>>2],g),q=i,v[o|0]=q;g=g+1|0;a=h;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:h;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=Ar(f);x[31609]=0;P(149,b|0,((a-l|0)+3&-4)+l|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break b}}}c=N()|0;fc(k);break a}ub(f);fb=d+1072|0;return}c=N()|0;break a}c=N()|0}ub(f);Q(c|0);p()}function eY(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;g=z[c>>1];a:{if((d&255)>>>0<=4){while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Bf(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Bf(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Bf(a,f+13|0)){break a}d=y[f+13|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!Bf(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!Bf(a,f+11|0)){break a}d=y[f+11|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}fb=f+16|0}function Nha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb+-64|0;fb=c;g=Nb(a);x[31609]=0;W(954,g|0);a=x[31609];x[31609]=0;a:{if((a|0)!=1){b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((b|0)==312){fb=c- -64|0;return g|0}k:{h=zu(44);if(h){x[31609]=0;d=P(36,c+36|0,x[b+42980>>2])|0;a=x[31609];x[31609]=0;if((a|0)==1){break k}a=x[b+42976>>2];x[31609]=0;i=c+48|0;O(955,i|0,d|0);e=x[31609];x[31609]=0;if((e|0)==1){break j}x[31609]=0;e=P(36,c+12|0,x[b+42984>>2])|0;f=x[31609];x[31609]=0;if((f|0)==1){break i}x[31609]=0;f=c+24|0;O(955,f|0,e|0);j=x[31609];x[31609]=0;if((j|0)==1){break h}x[31609]=0;a=ba(956,h|0,a|0,i|0,f|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break g}Eb(f);tb(e);Eb(i);tb(d);x[c+60>>2]=a;x[31609]=0;O(957,g|0,c+60|0);d=x[31609];x[31609]=0;if((d|0)==1){break b}v[a+40|0]=y[b+42996|0];d=b+42988|0;e=x[d+4>>2];x[a+32>>2]=x[d>>2];x[a+36>>2]=e;v[a+41|0]=y[a+41|0]&253|y[b+42997|0]<<1}b=b+24|0;continue}break}b=N()|0;break c}b=N()|0;break d}b=N()|0;break e}b=N()|0;break f}b=N()|0;Eb(c+24|0)}tb(e)}Eb(c+48|0)}tb(d)}Db(h);break a}b=N()|0;break a}b=N()|0}wc(g);Q(b|0);p()}function KL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),q=0,r=0;a:{if(y[b+21|0]){q=D(d,g);r=b+36|0;j=x[e>>2];l=x[f>>2];m=x[b>>2];b:{while(1){if((h|0)>0){if(x[a+1396>>2]<=9){vl(a)}g=x[a+1392>>2];k=w[((g&1023)<<1)+r>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;k=(g|0)<0?-1:k;break c}k=Im(a,b)}if((k|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((k|0)<0){if(!y[a+1376|0]){b=0;if(x[a+1384>>2]){break b}}bc(a,21);return 0}else{g=0;n=D(d,l);m=((m+n|0)+j|0)>(q|0)?(q-n|0)+j|0:m;n=(m|0)>0?m:0;k=D(k,x[b>>2]);o=E(0);d:{if(y[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=E(o+B[(x[b+28>>2]+(k<<2)|0)+(g<<2)>>2]);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=o+B[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+E(B[(x[b+28>>2]+(k<<2)|0)+(g<<2)>>2]+E(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}}break}x[e>>2]=j;x[f>>2]=l;b=1}return b}bc(a,21);return 0}_(7552,13274,1887,6586);p()}function sQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);c=fb-80|0;fb=c;d=x[b>>2];b=x[b+4>>2];e=Md(c+52|0);f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;b=qx(c+60|0,d,b,c+8|0);x[31609]=0;d=R(202,b|0)|0;e=x[31609];x[31609]=0;a:{if((e|0)==1){break a}x[31609]=0;d=U(949,b|0,c+19|0,d|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break a}if(!(!d|(y[c+23|0]|y[c+24|0]<<8|(y[c+25|0]<<16|y[c+26|0]<<24)|(y[c+19|0]|y[c+20|0]<<8|(y[c+21|0]<<16|y[c+22|0]<<24))!=542066252))){g=a,h=Pd((l(2,y[c+27|0]|y[c+28|0]<<8|(y[c+29|0]<<16|y[c+30|0]<<24)),r()),E(0)),B[g+4220>>2]=h;g=a,h=Pd((l(2,y[c+31|0]|y[c+32|0]<<8|(y[c+33|0]<<16|y[c+34|0]<<24)),r()),E(0)),B[g+4224>>2]=h;g=a,h=Pd((l(2,y[c+35|0]|y[c+36|0]<<8|(y[c+37|0]<<16|y[c+38|0]<<24)),r()),E(0)),B[g+4228>>2]=h;d=y[c+39|0]|y[c+40|0]<<8|(y[c+41|0]<<16|y[c+42|0]<<24);if(d>>>0<=5){x[a+4232>>2]=d}x[a+4236>>2]=y[c+43|0]|y[c+44|0]<<8|(y[c+45|0]<<16|y[c+46|0]<<24);v[a+4240|0]=y[c+47|0]!=0;v[a+4241|0]=y[c+48|0]!=0;v[a+4242|0]=y[c+49|0]!=0;v[a+4243|0]=y[c+50|0]!=0;v[a+4244|0]=y[c+51|0]!=0;ru(a)}ub(b);fb=c+80|0;return}a=N()|0;ub(b);Q(a|0);p()}function zha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=0,v=0,w=0,z=E(0);h=x[a+44>>2];g=Hc(h,0);h=Hc(h,1);j=x[a+56>>2];n=Hc(j,0);j=Hc(j,1);e=oc(x[a+4208>>2],x[a+4212>>2]);o=D(x[x[a+16>>2]+1074404>>2],y[a+4233|0]);k=o<<1;if(e>>>0<k>>>0){Cl(a+4208|0,k)}l=y[a+4232|0];a:{if(l){e=x[a+4220>>2];k=x[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=B[h>>2];e=e>>>0<o>>>0?e:0;i=e-o|0;i=((i|0)<0?e:i)<<1;v=yb(k,i);f=B[yb(k,i|1)>>2];s=B[g>>2];t=B[v>>2];p=E(s+t);B[n>>2]=p;q=E(r+f);B[j>>2]=q;f=E(0);m=E(0);b:{c:{switch(u|0){case 0:f=B[a+4224>>2];m=E(q*f);f=E(p*f);break b;case 1:case 2:f=B[a+4224>>2];m=E(p*f);f=E(q*f);break b;case 3:break c;default:break b}}f=E(E(E(E(s+r)*E(.5))+t)*B[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;h=h+4|0;g=g+4|0;i=e<<1;w=yb(k,i),z=E(F(f))<E(10000000195414814e-40)?E(0):f,B[w>>2]=z;w=yb(k,i|1),z=E(F(m))<E(10000000195414814e-40)?E(0):m,B[w>>2]=z;e=e+1|0;x[a+4220>>2]=e;l=l+1|0;continue}}e=g;g=d<<2;eD(e,e+g|0,n);eD(h,h+g|0,j)}g=a;a=x[a+56>>2];Ii(g,b,c,Hc(a,0),Hc(a,1),d)}function BD(a,b,c,d){v[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:v[a+3|0]=c?37:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(d){break a}v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=d?32:31;return;case 29:v[a+3|0]=d?33:0;return;case 27:v[a+3|0]=d?34:0;return;case 30:v[a+3|0]=d?35:0;return;case 31:v[a+3|0]=d?36:0;return;case 50:v[a+3|0]=d?25:0;return;case 51:v[a+3|0]=d?30:0;return;default:break b}}v[a+3|0]=0}}function q7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-144|0;fb=a;x[a+136>>2]=c;x[a+140>>2]=b;x[a+20>>2]=1274;i=a+20|0;b=De(a+24|0,a+32|0,i);j=a+16|0;cd(j,x[e+28>>2]);x[31609]=0;h=R(28,x[a+16>>2])|0;k=x[31609];x[31609]=0;if((k|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31609]=0;c=na(1275,a+140|0,c|0,d|0,j|0,e|0,f|0,a+15|0,h|0,b|0,i|0,a+132|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}sf(g);if(y[a+15|0]){x[31609]=0;c=P(29,h|0,45)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}x[31609]=0;O(115,g|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}}x[31609]=0;d=P(29,h|0,48)|0;c=x[31609];x[31609]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-1|0;c=x[b>>2];d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[31609]=0;U(1281,g|0,c|0,e|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break c}break a}x[31609]=0;c=P(1241,a+140|0,a+136|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+140>>2];_b(a+16|0);Lc(b);fb=a+144|0;return c|0}}}c=N()|0;_b(a+16|0);Lc(b);Q(c|0);p()}function Lla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;o=x[a+16>>2];p=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];l=x[a+128>>2];if(l){m=Hg(j,k,l);n=hb;g=x[a+76>>2];fg(b,f,uf(j,k,d),hb);i=hb>>>0>g>>>0?d:0}g=a+112|0;q=x[a+24>>2];r=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=f;a:while(1){if(d){f=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Pb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;ce(g,(w[((h&2147483646)<<1)+f>>1]+w[(h<<1|2)+f>>1]|0)/8<<16>>16);be(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}f=x[c>>2];b=Fg(g,p);x[c>>2]=f+D(b,r);x[c+4>>2]=x[c+4>>2]+D(b,q);Pb(e,j,k);c=c+8|0;continue a}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;ce(g,(w[((h&2147483646)<<1)+f>>1]+w[(h<<1|2)+f>>1]|0)/8<<16>>16);be(g,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function A1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;yc(b);Lp(a);e=d+60|0;a:{if(!cx(b,e)){break a}if(!YF(e)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],$b(y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24))-28|0)){break a}tx(a);g=d,h=sx(),x[g+40>>2]=h;c=d+40|0;rx(cj(x[a+4>>2])+32|0,c);os(c);e=x[cj(x[a+4>>2])+32>>2];f=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);x[31609]=0;S(186,c|0,b|0,$b(f)-28|0);b=x[31609];x[31609]=0;c:{d:{if((b|0)!=1){Mn(d+32|0,c);b=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);x[31609]=0;b=ba(187,x[d+32>>2],x[d+36>>2],e|0,$b(b)|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}Kc(c);f=0;if(!b){break a}se(d+16|0,x[e>>2],x[e+4>>2]);lf(d+24|0,x[d+16>>2],x[d+20>>2]);b=Md(d+8|0);e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=qx(c,x[d+24>>2],x[d+28>>2],d);kd(cj(x[a+4>>2])+12|0,b);ub(b);break b}a=ta(124540,24472)|0;b=gb;break c}a=ta(124540,24472)|0;b=gb;Kc(d+40|0)}e:{if(($(124540)|0)==(b|0)){break e}if(($(24472)|0)==(b|0)){break e}Q(a|0);p()}Y(a|0)|0;Z();f=0;break a}f=1}fb=d+96|0;return f|0}function rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=fb-16|0;fb=f;g=x[a+12>>2];h=x[a+8>>2];a:{b:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){e=131112;if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break a}e=262184;if((g|0)==-2&h>>>0<2147483648|g>>>0<4294967294){break a}break b}e=262184;if((g|0)==1&h>>>0>2147483648|g>>>0>1){break a}}e=196648}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];i=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=i;i=b+e|0;while(1){if(d){b=x[f+8>>2];m=(((x[f+12>>2]&2147483647)<<1|b>>>31)&-2)+j|0;b=(b>>>16&65520)+i|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];b=0;while(1){if((b|0)!=2){e=b+m|0;x[(b<<2)+f>>2]=(((((((D(v[e-4|0],t)+D(v[e-6|0],u)|0)+D(v[e-2|0],s)|0)+D(v[e|0],r)|0)+D(v[e+2|0],q)|0)+D(v[e+4|0],p)|0)+D(v[e+6|0],o)|0)+D(v[e+8|0],n)<<8)/32768;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],k);Pb(f+8|0,h,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;fb=f+16|0}function eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=E(0),t=0,u=0,v=0,w=0,y=0,z=E(0);a:{j=x[a+4272>>2];if(!j){break a}if(!ti(a+44|0)){break a}f=x[a+44>>2];l=Hc(f,0);m=Hc(f,1);u=x[a+4252>>2]-1|0;i=x[a+4268>>2];k=x[a+4256>>2];n=d;f=x[a+56>>2];q=Hc(f,0);o=q;r=Hc(f,1);p=r;while(1){if(n){e=B[m>>2];f=i<<1;h=yb(k,f);g=B[l>>2];B[h>>2]=g;y=yb(k,f|1),z=e,B[y>>2]=z;s=B[a+4276>>2];e=E(E(F(_P(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)))*E(4.656612873077393e-10));e=E(E(E(s-e)*B[(e>=s?4236:4240)+a>>2])+e);B[a+4276>>2]=e;g=B[a+4244>>2];e=E(E(E(E(g-(e<g?g:e))*B[a+4248>>2])+E(.9999998807907104))*E(2147483648));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=B[yb(k,t)>>2];h=f<<5;v=h;w=h|-2147483648;h=f>>>0<67108864;e=E(B[a+4232>>2]*E(E((h?v:w)>>>(h?31:32-(f>>>26|0)|0)>>>0)*E(4.656612873077393e-10)));B[o>>2]=g*e;y=p,z=E(B[yb(k,t|1)>>2]*e),B[y>>2]=z;i=((i?0:j)+i|0)-1|0;x[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{Ii(a,b,c,q,r,d)}break}}}function wo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-80|0;fb=c;g=Nb(a);a=x[b+24>>2];a:{b:{if(Gj(x[a+484360>>2],x[a+484364>>2])){c:{d:{e:while(1){if(Gj(x[a+484360>>2],x[a+484364>>2])>>>0<=f>>>0){break d}d=NR(VX(c+40|0,1),f&255,0,0);x[31609]=0;e=x[d+12>>2];x[c+16>>2]=x[d+8>>2];x[c+20>>2]=e;e=x[d+20>>2];x[c+24>>2]=x[d+16>>2];x[c+28>>2]=e;e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;V(1091,c+68|0,a|0,0,c+8|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}j=c,k=wb(x[c+68>>2]),x[j+36>>2]=k;d=wb(x[c+72>>2]);while(1){a=x[c+36>>2];if(!Ib(a,d)){f=f+1|0;Qi(c+68|0);a=x[b+24>>2];continue e}h=C[a>>3];e=x[a+16>>2];i=z[a+24>>1];a=c+40|0;x[a+16>>2]=f;x[a+12>>2]=i;x[a+8>>2]=e;C[a>>3]=h;x[31609]=0;O(1126,g|0,a|0);a=x[31609];x[31609]=0;if((a|0)!=1){Zq(c+36|0);continue}break}break}a=N()|0;Qi(c+68|0);break b}fb=c+80|0;return}a=N()|0;break b}b=dc(8);x[31609]=0;d=P(36,c+40|0,7310)|0;a=x[31609];x[31609]=0;if((a|0)!=1){sc(b,d);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=N()|0;lc(b)}nf(g);Q(a|0)}p()}function Qo(a,b,c,d){var e=0,f=0;e=b+1074312|0;f=Ob(e,120);v[a+797|0]=f;v[a+802|0]=f;w[a+800>>1]=0;v[a+803|0]=0;v[a+804|0]=0;v[a+841|0]=0;v[a+805|0]=0;x[a+708>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+764>>2]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;if(Ob(e,23)){v[a+807|0]=1;v[a+808|0]=0}v[a+846|0]=0;v[a+839|0]=0;w[a+774>>1]=0;v[a+850|0]=255;x[a+660>>2]=0;v[a+851|0]=y[a+851|0]&224;Wo(a+788|0);x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;v[a+845|0]=0;v[a+838|0]=0;v[a+821|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+836>>1]=32512;v[a+819|0]=0;v[a+820|0]=0;w[a+842>>1]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+852>>2]=0;x[a+856>>2]=0;v[a+851|0]=y[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+748>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|d;break a}x[a+748>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+784>>1]=0;v[a+795|0]=0;v[a+796|0]=0}function LK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-32|0;fb=d;a:{if(y[a+52|0]){f=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}if(y[a+53|0]){f=-1;c=x[a+32>>2];b:{if(x[c+76>>2]<0){c=HK(c);break b}c=HK(c)}if((c|0)!=-1){x[d+24>>2]=c}if((c|0)==-1){break a}c=x[d+24>>2];c:{if(!b){if(KK(c,x[a+32>>2])){break c}break a}x[a+48>>2]=c}f=c;break a}x[d+24>>2]=1;e=x[Ye(d+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((g|0)!=(h|0)){f=-1;c=dr(x[a+32>>2]);if((c|0)==-1){break a}v[(d+24|0)+h|0]=c;h=h+1|0;continue}break}k=d+24|0;d:{while(1){e:{i=x[a+40>>2];c=x[i>>2];h=x[i+4>>2];f=-1;g=d+24|0;j=g+e|0;f:{switch(YK(x[a+36>>2],i,g,j,d+16|0,d+20|0,k,d+12|0)-1|0){case 1:break a;case 2:break e;case 0:break f;default:break d}}g=x[a+40>>2];x[g>>2]=c;x[g+4>>2]=h;if((e|0)==8){break a}c=dr(x[a+32>>2]);if((c|0)==-1){break a}v[j|0]=c;e=e+1|0;continue}break}x[d+20>>2]=v[d+24|0]}g:{if(!b){while(1){if((e|0)<=0){break g}e=e-1|0;if((fo(v[e+(d+24|0)|0],x[a+32>>2])|0)!=-1){continue}break a}}f=x[d+20>>2];x[a+48>>2]=f;break a}f=x[d+20>>2]}fb=d+32|0;return f}function iS(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=128e3){g=fb-32|0;fb=g;b=ev(g);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=a+f|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;fb=g+32|0;f=f+32|0;continue}break}}function Nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;h=fb-16|0;fb=h;j=x[a+40>>2];k=x[a+36>>2];f=x[a+48>>2];e=x[a+44>>2];o=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];l=x[a+68>>2];s=l>>31;m=x[a+64>>2];t=m>>31;n=x[a+60>>2];u=n>>31;w=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Yb(e,-16777216,16776704);e=Aua(m,t,e,e>>31);i=hb;g=e;f=Yb(f,-16777216,16776704);e=Aua(l,s,f,f>>31);g=g+e|0;f=hb+i|0;f=e>>>0>g>>>0?f+1|0:f;z=g;e=x[h+8>>2];i=e>>>10&4194048;e=x[h+12>>2]+o|0;g=v[e|0];i=((D(v[e+1|0]-g|0,i)|0)/16384<<8)+(g<<16)|0;e=i;e=Aua(e,e>>31,n,u);g=e+z|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Sc(e,f,24);f=(e|0)/256|0;k=k+q|0;x[c>>2]=D(f,k>>12)+x[c>>2];j=j+p|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,f);Pb(h+8|0,w,y);e=e-(i&r)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=j>>12;fb=h+16|0}function qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31609]=0;W(1021,a|0);e=x[31609];x[31609]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[31609]=0;W(997,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break e}e=0;x[31609]=0;W(1022,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}a=Rb(c,0,d);if(!y[b|0]){break b}if(hi(b,47296)|(d|0)!=8){break d}x[a+4>>2]=1023;x[a>>2]=1024;break c}Y(T(0)|0)|0;x[31609]=0;V(983,12360,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();return 0}if(!(hi(b,47308)|(d|0)!=64)){x[a+60>>2]=1025;x[a+56>>2]=1026;x[a+52>>2]=1027;x[a+48>>2]=1028;x[a+44>>2]=1029;x[a+40>>2]=1030;x[a+36>>2]=1031;x[a+32>>2]=1032;x[a+28>>2]=1033;x[a+24>>2]=1034;x[a+20>>2]=1035;x[a+16>>2]=1036;x[a+12>>2]=1037;x[a+8>>2]=1038;x[a+4>>2]=1039;x[a>>2]=1040;break c}if(!(hi(b,47320)|(d|0)!=24)){x[a+20>>2]=1041;x[a+16>>2]=1042;x[a+12>>2]=1043;x[a+8>>2]=1044;x[a+4>>2]=1045;x[a>>2]=1046;break c}if(hi(b,47333)|(d|0)!=4){break b}x[a>>2]=1047}e=1}return e|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Rha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0;c=fb-32|0;fb=c;a:{b=x[a+20>>2];b:{if(!b){break b}x[b+148>>2]=-1;j=c,k=ib[x[x[a>>2]+40>>2]](a)|0,x[j+16>>2]=k;x[c+8>>2]=1073741822;b=c+16|0;d=c+8|0;g=x[Hb(b,d)>>2];e=g<<2;if(!e){break b}h=x[a+20>>2];x[31609]=0;O(287,h+4|0,e+4|0);e=x[31609];x[31609]=0;c:{d:{if((e|0)!=1){e=d;d=x[a+20>>2];se(e,x[d+4>>2],x[d+8>>2]);x[c>>2]=0;x[c+4>>2]=0;d=x[c+12>>2];x[b>>2]=x[c+8>>2];x[b+4>>2]=d;d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;d=fb-16|0;fb=d;x[d+12>>2]=0;pQ(b,d+12|0);fb=d+16|0;b=x[x[a>>2]+184>>2];x[31609]=0;O(b|0,a|0,-1);b=x[31609];x[31609]=0;if((b|0)==1){break d}while(1){if((f|0)==(g|0)){b=x[x[a>>2]+188>>2];x[31609]=0;W(b|0,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}break d}b=x[x[a>>2]+48>>2];x[31609]=0;i=E(_a(b|0,a|0,f|0));b=x[31609];x[31609]=0;if((b|0)!=1){B[c+8>>2]=i;f=f+1|0;pQ(c+16|0,c+8|0);continue}break}b=T(124540)|0;break c}b=T(124540)|0;break c}b=T(124540)|0}if((gb|0)!=($(124540)|0)){break a}Y(b|0)|0;Nc(x[a+20>>2]+4|0);Z()}fb=c+32|0;return}Q(b|0);p()}function sT(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=x[a+24620>>2];a:{b:{switch(y[a+480224|0]-1|0){default:x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=Aua(c,c>>31,5e4,0);e=hb;b=x[bd(d+12|0,d+8|0)>>2];c=Gc(Bua(c,e,b,b>>31),hb);break a;case 0:x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=Aua(c,c>>31,1e4,0);e=hb;b=x[bd(d+12|0,d+8|0)>>2];c=Gc(Bua(c,e,b,b>>31),hb);break a;case 1:break b}}f=60/(+A[b+44>>2]/1e4*(+(Aua(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(hb>>>0)*4294967296))*+(c>>>0);c:{d:{c=x[a+484344>>2];e=z[b+70>>1];if(!Je(c,x[a+484348>>2],e)){break d}c=Wb(c,e);if(!Ib(x[c+24>>2],x[c+28>>2])){break d}c=MR(c);break c}c=a+480248|0}e=x[c>>2];c=x[c+4>>2];if(!mc(e,c)){f=f*+A[yb(e,A[b+48>>2]%(oc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(F(f)<2147483648){c=~~f;break e}c=-2147483648}f=C[b+8>>3]+(f-+(c>>>0));C[b+8>>3]=f;if(f>=1){C[b+8>>3]=f+-1;c=c+1|0;break a}if(!(C[a+1074384>>3]<=-1)){break a}C[b+8>>3]=f+1;c=c-1|0}b=Aua(x[a+480244>>2],0,c,0);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Bc((a&65535)<<16|b>>>16,a>>>16|0);fb=d+16|0;return a>>>0<=1?1:a}function FL(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=a;d=fb-208|0;fb=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;b=4;f=4;e=2;while(1){a=b;b=(b+f|0)+4|0;x[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;f=a;if(b>>>0<h>>>0){continue}break}a=(g+h|0)-4|0;b:{if(a>>>0<=g>>>0){e=1;b=1;a=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){az(g,c,b,d+16|0);Nt(d+8|0,2);b=b+2|0;break c}h=d+16|0;f=b-1|0;d:{if(A[h+(f<<2)>>2]>=a-g>>>0){Mt(g,c,e,x[d+12>>2],b,0,h);break d}az(g,c,b,d+16|0)}if((b|0)==1){Lt(d+8|0,1);b=0;break c}Lt(d+8|0,f);b=1}e=x[d+8>>2]|1;x[d+8>>2]=e;g=g+4|0;if(a>>>0>g>>>0){continue}break}a=x[d+12>>2]}Mt(g,c,e,a,b,0,d+16|0);f=x[d+12>>2];e=x[d+8>>2];if(!(f|((b|0)!=1|(e|0)!=1))){break a}while(1){e:{if((b|0)<=1){a=yL(e,f);Nt(d+8|0,a);a=a+b|0;break e}f=d+8|0;Lt(f,2);x[d+8>>2]=x[d+8>>2]^7;Nt(f,1);h=g-4|0;e=d+16|0;a=b-2|0;Mt(h-x[e+(a<<2)>>2]|0,c,x[d+8>>2],x[d+12>>2],b-1|0,1,e);Lt(f,1);b=x[d+8>>2]|1;x[d+8>>2]=b;Mt(h,c,b,x[d+12>>2],a,1,e)}b=a;g=g-4|0;f=x[d+12>>2];e=x[d+8>>2];if(f|((b|0)!=1|(e|0)!=1)){continue}break}}fb=d+208|0}function vM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Xf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){i=x[c+20>>2];if(g>>>0>i>>>0){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=(D(e,h)<<2)+m|0;o=(D(h+j|0,i)<<1)+l|0;a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=yb(x[b>>2],a);q=d;d=x[(a<<2)+n>>2]+(x[d>>2]>>1)|0;r=d;d=Zt(k)+d&-4096;x[q>>2]=r-d;d=rd(d|2048,12);d=(d|0)>=32767?32767:d;w[(a<<1)+o>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function OW(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=fb-80|0;fb=c;x[c+72>>2]=0;x[c+76>>2]=0;b=c- -64|0;x[b>>2]=0;x[b+4>>2]=0;x[c+56>>2]=0;x[c+60>>2]=0;x[c+48>>2]=0;x[c+52>>2]=0;iC(a,nV(a),c+48|0);b=pc(c+40|0,14253);qf(Pe(a,0),x[b>>2],x[b+4>>2]);b=pc(c+32|0,14336);qf(Pe(a,1),x[b>>2],x[b+4>>2]);b=pc(c+24|0,5496);qf(Pe(a,3),x[b>>2],x[b+4>>2]);b=pc(c+16|0,15769);qf(Pe(a,4),x[b>>2],x[b+4>>2]);b=pc(c+8|0,9281);qf(Pe(a,8),x[b>>2],x[b+4>>2]);d=Pe(a+288|0,0);b=fb-16|0;fb=b;e=d;d=pc(b+8|0,4932);qf(e,x[d>>2],x[d+4>>2]);fb=b+16|0;d=a+800|0;b=0;a=fb+-64|0;fb=a;a:{b:{while(1){if((b|0)==128){break a}x[a+60>>2]=b<<3;c:{d:{if(b>>>0<=15){e=a+28|0;qw(e,4084);x[31609]=0;g=a+16|0;O(289,g|0,a+60|0);f=x[31609];x[31609]=0;if((f|0)==1){break c}x[31609]=0;f=a+40|0;S(290,f|0,e|0,g|0);h=x[31609];x[31609]=0;if((h|0)!=1){fe(a+52|0,f);qf(Pe(d,b),x[a+52>>2],x[a+56>>2]);tb(f);tb(g);Eb(e);break d}b=N()|0;tb(a+16|0);break b}e=pc(a+8|0,22292);qf(Pe(d,b),x[e>>2],x[a+12>>2])}b=b+1|0;continue}break}b=N()|0}Eb(a+28|0);Q(b|0);p()}fb=a- -64|0;fb=c+80|0}function Mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=fb-16|0;fb=h;i=x[a+40>>2];j=x[a+36>>2];e=x[a+48>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];v=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Aua(n,u,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Aua(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=(x[h+12>>2]<<1)+p|0;k=w[g>>1];k=k+((D(w[g+2>>1]-k|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=k;g=Aua(e,e>>31,o,v);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Sc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Pb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function BM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Xf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{i=x[c+4>>2];if(i>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}l=b+12|0;m=x[c+16>>2];n=x[c>>2];a=0;e:while(1){if((a|0)==(f|0)){break a}o=(D(a,i)<<2)+n|0;d=0;while(1)if((d|0)==(g|0)){a=a+1|0;continue e}else{e=yb(x[b>>2],d);h=e;k=d<<2;e=x[k+o>>2]+(x[e>>2]>>1)|0;q=e;e=Zt(l)+e&-4096;x[h>>2]=q-e;h=(x[m+k>>2]+(j<<1)|0)+(a<<1)|0;e=rd(e|2048,12);e=(e|0)>=32767?32767:e;w[h>>1]=(e|0)<=-32768?-32768:e;d=d+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;nd(c,0);w[d+14>>1]=y[a+36|0]|y[a+37|0]<<8;w[d+12>>1]=32767;g=c,h=(z[Oc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,w[g+28>>1]=h;w[d+10>>1]=y[a+38|0]|y[a+39|0]<<8;w[d+8>>1]=32767;g=c,h=(z[Oc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,w[g+30>>1]=h;w[c+32>>1]=64;x[c>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+4>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+8>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[c+24>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);e=y[b+166|0];if(e>>>0<=4){v[c+38|0]=y[e+41114|0]}e=y[b+167|0]|y[b+168|0]<<8;v[c+39|0]=e;f=(y[b+171|0]|y[b+172|0]<<8)>>>4|0;v[c+41|0]=f;b=(y[b+169|0]|y[b+170|0]<<8)>>>2|0;v[c+40|0]=b;if((b|f)&255){v[c+39|0]=e^-1}b=y[a+40|0]|y[a+41|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+40|0]|y[a+41|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+40|0]|y[a+41|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+40|0]|y[a+41|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}fb=d+16|0}function Cua(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(b){if(!c){break k}if(!d){break j}e=G(d)-G(b)|0;if(e>>>0<=31){break i}break c}if((d|0)==1|d>>>0>1){break c}hb=0;a=(a>>>0)/(c>>>0)|0;break a}if(!a){break h}if(!d|d-1&d){break g}a=b>>>zua(d)|0;hb=0;break a}if(!(c-1&c)){break f}h=(G(c)+33|0)-G(b)|0;g=0-h|0;break d}h=e+1|0;g=63-e|0;break d}hb=0;a=(b>>>0)/(d>>>0)|0;break a}e=G(d)-G(b)|0;if(e>>>0<31){break e}break c}if((c|0)==1){break b}d=zua(c);c=d&31;if((d&63)>>>0>=32){a=b>>>c|0}else{e=b>>>c|0;a=((1<<c)-1&b)<<32-c|a>>>c}hb=e;break a}h=e+1|0;g=63-e|0}e=h&63;f=e&31;if(e>>>0>=32){e=0;i=b>>>f|0}else{e=b>>>f|0;i=((1<<f)-1&b)<<32-f|a>>>f}g=g&63;f=g&31;if(g>>>0>=32){b=a<<f;a=0}else{b=(1<<f)-1&a>>>32-f|b<<f;a=a<<f}if(h){f=d-1|0;g=c-1|0;m=(g|0)!=-1?f+1|0:f;while(1){j=e<<1|i>>>31;e=i<<1|b>>>31;f=m-(j+(e>>>0>g>>>0)|0)>>31;k=c&f;i=e-k|0;e=j-((d&f)+(e>>>0<k>>>0)|0)|0;b=b<<1|a>>>31;a=l|a<<1;l=f&1;h=h-1|0;if(h){continue}break}}hb=b<<1|a>>>31;a=l|a<<1;break a}a=0;b=0}hb=b}return a}function JK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){f=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}if(y[a+53|0]){f=-1;d=dr(x[a+32>>2]);if((d|0)!=-1){v[c+24|0]=d}if((d|0)==-1){break a}d=zf(v[c+24|0]);b:{if(!b){if(IK(d,x[a+32>>2])){break b}break a}x[a+48>>2]=d}f=d;break a}x[c+24>>2]=1;e=x[Ye(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((g|0)!=(h|0)){f=-1;d=dr(x[a+32>>2]);if((d|0)==-1){break a}v[(c+24|0)+h|0]=d;h=h+1|0;continue}break}k=c+24|0;c:{while(1){d:{i=x[a+40>>2];d=x[i>>2];h=x[i+4>>2];f=-1;g=c+24|0;j=g+e|0;e:{switch(YK(x[a+36>>2],i,g,j,c+16|0,c+23|0,k,c+12|0)-1|0){case 1:break a;case 2:break d;case 0:break e;default:break c}}g=x[a+40>>2];x[g>>2]=d;x[g+4>>2]=h;if((e|0)==8){break a}d=dr(x[a+32>>2]);if((d|0)==-1){break a}v[j|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((fo(zf(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break a}}f=zf(v[c+23|0]);x[a+48>>2]=f;break a}f=zf(v[c+23|0])}fb=c+32|0;return f}function bna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=kg(1,2);b=hb;s=b;Pb(a,l,b);i=x[a+40>>2];j=x[a+36>>2];f=x[a+48>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=w[(x[g+12>>2]<<1)+r>>1]<<8;e=p;e=Aua(e,e>>31,o,A);k=hb;h=e;e=Yb(b,-16777216,16776704);e=Aua(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Aua(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Sc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Pb(g+8|0,B,C);e=e-(v&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Ig(a,l,s);fb=g+16|0}function VK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;n=fb-1040|0;fb=n;r=x[31484];a:{b:{j=n+16|0;q=z[((b>>>0<=153?b:0)<<1)+123424>>1]+121504|0;d=x[x[124115]+20>>2];if(d){k=x[d+4>>2];d=x[d>>2];e=x[d>>2]+1794895138|0;f=Bm(x[d+8>>2],e);g=Bm(x[d+12>>2],e);h=Bm(x[d+16>>2],e);c:{if(k>>>2>>>0<=f>>>0){break c}l=k-(f<<2)|0;if((g|h)&3|(l>>>0<=g>>>0|h>>>0>=l>>>0)){break c}s=h>>>2|0;t=d+(g&-4)|0;g=0;while(1){h=f>>>1|0;l=h+g|0;m=(l<<3)+t|0;i=Bm(x[m>>2],e);m=Bm(x[m+4>>2],e);if(m>>>0>=k>>>0|i>>>0>=k-m>>>0){break c}o=i;i=d+m|0;if(y[o+i|0]){break c}i=hi(q,i);if(!i){g=(d+(s<<2)|0)+(l<<3)|0;f=Bm(x[g>>2],e);e=Bm(x[g+4>>2],e);if(e>>>0>=k>>>0|f>>>0>=k-e>>>0){break c}c=d+e|0;c=y[c+f|0]?0:c;break c}if((f|0)==1){break c}o=h;f=f-h|0;h=(i|0)<0;f=h?o:f;g=h?g:l;continue}}}c=c?c:q;d=Ef(c);d:{if(d>>>0>=1024){zc(j,c,1023);v[j+1023|0]=0;c=68;break d}zc(j,c,d+1|0);c=0}if(c){if((c|0)!=28){break b}c=22292}else{c=j}break a}va();p()}if(!y[c|0]){x[n>>2]=b;sy(j,1024,13091,n);c=j}x[31484]=r;Dc(a,c);fb=n+1040|0}function cna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=kg(1,2);b=hb;s=b;Pb(a,l,b);i=x[a+40>>2];j=x[a+36>>2];f=x[a+48>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=v[x[g+12>>2]+r|0]<<16;e=p;e=Aua(e,e>>31,o,A);k=hb;h=e;e=Yb(b,-16777216,16776704);e=Aua(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Aua(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Sc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Pb(g+8|0,B,C);e=e-(w&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Ig(a,l,s);fb=g+16|0}function JL(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=B[b>>2];j=B[c>>2];k=B[d>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=f+B[b>>2];j=E(j-k);f=E(f-h);B[d>>2]=E(j*B[e>>2])-E(B[e+4>>2]*f);B[b>>2]=E(f*B[e>>2])+E(j*B[e+4>>2]);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=f+k;i=c-12|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+32>>2])-E(B[e+36>>2]*h);B[b>>2]=E(h*B[e+32>>2])+E(f*B[e+36>>2]);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=f+k;i=c-20|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+64>>2])-E(B[e+68>>2]*h);B[b>>2]=E(h*B[e+64>>2])+E(f*B[e+68>>2]);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=f+k;i=c-28|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+96>>2])-E(B[e+100>>2]*h);B[b>>2]=E(h*B[e+96>>2])+E(f*B[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}_(15858,13274,2423,9227);p()}function psa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;d=Wh(b,c);n=e,o=Bb(y[a|0]|y[a+1|0]<<8),w[n+14>>1]=o;w[e+12>>1]=64;fh(d,z[Oc(e+14|0,e+12|0)>>1]);n=d,o=Bb(y[a+14|0]|y[a+15|0]<<8),v[n+13|0]=o;n=d,o=Bb(y[a+16|0]|y[a+17|0]<<8),v[n+14|0]=o;n=d,o=Bb(y[a+20|0]|y[a+21|0]<<8),v[n+15|0]=o;n=d,o=Bb(y[a+22|0]|y[a+23|0]<<8),v[n+16|0]=o;h=x[d>>2];f=x[d+4>>2];b=y[d+12|0]&-2|mc(h,f)^1;v[d+12|0]=b;b=b&-3|Bb(y[a+12|0]|y[a+13|0]<<8)>>>3&2;v[d+12|0]=b;n=d,o=b&251|Bb(y[a+12|0]|y[a+13|0]<<8)>>>3&4,v[n+12|0]=o;b=4096;a:{b:{switch(c-1|0){case 0:i=-128;b=127;break a;case 1:break b;default:break a}}i=-1616;b=1616}l=a+26|0;d=b-i|0;j=d>>>1|0;m=Sd(h,f);b=0;while(1){if(b>>>0>=m>>>0){fb=e+16|0}else{c=yb(h,b);w[c>>1]=k;g=l+(b<<2)|0;a=ze((y[g+2|0]|y[g+3|0]<<8)<<16>>16)+i|0;f=a;a=a>>31<<6|a>>>26;f=j+(f<<6)|0;a=f>>>0<j>>>0?a+1|0:a;n=c,o=Eh(Gc(Bua(f,a,d,0),hb)),v[n+2|0]=o;n=e,o=Bb(y[g|0]|y[g+1|0]<<8),w[n+10>>1]=o;w[e+8>>1]=1;b=b+1|0;k=z[qe(e+10|0,e+8|0)>>1]+k|0;continue}break}}function Zqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=Ov(c,d);d=b&63;if(e>>>0>d>>>0){c=SY(c,d);d=0;g=fb-16|0;fb=g;v[a+12|0]=0;Nc(a);e=fb-32|0;fb=e;a:{b:{if(Vg(a)>>>0<=14){if(uh(1073741823)>>>0<=14){break b}f=Ab(a);f=Zf(e+12|0,15,oc(x[a>>2],x[a+4>>2]),f);Zr(a,f);Yf(f)}fb=e+32|0;break a}ed();p()}j=c+1|0;h=0-y[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=(d<<1)+j|0;f=y[e|0];if(!f){break c}v[g+11|0]=64;h=f+(h<<16>>16)|0;f=Yl(g+12|0,h&65535,y[Qb(e+1|0,g+11|0)|0]);d:{if(A[a+4>>2]<A[Ab(a)>>2]){OY(a,f);break d}i=fb-32|0;fb=i;e=Ab(a);e=Zf(i+12|0,Lf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),e);cp(x[e+8>>2],z[f>>1]|z[f+2>>1]<<16);x[e+8>>2]=x[e+8>>2]+4;Zr(a,e);Yf(e);fb=i+32|0}d=d+1|0;continue}break}d=y[c+32|0];v[a+14|0]=d>>>4;v[a+13|0]=d&15;c=y[c+31|0];d=c&15;v[a+15|0]=d;v[a+16|0]=d;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}fb=g+16|0}e:{f:{if(b<<24>>24>=0){b=a+12|0;break f}b=a+12|0;if(mc(x[a>>2],x[a+4>>2])){break f}a=y[a+12|0]|1;break e}a=y[b|0]&-2}v[b|0]=a}function Xla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;e=fb-16|0;fb=e;f=x[a+40>>2];g=x[a+36>>2];l=x[a+16>>2];k=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=k;m=b+24|0;n=x[a+32>>2];o=x[a+28>>2];k=x[a+8>>2];p=x[a+12>>2];while(1){if(d){b=x[e+8>>2];i=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;b=(((b>>>16|0)+4&131064)<<1)+m|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];v=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];b=0;while(1){if((b|0)!=2){j=b<<1;h=j+i|0;x[(b<<2)+e>>2]=(((((D(w[h+8>>1],s)+D(w[h+4>>1],t)|0)+D(w[h+12>>1],r)|0)+D(w[h+16>>1],q)|0)/2|0)+((((D(w[(j|-8)+i>>1],y)+D(w[(j|-12)+i>>1],z)|0)+D(w[(j|-4)+i>>1],v)|0)+D(w[h>>1],u)|0)/2|0)|0)/16384;b=b+1|0;continue}break}g=g+o|0;x[c>>2]=x[c>>2]+D(x[e>>2],g>>12);f=f+n|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],f>>12);Pb(e+8|0,k,p);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=e+16|0}function nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;g=x[a+12>>2];h=x[a+8>>2];a:{b:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){e=131112;if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break a}e=262184;if((g|0)==-2&h>>>0<2147483648|g>>>0<4294967294){break a}break b}e=262184;if((g|0)==1&h>>>0>2147483648|g>>>0>1){break a}}e=196648}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];k=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=k;k=b+e|0;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[f+8>>2];e=(x[f+12>>2]<<1)+l|0;b=(b>>>16&65520)+k|0;b=(((((((D(w[e-4>>1],w[b+2>>1])+D(w[e-6>>1],w[b>>1])|0)+D(w[e-2>>1],w[b+4>>1])|0)+D(w[e>>1],w[b+6>>1])|0)+D(w[e+2>>1],w[b+8>>1])|0)+D(w[e+4>>1],w[b+10>>1])|0)+D(w[e+6>>1],w[b+12>>1])|0)+D(w[e+8>>1],w[b+14>>1])|0)/32768|0;j=j+n|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(f+8|0,h,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=f+16|0}function Uta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-32|0;fb=g;i=a+8|0;c=x[a+8>>2];h=nc(a);a:{if((c|0)!=x[h>>2]){break a}k=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){f=fb-16|0;fb=f;l=f+8|0;a=fb-32|0;fb=a;fd(a+24|0,d,c);m=a+16|0;c=x[a+24>>2];h=x[a+28>>2];j=((d-e>>1)+1|0)/-2<<1;d=d+j|0;e=fb-16|0;fb=e;while(1){if((c|0)!=(h|0)){d=S$(d,c)+2|0;c=c+2|0;continue}break}x[e+12>>2]=d;qc(m,h,e+12|0);fb=e+16|0;c=x[a+16>>2];x[a+12>>2]=x[a+20>>2];qc(l,c,a+12|0);fb=a+32|0;fb=f+16|0;c=x[f+12>>2];x[i>>2]=c;x[k>>2]=x[k>>2]+j;break a}x[g+8>>2]=c-e;x[g+28>>2]=1;d=g+8|0;c=x[bd(d,g+28|0)>>2];c=ek(d,c,c>>>2|0,x[a+16>>2]);d=vb(g+4|0,x[a+4>>2]);f=vb(g,x[a+8>>2]);d=x[d>>2];e=rE(d,x[f>>2]);f=fb-16|0;fb=f;x[f+12>>2]=d;e=Bp(f,c+8|0,e);d=x[e>>2];while(1){if(x[e+4>>2]!=(d|0)){j=d;d=x[f+12>>2];$i(j,y[d|0]|y[d+1|0]<<8);d=x[e>>2]+2|0;x[e>>2]=d;ge(f+12|0);continue}break}je(e);fb=f+16|0;Tb(a,c);Tb(k,c+4|0);Tb(i,c+8|0);Tb(h,nc(c));aj(c);c=x[a+8>>2]}$i(c,y[b|0]|y[b+1|0]<<8);x[i>>2]=x[i>>2]+2;fb=g+32|0}function iC(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a|0]=e;v[a+1|0]=e>>>8;v[a+2|0]=e>>>16;v[a+3|0]=e>>>24;v[a+4|0]=d;v[a+5|0]=d>>>8;v[a+6|0]=d>>>16;v[a+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[a+24|0]=e;v[a+25|0]=e>>>8;v[a+26|0]=e>>>16;v[a+27|0]=e>>>24;v[a+28|0]=d;v[a+29|0]=d>>>8;v[a+30|0]=d>>>16;v[a+31|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[a+16|0]=e;v[a+17|0]=e>>>8;v[a+18|0]=e>>>16;v[a+19|0]=e>>>24;v[a+20|0]=d;v[a+21|0]=d>>>8;v[a+22|0]=d>>>16;v[a+23|0]=d>>>24;d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+8|0]=e;v[a+9|0]=e>>>8;v[a+10|0]=e>>>16;v[a+11|0]=e>>>24;v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function W9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=fb-32|0;fb=h;p=b+20|0;k=x[d+4>>2];m=x[d>>2];l=m;while(1){a:{if(!k){break a}g=0;e=fb-32|0;fb=e;i=b+20|0;f=b+212|0;j=c&-4096;b:{c:{while(1){if((g|0)==16){break c}d=x[yb(f,g)>>2];n=Vd(i,d);if(!((j|0)==x[n>>2]?y[n+8|0]:0)){g=g+1|0;continue}break}g=f+(g<<2)|0;dM(f,g,g+4|0);q=yb(f,0),r=d,x[q>>2]=r;break b}d=x[yb(f,15)>>2];dM(f,b+272|0,b+276|0);q=yb(f,0),r=d,x[q>>2]=r;f=Vd(i,d);x[f>>2]=j;oz(e+16|0,x[b+8>>2],d);g=x[x[b>>2]+44>>2];i=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=i;ib[g|0](e+24|0,b,j,e+8|0);x[f+4>>2]=x[e+28>>2];v[f+8|0]=1}fb=e+32|0;e=Vd(p,d);f=c-x[e>>2]|0;x[h+16>>2]=4096-f;x[h+8>>2]=k;g=h+16|0;j=h+8|0;q=h,r=x[Hb(g,j)>>2],x[q+28>>2]=r;e=x[e+4>>2];i=e-f|0;x[h+24>>2]=e>>>0>=i>>>0?i:0;e=x[Hb(h+28|0,h+24|0)>>2];oz(g,x[b+8>>2],d);g=x[h+16>>2];oz(j,x[b+8>>2],d);xk(f+g|0,e+(f+x[h+8>>2]|0)|0,l);o=e+o|0;if(e>>>0<A[h+28>>2]){break a}c=c+e|0;l=e+l|0;k=k-e|0;continue}break}cc(a,m,o);fb=h+32|0}function $ta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-144|0;fb=f;x[31609]=0;l=R(273,a|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){m=c+900380|0;n=f+16|0;while(1){a:{if((j&65535)>>>0>=l>>>0){ub(a);fb=f+144|0;return}x[31609]=0;O(292,a|0,f+8|0);e=x[31609];x[31609]=0;if((e|0)!=1){b:{e=Bb(z[f+8>>1]);if((e-1&65535)>>>0>=z[c+480192>>1]){break b}e=x[(e<<2)+m>>2];if(!e){break b}e=Wh(e,b);g=y[f+11|0];c:{if(!g){break c}h=y[f+10|0];if(h&1){v[e+12|0]=y[e+12|0]|1}if(h&2){v[e+12|0]=y[e+12|0]|4}if(!(h&4)){break c}v[e+12|0]=y[e+12|0]|2}v[f+4|0]=g;v[f+7|0]=31;h=y[Qb(f+4|0,f+7|0)|0];x[31609]=0;h=h+1&255;O(293,e|0,h|0);g=x[31609];x[31609]=0;if((g|0)==1){break a}v[e+13|0]=y[f+13|0];v[e+14|0]=y[f+14|0];g=y[f+12|0];v[e+15|0]=g;v[e+16|0]=g;g=x[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(e<<2)+n|0;o=Bb(z[i>>1]);k=yb(g,e);w[k>>1]=o;i=Bb(z[i+2>>1]);w[f+4>>1]=d?i+128>>>2|0:i;Hf(f+4|0,64);v[k+2|0]=y[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=N()|0;ub(a);Q(b|0);p()}function Ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=fb-16|0;fb=g;o=x[a+24>>2];p=x[a+20>>2];f=x[a+48>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];l=x[a+68>>2];s=l>>31;m=x[a+64>>2];t=m>>31;n=x[a+60>>2];u=n>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Yb(e,-16777216,16776704);i=Aua(m,t,e,e>>31);j=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38082>>1])+D(w[h-2>>1],w[e+38080>>1])|0)+D(w[h+2>>1],w[e+38084>>1])|0)+D(w[h+4>>1],w[e+38086>>1])|0)/16384<<8;e=h;e=Aua(e,e>>31,n,u);i=e+i|0;k=hb+j|0;k=e>>>0>i>>>0?k+1|0:k;f=Yb(f,-16777216,16776704);e=Aua(l,s,f,f>>31);j=e+i|0;f=hb+k|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Sc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Pb(g+8|0,v,y);e=e-(h&r)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;fb=g+16|0}function oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;g=x[a+12>>2];h=x[a+8>>2];a:{b:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){e=131112;if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break a}e=262184;if((g|0)==-2&h>>>0<2147483648|g>>>0<4294967294){break a}break b}e=262184;if((g|0)==1&h>>>0>2147483648|g>>>0>1){break a}}e=196648}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];k=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=k;k=b+e|0;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[f+8>>2];e=x[f+12>>2]+l|0;b=(b>>>16&65520)+k|0;b=(((((((D(v[e-2|0],w[b+2>>1])+D(v[e-3|0],w[b>>1])|0)+D(v[e-1|0],w[b+4>>1])|0)+D(v[e|0],w[b+6>>1])|0)+D(v[e+1|0],w[b+8>>1])|0)+D(v[e+2|0],w[b+10>>1])|0)+D(v[e+3|0],w[b+12>>1])|0)+D(v[e+4|0],w[b+14>>1])<<8)/32768|0;j=j+n|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Pb(f+8|0,h,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=f+16|0}function GD(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}v[d+15|0]=239;break b}v[d+15|0]=254;break b}if(c>>>0>=16){v[d+15|0]=c|15;break b}v[d+15|0]=c|240;break b;case 1:v[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){v[d+15|0]=c>>>4|240;break b}v[d+15|0]=c|224;break b;case 8:v[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:v[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=Eh(c<<1),v[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:v[d+15|0]=119;break b;case 1:v[d+15|0]=119;break b;case 2:v[d+15|0]=121;break b;case 3:break g;default:break b}}v[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}v[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=y[b+25008|0]}ee(e,a,d+15|0);fb=d+16|0}function cba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+24;_M(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+24;jc(c);fb=d+16|0;return}i=fb-32|0;fb=i;c=Ab(a);c=GJ(i+12|0,IJ(a,fj(x[a>>2],x[a+4>>2])+1|0),fj(x[a>>2],x[a+4>>2]),c);_M(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+24;g=fb-16|0;fb=g;d=vb(g+12|0,x[a+4>>2]);e=vb(g+8|0,x[a>>2]);f=x[vb(g+4|0,x[c+4>>2])>>2];h=fb-16|0;fb=h;b=fb-32|0;fb=b;fd(b+24|0,x[d>>2],x[e>>2]);k=b+16|0;e=x[b+24>>2];l=x[b+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=f;x[d+12>>2]=e;while(1){if(Fd(e,l)){e=il(e);f=il(x[d+8>>2]);x[f+16>>2]=x[e+16>>2];j=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=j;j=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=j;e=gt(d+12|0);gt(d+8|0);e=x[e>>2];continue}break}qc(k,e,d+8|0);fb=d+16|0;d=x[b+16>>2];x[b+12>>2]=x[b+20>>2];qc(h+8|0,d,b+12|0);fb=b+32|0;fb=h+16|0;x[c+4>>2]=x[h+12>>2];Tb(a,c+4|0);Tb(a+4|0,c+8|0);Tb(Ab(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;DJ(c);fb=i+32|0}function Bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;h=fb-16|0;fb=h;n=x[a+24>>2];o=x[a+20>>2];e=x[a+48>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];j=x[a+68>>2];r=j>>31;k=x[a+64>>2];s=k>>31;l=x[a+60>>2];t=l>>31;u=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Aua(k,s,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Aua(j,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;m=(((D(v[g|0],w[e+38082>>1])+D(v[g-1|0],w[e+38080>>1])|0)+D(v[g+1|0],w[e+38084>>1])|0)+D(v[g+2|0],w[e+38086>>1])<<8)/16384<<8;e=m;g=Aua(e,e>>31,l,t);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Sc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,y);f=f-(q&m)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function k8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}cd(g,x[d+28>>2]);x[31609]=0;b=R(1252,x[g>>2])|0;a=x[31609];x[31609]=0;d:{e:{f:{g:{if((a|0)!=1){_b(g);cd(g,x[d+28>>2]);x[31609]=0;a=R(1253,x[g>>2])|0;d=x[31609];x[31609]=0;if((d|0)==1){break g}_b(g);x[31609]=0;O(1254,g|0,a|0);d=x[31609];x[31609]=0;if((d|0)==1){b=N()|0;break d}x[31609]=0;O(1255,g|12,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break f}x[31609]=0;d=g+24|0;a=sa(1256,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31609];x[31609]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=Ub(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;_b(g);break d}b=N()|0;_b(g);break d}b=N()|0;Ub(g);break d}b=N()|0;while(1){d=Ub(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function v8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}cd(g,x[d+28>>2]);x[31609]=0;b=R(28,x[g>>2])|0;a=x[31609];x[31609]=0;d:{e:{f:{g:{if((a|0)!=1){_b(g);cd(g,x[d+28>>2]);x[31609]=0;a=R(1235,x[g>>2])|0;d=x[31609];x[31609]=0;if((d|0)==1){break g}_b(g);x[31609]=0;O(1236,g|0,a|0);d=x[31609];x[31609]=0;if((d|0)==1){b=N()|0;break d}x[31609]=0;O(1237,g|12,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break f}x[31609]=0;d=g+24|0;a=sa(1238,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31609];x[31609]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;_b(g);break d}b=N()|0;_b(g);break d}b=N()|0;tb(g);break d}b=N()|0;while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function rk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;b=i+4|0;cd(b,x[d+28>>2]);c=0;x[31609]=0;j=R(28,x[i+4>>2])|0;k=x[31609];x[31609]=0;if((k|0)!=1){_b(b);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(th(i+12|0,i+8|0)){break b}c:{if((ml(j,v[g|0])|0)==37){if((g+1|0)==(h|0)){break b}c=ml(j,v[g+1|0]);d:{if(!((c|0)==69|(c&255)==48)){b=0;k=1;break d}if((g+2|0)==(h|0)){break b}b=c;c=ml(j,v[g+2|0]);k=2}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,c,b)|0,x[l+12>>2]=m;g=(g+k|0)+1|0;break c}b=x[j+8>>2];if(Jf(b,1,v[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(Jf(b,1,v[g|0])){continue}}break}while(1){b=i+12|0;if(th(b,i+8|0)){break c}c=tl(x[i+12>>2]);if(!Jf(x[j+8>>2],1,c)){break c}Fm(b);continue}}if((Ky(j,tl(x[i+12>>2]))|0)==(Ky(j,v[g|0])|0)){g=g+1|0;Fm(i+12|0);break c}x[e>>2]=4}c=x[e>>2];continue}break}x[e>>2]=4}if(th(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;_b(i+4|0);Q(a|0);p()}function Iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Xf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(g>>>0<=d>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(f>>>0>x[c+24>>2]-h>>>0){break b}i=b+12|0;j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(f|0)){break a}l=(D(b,d)<<2)+k|0;a=0;while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{e=a<<2;m=x[e+l>>2];n=Yt(i);o=(x[e+j>>2]+(h<<1)|0)+(b<<1)|0;e=rd((rd(n,21)+m|0)+2048|0,12);e=(e|0)>=32767?32767:e;w[o>>1]=(e|0)<=-32768?-32768:e;a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function Fx(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){f=c+1073741824|0;e=e+1|0;f=e?f:f+1|0;break a}f=c+1073741824|0;if(a|(b|0)!=134217728){break a}a=e&1;e=a+e|0;f=a>>>0>e>>>0?f+1|0:f;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){a=d<<4|c>>>28;e=c<<4|b>>>28;f=a&524287|2146959360;break a}e=0;f=2146435072;if(h>>>0>1140785151){break a}f=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;$f(g+16|0,a,b,c,e,h-15233|0);cn(g,a,b,c,e,15361-h|0);b=x[g+8>>2];e=b<<4;b=x[g+12>>2]<<4|b>>>28;c=x[g>>2];f=x[g+4>>2];h=f;e=f>>>28|e;f=b;a=h&268435455;b=c|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){e=e+1|0;f=e?f:f+1|0;break a}if(b|(a|0)!=134217728){break a}a=e;e=e+(e&1)|0;f=a>>>0>e>>>0?f+1|0:f}fb=g+32|0;l(0,e|0);l(1,d&-2147483648|f);return+n()}function If(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;c=x[a+36>>2];ig(x[x[c>>2]-12>>2]+c|0,0);c=a+32|0;Qc(d+12|0,c,4);if(!Gb(x[x[d+12>>2]>>2],x[d+16>>2])){yy(a)}a:{if(!x[a+8>>2]){break a}Qc(d+12|0,c,6);if(Gb(x[x[d+12>>2]>>2],x[d+16>>2])){break a}Qc(d+24|0,c,7);if(Gb(x[x[d+24>>2]>>2],x[d+28>>2])){break a}f=x[a+36>>2];e=x[a+92>>2];g=D(x[a+28>>2],x[a+8>>2]);h=g;g=g+x[a+88>>2]|0;e=h>>>0>g>>>0?e+1|0:e;Ci(f,g,e,0)}Qc(d+12|0,c,5);c=0;b:{if(!Gb(x[x[d+12>>2]>>2],x[d+16>>2])){break b}e=fj(x[a+52>>2],x[a+56>>2]);while(1){if((e|0)==(i|0)){break b}c:{g=(x[a+108>>2]+i>>>0)%(e>>>0)|0;f=wf(x[a+52>>2],g);h=x[f>>2];j=x[a+40>>2];if(h>>>0>=Xc(j,x[a+44>>2])>>>0){break c}f=rl(d+12|0,xb(j,h),z[f+20>>1]);h=Jy(b,f);Eb(f);if(!h){break c}b=g+1|0;x[a+108>>2]=(b|0)!=(e|0)?b:0;c=wf(x[a+52>>2],g);b=x[c+8>>2];e=x[c+12>>2];if(!(b|e)){break b}f=x[a+16>>2];c=f+b|0;b=x[a+20>>2]+e|0;Ci(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);c=wf(x[a+52>>2],g);break b}i=i+1|0;continue}}fb=d+32|0;return c}function BH(a,b,c){var d=0,e=0,f=0;e=fb-32|0;fb=e;a:{f=_s(e+28|0,b);d=x[f>>2];if(!Ed(d)){x[31609]=0;b=P(36,e+4|0,b|0)|0;a=x[31609];x[31609]=0;b:{c:{d:{if((a|0)!=1){x[31609]=0;a=e+16|0;S(1011,a|0,17716,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break d}x[31609]=0;W(1367,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}p()}a=N()|0;break a}a=N()|0;break b}a=N()|0;tb(e+16|0)}tb(b);break a}Zs(d);if(!Ys(a+8|0,22292,x[f>>2])){v[a+8|0]=127}if(!Ys(a+9|0,22292,x[f>>2])){v[a+9|0]=127}x[31609]=0;O(272,a+12|0,22292);b=x[31609];x[31609]=0;e:{f:{if((b|0)==1){break f}x[31609]=0;b=a+24|0;O(272,b|0,22292);d=x[31609];x[31609]=0;if((d|0)==1){break f}x[a+60>>2]=0;x[31609]=0;O(272,a+36|0,22292);d=x[31609];x[31609]=0;if((d|0)==1){break f}x[31609]=0;O(272,a+48|0,22292);d=x[31609];x[31609]=0;if((d|0)==1){break f}x[31609]=0;b=P(71,e+16|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break e}a=N()|0;break a}a=N()|0;break a}bi(a- -64|0,c);bi(a+68|0,c);tb(b);gl(f);fb=e+32|0;return}gl(f);Q(a|0);p()}function hq(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=B[f>>2];k=B[c>>2];l=B[d>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=g+B[f>>2];k=E(k-l);g=E(g-i);B[d>>2]=E(k*B[e>>2])-E(B[e+4>>2]*g);B[f>>2]=E(g*B[e>>2])+E(k*B[e+4>>2]);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=g+l;j=c-12|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=g+l;j=c-20|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=g+l;j=c-28|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function Ai(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=pj(a)&2047;c=pj(5551115123125783e-32);a:{if(f-c>>>0>=pj(512)-c>>>0){if(c>>>0>f>>>0){return a+1}o(+a);c=j(1)|0;e=j(0)|0;b:{if(pj(1024)>>>0>f>>>0){break b}b=0;if(!e&(c|0)==-1048576){break a}if(pj(Infinity)>>>0<=f>>>0){return a+1}if((c|0)>0|(c|0)>=0){return Os(3105036184601418e216)}if(c>>>0<3230714880){break b}return Os(12882297539194267e-247)}c=c<<1|e>>>31;f=!(e<<1)&(c|0)==-2129002496|c>>>0<2165964800?f:0}b=C[177];g=b+a;a=a-(g-b);b=a*a;h=b*b*(a*C[182]+C[181]);b=b*(a*C[180]+C[179]);a=a*C[178];o(+g);j(1)|0;c=j(0)|0;d=c<<4&2032;a=h+(b+(a+C[d+1464>>3]));d=d+1472|0;e=0+x[d>>2]|0;d=x[d+4>>2]+(c<<13)|0;d=e>>>0<i>>>0?d+1|0:d;if(!f){c:{if(!(c&-2147483648)){l(0,e|0);l(1,d+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,e|0);l(1,d+1071644672|0);b=+n();g=b*a;a=g+b;if(a<1){gK(CK()*22250738585072014e-324);h=a+1;a=h+(g+(b-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,e|0);l(1,d|0);b=+n();b=b*a+b}return b}function zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb+-64|0;fb=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Xf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(f>>>0<=d>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(e>>>0>x[c+24>>2]-i>>>0){break b}j=b+12|0;k=x[c+16>>2];l=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}m=(D(b,d)<<2)+l|0;n=(D(b+i|0,h)<<1)+k|0;a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=rd((x[(a<<2)+m>>2]+rd(Yt(j),21)|0)+2048|0,12);g=(g|0)>=32767?32767:g;w[(a<<1)+n>>1]=(g|0)<=-32768?-32768:g;a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function Jla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Hg(j,k,l);n=hb;f=x[a+76>>2];fg(b,g,uf(j,k,d),hb);o=hb>>>0>f>>>0?d:0}f=a+112|0;h=x[a+40>>2];i=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;b=o;m=b?m:0;n=b?n:0;g=(g<<1)+p|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){ce(f,w[g+(x[e+12>>2]<<1)>>1]/4<<16>>16);be(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}g=x[a+32>>2];r=x[c>>2];b=Fg(f,q);i=x[a+28>>2]+i|0;x[c>>2]=D(b,i>>12)+r;h=g+h|0;x[c+4>>2]=x[c+4>>2]+D(b,h>>12);Pb(e,j,k);c=c+8|0;b=x[e>>2];g=x[e+4>>2];continue a}else{ce(f,w[g+(x[e+12>>2]<<1)>>1]/4<<16>>16);be(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;fb=e+16|0}function bA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);c=fb-48|0;fb=c;a:{b=x[a+20>>2];b:{if(!b){break b}d=x[b+4>>2];b=x[b+8>>2];if(Xc(d,b)>>>0<4){break b}se(c+16|0,d,b);b=Md(c+8|0);d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=__(c+28|0,x[c+16>>2],x[c+20>>2],c);x[31609]=0;b=R(151,d|0)|0;f=x[31609];x[31609]=0;c:{if((f|0)!=1){if(b){break c}b=x[x[a>>2]+40>>2];x[31609]=0;f=R(b|0,a|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}b=x[a+20>>2];if(Xc(x[b+4>>2],x[b+8>>2])-4>>>0<f<<2>>>0){break c}e=x[x[a>>2]+176>>2];b=0;x[31609]=0;O(e|0,a|0,-1);e=x[31609];x[31609]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=x[x[a>>2]+180>>2];x[31609]=0;W(b|0,a|0);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break a}x[31609]=0;g=E(xa(473,d|0));e=x[31609];x[31609]=0;d:{if((e|0)==1){break d}e=x[x[a>>2]+44>>2];x[31609]=0;wa(e|0,a|0,b|0,E(Um(g)?g:E(0)));e=x[31609];x[31609]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}ub(d)}fb=c+48|0;return}a=N()|0;ub(d);Q(a|0);p()}function qk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;c=i+4|0;cd(c,x[d+28>>2]);b=0;x[31609]=0;j=R(1252,x[i+4>>2])|0;k=x[31609];x[31609]=0;if((k|0)!=1){_b(c);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(fi(i+12|0,i+8|0)){break b}c:{if((pk(j,x[g>>2])|0)==37){if((g+4|0)==(h|0)){break b}b=pk(j,x[g+4>>2]);d:{if(!((b|0)==69|(b&255)==48)){c=0;k=4;break d}if((g+8|0)==(h|0)){break b}c=b;b=pk(j,x[g+8>>2]);k=8}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,b,c)|0,x[l+12>>2]=m;g=(g+k|0)+4|0;break c}if(oj(j,1,x[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(oj(j,1,x[g>>2])){continue}}break}while(1){b=i+12|0;if(fi(b,i+8|0)){break c}if(!oj(j,1,sl(x[i+12>>2]))){break c}jo(b);continue}}if((km(j,sl(x[i+12>>2]))|0)==(km(j,x[g>>2])|0)){g=g+4|0;jo(i+12|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(fi(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;_b(i+4|0);Q(a|0);p()}function yta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-2608|0;fb=g;d=eE(g+4|0,a);x[d+1060>>2]=0;x[d+1064>>2]=0;a=1068;while(1){e=a+d|0;v[e+4|0]=0;w[e>>1]=0;w[e+2>>1]=0;a=a+6|0;if((a|0)!=2604){continue}break}x[31609]=0;W(323,d|0);a=x[31609];x[31609]=0;a:{b:{if((a|0)!=1){if((w[d+1068>>1]|w[d+1070>>1])<0){break a}e=d+1068|0;c:{while(1){if((c|0)==(h|0)){break a}x[31609]=0;k=P(158,d|0,1)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}a=0;d:{while(1){x[31609]=0;f=P(158,d|0,1)|0;l=x[31609];x[31609]=0;if((l|0)==1){break d}a=e+D(a,6)|0;a=w[(f?a+2|0:a)>>1];e:{if((a|0)>255){break e}f=e+D(a,6)|0;i=y[f+4|0];if(w[f>>1]<0){break e}if(w[f+2>>1]>=0){continue}}break}i=(k?-1:0)^i;j=(j&255)+(i&255)|0;v[b+h|0]=j;h=h+1|0;continue}break}a=T(28816)|0;break b}a=T(28816)|0;break b}a=T(28816)|0}if((gb|0)==($(28816)|0)){Y(a|0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0}ub(d);Q(a|0);p()}a=Ar(d);ub(d);fb=g+2608|0;return a|0}function Lz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;a:{b:{c:{d:{e:{f:{g:{e=x[a+36>>2];c=x[a+40>>2];h:{if(Ib(e,c)){tc(d+12|0);break h}wo(d,a);x[31609]=0;c=R(1056,d|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break g}x[d+12>>2]=c;nf(d);c=x[a+40>>2];e=x[a+36>>2]}e=(h=a+36|0,i=x[d+12>>2],j=Ib(e,c),j?h:i);if((b|0)==-1){f=x[e>>2];c=0;g=4194304;break e}if((b|0)>=0){c=b;f=x[e>>2];if((fj(f,x[e+4>>2])|0)>(b|0)){break e}}b=dc(8);x[31609]=0;c=P(36,d|0,10982)|0;a=x[31609];x[31609]=0;if((a|0)==1){break f}sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}a=N()|0;tb(c);break d}a=N()|0;nf(d);break c}a=N()|0;lc(b);break d}x[a+8>>2]=b;b=x[a+24>>2];x[b+480208>>2]=x[b+480208>>2]&-4194305|g;Vj(b+484360|0,y[wf(f,c)+16|0]);b=wf(x[e>>2],c);c=x[b+8>>2];b=x[b+12>>2];x[31609]=0;+oa(1088,a|0,b|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}a=N()|0}xl(d+12|0)}Q(a|0)}p()}x[a+16>>2]=0;x[a+20>>2]=0;xl(d+12|0);fb=d+16|0}function Yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];y=w[b+4>>1];z=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=i+p|0;x[(i<<2)+e>>2]=((((D(v[f+4|0],s)+D(v[f+2|0],t)|0)+D(v[f+6|0],r)|0)+D(v[f+8|0],q)<<8>>1)+(((D(v[f-4|0],z)+D(v[f-6|0],b)|0)+D(v[f-2|0],y)|0)+D(v[f|0],u)<<8>>1)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Pb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function eV(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0;if(Kj(x[a+656>>2])){e=y[a+797|0];e=(l=e,m=y[a+799|0],n=Tc(e),n?l:m);f=Ob(d+1074312|0,34);d=x[a+656>>2];a:{if(!f){break a}f=e&255;if(!f|f>>>0>120){break a}e=y[xb(d+108|0,f-1|0)|0]}k=E(E(x[a+704>>2])*b);d=x[d+44>>2];g=((e&255)+c|0)-61<<16>>16;b:{c:{c=x[a+852>>2]+w[a+772>>1]|0;if(c){h=x[d+36>>2];if(h){break c}}b=Vm(d,c+g<<16>>16);break b}j=h+1|0;i=hA(c,j);e=iA(c,j);b=E(1);f=w[d+28>>1];c=g+i<<16>>16;d:{if((f|0)>(c|0)){break d}g=x[d+4>>2];if((c|0)>(oc(g,x[d+8>>2])+f|0)-1<<16>>16){break d}if(!e){b=B[yb(g,c-f|0)>>2];break b}e:{f:{g:{switch(z[d>>1]-1|0){case 2:h=x[d+16>>2];if(!oc(h,x[d+20>>2])){break f}b=B[yb(h,e-1|0)>>2];break e;case 0:break g;default:break f}}i=x[d+16>>2];if(!oc(i,x[d+20>>2])){break f}b=B[yb(i,(e+D(h,mA(c,z[d+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=Ee(E(Vm(d,c+1<<16>>16)/Vm(d,c)),E(E(e|0)/E(j|0)))}b=E(b*B[yb(g,c-f|0)>>2])}}l=a,m=Bk(E(E(k*b)*E(16))),x[l+700>>2]=m}}function eJ(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return c|0}function cta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;nd(b,32);g=b,h=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24)),x[g>>2]=h;f=$b(y[a+10|0]|y[a+11|0]<<8|(y[a+12|0]<<16|y[a+13|0]<<24));x[b+4>>2]=f;g=b,h=$b(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))+f|0,x[g+8>>2]=h;if(!(d?0:c)){c=$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Bb(y[a+42|0]|y[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}_l(b,+(c|0)*.0006510416666666666);v[e+15|0]=y[a+9|0];v[e+14|0]=64;g=b,h=y[Qb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;c=x[b+4>>2];d=x[b+8>>2];if(v[a+40|0]&1){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1}if(y[a+41|0]>=9){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1}b:{if(c+1>>>0<d>>>0){w[b+34>>1]=z[b+34>>1]|2;break b}x[b+4>>2]=0;x[b+8>>2]=0}fb=e+16|0}function Cy(a,b,c,d,e,f,g,h,i,j,k,l){var m=0,n=0;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Cb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Cb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;l=Ey(l,l+128|0,a)-l|0;g=l>>2;if((g|0)>31){break b}a=v[g+95168|0];d:{e:{f=l&-5;if((f|0)!=88){if((f|0)!=96){break e}b=x[e>>2];if((b|0)!=(d|0)){f=-1;if((pl(v[b-1|0])|0)!=(pl(v[c|0])|0)){break b}}x[e>>2]=b+1;v[b|0]=a;return 0}v[c|0]=80;break d}d=pl(a);if((d|0)!=v[c|0]){break d}m=c,n=ut(d),v[m|0]=n;if(!y[b|0]){break d}v[b|0]=0;if(!Cb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=a;f=0;if((g|0)>21){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-16|0;fb=g;x[g+12>>2]=1;a:{if(Zo(a)){c=x[a>>2];m=Mg(c,x[a+4>>2]);x[g+8>>2]=m;j=x[Hb(g+12|0,g+8|0)>>2];while(1){if(j){j=j-1|0;if((b|0)!=(c|0)){d=wb(x[b>>2]);f=d;e=wb(x[b+4>>2]);k=e;d=rE(d,e);h=fb-16|0;fb=h;b:{if(Hn(c)>>>0>=d>>>0){l=x[c>>2];i=$c(l,x[c+4>>2]);if(i>>>0<d>>>0){e=fb-16|0;fb=e;x[e+12>>2]=f;JX(e+12|0,i);fb=e+16|0;i=f;f=x[e+12>>2];XU(i,f,l);dv(c,f,k,d-$c(x[c>>2],x[c+4>>2])|0);break b}WU(h+8|0,f,k,l);Jd(c,x[h+12>>2]);break b}VU(c);JC(c,fk(c,d));dv(c,f,k,d)}fb=h+16|0;rs(c+12|0,b+12|0);w[c+28>>1]=z[b+28>>1]}c=c+32|0;continue}break}if(!m){ZB(a,1,b);break a}LU(a,x[a>>2]+32|0);break a}if(x[a>>2]){NU(a);c=x[a>>2];Zo(a);Db(c);n=Ab(a),o=0,x[n>>2]=o;x[a>>2]=0;x[a+4>>2]=0}d=Wq(a,1);c=fb-16|0;fb=c;if(uh(134217727)>>>0<d>>>0){ed();p()}JV(c+8|0,d);d=x[c+8>>2];x[a+4>>2]=d;x[a>>2]=d;n=Ab(a),o=d+(x[c+12>>2]<<5)|0,x[n>>2]=o;fb=c+16|0;ZB(a,1,b)}fb=g+16|0}function qz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=(D(b,f)<<3)+j|0;l=(D(b+h|0,g)<<2)+i|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=(a<<2)+l|0,n=E(+(vn(Fe(Jg(C[(a<<3)+k>>3])*134217728))|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=c- -64|0}function wA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;d=y[a+2|0];if(!(!d|(d|0)==255)){x[e+12>>2]=d+1;x[e+8>>2]=10;fh(b,x[Cd(e+12|0,e+8|0)>>2]);i=y[a+3|0];v[b+15|0]=i;v[b+16|0]=i;j=y[a+4|0];v[b+13|0]=j;l=y[a+5|0];v[b+14|0]=l;g=511;d=0;a:{b:{switch(c-1|0){case 1:d=4096;g=128;break a;case 0:break b;default:break a}}d=32768;g=1024}o=a+6|0;p=g>>>1|d;c=x[b>>2];k=Sd(c,x[b+4>>2]);d=0;while(1){if((d|0)==(k|0)){c=y[b+12|0]&-2|v[a|0]&1;v[b+12|0]=c;c=c&-5|(y[a|0]|y[a+1|0]<<8)<<1&(k>>>0>=i>>>0)<<2;v[b+12|0]=c;v[b+12|0]=c&253|(y[a|0]|y[a+1|0]<<8)>>>1&(j>>>0<=l>>>0?(k>>>0>=j>>>0)<<1:0)}else{m=yb(c,d);h=(d<<2)+o|0;f=(y[h|0]|y[h+1|0]<<8)>>>4|0;w[m>>1]=f;c:{if(d){n=z[yb(c,d-1|0)>>1];if(f>>>0>=n>>>0){break c}f=n+1|0}else{f=0}q=yb(c,d),r=f,w[q>>1]=r}x[e+12>>2]=(((y[h+2|0]|y[h+3|0]<<8)<<16>>16)+p|0)/(g|0);x[e+8>>2]=0;x[e+4>>2]=64;q=m,r=x[Zj(e+12|0,e+8|0,e+4|0)>>2],v[q+2|0]=r;d=d+1|0;continue}break}}fb=e+16|0}function q0(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;a:{if((y[a|0]-16&255)>>>0<241){break a}c=1698;while(1){if((c|0)==1954){h=a+1346|0;i=a+930|0;j=a+418|0;k=a+2|0;c=0;a=0;while(1){if((c|0)==32){l=a;break a}e=D(c,13);if(y[nc(e+k|0)|0]){break a}b=(c<<4)+j|0;if(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)){break a}f=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);if(f>>>0>1048575){break a}if(y[nc(e+i|0)|0]){break a}e=D(c,11)+h|0;if(y[xb(e,0)|0]>15){break a}if(y[xb(e,5)|0]>3){break a}if(y[xb(e,10)|0]>3){break a}b:{c:{d:{if(f){g=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);if(g>>>0<=1048574){if(f>>>0<g>>>0|(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))>>>0>g>>>0){break a}}if(a|f){break c}break d}if(a){break c}}v[d+7|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;x[d>>2]=0;x[d+4>>2]=0;a=0;if(p0(e,e+11|0,d)){break b}}a=1}c=c+1|0;continue}}b=a+c|0;c=c+1|0;if(v[b|0]>-2){continue}break}}fb=d+16|0;return l&1}function tr(a){var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(z[a+480192>>1]){break a}c=wb(x[a+484344>>2]);x[e+12>>2]=c;a=wb(x[a+484348>>2]);while(1){if(!Ib(c,a)){d=1;break a}if(!(!Ib(x[c>>2],x[c+4>>2])|x[c+12>>2]==64)){break a}c=x[Ul(e+12|0)>>2];continue}}d=16777216;break a}d=32;f=z[a+480188>>1];if(f>>>0>16){break a}b=a+480280|0;while(1){if((c|0)==(f|0)){break b}a=b+(c<<5)|0;if(v[a+1|0]&1){break a}c=c+1|0;if(z[a+6>>1]==64){continue}break}break a}d=2}fb=e+16|0;return d}function Gy(a,b,c,d,e,f,g,h,i,j,k,l){var m=0,n=0;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Cb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Cb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=Fi(l,l+32|0,a)-l|0;if((a|0)>31){break b}g=v[a+95168|0];d:{e:{switch((a&-2)-22|0){case 2:a=x[e>>2];if((a|0)!=(d|0)){if((pl(v[a-1|0])|0)!=(pl(v[c|0])|0)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0;case 0:v[c|0]=80;break d;default:break e}}d=pl(g);if((d|0)!=v[c|0]){break d}m=c,n=ut(d),v[m|0]=n;if(!y[b|0]){break d}v[b|0]=0;if(!Cb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>21){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){h=x[c+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(d>>>0>x[c+24>>2]-i>>>0){break b}j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=(D(b,g)<<2)+k|0;m=(D(b+i|0,h)<<1)+j|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=rd(x[(a<<2)+l>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[(a<<1)+m>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function rz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=(D(b,f)<<3)+i|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{k=Fe(Jg(C[(a<<3)+j>>3])*134217728);l=(x[(a<<2)+h>>2]+(g<<2)|0)+(b<<2)|0,m=E(+(vn(k)|0)*7.450580596923828e-9),B[l>>2]=m;a=a+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=c- -64|0}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=g+4|0;f=fb-160|0;fb=f;d=f+24|0;c=d+56|0;e=Ut(c);x[d>>2]=93900;x[e>>2]=93920;x[d+56>>2]=93960;x[d>>2]=93940;i=c;c=d+4|0;po(i,c);x[d>>2]=93900;x[e>>2]=93920;c=Pt(c);x[c>>2]=93384;Fb(c+32|0);x[c+44>>2]=0;x[c+48>>2]=16;j=x[x[d>>2]-12>>2];x[31609]=0;i=ca(104)|0;c=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}x[31609]=0;e=f+20|0;S(105,e|0,d+j|0,i|0);c=x[31609];x[31609]=0;if((c|0)==1){break f}_b(e);c=fb-16|0;fb=c;x[c+12>>2]=17;fb=c+16|0;wn(d+x[x[d>>2]-12>>2]|0,x[c+12>>2]);k=C[b>>3];x[31609]=0;e=Sa(1130,d|0,+k)|0;b=x[31609];x[31609]=0;if((b|0)==1){break e}x[31609]=0;c=f+8|0;O(1131,c|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}x[31609]=0;O(303,h|0,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}tb(c);gq(e);fb=f+160|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=N()|0;tb(f+8|0)}gq(d);Q(a|0);p()}Qh(a,h);tb(h);fb=g+16|0}function zia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=gk(d,x[a+4>>2]);if(c>>>0<b>>>0){h=fb-32|0;fb=h;f=b-c|0;d=x[Ab(a)>>2];b=x[a+4>>2];a:{if(f>>>0<=d-b>>11>>>0){c=fb-16|0;fb=c;b=c+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(f<<11);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){jc(b);fb=c+16|0}else{vu(a);a=a+2048|0;x[b+4>>2]=a;continue}break}break a}g=Ab(a);i=h+12|0;e=gk(x[a>>2],b)+f|0;c=fb-16|0;fb=c;x[c+12>>2]=e;d=fb-16|0;fb=d;x[d+12>>2]=2097151;x[d+8>>2]=2147483647;b=x[Hb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(b>>>0>=e>>>0){d=dA(a);if(d>>>0<b>>>1>>>0){x[c+8>>2]=d<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}ed();p()}d=GQ(i,b,gk(x[a>>2],x[a+4>>2]),g);c=d;e=fb-16|0;fb=e;g=x[c+8>>2];b=e+4|0;x[b+8>>2]=c+8;x[b>>2]=g;x[b+4>>2]=g+(f<<11);c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){vu(c);c=x[b>>2]+2048|0;x[b>>2]=c;continue}break}je(b);fb=e+16|0;FQ(a,d);EQ(d)}fb=h+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<11)|0)}}function y2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-48|0;fb=c;f=Fb(a);x[31609]=0;a=ca(117)|0;b=x[31609];x[31609]=0;a:{b:{if((b|0)==1){break b}c:{d:{if(!a){break d}x[31609]=0;b=P(1,c+24|0,8979)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;a=ca(117)|0;d=x[31609];x[31609]=0;e:{f:{g:{h:{if((d|0)==1){break h}x[31609]=0;x[c+8>>2]=a;a=c+12|0;O(126,a|0,c+8|0);d=x[31609];x[31609]=0;if((d|0)==1){break h}x[31609]=0;d=c+36|0;S(2,d|0,b|0,a|0);e=x[31609];x[31609]=0;if((e|0)==1){break g}e=zb(f,d);tb(d);tb(a);tb(b);x[31609]=0;a=ca(119)|0;b=x[31609];x[31609]=0;if((b|0)==1){break b}if(!a){break e}x[31609]=0;P(127,e|0,17550)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break e}break b}a=N()|0;break f}a=N()|0;tb(c+12|0)}tb(b);break a}x[31609]=0;a=ca(118)|0;b=x[31609];x[31609]=0;if((b|0)==1){break b}if(!a){break d}x[31609]=0;P(127,e|0,16836)|0;a=x[31609];x[31609]=0;if((a|0)==1){break b}}fb=c+48|0;return}a=N()|0;break a}a=N()|0}tb(f);Q(a|0);p()}function Kla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];l=x[a+128>>2];if(l){m=Hg(j,k,l);n=hb;f=x[a+76>>2];fg(b,g,uf(j,k,d),hb);o=hb>>>0>f>>>0?d:0}f=a+112|0;h=x[a+40>>2];i=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;o=o-1|0;b=o;m=b?m:0;n=b?n:0;g=g+p|0;b=l;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){ce(f,v[g+x[e+12>>2]|0]<<6);be(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}g=x[a+32>>2];r=x[c>>2];b=Fg(f,q);i=x[a+28>>2]+i|0;x[c>>2]=D(b,i>>12)+r;h=g+h|0;x[c+4>>2]=x[c+4>>2]+D(b,h>>12);Pb(e,j,k);c=c+8|0;b=x[e>>2];g=x[e+4>>2];continue a}else{ce(f,v[g+x[e+12>>2]|0]<<6);be(f,4);Pb(e+8|0,m,n);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=g;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;fb=e+16|0}function Cc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=x[b>>2];f=fb-48|0;fb=f;e=x[b+4>>2];b=y[b+8|0];d=e-(((b|0)==1|(b|0)==4)&(e|0)!=0)|0;e=Fb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){a=Fi(c,c+d|0,0);x[31609]=0;U(70,e|0,c|0,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break h}a=N()|0;break b}if((b-3&255)>>>0>1){break h}x[31609]=0;b=U(70,e|0,c|0,c+d|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break g}c=zd(b);d=Df(b);g=zd(b);a=fb-16|0;fb=a;x[a+8>>2]=g;x[a+12>>2]=c;while(1){if(Ib(c,d)){c=v[c|0];v[x[a+8>>2]]=c?c:32;c=we(a+12|0);we(a+8|0);c=x[c>>2];continue}break}fb=a+16|0;x[31609]=0;c=P(71,f+24|0,b|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break f}x[31609]=0;d=P(36,f+12|0,18454)|0;a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;a=f+36|0;S(72,a|0,c|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break d}zb(b,a);tb(a);tb(d);tb(c)}fb=f+48|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d)}tb(c)}tb(e);Q(a|0);p()}}function Haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Xf(c+48|0,c+32|0,e);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[c+20>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(e>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}k=(D(b,g)<<2)+j|0;a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{d=a<<2;l=(x[d+i>>2]+(h<<1)|0)+(b<<1)|0;d=rd(x[d+k>>2]+2048|0,12);d=(d|0)>=32767?32767:d;w[l>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function Cf(a,b,c){v[a+5|0]=c;a:{switch(b|0){case 0:v[a+3|0]=(c|0)!=0;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 14:v[a+3|0]=19;return;case 15:if(c>>>0<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=37;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break a}}v[a+3|0]=0}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=fb-2144|0;fb=b;vu(b+96|0);a:{b:{c:{f=x[c+4>>2];if(!f){a=dc(8);x[31609]=0;b=P(36,b+80|0,10469)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}g=x[c>>2];d=x[c+12>>2];c=x[c+8>>2];x[b+72>>2]=c;x[b+76>>2]=d;e=x[b+76>>2];x[b+32>>2]=x[b+72>>2];x[b+36>>2]=e;x[b+68>>2]=f;x[b+64>>2]=g;e=x[b+68>>2];x[b+24>>2]=x[b+64>>2];x[b+28>>2]=e;h=sM(b+24|0);if(h){x[b+56>>2]=c;x[b+60>>2]=d;c=x[b+60>>2];x[b+16>>2]=x[b+56>>2];x[b+20>>2]=c;x[b+52>>2]=f;x[b+48>>2]=g;c=x[b+52>>2];x[b+8>>2]=x[b+48>>2];x[b+12>>2]=c;c=kM(b+8|0)}else{c=0}x[b+80>>2]=c;x[b+84>>2]=0;d=0;c=2048;while(1){if(c){e=ib[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=Zb(b+40|0,b+96|0,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a=Au(a,b,h?b+80|0:0);fb=b+2144|0;return a|0}d=N()|0;lc(a)}Q(d|0)}p()}function Rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;h=fb-16|0;fb=h;m=x[a+24>>2];n=x[a+20>>2];f=x[a+48>>2];e=x[a+44>>2];o=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;p=x[a+72>>2];j=x[a+68>>2];q=j>>31;k=x[a+64>>2];r=k>>31;l=x[a+60>>2];s=l>>31;t=x[a+8>>2];u=x[a+12>>2];while(1){b=e;if(d){e=Yb(e,-16777216,16776704);e=Aua(k,r,e,e>>31);i=hb;g=e;f=Yb(f,-16777216,16776704);e=Aua(j,q,f,f>>31);g=g+e|0;f=hb+i|0;f=e>>>0>g>>>0?f+1|0:f;w=g;e=x[h+8>>2];i=e>>>10&4194048;e=x[h+12>>2]+o|0;g=v[e|0];i=((D(v[e+1|0]-g|0,i)|0)/16384<<8)+(g<<16)|0;e=i;e=Aua(e,e>>31,l,s);g=e+w|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Sc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,n)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,m);Pb(h+8|0,t,u);e=e-(i&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;fb=h+16|0}function Asa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;nd(b,32);fp(b);f=b,g=Bb(y[a+40|0]|y[a+41|0]<<8)>>>2|0,w[f+32>>1]=g;d=z[b+34>>1];if((ze((y[a+38|0]|y[a+39|0]<<8)<<16>>16)|0)>0){d=d|32;w[b+34>>1]=d;c=ze((y[a+38|0]|y[a+39|0]<<8)<<16>>16);e=(c<<8&-256)+2047|0;c=c>>>24|0;f=b,g=Bc(Cua(e,e>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}f=b,g=$b(y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24)),x[f>>2]=g;f=b,g=$b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24)),x[f+4>>2]=g;f=b,g=$b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24))+$b(y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24))|0,x[f+8>>2]=g;c=d&-3|((Bb(y[a+44|0]|y[a+45|0]<<8)|0)!=0)<<1;w[b+34>>1]=c;f=b,g=c&65531|Bb(y[a+44|0]|y[a+45|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=$b(y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24))<<1,x[f+24>>2]=g;c=ze((y[a+42|0]|y[a+43|0]<<8)<<16>>16);if(c){_l(b,+(c|0)/96);c=ze((y[a+42|0]|y[a+43|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function hB(a,b,c){var d=0,e=0,f=0;d=fb-112|0;fb=d;f=x[a>>2];e=x[f-4>>2];f=x[f-8>>2];x[d+76>>2]=0;x[d+80>>2]=0;x[d+84>>2]=0;x[d+88>>2]=0;x[d+92>>2]=0;x[d+96>>2]=0;x[d+100>>2]=0;x[d+104>>2]=0;v[d+107|0]=0;v[d+108|0]=0;v[d+109|0]=0;v[d+110|0]=0;x[d+68>>2]=0;x[d+72>>2]=0;x[d+64>>2]=b;x[d+60>>2]=a;x[d+56>>2]=c;a:{if(lh(e,c,0)){a=f?0:a;break a}b=a+f|0;if((b|0)<=(a|0)){x[d+44>>2]=0;x[d+48>>2]=0;v[d+51|0]=0;v[d+52|0]=0;v[d+53|0]=0;v[d+54|0]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+12>>2]=0;x[d+16>>2]=0;x[d+8>>2]=c;x[d+4>>2]=a;x[d>>2]=e;x[d+48>>2]=1;ib[x[x[e>>2]+20>>2]](e,d,b,b,1,0);if(x[d+24>>2]){break a}}a=0;ib[x[x[e>>2]+24>>2]](e,d+56|0,b,1,0);b:{switch(x[d+92>>2]){case 0:a=x[d+96>>2]==1?x[d+84>>2]==1?x[d+88>>2]==1?x[d+76>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+80>>2]!=1){if(x[d+96>>2]|x[d+84>>2]!=1|x[d+88>>2]!=1){break a}}a=x[d+72>>2]}fb=d+112|0;return a}function NL(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=x[a+32>>2];a:{b:{c:{d=x[a+1380>>2];if((d|0)==-1){c=1;break c}f=x[a+1116>>2];e=(d|0)>(f|0)?d:f;g=a+1120|0;c=d;while(1){d:{if((c|0)!=(e|0)){h=y[c+g|0];b=h+b|0;if((h|0)==255){break d}e=c}if(A[a+40>>2]<b>>>0){bc(a,1);break b}c=(e|0)==-1|(e|0)==(f|0);break c}c=c+1|0;continue}}d=(d|0)!=-1;while(1){e=1;if(!(c&1)){break a}e=x[a+40>>2];if(e>>>0<=b+26>>>0){bc(a,1);break b}if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))!=(y[125468]|y[125469]<<8|(y[125470]<<16|y[125471]<<24))){bc(a,21);break b}if(y[b+4|0]){bc(a,21);break b}e:{if(!d){if(!x[a+992>>2]|!(v[b+5|0]&1)){break e}bc(a,21);break b}if(v[b+5|0]&1){break e}bc(a,21);break b}c=0;f=b+27|0;d=y[b+26|0];b=f+d|0;if(e>>>0<b>>>0){bc(a,1);break b}while(1){f:{if((c|0)==(d|0)){c=d;break f}g=y[c+f|0];b=g+b|0;if((g|0)!=255){break f}c=c+1|0;continue}break}c=(c|0)==(d|0);d=1;if(b>>>0<=e>>>0){continue}break}bc(a,1)}e=0}return e}function xq(a){a=a|0;var b=0,c=0,d=0,e=0,f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0);b=x[a+36>>2];if(!b){Nc(a+16|0);return}a:{b:{switch(z[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Nc(c);return}Cl(c,b);b=x[a+36>>2]+1|0;c=b>>>0<=1?1:b;e=w[a+28>>1];g=Ee(E(Vm(a,e+1<<16>>16)/Vm(a,e)),E(E(1)/E(b>>>0)));a=x[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}f=Ee(g,E(b>>>0));n=yb(a,b-1|0),o=f,B[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;e=z[a+30>>1];if(e>>>0>1e3/(b>>>0)>>>0){Nc(c);return}Cl(c,D(b,e));h=z[a+30>>1];j=mA(w[a+28>>1],h);i=x[a+36>>2];g=E(E(1)/E(i+1>>>0));c=0;c:while(1){if(e>>>0<=(c&65535)>>>0){break a}b=1;d=mA(c+j<<16>>16,h);f=Vm(a,d+1<<16>>16);d=d<<16>>16;f=Ee(E(f/Vm(a,d)),g);k=D(d,x[a+36>>2]);l=x[a+16>>2];while(1){d=b&65535;if(d>>>0>i>>>0){c=c+1|0;continue c}else{m=Ee(f,E(d>>>0));n=yb(l,(d+k|0)-1|0),o=m,B[n>>2]=o;b=b+1|0;continue}}};case 0:Nc(a+16|0);return;default:break b}}Nc(a+16|0);x[a+36>>2]=0}}function jga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0,o=0,p=0,q=E(0),r=E(0),s=0,t=0,u=0,v=E(0),w=E(0),y=E(0),z=E(0),A=E(0),C=E(0),D=E(0);g=fb-16|0;fb=g;if(ti(a+44|0)){f=x[a+44>>2];e=Hc(f,0);x[g+8>>2]=e;f=Hc(f,1);x[g+12>>2]=f;i=x[a+56>>2];l=Hc(i,0);x[g>>2]=l;m=Hc(i,1);x[g+4>>2]=m;a:{if(B[yb(a+4208|0,2)>>2]!=E(.5)){s=a+4264|0;t=a+4256|0;u=a+4248|0;n=a+4240|0;f=d;b:while(1){i=0;if(!f){break a}while(1)if((i|0)==2){f=f-1|0;continue b}else{e=i<<2;j=e+(g+8|0)|0;h=x[j>>2];x[j>>2]=h+4;j=e+s|0;v=B[j>>2];o=e+u|0;w=B[o>>2];p=e+t|0;k=B[p>>2];q=B[h>>2];y=B[a+4236>>2];z=B[a+4232>>2];A=B[a+4228>>2];C=B[a+4220>>2];D=B[a+4224>>2];h=e+n|0;r=B[h>>2];B[o>>2]=r;B[h>>2]=q;B[j>>2]=k;k=E(E(E(E(A*w)+E(E(C*q)+E(D*r)))-E(z*k))-E(y*v));B[p>>2]=k;h=e+g|0;e=x[h>>2];x[h>>2]=e+4;B[e>>2]=k;i=i+1|0;continue}}}n=e;e=d<<2;zc(l,n,e);zc(m,f,e);f=x[a+56>>2];l=Hc(f,0);m=Hc(f,1)}Ii(a,b,c,l,m,d)}fb=g+16|0}function Qt(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{e=pj(a)&2047;d=pj(5551115123125783e-32);if(e-d>>>0<pj(512)-d>>>0){h=e;break b}if(d>>>0>e>>>0){return a+1}if(pj(1024)>>>0>e>>>0){break b}o(+a);d=j(1)|0;b=0;if(!(j(0)|0)&(d|0)==-1048576){break a}if(pj(Infinity)>>>0<=e>>>0){return a+1}if((d|0)<0){return Os(12882297539194267e-247)}return Os(3105036184601418e216)}b=C[170];f=C[169]*a+b;b=f-b;a=b*C[172]+(b*C[171]+a);b=a*a;g=b*b*(a*C[176]+C[175]);b=b*(a*C[174]+C[173]);o(+f);j(1)|0;e=j(0)|0;c=e<<4&2032;a=g+(b+(C[c+1464>>3]+a));c=c+1472|0;d=0+x[c>>2]|0;c=x[c+4>>2]+(e<<13)|0;c=d>>>0<i>>>0?c+1|0:c;if(!h){c:{if(!(e&-2147483648)){l(0,d|0);l(1,c-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){gK(CK()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function J2(){var a=0,b=0,c=0,d=0;d=fb-32|0;fb=d;a:{a=Dc(d+20|0,14821);if(!_c(x[a+4>>2],y[a+11|0])){break a}b:{if((Tg(a,14690)|0)!=-1){b=Tg(a,14690);x[31609]=0;c=d+8|0;V(121,c|0,a|0,b+1|0,-1);b=x[31609];x[31609]=0;if((b|0)==1){break b}zb(a,c);tb(c)}if((Tg(a,16834)|0)!=-1){b=Tg(a,16834);x[31609]=0;c=d+8|0;V(121,c|0,a|0,b+1|0,-1);b=x[31609];x[31609]=0;if((b|0)==1){break b}zb(a,c);tb(c)}if((Tg(a,13959)|0)!=-1){b=Tg(a,13959);x[31609]=0;c=d+8|0;V(121,c|0,a|0,0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break b}zb(a,c);tb(c)}if((Tg(a,13834)|0)!=-1){b=Tg(a,13834);x[31609]=0;c=d+8|0;V(121,c|0,a|0,0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break b}zb(a,c);tb(c)}if((Tg(a,13877)|0)!=-1){b=Tg(a,13877);x[31609]=0;c=d+8|0;V(121,c|0,a|0,0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break b}zb(a,c);tb(c)}x[31609]=0;c=R(122,a|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break a}}d=N()|0;tb(a);Q(d|0);p()}tb(a);fb=d+32|0;return c|0}function Nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-80|0;fb=e;x[e+76>>2]=c;c=e+76|0;a=re(a,c);g=tc(a+4|0);h=tc(a+24|0);i=tc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31609]=0;O(991,a|0,d|0);f=x[31609];x[31609]=0;a:{b:{c:{d:{if((f|0)!=1){f=x[b>>2];l=x[b+4>>2];m=x[b+12>>2];x[e+48>>2]=x[b+8>>2];x[e+52>>2]=m;x[e+40>>2]=f;x[e+44>>2]=l;b=Md(e+32|0);f=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=f;x[31609]=0;f=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=e+56|0;S(980,b|0,e+16|0,e+8|0);f=x[31609];x[31609]=0;if((f|0)==1){break d}x[31609]=0;S(992,a|0,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}ub(b);x[31609]=0;W(993,a|0);b=x[31609];x[31609]=0;if((b|0)==1){break b}Wc(c);fb=e+80|0;return a|0}d=N()|0;break a}d=N()|0;break a}d=N()|0;ub(e+56|0);break a}d=N()|0}Td(k);nf(j);Al(i);wh(h);vh(g);Wc(a);Wc(e+76|0);Q(d|0);p()}function Qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=fb-16|0;fb=h;n=x[a+24>>2];o=x[a+20>>2];e=x[a+48>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];v=x[a+12>>2];while(1){b=f;if(d){f=Yb(f,-16777216,16776704);g=Aua(l,s,f,f>>31);f=hb;e=Yb(e,-16777216,16776704);e=Aua(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=(x[h+12>>2]<<1)+p|0;i=w[g>>1];i=i+((D(w[g+2>>1]-i|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;g=Aua(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Sc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Pb(h+8|0,u,v);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function pqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;w[f+12>>1]=0;x[f+8>>2]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){w[f+6>>1]=0;eY(a,f+15|0,f+12|0,j,f+6|0);g=z[f+6>>1];e=z[f+12>>1];c=j;while(1){if(c&255){h=e<<1;e=h&254;d:{if(e){h=(h&65534)>>>0>255;break d}if(!Bf(a,f+5|0)){break c}e=y[f+5|0];h=e>>>7|0;e=e<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[f+12>>1]=e;break b}l=l+1|0;continue a}w[f+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}e=15;while(1){c=e;m=e&255;if(m>>>0<2){break e}e=e-1|0;if(!(h&1<<m)){continue}break}}e=g&1;v[f+15|0]=e;g=e-1^(g&65534)>>>1;e=g+z[f+8>>1]|0;w[f+6>>1]=e;w[i>>1]=e;x[f+8>>2]=((g>>1)-(k<<16>>16)|0)+(e<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=x[f+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}x[f+8>>2]=c}k=e;continue}}break}fb=f+16|0}function H1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-32|0;fb=h;e=Ln(h+12|0,a);i=fb-48|0;fb=i;j=-1;c=i+12|0;a:{if(!ZF(e,c)){break a}j=0;if(!bG(c)){break a}k=Ef(13181);if(k){o=x[e+12>>2];b:{if(!Wl(e,y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))){break b}while(1){if((y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24))>>>0<=l>>>0){break b}if(!jh(e,5)){break b}c:{if((y[c+4|0]|y[c+5|0]<<8)>>>0>=64){a=Kr(e);d=a&63;g=a<<24>>24;d:{if(!(a&64)){break d}a=6;while(1){f=Kr(e);d=(f&127)<<a|d;if(f<<24>>24>=0){break d}f=a>>>0<25;a=a+7|0;if(f){continue}break}}if((((g|0)<0?(d|0)<0?-2147483648:0-d|0:d)|0)<=0){break c}}d=0;a=1;while(1){f=Kr(e);if(f){m=d>>>0>=k>>>0;g=m&a;if(!((a^1)&1|m)){g=(Lq(f<<24>>24)&255)==y[d+13181|0]}a=g;d=d+1|0;continue}break}id(e,4);n=(d|0)==(k|0)&a|n}l=l+1|0;continue}}Wl(e,o)}if(!(n&1)){break a}j=xe(e,b,aG(c),0)}fb=i+48|0;fb=h+32|0;return j|0}function tia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=E(0),w=E(0),y=E(0),z=0,A=0,C=0,D=E(0);r=x[a+4220>>2];if(r){f=x[a+44>>2];k=Hc(f,0);l=Hc(f,1);g=x[a+56>>2];s=Hc(g,0);j=x[a+4208>>2];z=x[a+4228>>2];f=d;t=Hc(g,1);m=t;g=s;while(1){if(f){h=x[a+4224>>2];e=h-z|0;e=(x[a+4220>>2]&e>>31)+e<<1;A=yb(j,e);n=B[yb(j,e|1)>>2];u=B[a+4244>>2];o=B[A>>2];v=B[a+4252>>2];p=B[l>>2];w=B[a+4248>>2];q=B[k>>2];y=B[a+4256>>2];i=E(E(n*u)+E(E(o*v)+E(E(p*w)+E(q*y))));e=h<<1;C=yb(j,e),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;i=E(E(o*u)+E(E(n*v)+E(E(q*w)+E(p*y))));C=yb(j,e|1),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;h=h+1|0;x[a+4224>>2]=(h|0)!=(r|0)?h:0;B[g>>2]=E(q*B[a+4240>>2])+E(o*B[a+4236>>2]);B[m>>2]=E(p*B[a+4240>>2])+E(n*B[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{Ii(a,b,c,s,t,d)}break}}}function QM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;x[e+12>>2]=c;a:{b:{if(!b){a=a+120|0;uo(a);c=x[e+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(b+8|0,x[vb(b+4|0,a)>>2]);c:{if(c){x[31609]=0;O(1141,a|0,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}MM(a,c)}c=b+8|0;Qd(c);Xi(c);fb=b+16|0;break c}v[a+20|0]=0;break b}d=fb-16|0;fb=d;x[d+12>>2]=c;d:{if((b|0)==1){b=a+120|0;uo(b);h=wz(b,a,x[d+12>>2]),i=1,v[h+20|0]=i;break d}f=fb-16|0;fb=f;x[f+12>>2]=c;e:{if((b|0)==2){a=a+120|0;uo(a);c=x[f+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(b+8|0,x[vb(b+4|0,a)>>2]);f:{if(c){x[31609]=0;O(1140,a|0,c|0);g=x[31609];x[31609]=0;if((g|0)==1){break a}MM(a,c)}c=b+8|0;Qd(c);Xi(c);fb=b+16|0;break f}Md(a+12|0);v[a+20|0]=2;break e}b=fb-16|0;fb=b;x[b+12>>2]=c;c=a+120|0;uo(c);h=wz(c,a,x[b+12>>2]),i=3,v[h+20|0]=i;fb=b+16|0}fb=f+16|0}fb=d+16|0}fb=e+16|0;return}a=N()|0;Xi(b+8|0);Q(a|0);p()}function fna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=kg(1,2);b=hb;q=b;Pb(a,j,b);r=x[a+24>>2];s=x[a+20>>2];f=x[a+48>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];v=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=w[(x[g+12>>2]<<1)+p>>1]<<8;e=n;e=Aua(e,e>>31,m,y);i=hb;h=e;e=Yb(b,-16777216,16776704);e=Aua(l,v,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Aua(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Sc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Ig(a,j,q);fb=g+16|0}function Wt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=(D(b,f)<<2)+k|0;m=(D(b+h|0,g)<<2)+j|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{i=a<<2;B[i+m>>2]=E(x[l+i>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function Waa(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[31609]=0;f=P(21,d+8|0,a|0)|0;c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){d:{if(!Id(y[f|0])){break d}c=d+4|0;cd(c,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31609]=0;g=R(1132,x[d+4>>2])|0;e=x[31609];x[31609]=0;e:{f:{if((e|0)!=1){_b(c);c=qp(d,a);e=x[x[a>>2]-12>>2];x[31609]=0;e=a+e|0;h=R(22,e|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break f}c=x[c>>2];x[31609]=0;c=Ra(1133,g|0,c|0,e|0,h|0,+b)|0;g=x[31609];x[31609]=0;if((g|0)==1){break f}if(c){break d}c=x[x[a>>2]-12>>2];x[31609]=0;O(24,a+c|0,5);c=x[31609];x[31609]=0;if((c|0)!=1){break d}c=T(0)|0;break e}c=T(0)|0;_b(d+4|0);break e}c=T(0)|0}fm(f);break c}fm(f);break b}c=T(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[31609]=0;W(25,a+c|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31609]=0;X(26);d=x[31609];x[31609]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Lr(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;a:{if(y[a+3|0]!=19){break a}v[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=y[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}v[a+3|0]=0;break a}v[a+3|0]=2;v[a+5|0]=b|240;break a}v[a+3|0]=3;v[a+5|0]=b|240;break a}v[a+5|0]=b&15|16;break a}v[a+5|0]=b&3|48;break a}v[a+5|0]=b&223^120;break a}v[a+5|0]=b&15|176;break a}v[a+5|0]=b&3|64;break a}v[a+3|0]=15;v[a+5|0]=b&15;break a}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;break a}v[a+3|0]=0;break a}b=b&15;if(b){v[a+3|0]=11;x[c+12>>2]=b;x[c+8>>2]=14;d=a,e=y[Cd(c+12|0,c+8|0)|0]|240,v[d+5|0]=e;break a}v[a+3|0]=0;break a}if((b|0)!=192){break a}v[a|0]=254;v[a+3|0]=0;break a}if((b|0)!=208){break a}v[a+3|0]=0}fb=c+16|0}function Rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=0,q=0,r=0,s=E(0),t=E(0),u=E(0),v=0,w=E(0),z=0,A=0,C=0,D=0,G=0,H=E(0);g=fb-16|0;fb=g;l=x[a+4240>>2];a:{if(!l){break a}if(!ti(a+44|0)){break a}m=B[a+4220>>2];e=x[a+44>>2];D=g,G=Hc(e,0),x[D+8>>2]=G;D=g,G=Hc(e,1),x[D+12>>2]=G;e=x[a+56>>2];n=Hc(e,0);x[g>>2]=n;o=Hc(e,1);x[g+4>>2]=o;v=a+4248|0;w=E(E(1)-m);p=x[a+4208>>2];z=y[a+4264|0];e=d;b:while(1){if(e){k=x[a+4244>>2];A=k<<1;f=0;while(1)if((f|0)==2){f=k+1|0;x[a+4244>>2]=(f|0)!=(l|0)?f:0;e=e-1|0;continue b}else{h=(f^z)&255;j=x[(h<<2)+v>>2];C=x[a+4240>>2];q=f<<2;r=q+(g+8|0)|0;i=x[r>>2];x[r>>2]=i+4;j=k-j|0;s=B[yb(p,h|(j>>31&C)+j<<1)>>2];t=B[i>>2];u=E(E(s*B[a+4224>>2])+E(t*B[a+4260>>2]));D=yb(p,f|A),H=E(F(u))<E(10000000195414814e-40)?E(0):u,B[D>>2]=H;h=g+q|0;i=x[h>>2];x[h>>2]=i+4;B[i>>2]=E(t*w)+E(m*s);f=f+1|0;continue}}break}Ii(a,b,c,n,o,d)}fb=g+16|0}function Hha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(_c(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Wd(f,g)>>2];if(b>>>0>=2097152){x[31609]=0;O(963,d|0,63);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31609]=0;O(963,d|0,a<<24>>24);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[31609]=0;O(963,d|0,(a|i)<<24>>24);h=x[31609];x[31609]=0;a=e;break e}x[31609]=0;a=a-1|0;O(963,d|0,v[a+(c+10|0)|0]|-128);h=x[31609];x[31609]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function $I(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=v[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((y[a+1|0]&192)!=128){break a}break b}g=f&255;if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];f=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((f&224)==160){break c}break a}if((f&224)!=128){break a}break c}if((f&192)!=128){break a}}g=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0>=48){break a}break e;case 4:if((f&240)!=128){break a}break e;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function gna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=kg(1,2);b=hb;q=b;Pb(a,j,b);r=x[a+24>>2];s=x[a+20>>2];f=x[a+48>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];w=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=v[x[g+12>>2]+p|0]<<16;e=n;e=Aua(e,e>>31,m,y);i=hb;h=e;e=Yb(b,-16777216,16776704);e=Aua(l,w,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Yb(f,-16777216,16776704);e=Aua(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Sc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Pb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Ig(a,j,q);fb=g+16|0}function DV(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;f=b&15;b=y[f+25440|0];a:{b:{switch(f|0){case 0:b=c?d>>>0>=51?b:0:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;v[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}v[e+15|0]=0;b=25;break a;case 7:b=d>>>0>=52?b:0;break a;case 10:c=c&240;if(!c){break a}v[e+15|0]=c;break a;case 11:v[e+15|0]=D(c&15,17);break a;case 13:v[e+15|0]=D(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:v[e+15|0]=c|240;b=2;break a;case 1:v[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}v[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;v[e+15|0]=c&15;break a;case 9:v[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}v[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}ee(a,b,e+15|0);fb=e+16|0}function $la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=fb-16|0;fb=e;j=x[a+24>>2];k=x[a+20>>2];l=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;m=b+24|0;i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];g=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;b=(((b>>>16|0)+4&131064)<<1)+m|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];v=w[b>>1];b=0;while(1){if((b|0)!=2){h=b<<1;f=h+g|0;x[(b<<2)+e>>2]=(((((D(w[f+8>>1],q)+D(w[f+4>>1],r)|0)+D(w[f+12>>1],p)|0)+D(w[f+16>>1],o)|0)/2|0)+((((D(w[(h|-8)+g>>1],u)+D(w[(h|-12)+g>>1],v)|0)+D(w[(h|-4)+g>>1],t)|0)+D(w[f>>1],s)|0)/2|0)|0)/16384;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],k);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],j);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;g=x[a+12>>2];h=x[a+8>>2];a:{b:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){e=131112;if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break a}e=262184;if((g|0)==-2&h>>>0<2147483648|g>>>0<4294967294){break a}break b}e=262184;if((g|0)==1&h>>>0>2147483648|g>>>0>1){break a}}e=196648}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];i=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=i;i=b+e|0;while(1){if(d){b=x[f+8>>2];e=(x[f+12>>2]<<1)+j|0;b=(b>>>16&65520)+i|0;b=(((((((D(w[e-4>>1],w[b+2>>1])+D(w[e-6>>1],w[b>>1])|0)+D(w[e-2>>1],w[b+4>>1])|0)+D(w[e>>1],w[b+6>>1])|0)+D(w[e+2>>1],w[b+8>>1])|0)+D(w[e+4>>1],w[b+10>>1])|0)+D(w[e+6>>1],w[b+12>>1])|0)+D(w[e+8>>1],w[b+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Pb(f+8|0,h,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;fb=f+16|0}function cJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=v[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((y[a+1|0]&192)!=128){break a}break b}g=b&255;if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];b=y[a+1|0];c:{d:{if((g|0)!=237){if((g|0)!=224){break d}if((b&224)==160){break c}break a}if((b&224)!=128){break a}break c}if((b&192)!=128){break a}}f=3;if((h&192)!=128){break a}break b}if((d-a|0)<4|b>>>0>4294967284){break a}f=y[a+3|0];h=y[a+2|0];b=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0>=48){break a}break e;case 4:if((b&240)!=128){break a}break e;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function Xt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=(D(b,f)<<2)+j|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{h=a<<2;B[(x[h+i>>2]+(g<<2)|0)+(b<<2)>>2]=E(x[k+h>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7244,9061,33,8774);p()}_(7209,9061,34,8774);p()}_(5897,9061,35,8774);p()}_(5867,9061,36,8774);p()}fb=c- -64|0}function DE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-560|0;fb=f;w[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=x[e>>2];b:{if(b){c=cV(f,c);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;d=y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24);e=y[c+7|0]|y[c+8|0]<<8|(y[c+9|0]<<16|y[c+10|0]<<24);v[b+7|0]=e;v[b+8|0]=e>>>8;v[b+9|0]=e>>>16;v[b+10|0]=e>>>24;v[b+11|0]=d;v[b+12|0]=d>>>8;v[b+13|0]=d>>>16;v[b+14|0]=d>>>24;v[b+15|0]=y[c+15|0];d=x[c+44>>2];x[b+40>>2]=x[c+40>>2];x[b+44>>2]=d;d=x[c+36>>2];x[b+32>>2]=x[c+32>>2];x[b+36>>2]=d;d=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=d;d=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=d;OA(b+48|0,c+48|0);OA(b+68|0,c+68|0);OA(b+88|0,c+88|0);zc(b+108|0,c+108|0,448);d=b;Mv(c);break b}b=zu(556);if(!b){x[e>>2]=0;break a}d=cV(b,c);x[e>>2]=d}g=a,h=z[qe(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}fb=f+560|0;return d|0}function t1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(_c(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Wd(f,g)>>2];if(b>>>0>=2097152){x[31609]=0;O(50,d|0,63);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31609]=0;O(50,d|0,a&255);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}e=b-1|0;i=e+(c+10|0)|0;j=(2<<a)+255<<7-a&255;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[i|0];x[31609]=0;O(50,d|0,a|j);h=x[31609];x[31609]=0;a=e;break e}x[31609]=0;a=a-1|0;O(50,d|0,y[a+(c+10|0)|0]|128);h=x[31609];x[31609]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function eoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;w[e+12>>1]=c;w[e+14>>1]=b;w[e+10>>1]=d;g=z[x[x[a+24>>2]+8>>2]+12>>1];a:{if(g>>>0<=b>>>0){break a}if(!c|Hj(a)>>>0>=g>>>0){break a}Hf(e+12|0,g-b&65535);k=e,l=cm(x[a>>2],x[a+4>>2]),w[k+8>>1]=l;d=z[e+12>>1];xY(a,d+z[qe(e+14|0,e+8|0)>>1]|0);f=e+4|0;c=a;a=x[a>>2];if($c(a,x[c+4>>2])>>>0<b>>>0){vg(c,b);a=x[c>>2]}a=vb(f,KX(wb(a),b));h=e+10|0;j=fb-32|0;fb=j;b=x[a>>2];a=x[c>>2];f=(lp(b,wb(a))<<1)+a|0;a=d;b:{if(!a){break b}b=x[Ab(c)>>2];i=x[c+4>>2];if(a>>>0<=b-i>>1>>>0){b=a;d=i-f>>1;if(d>>>0<a>>>0){tp(c,a-d|0,h);b=d;if((f|0)==(i|0)){break b}}QU(c,f,i,(a<<1)+f|0);Jv(f,b,((f>>>0<=h>>>0?A[c+4>>2]>h>>>0?a:0:0)<<1)+h|0);break b}b=Ab(c);b=ek(j+12|0,fk(c,$c(x[c>>2],i)+a|0),f-x[c>>2]>>1,b);rF(b,a,h);f=PU(c,b,f);aj(b)}wb(f);fb=j+32|0;if($c(x[c>>2],x[c+4>>2])>>>0<=g>>>0){break a}vg(c,g)}fb=e+16|0}function Oqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-432|0;fb=d;yc(b);jD(b,d+380|0,d+300|0,d+16|0);k=d,l=Eh((m=y[d+431|0]+1|0,n=1,o=$b(y[d+412|0]|y[d+413|0]<<8|(y[d+414|0]<<16|y[d+415|0]<<24)),o?m:n)),v[k+12|0]=l;i=y[Qb(25200,d+12|0)|0];v[d+15|0]=i;w[d+12>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Bb(z[d+16>>1])<<16>>16;if(!((e|0)<0|y[d+299|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=$b(x[d+300>>2]);if(e>>>0<g>>>0){if(dd(b,g)){break c}}v[d+15|0]=h+1;break b}}else{d:{if(!dd(b,$b(y[d+396|0]|y[d+397|0]<<8|(y[d+398|0]<<16|y[d+399|0]<<24))+(f<<2)|0)){break d}if(!dd(b,op(b))){break d}e:{if(!c){j=Zd(b);break e}j=Pk(b)}w[d+10>>1]=j;k=d,l=z[qe(d+12|0,d+10|0)>>1],w[k+12>>1]=l}f=f+1|0;continue}break}g=$b(x[d+300>>2]);jD(b,d+380|0,d+300|0,d+16|0);h=h+1|0;continue}break}Ww(a);break a}uY(a,z[d+12>>1],d+15|0)}fb=d+432|0}function mra(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;b=fb-16|0;fb=b;x[b+4>>2]=1073741824;w[b+10>>1]=12;c=Ec(64);x[31609]=0;d=R(875,c|0)|0;f=x[31609];x[31609]=0;a:{b:{c:{if((f|0)!=1){c=yf(b,d);d=x[c>>2];x[31609]=0;O(876,d|0,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}a=x[c>>2];x[31609]=0;a=U(877,a|0,b+10|0,b+4|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}d:{if(!a){tc(b+12|0);break d}a=x[c>>2];x[31609]=0;O(878,a|0,15);a=x[31609];x[31609]=0;if((a|0)==1){break c}re(b+12|0,c)}mg(c);fb=b+16|0;b=x[b+12>>2];break a}a=N()|0;Db(c);break b}a=N()|0;mg(c)}Q(a|0);p()}x[e+12>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}x[31609]=0;c=P(1,e|0,(a<<2)+30512|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){x[31609]=0;S(499,b|0,a|0,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break g}tb(c);a=a+1|0;continue}break}a=N()|0;break f}a=N()|0;tb(c)}mg(e+12|0);Q(a|0);p()}fb=e+16|0;return b|0}function tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;g=x[a+12>>2];h=x[a+8>>2];a:{b:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){e=131112;if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break a}e=262184;if((g|0)==-2&h>>>0<2147483648|g>>>0<4294967294){break a}break b}e=262184;if((g|0)==1&h>>>0>2147483648|g>>>0>1){break a}}e=196648}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];i=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=i;i=b+e|0;while(1){if(d){b=x[f+8>>2];e=x[f+12>>2]+j|0;b=(b>>>16&65520)+i|0;b=(((((((D(v[e-2|0],w[b+2>>1])+D(v[e-3|0],w[b>>1])|0)+D(v[e-1|0],w[b+4>>1])|0)+D(v[e|0],w[b+6>>1])|0)+D(v[e+1|0],w[b+8>>1])|0)+D(v[e+2|0],w[b+10>>1])|0)+D(v[e+3|0],w[b+12>>1])|0)+D(v[e+4|0],w[b+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Pb(f+8|0,h,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;fb=f+16|0}function vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=(D(b,f)<<3)+j|0;l=(D(b+h|0,g)<<2)+i|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a<<2)+l>>2]=C[(a<<3)+k>>3];a=a+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=c- -64|0}function mqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=fb-16|0;fb=f;w[f+12>>1]=0;x[f+8>>2]=0;n=D(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){v[f+7|0]=0;dY(a,f+15|0,f+12|0,f+7|0);g=y[f+7|0];e=z[f+12>>1];c=k;while(1){if(c&255){h=e<<1;e=h&254;d:{if(e){h=(h&65534)>>>0>255;break d}if(!Bf(a,f+6|0)){break c}e=y[f+6|0];h=e>>>7|0;e=e<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[f+12>>1]=e;break b}l=l+1|0;continue a}w[f+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}e=7;while(1){c=e;m=e&255;if(m>>>0<2){break e}e=e-1|0;if(!(h&1<<m)){continue}break}}e=g&1;v[f+15|0]=e;g=e-1^(g&254)>>>1;e=g+y[f+8|0]|0;v[f+7|0]=e;v[i|0]=e;x[f+8>>2]=((g>>1)-(j<<24>>24)|0)+(e<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=x[f+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}x[f+8>>2]=c}j=e;continue}}break}fb=f+16|0}function XG(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;h=e;c=c&33554431;if(!(!e&(c|0)==16777216?!(a|b):!e&c>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(c^16777216|a|(b|h)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;$f(g+16|0,a,b,c,e,f-16129|0);cn(g,a,b,c,e,16257-f|0);a=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|a>>>25;c=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];b=0;a=a&33554431;if(!(!b&(a|0)==16777216?!(c|f):!b&a>>>0<16777216)){e=e+1|0;break a}if(a^16777216|c|(b|f)){break a}e=(e&1)+e|0}fb=g+32|0;return l(2,d&-2147483648|e),r()}function XC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-32|0;fb=i;g=fb-16|0;fb=g;nd(b,1);k=Bb(y[a+22|0]|y[a+23|0]<<8);h=k<<1;x[b>>2]=h;v[b+37|0]=y[a+24|0]<<4;v[g+15|0]=y[a+25|0];v[g+14|0]=64;m=b,n=y[Qb(g+15|0,g+14|0)|0]<<2,w[m+30>>1]=n;f=Bb(y[a+26|0]|y[a+27|0]<<8);e=f<<1;l=Bb(y[a+28|0]|y[a+29|0]<<8);j=l<<1;e=l>>>0>=2?e+j>>>0<=h>>>0?e:f+j>>>0>h>>>0?e:f:e;a:{b:{switch(k|0){case 1:x[b>>2]=0;break a;case 0:break a;default:break b}}x[b+4>>2]=e;f=e+j|0;x[b+8>>2]=f;if(e>>>0>=h>>>0){e=h-1|0;x[b+4>>2]=e}if(!(!(f>>>0<4|e>>>0>f>>>0)&f-e>>>0>3)){x[b+4>>2]=0;x[b+8>>2]=0;f=0;e=0}if(!(f>>>0>8|f>>>0>=h>>>0|(!d|e))){x[b+8>>2]=0;break a}if(e>>>0>=f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=g+16|0;d=i+8|0;Rk(d,3,a);b=i+20|0;Cc(b,d);c=Ac(c,b);tb(b);d=0;while(1){if((d|0)!=32){b=c+d|0;if((y[b|0]-1&255)>>>0<=30){v[b|0]=32}d=d+1|0;continue}break}a=_C(a);fb=i+32|0;return a}function Nla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Hg(i,j,k);m=hb;f=x[a+76>>2];fg(b,g,uf(i,j,d),hb);h=hb>>>0>f>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(g<<1)+n|0;b=k;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){ce(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);be(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}g=x[c>>2];b=Fg(f,o);x[c>>2]=g+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,j);c=c+8|0;continue a}else{ce(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);be(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function LH(a,b,c,d,e,f,g,h){var i=0,j=0,k=E(0);i=fb-96|0;fb=i;MA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[i+92>>2]=f;x[i+88>>2]=e;x[i+84>>2]=d;x[i+80>>2]=c;a:{d=i+80|0;c=0;while(1){b:{if((c|0)!=4){if(x[(c<<2)+d>>2]){break b}}else{c=4}break a}c=c+1|0;continue}}x[i+44>>2]=b;x[i+40>>2]=c;x[i+36>>2]=d;e=x[a+32>>2];k=B[a+48>>2];x[i+8>>2]=b;c=x[i+40>>2];x[i>>2]=x[i+36>>2];x[i+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[i+8>>2];c=x[i+4>>2];x[d>>2]=x[i>>2];x[d+4>>2]=c;c=FM(i+48|0);x[c+8>>2]=e;x[c+4>>2]=0;x[c>>2]=h;e=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=e;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=k;x[c>>2]=g;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[i+24>>2]=b;x[i+28>>2]=0;x[i+16>>2]=134217727;x[i+20>>2]=0;d=GM(d,x[Wr(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|j)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=i+96|0;return j}function Eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Xf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=(D(b,f)<<3)+i|0;a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(x[(a<<2)+h>>2]+(g<<2)|0)+(b<<2)>>2]=C[(a<<3)+j>>3];a=a+1|0;continue}}}_(7244,9061,77,8741);p()}_(7209,9061,78,8741);p()}_(5897,9061,79,8741);p()}_(5867,9061,80,8741);p()}fb=c- -64|0}function kG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;d=Ab(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);e=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=e;x[c+52>>2]=f;d=Ag(c+24|0,d,c+52|0,c+56|0);x[c+16>>2]=x[d+8>>2];f=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=f;zg(c+36|0,c+8|0);while(1){if(Fd(e,g)){gx(iG(x[c+56>>2]),cj(e));e=jG(c+60|0);jG(c+56|0);e=x[e>>2];continue}break}yg(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];e=fb-16|0;fb=e;f=x[d>>2];x[e+12>>2]=f;while(1){if(wi(f,j)){d=fb-16|0;fb=d;x[d+12>>2]=f;x[d+12>>2]=x[d+12>>2]+36;fb=d+16|0;Hp(iG(x[d+12>>2]));x[e+12>>2]=x[e+12>>2]+36;f=x[e+12>>2];continue}break}fb=e+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function Om(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;x[a+4>>2]=0;if(Id(y[Gm(e+15|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){b=a+24|0;while(1){c=x[b+x[x[a>>2]-12>>2]>>2];x[31609]=0;c=R(83,c|0)|0;d=x[31609];x[31609]=0;d:{if((d|0)!=1){if(!mc(c,-1)){break d}break b}break c}x[a+4>>2]=x[a+4>>2]+1;continue}}if(x[a+4>>2]>=(b|0)){break a}c=a+24|0;e:{while(1){d=x[c+x[x[a>>2]-12>>2]>>2];x[31609]=0;d=R(83,d|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}if(mc(d,-1)){break b}d=x[a+4>>2]+1|0;x[a+4>>2]=d;if((b|0)>(d|0)){continue}break}c=0;break a}}Y(T(0)|0)|0;c=1;Em(x[x[a>>2]-12>>2]+a|0,1);f:{g:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31609]=0;X(84);a=x[31609];x[31609]=0;if((a|0)!=1){break f}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break g}Q(a|0);p()}Z();break a}T(0)|0;Sb()}p()}c=2}Wj(x[x[a>>2]-12>>2]+a|0,c)}fb=e+16|0;return a|0}function Im(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;vl(a);a:{b:{c:{f=x[b+32>>2];d:{if(!f){e=x[b+2084>>2];if(e){break d}break b}c=x[b+4>>2];if((c|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Hm(h);d=x[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=A[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=y[x[b+8>>2]+d|0];if((c|0)==255){break f}g=x[a+1392>>2];if(x[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=x[a+1396>>2];if((e|0)>=(c|0)){x[a+1392>>2]=g>>>c;x[a+1396>>2]=e-y[x[b+8>>2]+d|0];return d}x[a+1396>>2]=0;break b}d=d+1|0;continue}break}bc(a,21);x[a+1396>>2]=0}return-1}_(11394,13274,1705,5445);p()}function g0(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{g:{h:{d=y[b+24688|0];switch(d-6|0){case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break c;case 13:break d;case 0:case 1:case 5:break f;case 8:break g;default:break h}}if((d|0)==31){break b}if((d|0)==23){break e}if((d|0)!=1){break a}d=(c|0)!=0;break a}v[e+15|0]=D(c>>>4|0,10)+(c&15);d=14;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}v[e+15|0]=b;break a}if(c>>>0<=64){v[e+15|0]=c<<1;d=23;break a}v[e+15|0]=128;d=23;break a}d=19;i:{switch(c-48>>>4|0){case 0:v[e+15|0]=159;d=20;break a;case 1:v[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}v[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break i;default:break a}}v[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}v[e+15|0]=(b<<5|c>>>3)^128;d=31}ee(a,d,e+15|0);fb=e+16|0}function _oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=c+11|0;fX(a,d);if((y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24))==1414807888){fX(a,d);v[b|0]=1;b=0}else{b=1}a=fb-176|0;fb=a;e=a+12|0;Yw(e,(c+11|0)+b|0);x[31609]=0;d=a+24|0;O(124,d|0,e|0);b=x[31609];x[31609]=0;a:{b:{c:{d:{e:{if((b|0)!=1){x[31609]=0;b=P(103,a+36|0,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break e}tb(d);tb(e);e=x[x[b>>2]-12>>2];x[31609]=0;g=ca(104)|0;f=x[31609];x[31609]=0;if((f|0)==1){break c}x[31609]=0;f=a+8|0;S(105,f|0,b+e|0,g|0);e=x[31609];x[31609]=0;if((e|0)==1){break c}_b(f);x[31609]=0;w[a+24>>1]=0;d=P(686,b|0,d|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break c}b=nk(x[(d+x[x[d>>2]-12>>2]|0)+16>>2]);e=z[a+24>>1];Gf(d);fb=a+176|0;a=(b?0:e)&65535;break a}c=N()|0;break d}c=N()|0;tb(a+24|0)}tb(a+12|0);break b}c=N()|0;Gf(b)}Q(c|0);p()}fb=c+16|0;return a|0}function eP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;b=x[a>>2];vb(g+12|0,b);a:{b:{c:{d:{e:{if(Ed(x[b+16>>2])){while(1){if(c>>>0>31){break e}x[31609]=0;d=ca(69)|0;e=x[31609];x[31609]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=T(125124)|0;if((gb|0)!=($(125124)|0)){break c}Y(c|0)|0;v[b+20|0]=0;x[31609]=0;W(57,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break d}Z();break e}v[b+20|0]=0}if(!y[b+20|0]){d=x[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=x[d+2496>>2];e=(b<<2)+d|0;i=x[((b+397>>>0)%624<<2)+d>>2];h=(b+1>>>0)%624|0;b=x[(h<<2)+d>>2];b=i^(b&2147483647|x[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;x[e>>2]=b;x[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}fb=g+16|0;break a}c=N()|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break b}}Q(c|0);p()}T(0)|0;Sb();p()}return x[a+28>>2]&f}function Dna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-32|0;fb=g;e=fb-16|0;fb=e;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;rR(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);rR(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){if((d|0)==96){if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;f=y[b+31|0];a:{b:{if(!f){d=1;break b}d=16;if(f>>>0<17){break a}}v[b+31|0]=d}w[e+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[e+12>>1]=127;i=b,j=y[Oc(e+14|0,e+12|0)|0]+1|0,v[i+30|0]=j}v[b+33|0]=y[c+212|0];fb=e+16|0}else{i=ac(f,d+12|0),j=y[c+d|0],w[i>>1]=j;d=d+1|0;continue}break}d=b+236|0;while(1){if((h|0)!=96){f=ac(d,h+12|0);e=y[c+h|0];w[f>>1]=e>>>0<(y[a+27|0]|y[a+28|0]<<8)>>>0?e:0;h=h+1|0;continue}break}d=g+8|0;Rk(d,3,a+4|0);c=g+20|0;Cc(c,d);Ac(b+492|0,c);tb(c);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}fb=g+32|0}function OG(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:pe(a,0,c);break a;case 1:pe(a,1,c);break a;case 2:pe(a,2,c);break a;case 3:pe(a,3,c);break a;case 4:pe(a,4,c);break a;case 5:pe(a,5,c);break a;case 6:pe(a,6,c);break a;case 7:pe(a,7,c);break a;case 8:pe(a,8,c);break a;case 9:pe(a,9,c);break a;case 10:pe(a,10,c);break a;case 11:pe(a,11,c);break a;case 12:pe(a,12,c);break a;case 13:pe(a,13,c);break a;case 14:pe(a,14,c);break a;case 15:pe(a,15,c);break a;case 16:pe(a,16,c);break a;case 17:pe(a,17,c);break a;case 18:pe(a,18,c);break a;case 19:pe(a,19,c);break a;case 20:NG(a,71392,c);break a;case 21:NG(a,72416,c);break a;case 22:pe(a,20,c);break a;case 23:pe(a,21,c);break a;case 24:pe(a,22,c);break a;case 25:pe(a,23,c);break a;case 26:pe(a,24,c);break a;case 27:pe(a,25,c);break a;case 28:pe(a,26,c);break a;default:break b}}Fb(a)}}function H0(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:te(a,0,c);break a;case 1:te(a,1,c);break a;case 2:te(a,2,c);break a;case 3:te(a,3,c);break a;case 4:te(a,4,c);break a;case 5:te(a,5,c);break a;case 6:te(a,6,c);break a;case 7:te(a,7,c);break a;case 8:te(a,8,c);break a;case 9:te(a,9,c);break a;case 10:te(a,10,c);break a;case 11:te(a,11,c);break a;case 12:te(a,12,c);break a;case 13:te(a,13,c);break a;case 14:te(a,14,c);break a;case 15:te(a,15,c);break a;case 16:te(a,16,c);break a;case 17:te(a,17,c);break a;case 18:te(a,18,c);break a;case 19:te(a,19,c);break a;case 20:G0(a,71392,c);break a;case 21:G0(a,72416,c);break a;case 22:te(a,20,c);break a;case 23:te(a,21,c);break a;case 24:te(a,22,c);break a;case 25:te(a,23,c);break a;case 26:te(a,24,c);break a;case 27:te(a,25,c);break a;case 28:te(a,26,c);break a;default:break b}}Fb(a)}}function i_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=b-1|0;while(1){a:{if(!c){c=0;break a}if(y[c+g|0]){break a}c=c-1|0;continue}break}b:{if((d|0)!=4){break b}g=0;while(1){if((c|0)==(e|0)){if((f|0)==(g|0)){d=2;if((f|0)==(h|0)){break b}}if(f){d=0;if(!g){break b}}d=f?3:g?1:3}else{c:{d:{e:{d=b+e|0;i=y[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}f=f+1|0;break c}g=g+1|0}if(e){h=((i|0)==10&y[d-1|0]==13)+h|0}e=e+1|0;continue}break}}f=0;g=(d|0)==2;e=0;while(1){if(c>>>0>e>>>0){e=((g&y[b+e|0]==13)+e|0)+1|0;f=f+1|0;continue}break}sf(a);zs(a,f);g=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;e=0;while(1){if(c>>>0>e>>>0){f:{g:{h:{i:{f=y[b+e|0];switch(f-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(f){break f}f=32;break f}e=d+e|0;f=g;break f}f=h}Rp(a,f<<24>>24);e=e+1|0;continue}break}}function TD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;e=Ab(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=d;x[c+52>>2]=f;e=Ag(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;zg(c+36|0,c+8|0);while(1){if(Fd(d,g)){WD(F_(x[c+56>>2]),d-20|0);d=G_(c+60|0);G_(c+56|0);d=x[d>>2];continue}break}yg(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(wi(d,j)){e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+12>>2]=x[e+12>>2]+20;fb=e+16|0;ub(F_(x[e+12>>2]));d=x[Qf(f+12|0)>>2];continue}break}fb=f+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function KU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;e=Ab(a);c=vb(h+12|0,x[a+4>>2]);g=vb(h+8|0,x[a>>2]);f=vb(h+4|0,x[b+4>>2]);d=x[c>>2];g=x[g>>2];c=fb+-64|0;fb=c;f=x[f>>2];x[c+56>>2]=f;x[c+60>>2]=d;x[c+52>>2]=f;e=Ag(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;zg(c+36|0,c+8|0);while(1){if(Fd(d,g)){XB(JU(x[c+56>>2]),en(d));d=Uo(c+60|0);Uo(c+56|0);d=x[d>>2];continue}break}yg(c+36|0);i=x[c+56>>2];if(!y[c+48|0]){g=fb-16|0;fb=g;d=vb(g+12|0,x[x[c+44>>2]>>2]);j=x[vb(g+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(wi(d,j)){e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+12>>2]=x[e+12>>2]+32;fb=e+16|0;Ak(JU(x[e+12>>2]));d=x[Zq(f+12|0)>>2];continue}break}fb=f+16|0;fb=g+16|0}fb=c- -64|0;x[b+4>>2]=i;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function vka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;b=x[a+4>>2];if(Id(y[b+223884|0])){yT(b+223860|0);b=x[a+4>>2]}x[a+24>>2]=0;x[a+28>>2]=0;x[b>>2]=0;c=x[a>>2];x[b+40>>2]=x[c+480196>>2];x[b+44>>2]=x[c+480204>>2];x[b+80>>2]=x[c+480200>>2];c=z[c+480188>>1];x[f+8>>2]=0;x[f+12>>2]=0;d=f+8|0;w[d+4>>1]=65280;x[d>>2]=0;e=fb-16|0;fb=e;x[e+12>>2]=c;b=a+8|0;a:{if(Sn(b)>>>0>=c>>>0){g=x[b>>2];h=ih(g,x[b+4>>2]);x[e+8>>2]=h;i=x[Hb(e+12|0,e+8|0)>>2];while(1){if(i){x[g>>2]=x[d>>2];w[g+4>>1]=z[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){JS(b,c-h|0,d);break a}Jd(b,x[b>>2]+(c<<3)|0);break a}VT(b);fU(b,ks(b,c));JS(b,c,d)}fb=e+16|0;b=0;while(1){c=x[a>>2];if(z[c+480188>>1]<=b>>>0){fb=f+16|0}else{d=D(b,872);Qo((d+x[a+4>>2]|0)+616|0,c,b&65535,67108864);c=d+x[a+4>>2]|0;w[c+1432>>1]=0;v[c+1415|0]=0;b=b+1|0;continue}break}}function rM(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;e=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){o(+a);c=j(1)|0;if(!(j(0)|c&2147483647)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}c=1072693248;k=-1023;if((b|0)!=1072693248){c=b;break b}if(e){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;e=j(0)|0;c=b;k=-1077}l(0,e|0);c=c+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=g+n|0;x[(g<<2)+e>>2]=((((D(v[f+4|0],q)+D(v[f+2|0],r)|0)+D(v[f+6|0],p)|0)+D(v[f+8|0],o)<<8>>1)+(((D(v[f-4|0],u)+D(v[f-6|0],b)|0)+D(v[f-2|0],t)|0)+D(v[f|0],s)<<8>>1)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Pb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Ola(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Gg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);i=x[a+8>>2];j=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];k=x[a+128>>2];if(k){l=Hg(i,j,k);m=hb;f=x[a+76>>2];fg(b,g,uf(i,j,d),hb);h=hb>>>0>f>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;a:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=g+n|0;b=k;while(1)if((b|0)<=0){Pb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){ce(f,v[x[e+12>>2]+g|0]<<6);be(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}g=x[c>>2];b=Fg(f,o);x[c>>2]=g+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Pb(e,i,j);c=c+8|0;continue a}else{ce(f,v[x[e+12>>2]+g|0]<<6);be(f,4);Pb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function Rqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=Q$(c+4|0,a);mD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;jc(a);fb=c+16|0;return}h=fb-32|0;fb=h;c=Ab(a);c=O$(h+12|0,P$(a,Hr(x[a>>2],x[a+4>>2])+1|0),Hr(x[a>>2],x[a+4>>2]),c);mD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;e=Ab(a);b=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);f=vb(g+4|0,x[c+4>>2]);d=x[b>>2];i=x[i>>2];b=fb+-64|0;fb=b;f=x[f>>2];x[b+56>>2]=f;x[b+60>>2]=d;x[b+52>>2]=f;e=Ag(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];f=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=f;zg(b+36|0,b+8|0);while(1){if(Fd(d,i)){mD(pE(x[b+56>>2]),Fr(d));d=pw(b+60|0);pw(b+56|0);d=x[d>>2];continue}break}d=b+36|0;yg(d);e=x[b+56>>2];M$(d);fb=b- -64|0;x[c+4>>2]=e;Tb(a,c+4|0);Tb(a+4|0,c+8|0);Tb(Ab(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;N$(c);fb=h+32|0}function Uj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=Q$(c+4|0,a);qE(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;jc(a);fb=c+16|0;return}h=fb-32|0;fb=h;c=Ab(a);c=O$(h+12|0,P$(a,Hr(x[a>>2],x[a+4>>2])+1|0),Hr(x[a>>2],x[a+4>>2]),c);qE(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;e=Ab(a);b=vb(g+12|0,x[a+4>>2]);i=vb(g+8|0,x[a>>2]);f=vb(g+4|0,x[c+4>>2]);d=x[b>>2];i=x[i>>2];b=fb+-64|0;fb=b;f=x[f>>2];x[b+56>>2]=f;x[b+60>>2]=d;x[b+52>>2]=f;e=Ag(b+24|0,e,b+52|0,b+56|0);x[b+16>>2]=x[e+8>>2];f=x[e+4>>2];x[b+8>>2]=x[e>>2];x[b+12>>2]=f;zg(b+36|0,b+8|0);while(1){if(Fd(d,i)){qE(pE(x[b+56>>2]),Fr(d));d=pw(b+60|0);pw(b+56|0);d=x[d>>2];continue}break}d=b+36|0;yg(d);e=x[b+56>>2];M$(d);fb=b- -64|0;x[c+4>>2]=e;Tb(a,c+4|0);Tb(a+4|0,c+8|0);Tb(Ab(a),nc(c));x[c>>2]=x[c+4>>2];fb=g+16|0;N$(c);fb=h+32|0}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;e=Fb(d+20|0);a:{b:{c:{if(c>>>0<=63){break c}x[31609]=0;c=R(184,b|0)|0;f=x[31609];x[31609]=0;d:{if((f|0)!=1){x[d+16>>2]=c;if((c|0)>0){break d}x[31609]=0;P(36,a|0,22292)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break b}}break a}x[31609]=0;c=R(202,b|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){g=d,h=uh(c),x[g+12>>2]=h;c=x[Cd(d+16|0,d+12|0)>>2];x[31609]=0;O(114,e|0,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{x[31609]=0;c=R(197,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break f}if(!c){break e}x[31609]=0;U(890,e|0,1,((c-65&255)>>>0<26?c|32:c)<<24>>24)|0;c=x[31609];x[31609]=0;if((c|0)!=1){continue}}break}break a}x[31609]=0;P(183,b|0,4)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}Uc(a,e)}tb(e);fb=d+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function Vw(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;a:{if(!c){break a}if(d){b=Zb(g+8|0,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];b:{if(!d){d=x[b>>2];break b}c=32-d|0;x[a+8>>2]=c;e=x[b>>2];h=c;c=x[Hb(a+8|0,a+12|0)>>2];x[e>>2]=-1<<d&-1>>>h-c|x[e>>2];c=x[a+12>>2]-c|0;x[a+12>>2]=c;d=e+4|0;x[b>>2]=d}x[a+4>>2]=-1;e=d;d=c>>>5|0;JF(e,d,a+4|0);e=x[a+12>>2];c=c&-32;f=e-c|0;x[a+12>>2]=f;if((c|0)!=(e|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]|-1>>>32-f}fb=a+16|0;break a}b=Zb(g,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];c:{if(!d){d=x[b>>2];break c}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];f=x[c>>2];h=e;e=x[Hb(a+8|0,a+12|0)>>2];x[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5|0;IF(e,d);c=c&31;x[a+12>>2]=c;if(c){e=b;b=x[b>>2]+(d<<2)|0;x[e>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-c^-1)}fb=a+16|0}fb=g+16|0}function by(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=x[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=x[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;d=y[b|0];if((d|0)!=61){b=b+1|0;if(d){continue}}break}b=c}if((a|0)==(b|0)){return 0}f=b-a|0;c:{if(y[f+a|0]){break c}e=x[125414];if(!e){break c}b=x[e>>2];if(!b){break c}while(1){d:{g=a;c=b;h=f;d=0;e:{if(!f){break e}d=y[a|0];if(d){f:{while(1){i=y[c|0];if((i|0)!=(d|0)|!i){break f}h=h-1|0;if(!h){break f}c=c+1|0;d=y[g+1|0];g=g+1|0;if(d){continue}break}d=0}}else{d=0}d=d-y[c|0]|0}if(!d){b=b+f|0;if(y[b|0]==61){break d}}b=x[e+4>>2];e=e+4|0;if(b){continue}break c}break}j=b+1|0}return j}function Cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];n=x[a+8>>2];o=x[a+12>>2];while(1){if(d){e=x[b+8>>2];j=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=e>>>21&2040;p=w[e+38086>>1];q=w[e+38084>>1];r=w[e+38082>>1];s=w[e+38080>>1];h=0;while(1){if((h|0)!=2){e=h<<1;i=e+j|0;x[(h<<2)+b>>2]=(((D(w[i>>1],r)+D(w[(e|-4)+j>>1],s)|0)+D(w[i+4>>1],q)|0)+D(w[i+8>>1],p)|0)/16384;h=h+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,n,o);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function qua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;nd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Nr(a+4|0,a);d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d;c=Nr(a+8|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=f;c=(y[a+15|0]|y[a+16|0]<<8)<<1;x[b+24>>2]=c;c=y[a+15|0]|y[a+16|0]<<8?c:16726;x[b+24>>2]=c;g=b,h=(D(xw(v[a+17|0],y[a+14|0]<<28>>24),c)>>>0)/8363|0,x[g+24>>2]=h;v[e+15|0]=y[a+18|0];v[e+14|0]=127;g=b,h=(((y[Qb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;c=y[a+14|0];if(c>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=c&240}c=y[a+19|0];if(c&4){w[b+34>>1]=z[b+34>>1]|1;c=y[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=z[b+34>>1];d=f|2;w[b+34>>1]=d;c=y[a+19|0];if(c&16){d=f|6;w[b+34>>1]=d;c=y[a+19|0]}if(!(c&64)){break a}w[b+34>>1]=d|128}fb=e+16|0}function jka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-880|0;fb=b;c=Rb(a,0,76);x[c+84>>2]=0;x[c+88>>2]=0;x[c+80>>2]=256;v[c+78|0]=0;w[c+76>>1]=65535;x[c+92>>2]=0;x[c+96>>2]=0;v[c+100|0]=1;a=616;while(1){RV(a+c|0);a=a+872|0;if((a|0)!=223848){continue}break}e=Nb(c+223848|0);g=iB(c+223860|0);f=b+8|0;Rb(f,0,108);qC(b+120|0,48e3);Rb(b+664|0,0,72);v[b+754|0]=0;w[b+752>>1]=65535;x[b+748>>2]=0;v[b+746|0]=0;w[b+744>>1]=65535;x[b+740>>2]=0;v[b+738|0]=0;w[b+736>>1]=65535;Rb(b+756|0,0,103);x[b+868>>2]=0;x[b+872>>2]=0;v[b+875|0]=0;v[b+876|0]=0;v[b+877|0]=0;v[b+878|0]=0;x[b+860>>2]=0;x[b+864>>2]=0;v[b+859|0]=y[b+859|0]&128;a=c+616|0;d=((a+223232|0)-a|0)/872|0;while(1){if((d|0)>0){d=d-1|0;a=Gq(a,f)+872|0;continue}break}x[31609]=0;O(553,e|0,32);a=x[31609];x[31609]=0;if((a|0)!=1){fb=b+880|0;return c|0}a=N()|0;Hq(g);fc(e);Q(a|0);p()}function RL(a,b,c,d){var e=0,f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=0;e=fb-96|0;fb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];d=0;while(1){if((d|0)!=4){i=d<<3;k=i+(e+48|0)|0;g=(d<<4)+a|0;h=B[g+4>>2];f=B[g+8>>2];B[k+4>>2]=h+f;B[(8-(d<<1)<<2)+e>>2]=h-f;h=B[g+16>>2];f=B[g+12>>2];B[(i^28)+e>>2]=h-f;B[k+8>>2]=-E(h+f);d=d+1|0;continue}break}QL(e+48|0);QL(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=B[i>>2];f=B[d+(e+48|0)>>2];l=B[d+87344>>2];m=B[d+87380>>2];n=B[d+e>>2];B[i>>2]=E(f*l)-E(m*n);i=a+d|0;d=c+d|0;f=E(E(f*m)+E(n*l));B[i>>2]=E(h*B[d>>2])-E(B[d+36>>2]*f);B[(17-g<<2)+a>>2]=E(h*B[d+36>>2])+E(f*B[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}fb=e+96|0}function KP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=0,n=0,o=0,p=E(0);d=a+4208|0;j=E(E(B[yb(d,2)>>2]*E(2999.9990234375))+E(.0010000000474974513));l=E(B[yb(d,3)>>2]*E(.9980000257492065));f=-3e3/(+A[x[a+16>>2]+24620>>2]*+j);h=a+4272|0;c=mk(10,f*+A[yb(h,4)>>2]);d=a+4232|0;o=yb(d,0),p=E(c),B[o>>2]=p;c=mk(10,f*+A[yb(h,5)>>2]);o=yb(d,1),p=E(c),B[o>>2]=p;m=f*(1/+E(l+E(.0010000000474974513))+-1);c=0;while(1){if((e|0)==4){e=a+4208|0;f=mk(10,+HP(B[yb(e,0)>>2])*.05);b=4/M(c)*f;c=mk(10,+HP(B[yb(e,1)>>2])*.1);B[a+4228>>2]=b*M(c);B[a+4224>>2]=f*M(1-c)}else{g=yb(h,e);k=e>>>1|0;n=x[yb(h,k|4)>>2];g=x[g>>2];i=mk(10,m*+(n+g>>>0));b=mk(10,f*+(g>>>0));j=B[yb(d,k)>>2];g=e<<1;i=(1-i)*.5;o=yb(d,g+2|0),p=E(b*(1-i)),B[o>>2]=p;o=yb(d,g+3|0),p=E(b*i),B[o>>2]=p;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;e=e+1|0;continue}break}}function oO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb+-64|0;fb=e;a:{b:{if((b|0)>=0){d=x[a+24>>2];if(Hj(Xb(x[d+484360>>2],y[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=x[a+24>>2];g=x[f+484344>>2];i=x[f+484348>>2];h=z[ac(x[Xb(x[f+484360>>2],y[f+484376|0])>>2],b)>>1];if(!Bn(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<x[Wb(g,h)+12>>2]){break c}}a=a+16|0;break a}w[f+1074448>>1]=b;c=f;f=b&65535;UR(c,f);c=x[a+24>>2];x[c+1074392>>2]=-2;x[c+1074428>>2]=d;g=y[a+64|0];b=e+24|0;w[b+4>>1]=0;v[b+6|0]=255;x[b+16>>2]=2;x[b>>2]=0;w[b+12>>1]=f;x[b+8>>2]=d;d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+52|0;Fv(b,c,g?7:1,e);j=a,k=C[en(x[e+56>>2])>>3],C[j+16>>3]=k;Qi(b);a=a+16|0}fb=e- -64|0;return+C[a>>3]}function Y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=nJ(a,0);f=fb-16|0;fb=f;c=4;a=UI(e+12|0,b);while(1){Fb(a+c|0);d=172;c=c+12|0;if((c|0)!=172){continue}break}while(1){Fb(a+d|0);c=460;d=d+12|0;if((d|0)!=460){continue}break}while(1){Fb(a+c|0);c=c+12|0;if((c|0)!=484){continue}break}c=Fb(a+484|0);d=Fb(a+496|0);h=Fb(a+508|0);i=Fb(a+520|0);x[31609]=0;b=P(1378,f+4|0,b|0)|0;g=x[31609];x[31609]=0;a:{b:{c:{if((g|0)!=1){x[31609]=0;O(1379,a|0,b|0);g=x[31609];x[31609]=0;if((g|0)==1){break c}dt(b);fb=f+16|0;break a}e=N()|0;break b}e=N()|0;dt(b)}Ub(i);Ub(h);Ub(d);Ub(c);d=484;while(1){d=d-12|0;Ub(a+d|0);c=460;if((d|0)!=460){continue}break}while(1){c=c-12|0;Ub(a+c|0);d=172;if((c|0)!=172){continue}break}while(1){d=d-12|0;Ub(a+d|0);if((d|0)!=4){continue}break}ct(a);Q(e|0);p()}x[e+8>>2]=100132;x[e>>2]=100056;return e|0}function _4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=oJ(a,0);f=fb-32|0;fb=f;c=4;a=UI(e+12|0,b);while(1){Fb(a+c|0);d=172;c=c+12|0;if((c|0)!=172){continue}break}while(1){Fb(a+d|0);c=460;d=d+12|0;if((d|0)!=460){continue}break}while(1){Fb(a+c|0);c=c+12|0;if((c|0)!=484){continue}break}c=Fb(a+484|0);d=Fb(a+496|0);h=Fb(a+508|0);i=Fb(a+520|0);x[31609]=0;b=P(1376,f+12|0,b|0)|0;g=x[31609];x[31609]=0;a:{b:{c:{if((g|0)!=1){x[31609]=0;O(1377,a|0,b|0);g=x[31609];x[31609]=0;if((g|0)==1){break c}at(b);fb=f+32|0;break a}e=N()|0;break b}e=N()|0;at(b)}tb(i);tb(h);tb(d);tb(c);d=484;while(1){d=d-12|0;tb(a+d|0);c=460;if((d|0)!=460){continue}break}while(1){c=c-12|0;tb(a+c|0);d=172;if((c|0)!=172){continue}break}while(1){d=d-12|0;tb(a+d|0);if((d|0)!=4){continue}break}ct(a);Q(e|0);p()}x[e+8>>2]=99836;x[e>>2]=99760;return e|0}function sja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;nd(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;x[c>>2]=y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24);x[c+4>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+8>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+24>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);d=y[b+151|0];if(d>>>0<=4){v[c+38|0]=y[d+41114|0]}d=y[b+152|0]|y[b+153|0]<<8;v[c+39|0]=d;e=(y[b+156|0]|y[b+157|0]<<8)>>>4|0;v[c+41|0]=e;b=(y[b+154|0]|y[b+155|0]<<8)>>>2|0;v[c+40|0]=b;if((b|e)&255){v[c+39|0]=d^-1}b=y[a+38|0]|y[a+39|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+38|0]|y[a+39|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+38|0]|y[a+39|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+38|0]|y[a+39|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}}function d7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=NJ(c);b:{if(b){b=k+4|0;ll(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;kl(b,a);break b}b=k+4|0;kt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;di(b,a)}nh(i,b);Ub(b);l=e,m=lj(a),x[l>>2]=m;l=f,m=mj(a),x[l>>2]=m;b=k+4|0;sh(b,a);zb(g,b);tb(b);ei(b,a);nh(h,b);Ub(b);a=Kk(a);break a}a=MJ(c);c:{if(b){b=k+4|0;ll(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;kl(b,a);break c}b=k+4|0;kt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;di(b,a)}nh(i,b);Ub(b);l=e,m=lj(a),x[l>>2]=m;l=f,m=mj(a),x[l>>2]=m;b=k+4|0;sh(b,a);zb(g,b);tb(b);ei(b,a);nh(h,b);Ub(b);a=Kk(a)}x[j>>2]=a;fb=k+16|0}function sK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=fb-32|0;fb=i;a:{b:{c:{if((b|0)!=(c|0)){k=x[31484];x[31484]=0;g=fb-16|0;fb=g;Od();f=fb-16|0;fb=f;e=fb-16|0;fb=e;_x(e,b,i+28|0,2);h=x[e>>2];j=x[e+4>>2];b=f;f=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=f;x[b>>2]=h;x[b+4>>2]=j;fb=e+16|0;f=x[b>>2];h=x[b+4>>2];e=g;g=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=g;x[e>>2]=f;x[e+4>>2]=h;fb=b+16|0;g=x[e>>2];f=x[e+4>>2];h=x[e+12>>2];b=i;x[b+16>>2]=x[e+8>>2];x[b+20>>2]=h;x[b+8>>2]=g;x[b+12>>2]=f;fb=e+16|0;e=x[b+16>>2];f=x[b+20>>2];g=x[b+8>>2];h=x[b+12>>2];j=x[31484];if(!j){break c}if(x[b+28>>2]!=(c|0)){break b}l=g;m=h;n=e;o=f;if((j|0)!=68){break a}break b}x[d>>2]=4;break a}x[31484]=k;if(x[i+28>>2]==(c|0)){break a}}x[d>>2]=4;g=l;h=m;e=n;f=o}x[a>>2]=g;x[a+4>>2]=h;x[a+8>>2]=e;x[a+12>>2]=f;fb=i+32|0}function h7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=QJ(c);b:{if(b){b=k+4|0;ll(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;kl(b,a);break b}b=k+4|0;kt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;di(b,a)}zb(i,b);tb(b);l=e,m=lj(a),v[l|0]=m;l=f,m=mj(a),v[l|0]=m;b=k+4|0;sh(b,a);zb(g,b);tb(b);ei(b,a);zb(h,b);tb(b);a=Kk(a);break a}a=PJ(c);c:{if(b){b=k+4|0;ll(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;kl(b,a);break c}b=k+4|0;kt(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;di(b,a)}zb(i,b);tb(b);l=e,m=lj(a),v[l|0]=m;l=f,m=mj(a),v[l|0]=m;b=k+4|0;sh(b,a);zb(g,b);tb(b);ei(b,a);zb(h,b);tb(b);a=Kk(a)}x[j>>2]=a;fb=k+16|0}function Rja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-48|0;fb=b;e=Nb(a);a=0;a:{while(1){b:{if((a|0)==432){a=0;break b}c=a+30564|0;g=pc(b+40|0,x[c>>2]);d=x[b+44>>2];c:{if(!d){break c}f=x[e+4>>2];if(!mc(x[e>>2],f)){g=x[g>>2];f=pc(b+32|0,x[xf(f)>>2]);h=x[f+4>>2];x[b+8>>2]=x[f>>2];x[b+12>>2]=h;if(Ic(g,d,b+8|0)){break c}}x[31609]=0;O(886,e|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}}a=a+8|0;continue}break}d:{while(1){if((a|0)==48){break d}c=pc(b+40|0,x[a+31e3>>2]);e:{g=x[b+44>>2];f:{if(!g){break f}d=x[e+4>>2];if(!mc(x[e>>2],d)){f=x[c>>2];d=pc(b+24|0,x[xf(d)>>2]);h=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=h;if(Ic(f,g,b)){break f}}c=x[c>>2];x[31609]=0;x[b+20>>2]=c;O(887,e|0,b+20|0);c=x[31609];x[31609]=0;if((c|0)==1){break e}}a=a+12|0;continue}break}break a}fb=b+48|0;return}a=N()|0;wc(e);Q(a|0);p()}function l3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=Nb(a);a=0;a:{b:{c:{while(1){if((Rx(b,c,a)|0)==-1){break b}g=Rx(b,c,a);x[31609]=0;e=d+4|0;V(100,e|0,b|0,a|0,g-a|0);g=x[31609];x[31609]=0;if((g|0)!=1){x[31609]=0;O(101,f|0,e|0);g=x[31609];x[31609]=0;if((g|0)==1){break c}tb(e);a=Rx(b,c,a)+_c(x[c+4>>2],y[c+11|0])|0;continue}break}a=N()|0;break a}a=N()|0;tb(d+4|0);break a}d:{e:{f:{g:{if(mc(x[f>>2],x[f+4>>2])){x[31609]=0;c=d+4|0;V(100,c|0,b|0,a|0,-1);e=x[31609];x[31609]=0;if((e|0)==1){break f}e=_c(x[d+8>>2],y[d+15|0]);tb(c);if(!e){break g}}x[31609]=0;c=d+4|0;V(100,c|0,b|0,a|0,-1);a=x[31609];x[31609]=0;if((a|0)==1){break e}x[31609]=0;O(101,f|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break d}tb(c)}fb=d+16|0;return}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(d+4|0)}Td(f);Q(a|0);p()}function pB(a,b,c,d,e){var f=0,g=0,h=0;f=(D(c,872)+b|0)+616|0;a:{if(d){if(!Ob(a+1074312|0,90)){v[f+811|0]=d}v[f+812|0]=d;break a}d=y[f+812|0]}g=x[a+480180>>2];if(!e){h=Ju(g)}b:{if((g|0)!=268435456){if((g|0)!=16777216){break b}g=x[f+656>>2];if(!g|!x[g+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){RS(b,c,240-a|0);return}if(!(a>>>0<224|e)){QS(f,224-a|0);return}PS(f,0-a|0);return}x[f+708>>2]=65535}b=d&255;c:{d:{if(!(b>>>0>223&h)){break d}e:{c=b&15;if(!c){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}mB(a,f,c);return}if(x[a+480180>>2]==524288){break d}lB(a,f,c);return}if(x[a+480180>>2]!=524288){break c}}f:{if(!(v[f+851|0]&1)){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}wk(a,f,f+700|0,0-(b<<2)|0,0)}}function ura(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=If(a,c);ae(f,x[a+36>>2]);j=a;a:{if(!c){Qc(f,a+32|0,5);d=0;if(Gb(x[x[f>>2]>>2],x[f+4>>2])){break a}}d=fb-32|0;fb=d;h=x[a+36>>2];e=d+30|0;ng(h,e);b:{c:{d:{e:{a=z[d+30>>1];if(a>>>0>=4001){k=x[b+12>>2];a=fb-16|0;fb=a;g=d+4|0;i=uc(a+4|0,15994);Uc(g,i);tb(i);fb=a+16|0;x[31609]=0;a=d+16|0;S(490,a|0,g|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break e}e=x[k+1298472>>2];x[31609]=0;S(385,e|0,2,a|0);e=x[31609];x[31609]=0;if((e|0)==1){break d}tb(a);Eb(g);a=4e3}vg(Mj(x[b>>2],0),a);a=Mj(x[b>>2],0);b=wb(x[a>>2]);x[d+16>>2]=b;a=wb(x[a+4>>2]);break b}b=N()|0;break c}b=N()|0;tb(d+16|0)}Eb(d+4|0);Q(b|0);p()}while(1){if(Ib(b,a)){ng(h,d+4|0);w[b>>1]=z[d+4>>1];b=x[ge(d+16|0)>>2];continue}break}fb=d+32|0;d=c}ef(j,d);fb=f+16|0}function Yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=fb-16|0;fb=h;if(ti(a+44|0)){g=x[a+44>>2];u=h,v=Hc(g,0),x[u+8>>2]=v;u=h,v=Hc(g,1),x[u+12>>2]=v;g=x[a+56>>2];l=Hc(g,0);x[h>>2]=l;m=Hc(g,1);x[h+4>>2]=m;p=a+4252|0;q=a+4244|0;r=a+4228|0;s=y[a+4273|0];t=y[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){i=k<<2;j=i+(h+8|0)|0;e=x[j>>2];x[j>>2]=e+4;f=E(B[e>>2]*B[a+4240>>2]);e=i+r|0;f=E(f+E(B[e>>2]*B[a+4236>>2]));B[e>>2]=f;f=_P(E(f*E(1073741824)),t,s);e=i+q|0;j=i+p|0;n=B[j>>2];o=B[a+4264>>2];f=E(E(E(f*B[a+4260>>2])-E(B[a+4268>>2]*B[e>>2]))-E(n*o));B[e>>2]=E(f*o)+n;B[j>>2]=f;e=h+i|0;i=x[e>>2];x[e>>2]=i+4;B[i>>2]=f*E(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{Ii(a,b,c,l,m,d)}break}}fb=h+16|0}function Gfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;x[31609]=0;W(996,a|0);d=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[31609]=0;W(997,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break g}x[31609]=0;W(997,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break g}f=x[a+24>>2];x[31609]=0;d=P(36,e+20|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break g}x[31609]=0;c=P(36,e+8|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break f}x[31609]=0;V(1012,f|0,d|0,c|0,1);b=x[31609];x[31609]=0;if((b|0)==1){break e}tb(c);tb(d);b=1;break b}b=T(0)|0;break c}b=T(0)|0;break d}b=T(0)|0;tb(c)}tb(d)}Y(b|0)|0;b=0;x[31609]=0;V(983,6409,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z()}fb=e+32|0;return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;p=w[e+38086>>1];q=w[e+38084>>1];r=w[e+38082>>1];e=w[e+38080>>1];h=0;while(1){if((h|0)!=2){i=h+o|0;x[(h<<2)+b>>2]=(((D(v[i|0],r)+D(v[i-2|0],e)|0)+D(v[i+2|0],q)|0)+D(v[i+4|0],p)<<8)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=Ji(a,b,c,d);x[b+4260>>2]=0;x[b>>2]=45148;d=4504;while(1){Nb(b+d|0);d=d+24|0;if((d|0)!=4960){continue}break}v[b+5046|0]=1;w[b+5044>>1]=0;a=b+4208|0;e=yb(a,0),f=1063675494,x[e>>2]=f;e=yb(a,1),f=1065185444,x[e>>2]=f;e=yb(a,2),f=0,x[e>>2]=f;e=yb(a,3),f=1032805417,x[e>>2]=f;e=yb(a,4),f=1053079357,x[e>>2]=f;e=yb(a,5),f=1059859440,x[e>>2]=f;e=yb(a,6),f=1047457519,x[e>>2]=f;e=yb(a,7),f=1062836634,x[e>>2]=f;e=yb(a,8),f=1038174126,x[e>>2]=f;e=yb(a,9),f=1065353216,x[e>>2]=f;e=yb(a,10),f=1065353216,x[e>>2]=f;e=yb(a,11),f=1048525618,x[e>>2]=f;e=yb(a,12),f=1059760811,x[e>>2]=f;x[31609]=0;O(941,b+44|0,2);a=x[31609];x[31609]=0;if((a|0)==1){a=N()|0;d=4960;while(1){d=d-24|0;wc(b+d|0);if((d|0)!=4504){continue}break}_f(b);Q(a|0);p()}return b|0}function Zla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function qB(a,b,c,d,e){var f=0,g=0,h=0;f=(D(c,872)+b|0)+616|0;a:{if(d){if(!Ob(a+1074312|0,90)){v[f+812|0]=d}v[f+811|0]=d;break a}d=y[f+811|0]}g=x[a+480180>>2];if(!e){h=Ju(g)}b:{if((g|0)!=268435456){if((g|0)!=16777216){break b}g=x[f+656>>2];if(!g|!x[g+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){RS(b,c,a-240|0);return}if(!(a>>>0<224|e)){QS(f,a-224|0);return}PS(f,a);return}x[f+708>>2]=1}b=d&255;c:{d:{if(!(b>>>0>223&h)){break d}e:{c=b&15;if(!c){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}nB(a,f,c);return}if(x[a+480180>>2]==524288){break d}oB(a,f,c);return}if(x[a+480180>>2]!=524288){break c}}f:{if(!(v[f+851|0]&1)){break f}if(x[a+1074416>>2]==1){if(Ob(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}wk(a,f,f+700|0,b<<2,0)}}function Xn(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;x[31609]=0;W(996,a|0);e=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=x[a+24>>2];x[31609]=0;O(d|0,f+4|0,e|0);d=x[31609];x[31609]=0;if((d|0)==1){break i}d=x[f+4>>2];e=Ud(d,x[f+8>>2]);if(e>>>0<2147483647){break h}d=dc(8);x[31609]=0;b=P(1051,d|0,7429)|0;e=x[31609];x[31609]=0;if((e|0)==1){break g}x[31609]=0;S(97,b|0,124900,162);b=x[31609];x[31609]=0;if((b|0)!=1){break b}b=T(0)|0;break f}b=T(0)|0;break e}b=T(0)|0;break e}j:{if(b>>>0>=e>>>0){b=Cg(22292);break j}b=Cg(Kb(Vd(d,b)))}Td(f+4|0);break d}b=T(0)|0;lc(d)}Td(f+4|0)}Y(b|0)|0;b=0;x[31609]=0;V(983,c|0,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Z()}fb=f+16|0;return b}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break a}T(0)|0;Sb()}p()}Q(a|0);p()}function sr(a,b){var c=0;c=fb-16|0;fb=c;a=ds(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:RA(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;bg(a,107);break a;case 3:RA(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;bg(a,4);break a;case 2:break b;case 0:break c}}Lb(a,88,1);break a}RA(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}fb=c+16|0}function npa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;j=c,k=jf(a)>>>5|0,w[j+32>>1]=k;w[c+20>>1]=3999;d=z[Oc(c+32|0,c+20|0)>>1];w[b+480190>>1]=d;i=b+946304|0;g=1;while(1){f=g&65535;if(f>>>0<=d>>>0){d=ni(b,f);e=c+32|0;xr(a,e);nd(d,0);h=c+8|0;pi(h,2,e);e=c+20|0;Cc(e,h);Ac((f<<5)+i|0,e);tb(e);x[d+24>>2]=8287;j=c,k=Bb(y[c+60|0]|y[c+61|0]<<8),w[j+20>>1]=k;w[c+8>>1]=64;j=d,k=z[Oc(e,h)>>1]<<2,w[j+30>>1]=k;j=d,k=$b(y[c+52|0]|y[c+53|0]<<8|(y[c+54|0]<<16|y[c+55|0]<<24))&-2,x[j>>2]=k;e=Bb(y[c+62|0]|y[c+63|0]<<8);j=yb(d+68|0,0),k=e,x[j>>2]=k;e=Bb(y[c+56|0]|y[c+57|0]<<8);f=Bb(y[c+58|0]|y[c+59|0]<<8);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>A[d>>2]){break a}x[d+16>>2]=f;x[d+12>>2]=e<<1;w[d+34>>1]=z[d+34>>1]|8}g=g+1|0;d=z[b+480190>>1];continue}break}fb=c- -64|0}function Aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((gk(x[a>>2],x[a+4>>2])|0)==2){if((gk(x[a+12>>2],x[a+16>>2])|0)==(b|0)){break b}}x[31609]=0;O(943,a|0,2);c=x[31609];x[31609]=0;c:{if((c|0)==1){break c}x[31609]=0;O(943,a+12|0,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}x[31609]=0;O(944,a+24|0,2);c=x[31609];x[31609]=0;if((c|0)==1){break c}x[31609]=0;O(944,a+36|0,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=as(x[c+12>>2],a);f=yb(x[c+36>>2],a),g=d,x[f>>2]=g;a=a+1|0;continue}}else{e=as(x[a>>2],d);f=yb(x[a+24>>2],d),g=e,x[f>>2]=g;d=d+1|0;continue}}b=T(124540)|0;if((gb|0)!=($(124540)|0)){break a}Y(b|0)|0;Nc(a);IQ(a);b=a+12|0;Nc(b);IQ(b);b=a+24|0;Nc(b);HQ(b);a=a+36|0;Nc(a);HQ(a);Z()}return}Q(b|0);p()}function td(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];i=!!(b|d);h=b;e=x[a+4>>2];f=x[a+44>>2];b=e-f|0;g=b;c=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;a:{b=c>>>0<g>>>0?b+1|0:b;if(!(((b|0)>=(d|0)&c>>>0>=h>>>0|(b|0)>(d|0))&i)){i=zt(a);if((i|0)>=0){break a}e=x[a+4>>2];f=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=e;g=c;c=f-e|0;d=g+c|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=c>>>0>d>>>0?b+1|0:b;return-1}d=c+1|0;b=d?b:b+1|0;h=x[a+4>>2];f=x[a+8>>2];c=x[a+116>>2];g=c;e=x[a+112>>2];b:{if(!(c|e)){break b}c=e-d|0;e=g-(b+(d>>>0>e>>>0)|0)|0;j=f-h|0;g=j>>31;if((e|0)>=(g|0)&c>>>0>=j>>>0|(e|0)>(g|0)){break b}f=c+h|0}x[a+104>>2]=f;c=x[a+44>>2];f=c-h|0;d=f+d|0;b=(f>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<f>>>0?b+1|0:b;if(c>>>0>=h>>>0){v[h-1|0]=i}return i}function Ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;l=If(a,c);ae(f,x[a+36>>2]);m=a;a:{if(!l){Qc(f,a+32|0,5);c=0;if(Gb(x[x[f>>2]>>2],x[f+4>>2])){break a}}e=fb-48|0;fb=e;j=x[a+36>>2];ol(j,e+40|0);h=x[e+44>>2];if(!h&A[e+40>>2]>=257|h){x[e+40>>2]=256;x[e+44>>2]=0}h=x[e+40>>2];n=x[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!n&c>>>0>=h>>>0){break b}i=e+38|0;ng(j,i);a=Fb(e+24|0);x[31609]=0;P(498,j|0,a|0)|0;g=x[31609];x[31609]=0;if((g|0)!=1){x[31609]=0;g=e+12|0;S(496,g|0,d|0,a|0);k=x[31609];x[31609]=0;if((k|0)==1){break e}x[31609]=0;i=P(931,b|0,i|0)|0;k=x[31609];x[31609]=0;if((k|0)==1){break d}zb(i,g);tb(g);tb(a);c=c+1|0;continue}break}c=N()|0;break c}c=N()|0;break c}c=N()|0;tb(e+12|0)}tb(a);Q(c|0);p()}fb=e+48|0;c=l}ef(m,c);fb=f+16|0}function HT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;c=vb(g+12|0,x[a+4>>2]);d=vb(g+8|0,x[a>>2]);e=x[vb(g+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;j=h+8|0;f=fb-32|0;fb=f;fd(f+24|0,x[c>>2],x[d>>2]);k=f+16|0;c=x[f+24>>2];l=x[f+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=e;x[d+12>>2]=c;while(1){if(Fd(c,l)){c=ET(c);e=ET(x[d+8>>2]);i=y[c+3|0]|y[c+4|0]<<8|(y[c+5|0]<<16|y[c+6|0]<<24);v[e+3|0]=i;v[e+4|0]=i>>>8;v[e+5|0]=i>>>16;v[e+6|0]=i>>>24;c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=c;v[e+1|0]=c>>>8;v[e+2|0]=c>>>16;v[e+3|0]=c>>>24;c=DT(d+12|0);DT(d+8|0);c=x[c>>2];continue}break}qc(k,c,d+8|0);fb=d+16|0;c=x[f+16>>2];x[f+12>>2]=x[f+20>>2];qc(j,c,f+12|0);fb=f+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=g+16|0}function o4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-160|0;fb=d;Rb(d+116|0,0,44);h=a+4|0;while(1){if((c|0)==7){a:{h=a+172|0;c=0;while(1){if((c|0)==12){break a}x[d+132>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14339,f|0,x[a>>2])|0;g=h+D(c,12)|0;ld(g,e);fa(e|0,100,13349,f|0,x[a>>2])|0;ld(g+144|0,e);c=c+1|0;continue}}}else{x[d+140>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14352,f|0,x[a>>2])|0;g=h+D(c,12)|0;ld(g,e);fa(e|0,100,13556,f|0,x[a>>2])|0;ld(g+84|0,e);c=c+1|0;continue}break}x[d+124>>2]=1;c=d+16|0;e=d+116|0;fa(c|0,100,9278,e|0,x[a>>2])|0;ld(a+460|0,c);x[d+124>>2]=13;fa(c|0,100,9278,e|0,x[a>>2])|0;ld(a+472|0,c);c=d+4|0;$s(c,a,99,b);zb(a+484|0,c);tb(c);$s(c,a,114,b);zb(a+496|0,c);tb(c);$s(c,a,120,b);zb(a+508|0,c);tb(d+4|0);$s(c,a,88,b);zb(a+520|0,c);tb(d+4|0);fb=d+160|0}function _la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Pb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function Qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=fb-4112|0;fb=c;h=ib[x[x[a>>2]+120>>2]](a)|0;if(!h){ib[x[x[a>>2]+124>>2]](a)}x[c+12>>2]=0;f=fb-16|0;fb=f;while(1){d=x[a+44>>2];if(gk(d,x[a+48>>2])>>>0<=e>>>0){fb=f+16|0}else{x[f+12>>2]=0;d=as(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){B[d>>2]=B[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}d=c+2064|0;a:while(1){if(b){x[c+8>>2]=b;xc(c+8|0,512);e=c+16|0;VA(e);f=x[c+8>>2];ib[x[x[a>>2]+60>>2]](a,e,d,f);e=0;while(1)if((e|0)==(f|0)){b=b-f|0;continue a}else{g=e<<2;B[c+4>>2]=F(B[g+(c+16|0)>>2]);i=c,j=B[Xz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;B[c+4>>2]=F(B[d+g>>2]);i=c,j=B[Xz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){ib[x[x[a>>2]+128>>2]](a)}fb=c+4112|0;return E(B[c+12>>2])}function FK(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;g=x[124115];if(x[b+72>>2]<=0){My(b)}x[124115]=x[b+136>>2];a:{b:{c:{if(a>>>0<=127){d:{if(x[b+80>>2]==(a|0)){break d}c=x[b+20>>2];if((c|0)==x[b+16>>2]){break d}x[b+20>>2]=c+1;v[c|0]=a;break a}d=fb-16|0;fb=d;v[d+15|0]=a;c=x[b+16>>2];e:{if(!c){c=-1;if(Uw(b)){break e}c=x[b+16>>2]}f:{f=x[b+20>>2];if((c|0)==(f|0)){break f}c=a&255;if((c|0)==x[b+80>>2]){break f}x[b+20>>2]=f+1;v[f|0]=a;break e}c=-1;if((ib[x[b+36>>2]](b,d+15|0,1)|0)!=1){break e}c=y[d+15|0]}fb=d+16|0;a=c;break c}c=x[b+20>>2];if(A[b+16>>2]>c+4>>>0){c=Kt(c,a);if((c|0)<0){break b}x[b+20>>2]=c+x[b+20>>2];break c}d=e+12|0;c=Kt(d,a);if((c|0)<0){break b}if(Rr(d,c,b)>>>0<c>>>0){break b}}if((a|0)!=-1){break a}}x[b>>2]=x[b>>2]|32;a=-1}x[124115]=g;fb=e+16|0;return a}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;x[e+60>>2]=c;a=re(a,e+60|0);c=tc(a+4|0);g=tc(a+24|0);h=tc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31609]=0;O(991,a|0,d|0);f=x[31609];x[31609]=0;a:{b:{c:{d:{if((f|0)!=1){se(e+24|0,x[b>>2],x[b+4>>2]);lf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Md(e+16|0);x[31609]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=e+40|0;Ms(995,b,x[e+32>>2],x[e+36>>2],e+8|0);f=x[31609];x[31609]=0;if((f|0)==1){break d}x[31609]=0;S(992,a|0,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}ub(b);x[31609]=0;W(993,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+40|0)}Td(j);nf(i);Al(h);wh(g);vh(c);Wc(a);Wc(e+60|0);Q(d|0);p()}Wc(e+60|0);fb=e- -64|0;return a|0}function raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;x[31609]=0;e=x[b+12>>2];x[d+40>>2]=x[b+8>>2];x[d+44>>2]=e;e=x[b+4>>2];x[d+32>>2]=x[b>>2];x[d+36>>2]=e;e=R(1197,d+32|0)|0;f=x[31609];x[31609]=0;if((f|0)!=1){a:{b:{if(e){x[31609]=0;e=d+72|0;O(1198,e|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){b=d+80|0;Jp(b,e);f=Ff(d+88|0,b);g=Ff(d- -64|0,c);h=x[f+4>>2];x[d+8>>2]=x[f>>2];x[d+12>>2]=h;f=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=f;Kp(a,d+8|0,d);break b}break a}x[31609]=0;e=d+72|0;O(1199,e|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=d+80|0;Jp(b,e);f=Ff(d+56|0,b);g=Ff(d+48|0,c);h=x[f+4>>2];x[d+24>>2]=x[f>>2];x[d+28>>2]=h;f=x[g+4>>2];x[d+16>>2]=x[g>>2];x[d+20>>2]=f;Kp(a,d+24|0,d+16|0)}me(b);me(e);me(c);fb=d+96|0;return}}a=N()|0;me(c);Q(a|0);p()}function LQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;if(!(oc(x[a>>2],x[a+4>>2])>>>0>511|x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){d=fb-16|0;fb=d;f=Ec(64);x[31609]=0;g=R(875,f|0)|0;h=x[31609];x[31609]=0;a:{b:{if((h|0)!=1){f=yf(d+8|0,g);g=x[f>>2];x[31609]=0;g=U(938,g|0,b|0,c|0)|0;h=x[31609];x[31609]=0;c:{d:{if((h|0)!=1){if((g|0)==1){break d}tc(d+12|0);break c}a=N()|0;mg(f);break b}re(d+12|0,f)}mg(f);fb=d+16|0;d=x[d+12>>2];break a}a=N()|0;Db(f)}Q(a|0);p()}x[e+12>>2]=d;e:{f:{if(!Ed(d)){x[31609]=0;b=P(936,b|0,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break f}x[e+8>>2]=b;b=e+8|0;tZ(e+12|0,ne(b));mg(b);d=x[e+12>>2]}if(!Ed(d)){break e}x[31609]=0;O(500,a|0,e+12|0);a=x[31609];x[31609]=0;i=d;if((a|0)!=1){break e}}a=N()|0;mg(e+12|0);Q(a|0);p()}mg(e+12|0)}fb=e+16|0;return i}function Fo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;f=x[b+656>>2];if(!(!f|v[b+730|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}e=z[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;x[b+88>>2]=d;e=x[c>>2];x[b+76>>2]=e;g=x[c+4>>2];x[b+80>>2]=g;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<e>>>0){x[b+76>>2]=c;h=c}else{h=e}e=x[b+4>>2];if(h>>>0>=e>>>0){break b}x[b>>2]=0;x[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;x[b+88>>2]=d;x[b+76>>2]=x[c>>2]}if(!f){break a}if(!(!(y[f+60|0]&2|x[a+480180>>2]&1064964)|!x[f>>2])){x[b+88>>2]=d|4096}if(y[f+65|0]==255|z[b+728>>1]!=65535){break a}i=b,j=gd(Rq(f+48|0,x[b+724>>2],256,64)),w[i+728>>1]=j;i=b,j=z[yb(x[f+48>>2],y[f+65|0])>>1],x[i+724>>2]=j}}function Rq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;a:{e=x[a>>2];f=x[a+4>>2];if(mc(e,f)){break a}i=Sd(e,f)-1|0;while(1){b:{if(Sd(e,f)-1>>>0>g>>>0){j=Pc(e,f,g);f=x[a+4>>2];e=x[a>>2];if(z[j>>1]<(b|0)){break b}i=g}g=z[Pc(e,f,i)>>1];f=0;x[h+12>>2]=0;c:{if((b|0)>=(g|0)){k=h,l=(y[Pc(x[a>>2],x[a+4>>2],i)+2|0]<<16>>>0)/(d>>>0)|0,x[k+12>>2]=l;break c}e=0;if(i){e=i-1|0;f=(y[Pc(x[a>>2],x[a+4>>2],e)+2|0]<<16>>>0)/(d>>>0)|0;x[h+12>>2]=f;e=z[Pc(x[a>>2],x[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=g>>>0){break c}a=((y[Pc(x[a>>2],x[a+4>>2],i)+2|0]<<16>>>0)/(d>>>0)|0)-f|0;d=a;i=a>>31;a=b-e|0;b=Aua(d,i,a,a>>31);a=g-e|0;k=h,l=Gc(Bua(b,hb,a,a>>31),hb)+f|0,x[k+12>>2]=l}Ge(h+12|0,0,65536);g=(D(x[h+12>>2],c)+32768|0)/65536|0;break a}g=g+1|0;continue}}fb=h+16|0;return g}function Cq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;b=x[a+24620>>2];a:{b:{switch(y[a+480224|0]-1|0){default:x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;e=Aua(b,b>>31,5e4,0);d=hb;b=x[bd(c+8|0,c)>>2];b=Gc(Bua(e,d,b,b>>31),hb);break a;case 1:x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=Aua(x[a+1074420>>2],0,Aua(x[a+1074408>>2],0,x[a+1074416>>2],0),hb),x[g>>2]=h;x[c+4>>2]=hb;b=Aua(b,0,6e5,0);d=c+8|0;e=b;f=hb;b=Rw(x[d>>2],x[d+4>>2],x[c>>2],x[c+4>>2])?c:d;b=Cua(e,f,x[b>>2],x[b+4>>2]);break a;case 0:break b}}x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];e=Aua(b,b>>31,1e4,0);d=hb;b=x[bd(c+8|0,c)>>2];b=Gc(Bua(e,d,b,b>>31),hb)}x[a+1074404>>2]=b;d=x[a+480244>>2];d=Aua(d,d>>31,b,b>>31);b=hb;d=d+32768|0;b=d>>>0<32768?b+1|0:b;e=a;a=Gc(Bua(d,b,65536,0),hb);x[e+1074404>>2]=a>>>0<=1?1:a;fb=c+16|0}function TH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[31609]=0;W(996,a|0);e=x[31609];x[31609]=0;a:{b:{c:{if((e|0)!=1){e=Fb(d+20|0);x[31609]=0;W(c|0,d+8|0);c=x[31609];x[31609]=0;d:{e:{if((c|0)!=1){h=d,i=wb(x[d+8>>2]),x[h+4>>2]=i;f=1;while(1){g=wb(x[d+12>>2]);c=x[d+4>>2];if(!Ib(c,g)){c=Cg(Kb(e));Td(d+8|0);tb(e);break b}if(!f){x[31609]=0;P(985,e|0,14665)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}c=x[d+4>>2]}x[31609]=0;P(838,e|0,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break e}xm(d+4|0);f=0;continue}}c=T(0)|0;break d}c=T(0)|0;Td(d+8|0)}tb(e);break c}c=T(0)|0}Y(c|0)|0;c=0;x[31609]=0;V(983,b|0,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z()}fb=d+32|0;return c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){T(0)|0;Sb();p()}Q(a|0);p()}function G2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;x[c+28>>2]=0;if(Id(y[Gm(c+27|0,a,0)|0])){cd(c+16|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31609]=0;e=R(1223,x[c+16>>2])|0;d=x[31609];x[31609]=0;a:{b:{if((d|0)!=1){d=qp(c+12|0,a);f=tc(c+8|0);g=x[x[a>>2]-12>>2];f=x[f>>2];d=x[d>>2];x[31609]=0;ja(1225,e|0,d|0,f|0,a+g|0,c+28|0,c+20|0);e=x[31609];x[31609]=0;if((e|0)!=1){break b}}b=T(0)|0;_b(c+16|0);Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;Em(x[x[a>>2]-12>>2]+a|0,b);c:{d:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31609]=0;X(84);a=x[31609];x[31609]=0;if((a|0)!=1){break c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break d}Q(a|0);p()}Z();break a}T(0)|0;Sb()}p()}_b(c+16|0);x[b>>2]=x[c+20>>2]}Wj(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}fb=c+32|0;return a|0}function CF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[31609]=0;f=P(21,e+8|0,a|0)|0;d=x[31609];x[31609]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!Id(y[f|0])){break e}g=qp(e+4|0,a);d=x[x[a>>2]-12>>2]+a|0;h=x[d+4>>2];x[31609]=0;i=R(22,d|0)|0;j=x[31609];x[31609]=0;if((j|0)==1){break d}g=x[g>>2];x[31609]=0;c=b+c|0;b=ea(23,g|0,b|0,((h&176)==32?c:b)|0,c|0,d|0,i|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}if(b){break e}b=x[x[a>>2]-12>>2];x[31609]=0;O(24,a+b|0,5);b=x[31609];x[31609]=0;if((b|0)!=1){break e}break d}fm(f);break b}b=T(0)|0;fm(f);break c}b=T(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[31609]=0;W(25,a+b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}Z()}fb=e+16|0;return a}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){T(0)|0;Sb();p()}Q(a|0);p()}function Tca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb+-64|0;fb=f;x[f+60>>2]=d;a=re(a,f+60|0);d=tc(a+4|0);g=tc(a+24|0);h=tc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31609]=0;O(991,a|0,e|0);k=x[31609];x[31609]=0;a:{b:{c:{d:{if((k|0)!=1){cc(f+24|0,b,c);lf(f+32|0,x[f+24>>2],x[f+28>>2]);b=Md(f+16|0);x[31609]=0;c=x[b+4>>2];x[f+8>>2]=x[b>>2];x[f+12>>2]=c;b=f+40|0;Ms(995,b,x[f+32>>2],x[f+36>>2],f+8|0);c=x[31609];x[31609]=0;if((c|0)==1){break d}x[31609]=0;S(992,a|0,b|0,e|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}ub(b);x[31609]=0;W(993,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(f+40|0)}Td(j);nf(i);Al(h);wh(g);vh(d);Wc(a);Wc(f+60|0);Q(e|0);p()}Wc(f+60|0);fb=f- -64|0;return a|0}function uQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;e=x[b+4220>>2];f=x[b+4224>>2];g=x[b+4228>>2];h=x[b+4232>>2];i=x[b+4240>>2];j=x[b+4236>>2];k=y[b+4244|0];Jk(b+4208|0,33);d=x[b+4208>>2];v[d+32|0]=k;v[d+24|0]=j;v[d+25|0]=j>>>8;v[d+26|0]=j>>>16;v[d+27|0]=j>>>24;v[d+28|0]=i;v[d+29|0]=i>>>8;v[d+30|0]=i>>>16;v[d+31|0]=i>>>24;v[d+16|0]=g;v[d+17|0]=g>>>8;v[d+18|0]=g>>>16;v[d+19|0]=g>>>24;v[d+20|0]=h;v[d+21|0]=h>>>8;v[d+22|0]=h>>>16;v[d+23|0]=h>>>24;v[d+8|0]=e;v[d+9|0]=e>>>8;v[d+10|0]=e>>>16;v[d+11|0]=e>>>24;v[d+12|0]=f;v[d+13|0]=f>>>8;v[d+14|0]=f>>>16;v[d+15|0]=f>>>24;v[d|0]=76;v[d+1|0]=70;v[d+2|0]=79;v[d+3|0]=32;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;se(c+8|0,x[b+4208>>2],x[b+4212>>2]);Zb(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function F1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;dd(b,y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24));h=Nb(a);a=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);x[31609]=0;O(179,h|0,a|0);a=x[31609];x[31609]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))>>>0<=a>>>0){break b}e=x[b+8>>2];f=x[b>>2];x[31609]=0;e=U(150,f|0,e|0,4)|0;f=x[31609];x[31609]=0;if((f|0)==1){break a}if(!e){break b}e=y[c+4|0]|y[c+5|0]<<8;x[31609]=0;e=P(180,b|0,e|0)|0;f=x[31609];x[31609]=0;c:{if((f|0)!=1){x[g+12>>2]=e;if(Ud(x[d>>2],x[d+4>>2])>>>0<=e>>>0){break c}x[31609]=0;O(181,h|0,g+12|0);e=x[31609];x[31609]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}fb=g+16|0;return}}a=N()|0;wc(h);Q(a|0);p()}function AP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-48|0;fb=j;k=x[a+4>>2];l=x[a>>2];a=x[a+8>>2];x[j+32>>2]=b;x[j+44>>2]=a;x[j+36>>2]=l;x[j+40>>2]=k;x[31609]=0;a=P(976,(d?d:977)|0,e|0)|0;b=x[31609];x[31609]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+24>>2]=a;a=j+24|0;b=x[re(j+28|0,a)>>2];k=x[j+44>>2];x[j+16>>2]=x[j+40>>2];x[j+20>>2]=k;x[31609]=0;k=x[j+36>>2];x[j+8>>2]=x[j+32>>2];x[j+12>>2]=k;c=+pa(978,j+8|0,+c,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}Wc(a);break b}a=T(0)|0;break c}a=T(0)|0;Wc(j+24|0)}Y(a|0)|0;x[31609]=0;ga(979,15142,d|0,e|0,f|0,g|0,h|0,i|0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();c=0}fb=j+48|0;return+c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Bx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;e=Ab(a);c=vb(h+12|0,x[a+4>>2]);f=vb(h+8|0,x[a>>2]);g=vb(h+4|0,x[b+4>>2]);d=x[c>>2];f=x[f>>2];c=fb+-64|0;fb=c;g=x[g>>2];x[c+56>>2]=g;x[c+60>>2]=d;x[c+52>>2]=g;e=Ag(c+24|0,e,c+52|0,c+56|0);x[c+16>>2]=x[e+8>>2];g=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=g;zg(c+36|0,c+8|0);while(1){if(Fd(d,f)){xs(Pp(x[c+56>>2]),bl(d));d=jk(c+60|0);jk(c+56|0);d=x[d>>2];continue}break}yg(c+36|0);g=x[c+56>>2];if(!y[c+48|0]){e=fb-16|0;fb=e;d=vb(e+12|0,x[x[c+44>>2]>>2]);i=x[vb(e+8|0,x[x[c+40>>2]>>2])>>2];f=fb-16|0;fb=f;d=x[d>>2];x[f+12>>2]=d;while(1){if(wi(d,i)){Eb(Ax(d));d=x[xm(f+12|0)>>2];continue}break}fb=f+16|0;fb=e+16|0}fb=c- -64|0;x[b+4>>2]=g;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function ija(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-32|0;fb=e;c=z[x[x[a+48>>2]+12>>2]+480188>>1];a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((Hk(x[a>>2],x[a+4>>2])|0)!=(c|0)){break b}b=fb-16|0;fb=b;d=wb(x[a>>2]);a=wb(x[a+4>>2]);w[b+12>>1]=0;x[b+8>>2]=0;f=wu(a,d);c=fb-16|0;fb=c;x[c+12>>2]=d;while(1){if((f|0)>0){a=x[c+12>>2];d=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;f=f-1|0;tg(c+12|0);continue}break}fb=c+16|0;fb=b+16|0;break a}w[e+16>>1]=0;x[e+12>>2]=0;c=EZ(e+20|0,c,e+12|0);gR(a);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];f=Ab(c);g=Ab(a),h=x[f>>2],x[g>>2]=h;x[f>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Mk(c);x[a+12>>2]=b}fb=e+32|0}function aba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=ZM(),x[j+12>>2]=k;h=a+24|0;f=d+12|0;WM(h,ne(f));wh(f);w[a+28>>1]=0;JP();g=fb-16|0;fb=g;i=Ec(144);x[31609]=0;c=P(1128,i|0,4)|0;e=x[31609];x[31609]=0;a:{if((e|0)!=1){e=yf(g+12|0,c);fb=g+16|0;e=x[e>>2];break a}a=N()|0;Db(i);Q(a|0);p()}x[d+12>>2]=e;VM(a+32|0,ne(f));Al(f);j=d,k=XM(x[a>>2]),x[j+12>>2]=k;UM(a+4|0,ne(f));vh(f);vo(x[h>>2],x[a+4>>2]);v[a+64|0]=1;x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;c=Ti(x[b>>2]);x[d+12>>2]=c;e=Pf(b);b:{while(1){if(!Zg(c,e)){break b}b=ud(c);c=jg(d,b);x[31609]=0;V(1012,a|0,c|0,b+12|0,0);b=x[31609];x[31609]=0;if((b|0)!=1){tb(c);c=x[ah(d+12|0)>>2];continue}break}a=N()|0;tb(c);Q(a|0);p()}fb=d+16|0}function oqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){w[e+10>>1]=0;eY(a,e+15|0,e+12|0,j,e+10|0);i=z[e+10>>1];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!Bf(a,e+9|0)){break c}f=y[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=f-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;w[e+10>>1]=l;w[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function QL(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);f=B[a>>2];i=B[a+24>>2];c=E(f-i);d=B[a+16>>2];b=B[a+32>>2];g=B[a+8>>2];e=E(d+E(b-g));B[a+16>>2]=c+e;j=E(c-E(e*E(.5)));c=B[a+4>>2];e=B[a+20>>2];h=B[a+28>>2];k=E(E(E(c-e)-h)*E(.8660253882408142));B[a+4>>2]=j+k;l=E(E(d-b)*E(.1736481785774231));f=E(f+E(i*E(.5)));i=E(E(g+b)*E(.7660444378852844));m=E(l+E(f-i));n=E(E(c+e)*E(.9848077297210693));b=E(B[a+12>>2]*E(.8660253882408142));c=E(E(c+h)*E(.6427876353263855));o=E(E(n-b)-c);B[a+12>>2]=m+o;B[a+20>>2]=m-o;B[a+28>>2]=j-k;d=E(E(g+d)*E(.9396926164627075));g=E(E(f+d)-l);e=E(E(e-h)*E(.3420201539993286));h=E(E(e-b)-n);B[a+32>>2]=g+h;d=E(E(f-d)+i);b=E(E(b+e)-c);B[a+24>>2]=d+b;B[a+8>>2]=d-b;B[a>>2]=g-h}function Cs(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[d+28>>2]=0;a:{b:{c:{if(Id(y[Gm(d+27|0,a,0)|0])){g=d+20|0;cd(g,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31609]=0;h=R(1223,x[d+20>>2])|0;e=x[31609];x[31609]=0;d:{e:{if((e|0)==1){break e}e=qp(d+16|0,a);f=tc(d+12|0);i=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[31609]=0;ja(c|0,h|0,e|0,f|0,a+i|0,d+28|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break e}_b(g);break d}b=T(0)|0;_b(d+20|0);Y(b|0)|0;b=x[d+28>>2]|1;x[d+28>>2]=b;Em(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31609]=0;X(84);a=x[31609];x[31609]=0;if((a|0)!=1){break b}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break c}Q(a|0);p()}Z()}Wj(x[x[a>>2]-12>>2]+a|0,x[d+28>>2])}fb=d+32|0;break a}T(0)|0;Sb()}p()}return a}function uq(a){var b=E(0),c=0,d=0,e=0,f=0;f=fb-16|0;fb=f;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){b=E(1);if(c>>>0<964689920){break a}b=yi(+a);break a}if(c>>>0<=1081824209){if(c>>>0>=1075235812){b=E(-yi(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}d=+a;if((e|0)<0){b=zi(d+1.5707963267948966);break a}b=zi(1.5707963267948966-d);break a}if(c>>>0<=1088565717){if(c>>>0>=1085271520){b=yi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=zi(-4.71238898038469-+a);break a}b=zi(+a+-4.71238898038469);break a}b=E(a-a);if(c>>>0>=2139095040){break a}c=Zy(a,f+8|0);d=C[f+8>>3];b:{switch(c&3){case 0:b=yi(d);break a;case 1:b=zi(-d);break a;case 2:b=E(-yi(d));break a;default:break b}}b=zi(d)}a=b;fb=f+16|0;return a}function _V(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=fb-16|0;fb=g;n=x[a+20>>2];h=z[a+34>>1]&65;x[g+12>>2]=h;x[g+8>>2]=h^65;h=b;i=1074992;k=zj(d);while(1){if((i|0)!=1298224){e=d+i|0;if(x[e+104>>2]==(a|0)){if(x[e+16>>2]){x[e+16>>2]=h}if(A[e+4>>2]>c>>>0){x[e>>2]=0;x[e+4>>2]=0}b=a;if(x[e+76>>2]){xc(e+76|0,c);b=x[e+104>>2]}f=x[e+88>>2];b=UF(f,b);j=x[(b?12:4)+a>>2];x[e+84>>2]=x[(b?16:8)+a>>2];x[e+80>>2]=j;b=f|x[g+12>>2];x[e+88>>2]=b;x[e+88>>2]=b&(x[g+8>>2]^-1);f=x[e+704>>2];b=x[a+24>>2];a:{if(!f|!b){break a}if(xn(x[d+480180>>2])){break a}j=Aua(x[e+700>>2],0,k?b:f,0);f=k?f:b;l=j+(f>>>1|0)|0;m=hb;o=e,p=Bc(Cua(l,j>>>0>l>>>0?m+1|0:m,f,0),hb),x[o+700>>2]=p}x[e+704>>2]=b}i=i+872|0;continue}break}x[a>>2]=c;x[a+20>>2]=h;cC(n);fb=g+16|0}function mq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;f=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){o(+a);d=j(1)|0;if(!(j(0)|d&2147483647)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}d=1072693248;g=-1023;if((b|0)!=1072693248){d=b;break b}if(f){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;f=j(0)|0;d=b;g=-1077}b=d+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,f|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function bQ(a){var b=0,c=0,d=0,e=0;e=fb-16|0;fb=e;d=(q(a),j(2));c=d&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=zi(+a);break a}if(c>>>0<=1081824209){b=+a;if(c>>>0<=1075235811){if((d|0)<0){a=E(-yi(b+1.5707963267948966));break a}a=yi(b+-1.5707963267948966);break a}a=zi(-(((d|0)>=0?-3.141592653589793:3.141592653589793)+b));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){b=+a;if((d|0)<0){a=yi(b+4.71238898038469);break a}a=E(-yi(b+-4.71238898038469));break a}a=zi(((d|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}c=Zy(a,e+8|0);b=C[e+8>>3];b:{switch(c&3){case 0:a=zi(b);break a;case 1:a=yi(b);break a;case 2:a=zi(-b);break a;default:break b}}a=E(-yi(b))}fb=e+16|0;return a}function Go(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;if(e){x[e>>2]=0}a:{i=x[a+484344>>2];if(!Je(i,x[a+484348>>2],b)){break a}g=Wb(i,b);k=x[x[g+48>>2]+12>>2];b=md(x[g>>2],k,c,d);f=y[b+5|0];b:{c:{d:{e:{j=y[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}x[h+12>>2]=1;i=0;if((j|0)!=17){break b}i=x[a+480180>>2]==4;break b}x[h+12>>2]=2;i=0}x[h+8>>2]=x[g+12>>2]+(c^-1);d=0;a=x[Hb(h+8|0,h+12|0)>>2];c=a;while(1){f:{if(c){b=D(z[k+480188>>1],6)+b|0;if(y[b+3|0]==34){break f}a=d}f=(j-37&255)>>>0<254?f:a?f:f<<8;if(!e){break a}x[e>>2]=a;break a}g=f<<8;f=y[b+5|0]|(i?f>>>0>31?f>>>0<256?g+-8192|0:g:g:g);d=d+1|0;c=c-1|0;continue}}fb=h+16|0;return f}function t_(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=Fb(a);a=zd(b);x[e+12>>2]=a;f=Df(b);b=0;a:{while(1){b:{if(!Ib(a,f)){if(!b){break b}x[31609]=0;O(35,d|0,65533);a=x[31609];x[31609]=0;if((a|0)!=1){break b}break a}a=y[a|0];c:{d:{if(!b){if(a<<24>>24>=0){b=0;x[31609]=0;O(35,d|0,a|0);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break a}if((a&224)==192){c=a&31;b=1;break c}if((a&240)==224){c=a&15;b=2;break c}c=65533;if((a&248)!=240){break d}c=a&7;b=3;break c}if((a&192)!=128){c=0;x[31609]=0;O(35,d|0,65533);g=x[31609];x[31609]=0;b=0;if((g|0)==1){break a}}c=a&63|c<<6;b=b-1|0;if(b){break c}}b=0;x[31609]=0;O(35,d|0,c|0);a=x[31609];x[31609]=0;c=0;if((a|0)==1){break a}}a=x[we(e+12|0)>>2];continue}break}fb=e+16|0;return}a=N()|0;Ub(d);Q(a|0);p()}function nqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;n=D(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){v[e+11|0]=0;dY(a,e+15|0,e+12|0,e+11|0);i=y[e+11|0];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!Bf(a,e+10|0)){break c}f=y[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(m>>>0<2){break e}f=f-1|0;if(!(g&1<<m)){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;v[e+11|0]=l;v[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function Bl(a,b,c){var d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;d=x[a+24>>2];g=x[d+24620>>2];a:{if(!((g|0)!=(b|0)|x[d+24624>>2]!=(c|0))){if(y[a+29|0]){break a}LR(d,1);break a}f=e+8|0;zc(f,d+24604|0,40);x[e+28>>2]=c;x[e+24>>2]=b;c=x[e+44>>2];cu(f,x[e+40>>2]);Oo(f,c);NA(d,f);if((b|0)==(g|0)){break a}c=x[a+24>>2]+906300|0;d=uk(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];b:{if(!b){break b}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break b}ib[x[x[b>>2]+112>>2]](b,0);ib[x[x[b>>2]+100>>2]](b);ib[x[x[b>>2]+128>>2]](b)}c=c+160|0;continue}break}c=x[a+24>>2]+906300|0;d=uk(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];c:{if(!b){break c}if(ib[x[x[b>>2]+120>>2]](b)|0){break c}ib[x[x[b>>2]+112>>2]](b,1);ib[x[x[b>>2]+124>>2]](b)}c=c+160|0;continue}break}}v[a+29|0]=1;fb=e+48|0}function lk(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;a:{b:{while(1){f=d+8|0;e=c<<2;h=f+e|0;g=1<<c&2147483647;if(g|1){e=rI(c,g?a:22292)}else{e=x[e>>2]}x[h>>2]=e;if((e|0)==-1){break b}c=c+1|0;if((c|0)!=6){continue}break}if(!sI(0)){b=104904;if(!jd(f,104904,24)){break a}b=104928;if(!jd(f,104928,24)){break a}c=0;if(!y[501648]){while(1){i=(c<<2)+501600|0,j=rI(c,22292),x[i>>2]=j;c=c+1|0;if((c|0)!=6){continue}break}v[501648]=1;x[125406]=x[125400]}b=501600;a=d+8|0;if(!jd(a,501600,24)){break a}b=501624;if(!jd(a,501624,24)){break a}b=Gd(24);if(!b){break b}}a=x[d+12>>2];x[b>>2]=x[d+8>>2];x[b+4>>2]=a;a=x[d+28>>2];x[b+16>>2]=x[d+24>>2];x[b+20>>2]=a;a=x[d+20>>2];x[b+8>>2]=x[d+16>>2];x[b+12>>2]=a;break a}b=0}fb=d+32|0;return b}function $R(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:Bq(a,E(1));tk(a,E(3.725290298461914e-9));Aq(a,E(268435456));zq(a,0);break b;case 1:Bq(a,E(32));tk(a,E(4.656612873077393e-10));Aq(a,E(2147483648));zq(a,0);break b;case 2:Bq(a,E(2));tk(a,E(7.450580596923828e-9));Aq(a,E(134217728));zq(a,1);break b;default:Bq(a,E(1));tk(a,E(7.450580596923828e-9));Aq(a,E(134217728));zq(a,1);GA(a,0);FA(a,1);EA(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}Bq(a,E(.75));tk(a,E(7.450580596923828e-9));Aq(a,E(134217728));zq(a,1);GA(a,0);b=(b|0)==4;FA(a,b?2:3);EA(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}GA(a,1);FA(a,0);EA(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function qL(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:ib[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function YX(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=x[b>>2];while(1){if((i|0)==128){vg(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(Lh(x[a>>2])&-2)){break c}dd(a,c+(f<<10)|0);if(!VC(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((Lh(x[a>>2])|0)!=(d+D(f,i)|0)){break a}}dd(a,c+D(f,z[e>>1])|0);h=VC(a,64,1)?h:k}dd(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(Lh(x[a>>2])|0)){break d}}if(c>>>0>=255){UC(b,254,65534);UC(b,255,65535)}l=h}a=l&65535}else{j=z[ac(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function eB(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=z[a+480188>>1];h=d>>>0<=256?256:d;g=a+1074992|0;f=x[a+1298300>>2];a=d;a:{while(1){if((a|0)!=(h|0)){e=D(a,872)+g|0;if(!x[e+76>>2]){if(!Bj(x[e+656>>2])|y[e+89|0]&24){break a}}if(y[e+89|0]&2){if(!Ed(f)){break a}if(!GS(f,a&65535)){break a}}a=a+1|0;continue}break}e=8388608;if(b>>>0<=255){b=D(b,872)+g|0;if(!x[b+696>>2]){a=65535;if(x[b+76>>2]){break a}}e=x[b+688>>2]|x[b+680>>2]<<9}b=0;a=65535;while(1){if((d|0)==(h|0)){break a}c=D(d,872)+g|0;if(!(x[c+696>>2]?0:x[c+76>>2])){f=(x[c+688>>2]|x[c+680>>2]<<9)>>>(x[c+88>>2]>>>1&1)|0;b:{c:{if(f>>>0<e>>>0){c=x[c+724>>2];break c}if((e|0)!=(f|0)){break b}c=x[c+724>>2];if(c>>>0<=b>>>0){break b}}e=f;a=d;b=c}d=d+1|0;continue}break}a=d}return a&65535}function yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;h=a+8|0;c=x[a+8>>2];j=nc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Kv(d,c,a+d|0);x[h>>2]=c;x[i>>2]=a+x[i>>2];break a}x[g+8>>2]=c-e>>1;x[g+28>>2]=1;d=g+8|0;c=x[bd(d,g+28|0)>>2];c=Zf(d,c,c>>>2|0,x[a+16>>2]);d=vb(g+4|0,x[a+4>>2]);f=x[vb(g,x[a+8>>2])>>2];e=x[d>>2];f=Lv(f,e);d=fb-16|0;fb=d;x[d+12>>2]=e;e=Fn(d,c+8|0,f);f=x[e>>2];while(1){if(x[e+4>>2]!=(f|0)){k=f;f=x[d+12>>2];cp(k,z[f>>1]|z[f+2>>1]<<16);f=x[e>>2]+4|0;x[e>>2]=f;Xe(d+12|0);continue}break}je(e);fb=d+16|0;Tb(a,c);Tb(i,c+4|0);Tb(h,c+8|0);Tb(j,nc(c));Yf(c);c=x[a+8>>2]}cp(c,z[b>>1]|z[b+2>>1]<<16);x[h>>2]=x[h>>2]+4;fb=g+32|0}function ala(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);c=x[b+4>>2];f=c;d=x[b>>2];b=ih(d,c);c=fb-16|0;fb=c;Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{b:{if(b){x[31609]=0;O(799,a|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break b}g=fb-16|0;fb=g;h=hs(g+4|0,a,b);i=x[h+4>>2];e=fb-16|0;fb=e;fd(e+8|0,d,f);f=fb-16|0;fb=f;n=f+8|0;b=fb-32|0;fb=b;fd(b+24|0,x[e+8>>2],x[e+12>>2]);d=fb-16|0;fb=d;j=x[b+28>>2];k=x[b+24>>2];l=j-k|0;m=l>>3;if(m){hl(i,k,m<<3)}x[d+12>>2]=i+l;qc(b+16|0,j,d+12|0);fb=d+16|0;d=x[b+16>>2];x[b+12>>2]=x[b+20>>2];qc(n,d,b+12|0);fb=b+32|0;fb=f+16|0;fb=e+16|0;x[h+4>>2]=x[f+12>>2];jc(h);fb=g+16|0}b=c+8|0;Qd(b);_u(b);fb=c+16|0;break a}a=N()|0;_u(c+8|0);Q(a|0);p()}return a|0}function ZS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;i=-1;a:{if(!HA(a,b,2)){break a}f=x[b+656>>2];d=a+1074312|0;g=Ob(d,31);h=x[b+740>>2];if(h?0:g){break a}h=h-Ob(d,31)|0;g=x[a+480180>>2];d=(g|0)==4096;j=f+88|0;f=d?64:(g|0)==16384?192:512;d=Rq(j,h,f,d?255:64)-(f>>>1|0)|0;if(y[b+746|0]&16){i=Kq(a,b,!(x[b+88>>2]&32768),d);break a}if(Kj(x[b+656>>2])){if((d|0)==w[b+772>>1]){break a}k=b,l=gd(d),w[k+772>>1]=l;v[b+851|0]=y[b+851|0]|64;break a}a=zj(a);x[e+12>>2]=d;b:{if((d|0)<0){x[e+12>>2]=0-d;ui(e+12|0,255);a=(x[e+12>>2]<<2)+(a?36528:35504)|0;break b}ui(e+12|0,255);a=(x[e+12>>2]<<2)+(a?35504:36528)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];k=c,l=Gc(Bua(Aua(b,d,a,a>>31),hb,65536,0),hb),x[k>>2]=l}fb=e+16|0;return i}function Mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;g=Kb(b);e=Cb(x[b+4>>2],y[b+11|0]);i=Kb(c);f=Cb(x[c+4>>2],y[c+11|0]);d=e+g|0;e=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(sq(i,f,y[d|0])){continue}break}e=d-g|0}b:{c:{if((e|0)!=-1){f=vb(h+12|0,vf(vf(zd(b),e),1));c=vb(h+8|0,Df(b));_r(b,x[f>>2],x[c>>2]);break c}if(!_c(x[b+4>>2],y[b+11|0])){break c}i=Kb(b);e=Cb(x[b+4>>2],y[b+11|0]);f=Kb(c);d=Cb(x[c+4>>2],y[c+11|0]);if(!e|!d){c=-1}else{c=i;e=e+c|0;j=d+f|0;while(1){d:{d=f;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(j|0)){break e}g=v[d|0];d=d+1|0;if(!mc(v[c|0],g)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-i|0}if(c){break c}Fb(a);break b}Uc(a,b)}fb=h+16|0}function j2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;g=Kb(b);e=Cb(x[b+4>>2],y[b+11|0]);i=Kb(c);f=Cb(x[c+4>>2],y[c+11|0]);d=e+g|0;e=-1;a:{while(1){if((d|0)==(g|0)){break a}d=d-1|0;if(Eu(i,f,y[d|0])){continue}break}e=d-g|0}b:{c:{if((e|0)!=-1){f=vb(h+12|0,vf(vf(zd(b),e),1));c=vb(h+8|0,Df(b));_r(b,x[f>>2],x[c>>2]);break c}if(!_c(x[b+4>>2],y[b+11|0])){break c}i=Kb(b);e=Cb(x[b+4>>2],y[b+11|0]);f=Kb(c);d=Cb(x[c+4>>2],y[c+11|0]);if(!e|!d){c=-1}else{c=i;e=e+c|0;j=d+f|0;while(1){d:{d=f;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(j|0)){break e}g=y[d|0];d=d+1|0;if(!mc(y[c|0],g)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-i|0}if(c){break c}Fb(a);break b}Uc(a,b)}fb=h+16|0}function W2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=fb-176|0;fb=d;b=d+12|0;Tk(b,a);x[31609]=0;c=d+24|0;O(102,c|0,b|0);a=x[31609];x[31609]=0;a:{b:{c:{d:{if((a|0)!=1){x[31609]=0;a=P(103,d+36|0,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}tb(c);tb(b);b=x[x[a>>2]-12>>2];x[31609]=0;f=ca(104)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}x[31609]=0;e=d+8|0;S(105,e|0,a+b|0,f|0);b=x[31609];x[31609]=0;if((b|0)==1){break b}_b(e);b=a+x[x[a>>2]-12>>2]|0;x[b+4>>2]=x[b+4>>2]&-75;x[b+4>>2]=x[b+4>>2]|8;x[31609]=0;c=P(106,a|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break b}a=nk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2]);b=x[d+24>>2];Gf(c);fb=d+176|0;return(a?0:b)|0}c=N()|0;break c}c=N()|0;tb(d+24|0)}tb(d+12|0);break a}c=N()|0;Gf(a)}Q(c|0);p()}function tI(a,b,c,d,e,f){var g=0;g=fb-80|0;fb=g;a:{if((f|0)>=16384){Xd(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Xd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}Xd(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Xd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}Xd(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;fb=g+80|0}function Uka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;e=x[vb(i+12|0,wb(x[a+4>>2]))>>2];f=LT(b,c);h=fb-32|0;fb=h;d=e;e=x[a>>2];e=(lp(d,wb(e))<<1)+e|0;a:{if((f|0)<=0){break a}d=x[Ab(a)>>2];g=x[a+4>>2];if((f|0)<=d-g>>1){d=fb-16|0;fb=d;x[d+12>>2]=b;KT(d+12|0,f);j=x[d+12>>2];fb=d+16|0;d=g-e>>1;if((d|0)<(f|0)){x[h+12>>2]=b;KT(h+12|0,d);j=x[h+12>>2];dv(a,j,c,f-d|0);if((d|0)<=0){break a}}QU(a,e,g,(f<<1)+e|0);aC(b,j,e);break a}c=Ab(a);d=ek(h+12|0,fk(a,$c(x[a>>2],g)+f|0),e-x[a>>2]>>1,c);g=fb-16|0;fb=g;c=Bp(g+4|0,d+8|0,f);f=x[c>>2];while(1){if(x[c+4>>2]!=(f|0)){mm(f,z[b>>1]);f=x[c>>2]+2|0;x[c>>2]=f;b=b+2|0;continue}break}je(c);fb=g+16|0;e=PU(a,d,e);aj(d)}wb(e);fb=h+32|0;fb=i+16|0;return a|0}function SB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;i=Ql(a,b);a:{if((i|0)==255){break a}if(Fj(x[a>>2])){break a}b:{if(c>>>0>6208431){j=7168;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}j=f<<10;f=20-f|0;g=f&31;if((f&63)>>>0>=32){f=c<<g;c=0}else{f=(1<<g)-1&c>>>32-g;c=c<<g}g=c+24858e3|0;c=f;c=Bc(Cua(g,g>>>0<24858e3?c+1|0:c,49716e3,0),hb)}if(e){w[h+14>>1]=(b&3)+c;w[h+12>>1]=1023;c=z[Oc(h+14|0,h+12|0)>>1]}e=bv(i);f=xb(a+8|0,i);v[f|0]=(c|j)>>>8|(d?0:32);Ah(x[a>>2],x[a+4>>2],b,e|160,c&255);Ah(x[a>>2],x[a+4>>2],b,e|176,y[f|0]);v[a+534|0]=1}fb=h+16|0}function $C(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;e=y[a|0];if(e&1){v[b+12|0]=y[b+12|0]|1;e=y[a|0]}if(e&2){v[b+12|0]=y[b+12|0]|4;e=y[a|0]}if(e&4){v[b+12|0]=y[b+12|0]|2;e=y[a|0]}if(e&16){v[b+12|0]=y[b+12|0]|16;e=y[a|0]}if(e&32){v[b+12|0]=y[b+12|0]|8}v[f+15|0]=y[a+1|0];v[f+14|0]=25;fh(b,y[Qb(f+15|0,f+14|0)|0]);e=y[a+2|0];v[b+15|0]=e;v[b+16|0]=(d|0)==4?e:y[a+3|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];e=a+6|0;h=x[b>>2];d=Sd(h,x[b+4>>2]);b=0;while(1){if((b|0)!=(d|0)){i=yb(h,b);g=e+(b<<2)|0;a=y[g|0]|y[g+1|0]<<8;w[i>>1]=a;a:{if(!b){break a}j=a;a=z[yb(h,b-1|0)>>1];if(j>>>0>=a>>>0){break a}w[i>>1]=a+1}k=i,l=Yb((y[g+2|0]|y[g+3|0]<<8)<<16>>16>>c,0,64),v[k+2|0]=l;b=b+1|0;continue}break}fb=f+16|0}function pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;c=If(a,c);ae(f,x[a+36>>2]);i=a;a:{if(!c){Qc(f,a+32|0,5);d=0;if(Gb(x[x[f>>2]>>2],x[f+4>>2])){break a}}g=x[a+36>>2];a=fb-16|0;fb=a;x[a+12>>2]=0;AN(g,a+12|0,1);e=x[a+12>>2];d=e>>>2&3;v[a+11|0]=d;if(d){v[a+4|0]=3;h=a+4|0;d=y[Qb(h,a+11|0)|0];v[a+4|0]=0;v[a|0]=0;v[a+10|0]=0;b:{if(!d){break b}Ei(g,h);if((d|0)==1){break b}Ei(g,a);if(d>>>0<3){break b}Ei(g,a+10|0);j=y[a+10|0]<<24}e=e&255|(y[a+4|0]<<8|y[a|0]<<16|j)}d=e>>>4|0;x[a+4>>2]=d;x[a>>2]=1e6;hC(b,x[Hb(a+4|0,a)>>2]);e=0;while(1){h=Cb(x[b+4>>2],y[b+11|0]);if(h>>>0<=e>>>0){if((d|0)!=(h|0)){Om(g,d-h|0)}fb=a+16|0}else{vj(g,ec(b,e),1);e=e+1|0;continue}break}d=c}ef(i,d);fb=f+16|0}function Zy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=uL(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}fb=e+16|0;return c}function Sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>18|0;p=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){i=(e<<1)+p|0;j=w[i>>1];x[(e<<2)+b>>2]=j+((D(w[i+4>>1]-j|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=e>>>21&2040;n=w[e+38086>>1];o=w[e+38084>>1];p=w[e+38082>>1];q=w[e+38080>>1];f=0;while(1){if((f|0)!=2){e=f<<1;g=e+h|0;x[(f<<2)+b>>2]=(((D(w[g>>1],p)+D(w[(e|-4)+h>>1],q)|0)+D(w[g+4>>1],o)|0)+D(w[g+8>>1],n)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb+-64|0;fb=d;a=x[a+4>>2];g=d+16|0;vx(g,b);x[31609]=0;b=P(1,d+4|0,18407)|0;e=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[31609]=0;e=d+28|0;S(2,e|0,g|0,b|0);f=x[31609];x[31609]=0;if((f|0)==1){break h}x[31609]=0;f=d+40|0;S(489,f|0,e|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break g}x[31609]=0;c=d+52|0;O(1059,c|0,f|0);h=x[31609];x[31609]=0;if((h|0)==1){break f}h=x[x[a>>2]+8>>2];x[31609]=0;O(h|0,a|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}tb(c);tb(f);tb(e);tb(b);tb(g);fb=d- -64|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;tb(d+52|0)}tb(d+40|0)}tb(d+28|0)}tb(b)}tb(d+16|0);Q(a|0);p()}function NX(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],1024)){x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;a=64;while(1){if(a){d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}SC(c+8|0,b);sd(c+16|0,a,x[c+8>>2],x[c+12>>2])}fb=c+32|0}function JH(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=fb-80|0;fb=g;MA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[g+44>>2]=b;x[g+40>>2]=c;x[g+36>>2]=d;i=B[a+48>>2];j=x[a+32>>2];x[g+8>>2]=b;c=x[g+40>>2];x[g>>2]=x[g+36>>2];x[g+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[g+8>>2];c=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=c;c=FM(g+48|0);x[c+8>>2]=j;x[c+4>>2]=0;x[c>>2]=f;f=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=f;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=i;x[c>>2]=e;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;d=GM(d,x[Wr(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|h)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=g+80|0;return h}function Kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=fb-80|0;fb=g;e=Rf(g+52|0);x[31609]=0;d=P(831,b|0,e|0)|0;c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)!=1){if(d){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31609]=0;R(832,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];f=x[e>>2];x[31609]=0;d=g+12|0;c=$b(c);d:{if(!c){h=-1;if(($b(f)|0)==1112491097){break d}}h=c}c=h;S(185,d|0,b|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break a}f=hc(g+32|0,d);kd(e+8|0,f);ub(f);ub(d);e:{d=c&1;if(!d){break e}x[31609]=0;P(183,b|0,2-d|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break e}break a}Ok(a,e)}Hd(e);fb=g+80|0;return}a=N()|0;Hd(e);Q(a|0);p()}function Ooa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-32|0;fb=f;nd(c,2);v[f+20|0]=y[b+13|0];v[f+8|0]=64;d=f+20|0;e=f+8|0;i=c,j=y[Qb(d,e)|0]<<2,w[i+30>>1]=j;x[c+24>>2]=(y[b+14|0]|y[b+15|0]<<8)<<1;Lk(e,2,b+1|0);Cc(d,e);Be(c+43|0,d);tb(d);d=Zc(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}g=y[b+22|0]|y[b+23|0]<<8|(y[b+24|0]<<16|y[b+25|0]<<24);x[c>>2]=g;e=y[b+26|0]|y[b+27|0]<<8|(y[b+28|0]<<16|y[b+29|0]<<24);x[c+4>>2]=e;a=y[b+30|0]|y[b+31|0]<<8|(y[b+32|0]<<16|y[b+33|0]<<24);h=a-(a>>>0>e>>>0)|0;x[c+8>>2]=h;a=y[b|0];if(a&4){w[c+34>>1]=z[c+34>>1]|2;a=y[b|0]}if(a&8){w[c+34>>1]=z[c+34>>1]|4;a=y[b|0]}if(!(a&16)){break a}hd(d,16);wg(d,9);x[c+8>>2]=h>>>1;x[c+4>>2]=e>>>1;x[c>>2]=g>>>1}fb=f+32|0}function NH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;x[f+44>>2]=c;a=re(a,f+44|0);c=tc(a+4|0);h=tc(a+24|0);i=tc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31609]=0;O(991,a|0,d|0);g=x[31609];x[31609]=0;a:{b:{c:{d:{if((g|0)!=1){se(f+16|0,x[b>>2],x[b+4>>2]);b=Md(f+8|0);x[31609]=0;g=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=g;b=f+24|0;Ms(e,b,x[f+16>>2],x[f+20>>2],f);e=x[31609];x[31609]=0;if((e|0)==1){break d}x[31609]=0;S(992,a|0,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}ub(b);x[31609]=0;W(993,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(f+24|0)}Td(k);nf(j);Al(i);wh(h);vh(c);Wc(a);Wc(f+44|0);Q(d|0);p()}Wc(f+44|0);fb=f+48|0;return a}function Dx(a,b,c){var d=0,e=0,f=0,g=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31609]=0;O(114,d|0,_c(e,a)|0);a=x[31609];x[31609]=0;if((a|0)!=1){a:{while(1){if(_c(x[b+4>>2],y[b+11|0])>>>0>f>>>0){a=32;e=x[Wd(b,f)>>2];g=(e&-32)==128;b:{while(1){c:{if((a|0)==256){a=0;break c}if((e|0)!=x[(a<<2)+c>>2]|g){a=a+1|0;continue}else{x[31609]=0;O(115,d|0,a<<24>>24);a=x[31609];x[31609]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31609]=0;O(115,d|0,a<<24>>24);a=x[31609];x[31609]=0;if((a|0)!=1){break b}break a}x[31609]=0;O(115,d|0,63);a=x[31609];x[31609]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function Tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>10&4194048;p=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){i=e+p|0;j=v[i|0];x[(e<<2)+b>>2]=((D(v[i+2|0]-j|0,o)|0)/16384|0)+(j<<8);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Tm(a,b){var c=0,d=0,e=0,f=0;c=fb+-64|0;fb=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;ig(d,e);a:{b:{if(Id(y[Gm(c+63|0,a,1)|0])){d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31609]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;S(937,c+40|0,d|0,c+8|0);b=x[31609];x[31609]=0;c:{if((b|0)!=1){b=ai(c+24|0,-1,-1);b=bo(x[c+48>>2],x[c+52>>2],x[b+8>>2],x[b+12>>2])?e|4:e;break c}Y(T(0)|0)|0;b=e|1;Em(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31609]=0;X(84);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}Wj(x[x[a>>2]-12>>2]+a|0,b)}fb=c- -64|0;return}T(0)|0;Sb()}p()}function vB(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{f=a+1074312|0;if(h=Ob(f,77),i=0,j=x[(D(c,872)+b|0)+704>>2]&67109888,j?h:i){break a}g=b+616|0;c=g+D(x[a+480180>>2]!=2?c:0,872)|0;if(!d){x[c+764>>2]=x[b+48>>2];return}e=y[c+841|0];b:{if(e){d=e-1|0;v[c+841|0]=d;if(d&255){break b}if(!Ob(f,16)&x[a+480180>>2]!=2){break a}x[c+764>>2]=x[b+48>>2]+1;return}c:{if(Ob(f,17)|y[a+480180|0]&3){break c}e=0;a=z[a+480188>>1];while(1){if(a>>>0<=(e&65535)>>>0){break c}if(y[g+841|0]?(c|0)!=(g|0):0){break a}g=g+872|0;e=e+1|0;continue}}v[c+841|0]=d}a=x[c+764>>2];x[b+56>>2]=a;if((a|0)==-1){break a}d:{if(x[b+60>>2]==-1){break d}if(!Ob(f,68)){break d}x[b+60>>2]=a}x[b+64>>2]=a;if(!Ob(f,103)){break a}w[b+68>>1]=65535}}function _Z(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=fb-176|0;fb=c;d=c+12|0;Uf(d,a);x[31609]=0;b=c+24|0;O(124,b|0,d|0);a=x[31609];x[31609]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31609]=0;a=P(103,c+36|0,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}tb(b);tb(d);d=x[x[a>>2]-12>>2];x[31609]=0;f=ca(104)|0;e=x[31609];x[31609]=0;if((e|0)==1){break c}x[31609]=0;e=c+8|0;S(105,e|0,a+d|0,f|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}_b(e);x[31609]=0;x[c+24>>2]=0;x[c+28>>2]=0;b=P(409,a|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}a=nk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);g=C[c+24>>3];Gf(b);fb=c+176|0;g=a?0:g;break a}b=N()|0;break d}b=N()|0;tb(c+24|0)}tb(c+12|0);break b}b=N()|0;Gf(a)}Q(b|0);p()}return+g}function Spa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=fb-528|0;fb=b;e=-1;a:{if(!jh(a,1468)){break a}Wl(a,1464);c=b+524|0;aY(a,c);if(!oe(c,25284)){e=0;if(!oe(c,15612)){break a}}Wl(a,20);c=1;b:{while(1){if((c&65535)>>>0>31){break b}e=ZX(a,b);if(!e){IX(b)}if(e){c=c+1|0;d=_C(b)+d|0;continue}break}e=-1;break a}e=0;if(d>>>0>40){break a}d=b+522|0;c=fb-16|0;fb=c;c:{if(!jh(a,2)){v[c|0]=0;sF(d,c);break c}Cp(c+8|0,d);YC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;if(y[b+522|0]>128){break a}d=Jc(d);c=fb-16|0;fb=c;d:{if(!jh(a,512)){HX(b);break d}zE(c+8|0,b);YC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;c=0;e=1;a=y[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=y[d|0]){continue}break}e=0}fb=b+528|0;return e|0}function Ph(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0;f=NP(a);h=a+4208|0;c=E(E(B[yb(h,4)>>2]*E(1.899999976158142))+E(.10000000149011612));g=B[a+4268>>2];d=Ee(E(10),E(E(E(E(E(x[((b<<2)+a|0)+4292>>2])/g)*E(-60))/E(E(B[yb(h,3)>>2]*E(19.899999618530273))+E(.10000000149011612)))/E(20)));c=E(E(Ee(d,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-uq(c>E(1)?E(3.1415927410125732):E(f*E(E(6.2831854820251465)/g)))));a:{if(c==E(0)){break a}if(!Um(c)){break a}g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(c>E(0)){e=E(M(c))}c=E(E(e-f)/g);if(E(F(c))>E(1)){c=E(E(E(-f)-e)/g)}e=ag(c)}b=(b<<3)+a|0;B[b+4404>>2]=e;B[b+4400>>2]=d;c=B[a+4272>>2];c=E(c*c);e=E(E(1)-c);d=E(d*d);return E(E(E(e*E(d/E(E(1)-E(c*d))))*e)+c)}function Oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-48|0;fb=e;x[e+44>>2]=c;a=re(a,e+44|0);f=tc(a+4|0);g=tc(a+24|0);h=tc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31609]=0;O(991,a|0,d|0);c=x[31609];x[31609]=0;a:{b:{c:{d:{if((c|0)!=1){c=Md(e+16|0);x[31609]=0;k=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=k;c=e+24|0;S(1115,c|0,b|0,e+8|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}x[31609]=0;S(992,a|0,c|0,d|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}ub(c);x[31609]=0;W(993,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+24|0)}Td(j);nf(i);Al(h);wh(g);vh(f);Wc(a);Wc(e+44|0);Q(d|0);p()}Wc(e+44|0);fb=e+48|0;return a|0}function rI(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=by(13961);if(y[b|0]?b:0){break a}b=by(D(a,12)+104960|0);if(y[b|0]?b:0){break a}b=by(14217);if(y[b|0]?b:0){break a}b=14787}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14787;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!hi(e,14787)){break e}if(hi(e,13654)){break d}}if(!a){c=105032;if(y[e+1|0]==46){break c}}return 0}c=x[125413];if(c){while(1){if(!hi(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=Gd(36);if(c){x[c+4>>2]=20;x[c>>2]=95136;b=c+8|0;zc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[125413];x[125413]=c}c=a|c?c:105032}return c}function Sfa(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;c=Fb(b+20|0);x[31609]=0;W(984,b+8|0);a=x[31609];x[31609]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=wb(x[b+8>>2]),x[f+4>>2]=g;d=1;while(1){e=wb(x[b+12>>2]);a=x[b+4>>2];if(!Ib(a,e)){a=Cg(Kb(c));Td(b+8|0);tb(c);break b}if(!d){x[31609]=0;P(985,c|0,14665)|0;a=x[31609];x[31609]=0;if((a|0)==1){break d}a=x[b+4>>2]}x[31609]=0;P(838,c|0,a|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break d}xm(b+4|0);d=0;continue}}a=T(0)|0;break c}a=T(0)|0;Td(b+8|0)}tb(c);Y(a|0)|0;a=0;x[31609]=0;V(983,7040,0,0,0);c=x[31609];x[31609]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}b=N()|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){T(0)|0;Sb();p()}Q(b|0);p()}function hna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=kg(1,2);e=hb;l=e;Pb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=((((x[b+12>>2]&2147483647)<<1|i>>>31)&2147483646)<<1)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=w[(h<<1)+i>>1];h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Ig(a,j,l);fb=b+16|0}function b9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=x[b+44>>2];i=x[b+24>>2];if(h>>>0<i>>>0){x[b+44>>2]=i;h=i}m=-1;n=-1;o=f&24;a:{if(!o|(e|0)==1&(o|0)==24){break a}if(h){j=h-Kb(b+32|0)|0;k=j>>31}b:{c:{switch(e|0){case 1:if(f&8){g=x[b+12>>2]-x[b+8>>2]|0;l=g>>31;break b}g=i-x[b+20>>2]|0;l=g>>31;break b;case 0:break b;case 2:break c;default:break a}}g=j;l=k}d=d+l|0;c=c+g|0;d=g>>>0>c>>>0?d+1|0:d;if((d|0)<0|(c>>>0>j>>>0&(d|0)>=(k|0)|(d|0)>(k|0))){break a}e=f&8;d:{if(!(c|d)){break d}if(x[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!i){break a}}if(e){e=x[b+8>>2];Vn(b,e,c+e|0,h)}if(f&16){Ex(b,x[b+20>>2],x[b+28>>2]);As(b,c)}m=c;n=d}ai(a,m,n)}function YH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;x[g+44>>2]=d;a=re(a,g+44|0);d=tc(a+4|0);h=tc(a+24|0);i=tc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31609]=0;O(991,a|0,e|0);l=x[31609];x[31609]=0;a:{b:{c:{d:{if((l|0)!=1){cc(g+16|0,b,c);b=Md(g+8|0);x[31609]=0;c=x[b+4>>2];x[g>>2]=x[b>>2];x[g+4>>2]=c;b=g+24|0;Ms(f,b,x[g+16>>2],x[g+20>>2],g);c=x[31609];x[31609]=0;if((c|0)==1){break d}x[31609]=0;S(992,a|0,b|0,e|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}ub(b);x[31609]=0;W(993,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(g+24|0)}Td(k);nf(j);Al(i);wh(h);vh(d);Wc(a);Wc(g+44|0);Q(e|0);p()}Wc(g+44|0);fb=g+48|0;return a}function ioa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{if(b){x[31609]=0;O(739,a|0,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;d=f+4|0;x[d>>2]=a;c=x[a+4>>2];x[d+4>>2]=c;x[d+8>>2]=c+D(b,36);b=x[d+4>>2];g=x[d+8>>2];while(1){if((b|0)==(g|0)){jc(d);fb=f+16|0}else{c=Rb(b,0,36);x[c>>2]=0;x[c+4>>2]=0;w[c+22>>1]=0;w[c+24>>1]=0;w[c+26>>1]=0;w[c+28>>1]=0;v[c+21|0]=64;v[c+19|0]=64;v[c+20|0]=100;v[c+15|0]=0;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;x[c+8>>2]=0;x[c+12>>2]=0;w[c+30>>1]=0;w[c+32>>1]=0;b=b+36|0;x[d+4>>2]=b;continue}break}}b=e+8|0;Qd(b);YV(b);fb=e+16|0;return a|0}a=N()|0;YV(e+8|0);Q(a|0);p()}function J0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;nd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Nr(a+4|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=f;c=Nr(a+8|0,a);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=c;v[e+15|0]=127;v[e+14|0]=y[a+15|0];g=b,h=(((y[Qb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;d=y[a+12|0];if(d>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=d&240}d=(y[a+13|0]|y[a+14|0]<<8)<<1;x[b+24>>2]=d;d=y[a+13|0]|y[a+14|0]<<8?d:16726;x[b+24>>2]=d;g=b,h=(D(xw(0,y[a+12|0]<<28>>24),d)>>>0)/8363|0,x[g+24>>2]=h;if(c>>>0>f>>>0){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}fb=e+16|0}function Jo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){v[b+809|0]=c;break a}c=y[b+809|0]}e=x[a+480180>>2];d=e&202376205?c&240?c&-16:c:c;c=x[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){Io(a,b,(d&240)>>>4|0,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){Ho(a,b,f,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+851|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}c=c-(a<<2)|0;break d}c=((d&255)>>>2|0)+c|0}if((e|0)!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}h=b,i=Yb(c,0,256),x[h+688>>2]=i}function zs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Mc(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Fh(x[bd(d+12|0,d+8|0)>>2]);if((Mc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Cb(x[a+4>>2],y[a+11|0]);b:{c:{h=Nk(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Mc(a)>>>0<b>>>0){qg(e+8|0,c);break e}x[31609]=0;O(116,e+8|0,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=vd(c);g=Kb(a);c=Cb(x[a+4>>2],c)}b=Dg(b,g,c+1|0);if(i){Db(g)}if(!h){of(a,j);Bd(a,f);yd(a,b);break b}Ne(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}pf();p()}function H2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=fb-176|0;fb=d;c=d+12|0;Uf(c,a);x[31609]=0;b=d+24|0;O(124,b|0,c|0);a=x[31609];x[31609]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31609]=0;a=P(103,d+36|0,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break e}tb(b);tb(c);c=x[x[a>>2]-12>>2];x[31609]=0;f=ca(104)|0;e=x[31609];x[31609]=0;if((e|0)==1){break c}x[31609]=0;e=d+8|0;S(105,e|0,a+c|0,f|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}_b(e);x[31609]=0;x[d+24>>2]=0;b=P(125,a|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}a=nk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);c=x[d+24>>2];Gf(b);fb=d+176|0;a=a?0:c;break a}b=N()|0;break d}b=N()|0;tb(d+24|0)}tb(d+12|0);break b}b=N()|0;Gf(a)}Q(b|0);p()}return a|0}function hU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Mc(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Fh(x[bd(d+12|0,d+8|0)>>2]);if((Mc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Cb(x[a+4>>2],y[a+11|0]);b:{c:{h=Nk(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Mc(a)>>>0<b>>>0){qg(e+8|0,c);break e}x[31609]=0;O(52,e+8|0,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=vd(c);g=Kb(a);c=Cb(x[a+4>>2],c)}b=Xg(b,g,c+1|0);if(i){Db(g)}if(!h){of(a,j);Bd(a,f);yd(a,b);break b}Ne(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}pf();p()}function Ji(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=42712;c=a+24|0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;b=Nb(a+44|0);d=Nb(b+12|0);e=Nb(b+24|0);f=Nb(b+36|0);x[31609]=0;O(941,b|0,0);g=x[31609];x[31609]=0;if((g|0)==1){a=N()|0;wc(f);wc(e);ou(d);ou(b);Q(a|0);p()}w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;d=x[a+16>>2];x[d+946300>>2]=x[d+946300>>2]+1;x[31609]=0;d=R(942,a+92|0)|0;e=x[31609];x[31609]=0;a:{if((e|0)!=1){b=a+4200|0;x[c>>2]=d;c=x[a+16>>2]+906300|0;d=y[a+4200|0];e=x[a+20>>2];while(1){if(($d(c,d)|0)==(e|0)|d>>>0>248){break a}d=d+1|0;v[b|0]=d;continue}}a=N()|0;qQ(b);Q(a|0);p()}return a}function df(a,b,c){var d=0,e=0,f=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31609]=0;O(114,d|0,_c(e,a)|0);a=x[31609];x[31609]=0;if((a|0)!=1){a:{while(1){if(_c(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Wd(b,f)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((e|0)==x[(a<<2)+c>>2]){x[31609]=0;O(115,d|0,a<<24>>24);a=x[31609];x[31609]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31609]=0;O(115,d|0,a<<24>>24);a=x[31609];x[31609]=0;if((a|0)!=1){break b}break a}x[31609]=0;O(115,d|0,63);a=x[31609];x[31609]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function xna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;nd(b,4);w[b+30>>1]=y[a+12|0]<<2;Hf(b+30|0,256);e=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=e;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=f;c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+4>>2]=c;d=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+c|0;x[b+8>>2]=d;e=y[a+14|0];if(e&16){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;f=f>>>1|0;x[b>>2]=f;e=y[a+14|0]}if(e&32){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;x[b>>2]=f>>>1;e=y[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){w[b+34>>1]=34;w[b+34>>1]=y[a+14|0]&2?38:34}a=Dc(g+4|0,22292);Be(b+43|0,a);tb(a);fb=g+16|0}function kka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<1073741808){a:{if(sn(a)>>>0>=b>>>0){break a}k=d,l=Cb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=rn(x[bd(d+12|0,d+8|0)>>2]);if((sn(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;i=1;f=b+1|0;c=sn(a);g=Cb(x[a+4>>2],y[a+11|0]);b:{c:{j=fr(b);d:{if(j){h=x[a>>2];b=a;c=g;break d}e:{if(b>>>0>c>>>0){Nj(e+8|0,f);break e}x[31609]=0;O(54,e+8|0,f|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}}f=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=vd(c);h=Kb(a);c=Cb(x[a+4>>2],c)}b=Ri(b,h,c+1|0);if(i){Db(h)}if(!j){of(a,f);Bd(a,g);yd(a,b);break b}Ne(a,g);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}pf();p()}function caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;x[31609]=0;f=R(1201,b|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){a:{b:{if(f){x[31609]=0;f=d+56|0;O(1202,f|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){b=d- -64|0;Jp(b,f);e=Ff(d+72|0,b);g=Ff(d+48|0,c);h=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=h;e=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=e;Kp(a,d+8|0,d);break b}break a}x[31609]=0;f=d+56|0;O(1203,f|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}b=d- -64|0;Jp(b,f);e=Ff(d+40|0,b);g=Ff(d+32|0,c);h=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=h;e=x[g+4>>2];x[d+16>>2]=x[g>>2];x[d+20>>2]=e;Kp(a,d+24|0,d+16|0)}me(b);me(f);me(c);fb=d+80|0;return}}a=N()|0;me(c);Q(a|0);p()}function SX(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;x[c+12>>2]=20;x[c+8>>2]=a;e=RX(x[c+8>>2],x[c+12>>2]);a:{if(e>>>0>5){break a}i=a+20|0;while(1){if((d|0)!=15){x[c+4>>2]=22;b=D(d,30)+i|0;x[c>>2]=b;e=RX(x[c>>2],x[c+4>>2])+e|0;if(e>>>0>48){break a}g=y[b+25|0];if(y[b+24|0]|g>>>0>64){break a}b=Bb(y[b+22|0]|y[b+23|0]<<8);if(b>>>0>32768){break a}d=d+1|0;f=f|g;h=b+h|0;continue}break}if(!h|!(f&255)){break a}e=y[a+470|0];if(e>>>0>128){break a}f=y[a+471|0];if(f>>>0>220){break a}a=a+472|0;b=PC(a);b:{if((a|0)==(b|0)){break b}d=a;while(1){d=d+1|0;if((b|0)==(d|0)){break b}a=_t(y[a|0],y[d|0])?d:a;continue}}a=y[a|0];if(a>>>0>63){break a}j=(f|(a|e))!=0}fb=c+16|0;return j}function rR(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=fb-16|0;fb=j;v[j+15|0]=c;v[j+14|0]=12;fh(b,y[Qb(j+15|0,j+14|0)|0]);n=(h?144:96)+a|0;c=0;a=x[b>>2];l=x[b+4>>2];o=Sd(a,l);while(1){if((c|0)==(o|0)){c=0;v[b+12|0]=0;a:{if(!(d&1)){break a}if(mc(a,l)){break a}c=1;v[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;v[b+12|0]=c}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=c|2}v[b+14|0]=g;v[b+13|0]=f}fb=j+16|0}else{h=yb(a,c);k=(c<<2)+n|0;i=y[k|0]|y[k+1|0]<<8;w[h>>1]=i;v[h+2|0]=y[k+2|0];b:{if(!c){break b}k=yb(a,c-1|0);m=z[k>>1];if(i>>>0>255|i>>>0>=m>>>0){break b}i=i|m&65280;w[h>>1]=i;if(z[k>>1]<=(i&65535)>>>0){break b}w[h>>1]=i+256}c=c+1|0;continue}break}}function Yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=g+4|0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{c:{while(1){c=Kb(d);j=Cb(x[d+4>>2],y[d+11|0])+c|0;i=x[b>>2];k=e+12|0;f=x[b+4>>2];if(!((c|0)==(j|0)|((f|0)>=0|(f|0)>0))){v[c|0]=45;i=VN(i,f);f=hb;c=c+1|0}ON(k,c,j,i,f);if(!x[e+16>>2]){break c}c=ki(Cb(x[d+4>>2],y[d+11|0]));x[31609]=0;O(45,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){continue}break}break b}b=x[e+12>>2];c=Kb(d);x[31609]=0;O(46,d|0,b-c|0);b=x[31609];x[31609]=0;d:{if((b|0)!=1){x[31609]=0;O(303,h|0,d|0);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break b}break b}tb(d);fb=e+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}Qh(a,h);tb(h);fb=g+16|0}function Pg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb+-64|0;fb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=x[a>>2];e=x[a+4>>2];if(Je(d,e,b)){break b}c:{d:{if(hm(d,e)>>>0<=b>>>0){d=rA(f+12|0,a);x[31609]=0;S(199,a|0,b+1|0,d|0);e=x[31609];x[31609]=0;if((e|0)==1){break d}vk(d);d=x[a>>2]}x[31609]=0;O(200,_i(d,b)|0,c|0);c=x[31609];x[31609]=0;e:{if((c|0)!=1){c=_i(x[a>>2],b);x[c+16>>2]=0;x[c+20>>2]=0;c=x[a>>2];x[31609]=0;W(201,_i(c,b)|0);c=x[31609];x[31609]=0;if((c|0)!=1){break e}}b=T(124540)|0;a=gb;break c}a=_i(x[a>>2],b);g=Ib(x[a>>2],x[a+4>>2]);break b}b=T(124540)|0;a=gb;vk(d)}if(($(124540)|0)!=(a|0)){break a}Y(b|0)|0;Z()}fb=f- -64|0;return g|0}Q(b|0);p()}function PQ(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{f=fb-48|0;fb=f;d=Fb(f+36|0);x[31609]=0;O(932,b|0,f+24|0);g=x[31609];x[31609]=0;if((g|0)!=1){b:{g=x[f+28>>2];e=x[f+24>>2];sf(d);x[31609]=0;g=!g&e>>>0>=255|g?255:e;O(46,d|0,g|0);e=x[31609];x[31609]=0;if((e|0)==1){break b}c:{while(1){if((g|0)==(h|0)){b=X$(Kb(d),Cb(x[d+4>>2],y[d+11|0]));if((b|0)==-1){break c}x[31609]=0;O(46,d|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break c}break b}e=ec(d,h);x[31609]=0;P(933,b|0,e|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){h=h+1|0;continue}break}break b}x[31609]=0;b=f+12|0;S(496,b|0,a|0,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}zb(c,b);tb(b);tb(d);fb=f+48|0;break a}}a=N()|0;tb(d);Q(a|0);p()}}function Hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;n=w[e+38086>>1];o=w[e+38084>>1];p=w[e+38082>>1];e=w[e+38080>>1];f=0;while(1){if((f|0)!=2){g=f+m|0;x[(f<<2)+b>>2]=(((D(v[g|0],p)+D(v[g-2|0],e)|0)+D(v[g+2|0],o)|0)+D(v[g+4|0],n)<<8)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Pb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function pT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-112|0;fb=f;x[f+108>>2]=0;e=Go(a,e&65535,d,c,f+108|0);c=y[b+790|0];if(!x[f+108>>2]){d=(c|0)==15;h=d&!y[b+792|0];e=e<<8;a:{if(e){x[b+664>>2]=e;break a}e=0;if(d){break a}e=x[b+664>>2]}h=h?0:y[b+836|0]<<16}if((c|0)==15){c=y[b+792|0];b:{if(!c){c=x[b+76>>2];x[f+4>>2]=1;g=x[bd(f+4|0,f+108|0)>>2]<<3;e=Aua(c,0,e,0);d=(256<<g>>>1|0)+e|0;c=hb;c=d>>>0<e>>>0?c+1|0:c;e=g+8|0;g=d;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}e=Bc(c,e);break b}_v(f+4|0);if(c>>>0>9){break b}c=x[b+104>>2];if(!c){break b}e=x[yb(c+68|0,y[b+792|0]-1|0)>>2]+e|0}x[b+664>>2]=e}Ko(a,b,e+h|0);fb=f+112|0}function pN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;a:{b:{c:{d:{e:{if((b|0)>=0){d=x[a+32>>2];if((xo(d)|0)>(b|0)){break e}}a=dc(8);x[31609]=0;b=P(36,f+4|0,10751)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}e=(d+(b<<5)|0)+480280|0;g=c?67109888:0;x[e>>2]=g|x[e>>2]&-67109889;c=(d+D(b,872)|0)+1075080|0;x[c>>2]=x[c>>2]&-67109889|g;c=z[d+480188>>1];d=c>>>0<=256?256:c;b=b+1|0;e=x[a+32>>2]+1074992|0;while(1){if((c|0)==(d|0)){break a}a=e+D(c,872)|0;if((b|0)==z[a+786>>1]){x[a+88>>2]=x[a+88>>2]&-67109889|g}c=c+1|0;continue}}c=N()|0;lc(a)}Q(c|0)}p()}fb=f+16|0}function ina(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=kg(1,2);e=hb;l=e;Pb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=(((x[b+12>>2]&2147483647)<<1|i>>>31)&-2)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=v[h+i|0]<<8;h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Pb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Ig(a,j,l);fb=b+16|0}function B9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!_y(Aa(x[a+60>>2],b|0,i|0,d+12|0)|0)){g=x[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[b+4>>2]|0}fb=d+32|0;return a|0}function bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Pb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function bG(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-1641380927){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(b>>>0<36){break a}c=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);if(c>>>0<36){break a}d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);if(d>>>0<36){break a}e=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24);if(D(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function aB(a,b,c,d){var e=0,f=0,g=0,h=0;a:{if(!d){break a}if(c){v[b+815|0]=c;break a}c=y[b+815|0]}f=x[a+480180>>2];d=f&1048580;c=d?c&240?c&-16:c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{e=c&15;if((e|0)==15){a=x[a+480208>>2]&4096;if(!d){break h}if(!a){break b}c=0-(d>>>2|0)|0;break d}a=x[a+480208>>2]&4096;if(!e|(d|0)!=240){break g}if(!a){break b}c=e<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!e){break e}}c=e<<2;if(!d|!(f&16777248)){break c}break b}c=0-((c&255)>>>2|0)|0;break d}if(y[a+480209|0]&16){break b}d=c&240;c=d?d>>>2|0:0-((c&255)<<2)|0;if(!Ob(a+1074312|0,56)){break d}c=c>>2}if(!c){break b}}a=x[b+692>>2];w[b+784>>1]=0;g=b,h=Yb(a+c|0,0,256),x[g+692>>2]=h}}function UQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=E(0),k=0,l=E(0);g=fb-16|0;fb=g;e=w[d>>1];f=w[d+2>>1];if(!(!z[b>>1]|(e|0)>(f|0)|(!(B[c>>2]>E(0))|(f-e|0)>32766))){w[a>>1]=3;f=a+4|0;Nc(f);w[a+28>>1]=65472;x[g+12>>2]=1065353216;YQ(f,g+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Nc(a+16|0);h=w[d>>1];w[a+28>>1]=h;e=fb-16|0;fb=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Oc(e+14|0,e+12|0)>>1];fb=e+16|0;w[a+30>>1]=b;i=E(F(B[c>>2]));B[a+32>>2]=i;i=Ee(i,E(E(1)/E(b|0)));Cl(f,(w[d+2>>1]-h|0)+1|0);b=x[a+4>>2];c=w[a+28>>1];e=w[d+2>>1];d=w[d>>1];while(1){if((d|0)>(e|0)){xq(a)}else{j=Ee(i,E(d|0));k=yb(b,d-c|0),l=j,B[k>>2]=l;d=d+1|0;continue}break}h=1}fb=g+16|0;return h|0}function HO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;g=Nb(a);a=0;c=x[b+24>>2];c=Zu(x[c+484344>>2],x[c+484348>>2]);x[31609]=0;O(176,g|0,c|0);c=x[31609];x[31609]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=x[b+24>>2];d=x[c+484344>>2];if(Zu(d,x[c+484348>>2])>>>0<=a>>>0){break b}x[31609]=0;c=e+8|0;O(1066,c|0,Wb(d,a)|0);d=x[31609];x[31609]=0;if((d|0)!=1){f=x[b+24>>2];x[31609]=0;d=e+20|0;S(1053,d|0,f|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}x[31609]=0;O(178,g|0,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break d}a=a+1|0;tb(d);tb(c);continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(e+8|0);break a}fb=e+32|0;return}a=N()|0}Td(g);Q(a|0);p()}function goa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Qj(b),x[i+4>>2]=j;d=fb-16|0;fb=d;h=a;c=de(a);a:{if(c){f=gc(a);while(1){a=c;c=a+13|0;if(ov(b,c)){f=a;c=x[a>>2];if(c){continue}break a}if(!ov(c,b)){break a}f=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(h);f=a}x[d+12>>2]=a;b=x[f>>2];if(!b){c=fb-16|0;fb=c;a=gc(h);g=Dh(d,Ec(20),Og(c+8|0,a));b=x[g>>2];a=x[e+4>>2];a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+17|0]=0;v[b+13|0]=a;v[b+14|0]=a>>>8;v[b+15|0]=a>>>16;v[b+16|0]=a>>>24;i=gc(g),j=1,v[i+4|0]=j;fb=c+16|0;$g(h,x[d+12>>2],f,x[d>>2]);b=ne(d);Ik(d);g=1}_g(e+8|0,x[vb(d,b)>>2],g);fb=d+16|0;fb=e+16|0;return x[e+8>>2]+17|0}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;x[31609]=0;W(996,a|0);e=x[31609];x[31609]=0;a:{b:{c:{if((e|0)==1){break c}x[31609]=0;W(997,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break c}x[31609]=0;W(997,c|0);f=x[31609];x[31609]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=pc(d+24|0,b);c=pc(d+16|0,c);g=x[c>>2];c=x[c+4>>2];x[31609]=0;h=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=h;Ns(1018,f,d+8|0,g,c,1);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,5507,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();e=0}fb=d+32|0;return e|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function qU(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=$u(b);e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);h=e+8|0;Rd(h,x[vb(e+4|0,a)>>2]);x[31609]=0;O(799,a|0,2048);d=x[31609];x[31609]=0;a:{if((d|0)!=1){i=fb-16|0;fb=i;g=hs(i+4|0,a,2048);d=x[g+4>>2];k=x[g+8>>2];while(1){if((d|0)==(k|0)){jc(g);fb=i+16|0}else{x[d>>2]=0;x[d+4>>2]=0;d=d+8|0;x[g+4>>2]=d;continue}break}Qd(h);_u(h);fb=e+16|0;break a}a=N()|0;_u(e+8|0);Q(a|0);p()}while(1){b:{c=1;if((f|0)!=1024){if((f|0)==2048){break b}c=+(f-1024|0);l=$u(M(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=l*Pi(c)/(j*c)}m=Se(x[a>>2],f),n=c*.011841342921061943,C[m>>3]=n;f=f+1|0;continue}break}}function WY(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;d=vb(g+12|0,x[a+4>>2]);c=vb(g+8|0,x[a>>2]);f=x[vb(g+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;fd(e+24|0,x[d>>2],x[c>>2]);j=e+16|0;c=x[e+24>>2];k=x[e+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=f;x[d+12>>2]=c;while(1){if(Fd(c,k)){c=xf(c);f=xf(x[d+8>>2]);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=c;v[f+1|0]=c>>>8;v[f+2|0]=c>>>16;v[f+3|0]=c>>>24;c=wj(d+12|0);wj(d+8|0);c=x[c>>2];continue}break}qc(j,c,d+8|0);fb=d+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(i,d,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=g+16|0}function mv(a,b){var c=0,d=0,e=0;e=fb-48|0;fb=e;d=e+28|0;TV(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);a=e+8|0;TV(a,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=x[d>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a>>2];b=lv(c,y[b|0]|y[b+1|0]<<8);a:{if(!Lj(b)){break a}b=x[d+4>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+4>>2];b=lv(c,y[b|0]|y[b+1|0]<<8);if(!Lj(b)){break a}b=x[d+8>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+8>>2];b=lv(c,y[b|0]|y[b+1|0]<<8);if(!Lj(b)){break a}b=x[a+12>>2];b=(y[b|0]|y[b+1|0]<<8)<<16>>16;c=x[d+12>>2];c=ze((y[c|0]|y[c+1|0]<<8)<<16>>16);b=ze(b);b=(b|0)!=(c|0)?(c|0)<(b|0)?-1:1:0;if(!Lj(b)){break a}b=x[d+16>>2];a=x[a+16>>2];b=lv(y[b|0]|y[b+1|0]<<8,y[a|0]|y[a+1|0]<<8)}a=vd(b);fb=e+48|0;return a}function HK(a){var b=0,c=0,d=0,e=0,f=0;f=x[124115];if(x[a+72>>2]<=0){My(a)}x[124115]=x[a+136>>2];c=fb-32|0;fb=c;a:{b:{c:{b=x[a+4>>2];d=x[a+8>>2];if((b|0)==(d|0)){break c}b=GK(c+28|0,b,d-b|0);if((b|0)==-1){break c}x[a+4>>2]=!b+(b+x[a+4>>2]|0);break b}x[c+16>>2]=0;x[c+20>>2]=0;b=0;while(1){d=b;d:{b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;v[c+15|0]=y[b|0];break d}b=zt(a);v[c+15|0]=b;if((b|0)>=0){break d}b=-1;if(!(d&1)){break a}x[a>>2]=x[a>>2]|32;x[31484]=25;break a}b=1;e=fq(c+28|0,c+15|0,1,c+16|0);if((e|0)==-2){continue}break}b=-1;if((e|0)!=-1){break b}if(!(d&1)){break a}x[a>>2]=x[a>>2]|32;fo(y[c+15|0],a);break a}b=x[c+28>>2]}fb=c+32|0;x[124115]=f;return b}function w7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-416|0;fb=h;d=h+416|0;x[h+12>>2]=d;c=fb-144|0;fb=c;x[c+28>>2]=c+132;i=c+32|0;dK(x[a+8>>2],i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;f=oc(e,x[h+12>>2]);a=Di(e,c+12|0,f,c+16|0,x[a+8>>2]);if((a|0)==-1){go(12677);p()}x[h+12>>2]=e+(a<<2);fb=c+144|0;f=fb-16|0;fb=f;i=f+8|0;a=fb-32|0;fb=a;fd(a+24|0,e,x[h+12>>2]);h=a+16|0;e=x[a+24>>2];g=x[a+28>>2];c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){if((e|0)!=(g|0)){ZK(c+12|0,x[e>>2]);e=e+4|0;continue}break}qc(h,g,c+12|0);fb=c+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];qc(i,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=d;return x[f+12>>2]}function cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Pb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function c9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;a:{b:{if(!mc(b,-1)){i=x[a+8>>2];j=x[a+12>>2];d=x[a+24>>2];if((d|0)==x[a+28>>2]){c=-1;if(!(y[a+48|0]&16)){break a}k=x[a+44>>2];h=x[a+20>>2];x[31609]=0;g=a+32|0;O(115,g|0,0);e=x[31609];x[31609]=0;if((e|0)==1){break b}e=Mc(g);x[31609]=0;O(46,g|0,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break b}c=Kb(g);Ex(a,c,Cb(x[a+36>>2],y[a+43|0])+c|0);As(a,d-h|0);x[a+44>>2]=x[a+20>>2]+(k-h|0);d=x[a+24>>2]}x[f+12>>2]=d+1;d=x[bd(f+12|0,a+44|0)>>2];x[a+44>>2]=d;if(y[a+48|0]&8){c=Kb(a+32|0);Vn(a,c,c+(j-i|0)|0,d)}c=fL(a,b<<24>>24);break a}c=Qy(b);break a}Y(T(0)|0)|0;Z()}fb=f+16|0;return c|0}function eo(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0,n=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;n=a&255;if((n|0)!=y[k+24|0]){m=45;if(y[k+25|0]!=(n|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Cb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;a=Fi(k,k+26|0,a)-k|0;if((a|0)>23){break c}d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(a|0)<22){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+95168|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+95168|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function Ioa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-160|0;fb=e;b=-1;a:{if(!wm(a,80)){break a}b:{c:{if(!Wl(a,60)){break c}d=e+140|0;if(!KW(a,d)){break c}c=15;if(yv(d,15)){break b}}if(!wm(a,144)){break a}b=0;if(!Wl(a,124)){break a}d=e+140|0;if(!KW(a,d)){break a}c=31;if(!yv(d,31)){break a}}vE(a);b=0;d:{while(1){if((b&65535)>>>0>=c>>>0){break d}b=b+1|0;if(IW(a)>>>0<=131072){continue}break}b=0;break a}b=-1;if(!id(a,D(c,30)|20)){break a}c=fb-16|0;fb=c;f=e+10|0;WC(c+8|0,f);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((d|0)==(g|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(g|0);if(!a){MC(f)}if(!a){break a}b=JW(y[e+10|0])}fb=e+160|0;return b|0}function Ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[h>>1],w[e+38082>>1])+D(w[h-2>>1],w[e+38080>>1])|0)+D(w[h+2>>1],w[e+38084>>1])|0)+D(w[h+4>>1],w[e+38086>>1])|0)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function us(a){var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;c=b+8|0;Dc(c,13707);x[31609]=0;d=b+20|0;S(123,d|0,1,c|0);e=x[31609];x[31609]=0;a:{b:{c:{if((e|0)!=1){x[31609]=0;O(12,a|0,d|0);e=x[31609];x[31609]=0;if((e|0)==1){break c}Ub(d);tb(c);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Ub(b+20|0)}tb(b+8|0);Q(a|0);p()}x[31609]=0;b=ca(117)|0;c=x[31609];x[31609]=0;d:{if((c|0)==1){break d}x[a+12>>2]=b;x[31609]=0;b=ca(118)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}v[a+16|0]=b;x[31609]=0;b=ca(119)|0;c=x[31609];x[31609]=0;if((c|0)==1){break d}v[a+18|0]=0;v[a+17|0]=b;x[31609]=0;W(120,a+20|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}return}b=N()|0;tb(a);Q(b|0);p()}function D8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;a:{if(mc(b,-1)){e=b;if(y[a+52|0]){break a}e=x[a+48>>2];f=a,g=mc(e,-1)^1,v[f+52|0]=g;break a}b:{e=y[a+52|0];if(!(!y[a+53|0]|!e)){e=-1;if(!IK(x[a+48>>2],x[a+32>>2])){break a}break b}if(!e){break b}v[c+19|0]=x[a+48>>2]<<24>>24;e=-1;c:{d:{d=c+20|0;switch(pr(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break a;case 2:break d;default:break c}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((fo(v[d|0],x[a+32>>2])|0)!=-1){continue}break}break a}v[a+52|0]=1;x[a+48>>2]=b;e=b}fb=c+32|0;return e|0}function pra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[d+28>>2]=0;Gk(a,d+28|0);a:{b:{i=x[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}h=Fb(d+16|0);x[31609]=0;w[d+14>>1]=0;g=U(495,a|0,h|0,255)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}if(!g){break d}x[31609]=0;g=d+14|0;O(484,a|0,g|0);e=x[31609];x[31609]=0;if((e|0)==1){break b}x[31609]=0;S(496,d|0,c|0,h|0);e=x[31609];x[31609]=0;if((e|0)!=1){x[31609]=0;g=P(497,b|0,g|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break e}zb(g,d);tb(d);tb(h);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(h)}fb=d+32|0;return}f=N()|0}tb(h);Q(f|0);p()}function Ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;d=Rf(e+52|0);x[31609]=0;g=P(835,b|0,d|0)|0;f=x[31609];x[31609]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31609]=0;R(836,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break b}}break a}g=x[d+4>>2];x[31609]=0;f=e+12|0;S(185,f|0,b|0,g|0);h=x[31609];x[31609]=0;if((h|0)==1){break a}h=hc(e+32|0,f);kd(d+8|0,h);ub(h);ub(f);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}x[31609]=0;P(183,b|0,2-c|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break d}break a}Ok(a,d)}Hd(d);fb=e+80|0;return}a=N()|0;Hd(d);Q(a|0);p()}function Rra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=b;c=fb-48|0;fb=c;d=a;a:{if(Sv(x[d>>2],x[d+8>>2])){x[g>>2]=0;break a}cZ(c+16|0,c+32|0);kc(c+24|0,x[d>>2],x[d+8>>2],x[c+16>>2],x[c+20>>2]);h=x[c+28>>2];i=y[c+32|0];f=i&127;x[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(D(h,7)+a|0)+D(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}j=c+32|0;i=y[j+e|0];f=i&127|f<<7;x[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Vb(d,h);cZ(c+8|0,j);kc(c+24|0,x[d>>2],x[d+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+28>>2];f=x[g>>2];e=0;a=b;continue}break}Vb(d,e);if(a>>>0<33){break a}x[g>>2]=-1}fb=c+48|0}function oG(a){a=a|0;var b=0,c=0,d=0,e=0;b=oF(x[(x[x[a>>2]-12>>2]+a|0)+28>>2],10);d=fb-16|0;fb=d;x[31609]=0;c=P(21,d+8|0,a|0)|0;e=x[31609];x[31609]=0;a:{b:{c:{d:{if((e|0)!=1){e:{if(!Id(y[c|0])){break e}e=qp(d+4|0,a);x[31609]=0;b=P(30,e|0,b|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){if(x[b>>2]){break e}b=x[x[a>>2]-12>>2];x[31609]=0;O(24,a+b|0,1);b=x[31609];x[31609]=0;if((b|0)!=1){break e}}b=T(0)|0;fm(c);break d}fm(c);break c}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31609]=0;W(25,a+c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}Z()}fb=d+16|0;break a}a=N()|0;x[31609]=0;X(26);d=x[31609];x[31609]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return sp(a)|0}function _S(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{b:{c:{if(v[b+851|0]&1){f=y[b+848|0];g=c&240;if(g){f=f&15|g;v[b+848|0]=f}c=c&15;if(c){f=c|f&-16;v[b+848|0]=f}v[b+849|0]=(f&240)>>>4;if(x[a+480180>>2]!=32768){break a}break c}if(x[a+480180>>2]==32768){break c}c=y[b+849|0]-1|0;v[b+849|0]=c;if(c&255){break a}f=y[b+848|0];break b}f=y[b+848|0];if((f&240)==16){break b}if(!(y[a+480209|0]&16)){break a}}v[b+849|0]=(f&240)>>>4;c=f&15;c=d?c:0-c|0;d=x[b+656>>2];d:{if(Kj(d)){x[b+852>>2]=x[b+852>>2]+D(c,x[x[d+44>>2]+36>>2]);break d}h=b,i=zh(a,Ku(a,x[b+700>>2],w[b+772>>1],x[b+704>>2])+c|0,w[b+772>>1],x[b+704>>2]),x[h+700>>2]=i}if(!e){break a}x[b>>2]=0;x[b+4>>2]=0}}function sp(a){var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[31609]=0;c=P(21,d+8|0,a|0)|0;b=x[31609];x[31609]=0;c:{if((b|0)!=1){d:{if(!Id(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31609]=0;b=R(31,b|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[31609]=0;O(24,a+b|0,1);b=x[31609];x[31609]=0;if((b|0)!=1){break d}}b=T(0)|0;fm(c);break c}fm(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31609]=0;W(25,a+c|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a}a=N()|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ora(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;w[d+30>>1]=0;ng(a,d+30|0);a:{b:{i=z[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}h=Fb(d+16|0);x[31609]=0;w[d+14>>1]=0;g=P(498,a|0,h|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}if(!g){break d}x[31609]=0;g=d+14|0;O(484,a|0,g|0);e=x[31609];x[31609]=0;if((e|0)==1){break b}x[31609]=0;S(496,d|0,c|0,h|0);e=x[31609];x[31609]=0;if((e|0)!=1){x[31609]=0;g=P(497,b|0,g|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break e}zb(g,d);tb(d);tb(h);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(h)}fb=d+32|0;return}f=N()|0}tb(h);Q(f|0);p()}function co(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;if(x[k+96>>2]!=(a|0)){m=45;if(x[k+100>>2]!=(a|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Cb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;a=Ey(k,k+104|0,a)-k>>2;if((a|0)>23){break c}d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(a|0)<22){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+95168|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+95168|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function XH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;x[31609]=0;W(996,a|0);e=x[31609];x[31609]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}x[31609]=0;W(997,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break f}g=x[a+24>>2];x[31609]=0;e=P(36,f+8|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break e}x[31609]=0;b=d;d=f+20|0;S(b|0,d|0,g|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}b=Cg(Kb(d));tb(d);tb(e);break b}b=T(0)|0;break c}b=T(0)|0;break c}b=T(0)|0;tb(e)}Y(b|0)|0;b=0;x[31609]=0;V(983,c|0,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z()}fb=f+32|0;return b}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Ara(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;e=c+12|0;g=Nb(e+8|0);x[31609]=0;d=R(202,b|0)|0;f=x[31609];x[31609]=0;a:{b:{if((f|0)==1){break b}c:{if(!mZ(d)){x[31609]=0;X(507);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break b}x[31609]=0;d=R(202,b|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}x[31609]=0;S(169,e|0,b|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break b}d=x[e>>2];x[31609]=0;P(183,b|0,d|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break b}break a}p()}a=N()|0;fc(g);Q(a|0);p()}Mn(c+4|0,e);x[31609]=0;S(475,a|0,x[c+4>>2],x[c+8>>2]);a=x[31609];x[31609]=0;if((a|0)!=1){Kc(e);fb=c+32|0;return}a=N()|0;Kc(c+12|0);Q(a|0);p()}function Fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[h|0],w[e+38082>>1])+D(v[h-1|0],w[e+38080>>1])|0)+D(v[h+1|0],w[e+38084>>1])|0)+D(v[h+2|0],w[e+38086>>1])<<8)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function O9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;h=Fb(a);f=Fb(d+20|0);a=1;a:{b:{c:{while(1){e=a&65535;c=x[b+24>>2];if(e>>>0>z[c+480192>>1]){if(!(i&1)){break c}x[31609]=0;O(247,h|0,f|0);a=x[31609];x[31609]=0;if((a|0)!=1){break c}a=N()|0;break a}c=RR(c,e);x[31609]=0;c=P(36,d+8|0,c|0)|0;e=x[31609];x[31609]=0;if((e|0)==1){break b}e=Ad(x[d+12>>2],y[d+19|0]);x[31609]=0;g=P(838,f|0,c|0)|0;j=x[31609];x[31609]=0;d:{if((j|0)==1){break d}x[31609]=0;P(985,g|0,22267)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}i=e^1|i;tb(c);a=a+1|0;continue}break}a=N()|0;tb(c);break a}tb(f);fb=d+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function Sz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;x[c>>2]=a;x[c+4>>2]=b;x[c+8>>2]=a;x[c+12>>2]=b;b=fb+-64|0;fb=b;a:{if(!x[c+4>>2]){break a}a=x[c>>2];h=x[c+4>>2];while(1){if((e|0)==432){while(1){e=(g|0)!=48;if((g|0)==48){break a}x[b+40>>2]=a;x[b+44>>2]=h;f=pc(b+32|0,x[g+31e3>>2]);d=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=d;d=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=d;g=g+12|0;if(!AR(b+8|0,b)){continue}break a}}x[b+56>>2]=a;x[b+60>>2]=h;f=pc(b+48|0,x[e+30564>>2]);d=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=d;d=x[f+4>>2];x[b+16>>2]=x[f>>2];x[b+20>>2]=d;e=e+8|0;if(!AR(b+24|0,b+16|0)){continue}break}e=1}fb=b- -64|0;fb=c+16|0;return e}function t7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=QJ(b);ll(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;kl(a,b);zb(i,a);tb(a);di(a,b);zb(h,a);tb(a);m=d,n=lj(b),v[m|0]=n;m=e,n=mj(b),v[m|0]=n;sh(a,b);zb(f,a);tb(k+4|0);ei(a,b);zb(g,a);tb(k+4|0);a=Kk(b);break a}a=k+4|0;b=PJ(b);ll(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;kl(a,b);zb(i,a);tb(a);di(a,b);zb(h,a);tb(a);m=d,n=lj(b),v[m|0]=n;m=e,n=mj(b),v[m|0]=n;sh(a,b);zb(f,a);tb(k+4|0);ei(a,b);zb(g,a);tb(k+4|0);a=Kk(b)}x[l>>2]=a;fb=k+16|0}function $0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;nd(b,0);e=c+16|0;f=rf(e,1,v[a+1|0]);Be(b+43|0,f);tb(f);x[b>>2]=y[a+6|0]|y[a+7|0]<<8|(y[a+8|0]<<16|y[a+9|0]<<24);x[b+24>>2]=y[a+10|0]|y[a+11|0]<<8;v[c+16|0]=y[a+12|0];v[c+12|0]=64;g=b,h=y[Qb(e,c+12|0)|0]<<2,w[g+30>>1]=h;x[b+4>>2]=y[a+13|0]|y[a+14|0]<<8|(y[a+15|0]<<16|y[a+16|0]<<24);e=y[a+19|0];f=y[a+17|0]|y[a+18|0]<<8;v[c+14|0]=0;v[c+18|0]=e;w[c+16>>1]=f;w[c+12>>1]=0;while(1){if((d|0)!=3){e=xb(c+16|0,d);g=xb(c+12|0,d),h=y[e|0],v[g|0]=h;d=d+1|0;continue}break}d=cg(c+12|0);x[b+8>>2]=d;if(!(!y[a|0]|d>>>0<=x[b+4>>2]+2>>>0|d>>>0>A[b>>2])){w[b+34>>1]=z[b+34>>1]|2}fb=c+32|0}function Wra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];d=Br(c,x[a+4>>2]);if(d>>>0<b>>>0){f=fb-32|0;fb=f;c=b-d|0;b=x[Ab(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=(b-e|0)/40>>>0){d=fb-16|0;fb=d;b=t$(d+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){jc(b);fb=d+16|0}else{ZY(a);a=a+40|0;x[b+4>>2]=a;continue}break}break a}b=Ab(a);d=q$(f+12|0,r$(a,Br(x[a>>2],e)+c|0),Br(x[a>>2],x[a+4>>2]),b);e=fb-16|0;fb=e;g=x[d+8>>2];b=e+4|0;x[b+8>>2]=d+8;x[b>>2]=g;x[b+4>>2]=D(c,40)+g;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){ZY(c);c=x[b>>2]+40|0;x[b>>2]=c;continue}break}je(b);fb=e+16|0;p$(a,d);o$(d)}fb=f+32|0;return}if(b>>>0<d>>>0){Jd(a,c+D(b,40)|0)}}function N9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;h=Fb(a);f=Fb(c+20|0);a=1;a:{b:{c:{while(1){d=a&65535;e=x[b+24>>2];if(d>>>0>z[e+480190>>1]){if(!(i&1)){break c}x[31609]=0;O(247,h|0,f|0);a=x[31609];x[31609]=0;if((a|0)!=1){break c}a=N()|0;break a}x[31609]=0;e=P(36,c+8|0,SR(e,d)|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}d=Ad(x[c+12>>2],y[c+19|0]);x[31609]=0;g=P(838,f|0,e|0)|0;j=x[31609];x[31609]=0;d:{if((j|0)==1){break d}x[31609]=0;P(985,g|0,22267)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}i=d^1|i;tb(e);a=a+1|0;continue}break}a=N()|0;tb(e);break a}tb(f);fb=c+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function K8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;a:{if(ko(b)){e=b;if(y[a+52|0]){break a}e=x[a+48>>2];f=a,g=ko(e)^1,v[f+52|0]=g;break a}b:{e=y[a+52|0];if(!(!y[a+53|0]|!e)){e=-1;if(!KK(x[a+48>>2],x[a+32>>2])){break a}break b}if(!e){break b}x[c+16>>2]=x[a+48>>2];e=-1;c:{d:{d=c+20|0;switch(pr(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break a;case 2:break d;default:break c}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((fo(v[d|0],x[a+32>>2])|0)!=-1){continue}break}break a}v[a+52|0]=1;x[a+48>>2]=b;e=b}fb=c+32|0;return e|0}function m7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=NJ(b);ll(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;kl(a,b);nh(i,a);Ub(a);di(a,b);nh(h,a);Ub(a);m=d,n=lj(b),x[m>>2]=n;m=e,n=mj(b),x[m>>2]=n;sh(a,b);zb(f,a);tb(a);ei(a,b);nh(g,a);Ub(k+4|0);a=Kk(b);break a}a=k+4|0;b=MJ(b);ll(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;kl(a,b);nh(i,a);Ub(a);di(a,b);nh(h,a);Ub(a);m=d,n=lj(b),x[m>>2]=n;m=e,n=mj(b),x[m>>2]=n;sh(a,b);zb(f,a);tb(a);ei(a,b);nh(g,a);Ub(k+4|0);a=Kk(b)}x[l>>2]=a;fb=k+16|0}function GC(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;h=x[a>>2];a:{if(Xc(h,x[a+4>>2])>>>0<=b>>>0){break a}b:{c:{switch(c|0){case 0:if((d|0)>=0){i=xb(h,b),j=d^128,v[i|0]=j}c=g+8|0;Jb(c,x[a+24>>2],b);kf(c,0);break b;case 2:i=xb(h,b),j=128,v[i|0]=j;c=g+8|0;Jb(c,x[a+24>>2],b);kf(c,1);break b;case 4:break c;default:break b}}i=xb(h,b),j=128,v[i|0]=j;c=g+8|0;Jb(c,x[a+24>>2],b);kf(c,0)}if(y[e|0]){break a}c=x[f+4>>2];if(mc(x[f>>2],c)){break a}c=eX(c);if(y[xb(x[c>>2],b)|0]==y[xb(x[a>>2],b)|0]){Jb(g+8|0,x[c+24>>2],b);c=Gb(x[x[g+8>>2]>>2],x[g+12>>2]);Jb(g,x[a+24>>2],b);if((Gb(x[x[g>>2]>>2],x[g+4>>2])|0)==(c|0)){break a}}v[e|0]=1}fb=g+16|0}function Fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Kb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Kb(c);j=Cb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(sq(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=vb(g+12|0,zd(b));d=vb(g+8|0,vf(zd(b),f));_r(b,x[c>>2],x[d>>2]);break c}f=_c(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Kb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Kb(c);d=-1;h=Cb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!sq(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}Uc(a,b)}fb=g+16|0}function r2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Kb(b);d=Cb(x[b+4>>2],y[b+11|0]);i=Kb(c);j=Cb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(Eu(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=vb(g+12|0,zd(b));d=vb(g+8|0,vf(zd(b),f));_r(b,x[c>>2],x[d>>2]);break c}f=_c(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Kb(b);i=Cb(x[b+4>>2],y[b+11|0]);j=Kb(c);d=-1;h=Cb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!Eu(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}Uc(a,b)}fb=g+16|0}function jqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Hb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Hb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=(D(b,e)<<1)+i|0;a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a<<1)+k|0;f=li(E(Pd(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(32768)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=gd(g),w[m>>1]=n;a=a+1|0;continue}}}_(17387,8999,27,9541);p()}_(17337,8999,28,9541);p()}fb=c+16|0}function nja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;d=Rf(e+52|0);x[31609]=0;g=P(911,b|0,d|0)|0;f=x[31609];x[31609]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31609]=0;R(912,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break b}}break a}g=x[d+4>>2];x[31609]=0;f=e+12|0;S(185,f|0,b|0,g|0);h=x[31609];x[31609]=0;if((h|0)==1){break a}h=hc(e+32|0,f);kd(d+8|0,h);ub(h);ub(f);d:{if(!(g&1)|c>>>0<2){break d}x[31609]=0;P(183,b|0,1)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break d}break a}Ok(a,d)}Hd(d);fb=e+80|0;return}a=N()|0;Hd(d);Q(a|0);p()}function $3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{c:{if(hi(b,14337)){d=_s(c+28|0,b);e=x[d>>2];if(!Ed(e)){x[31609]=0;b=P(36,c+4|0,b|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}x[31609]=0;a=c+16|0;S(1011,a|0,17826,b|0);e=x[31609];x[31609]=0;d:{e:{if((e|0)!=1){x[31609]=0;W(1367,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break e}p()}a=N()|0;break d}a=N()|0;tb(c+16|0)}tb(b);break a}Zs(e);if(!Ys(a+8|0,16806,x[d>>2])){v[a+8|0]=v[a+8|0]}if(!Ys(a+9|0,22292,x[d>>2])){v[a+9|0]=v[a+9|0]}x[31609]=0;O(272,a+12|0,22292);a=x[31609];x[31609]=0;if((a|0)==1){break b}gl(d)}fb=c+32|0;return}a=N()|0;break a}a=N()|0}gl(d);Q(a|0);p()}function cla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb+-64|0;fb=c;f=oU(a,1<<b-1);x[f+12>>2]=b;l(0,1413754136-0|0);l(1,-1072094725-((b<<20)+(d>>>0>1413754136)|0)|0);h=+n();a=1;g=1<<b>>>2|0;b=g;while(1){if(b){e=x[10057];d=c+32|0;x[d+8>>2]=x[10056];x[d+12>>2]=e;e=x[10055];x[d>>2]=x[10054];x[d+4>>2]=e;PB(d,h*+(b>>>0));jU(c+48|0,C[c+32>>3],C[c+40>>3]);d=Yd(x[f>>2],a);e=x[c+60>>2];x[d+8>>2]=x[c+56>>2];x[d+12>>2]=e;e=x[c+52>>2];x[d>>2]=x[c+48>>2];x[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=Pl(c+16|0,1,0);b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;AA(f,0,g,c);fb=c- -64|0;return f|0}function Xw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;i=a+1|0;e=f+15|0;fh(b,y[Qb(i,e)|0]);g=y[Qb(a+2|0,e)|0];v[b+13|0]=g;k=b,l=Ld(y[a+3|0],g,d),v[k+14|0]=l;e=y[Qb(a+4|0,e)|0];v[b+15|0]=e;k=b,l=Ld(y[a+5|0],e,d),v[k+16|0]=l;g=a+6|0;e=x[b>>2];b=0;while(1){v[f+14|0]=25;if(b>>>0<y[Qb(f+14|0,i)|0]){d=D(b,3)+g|0;h=Yb(y[d|0]+c<<24>>24,0,64);a=yb(e,b);v[a+2|0]=h;d=y[d+1|0]|y[d+2|0]<<8;w[a>>1]=d;a:{if(!b){break a}h=yb(e,b-1|0);j=z[h>>1];if(d>>>0>255|d>>>0>=j>>>0){break a}d=d|j&65280;w[a>>1]=d;if(z[h>>1]<=(d&65535)>>>0){break a}w[a>>1]=d+256}b=b+1|0;continue}break}fb=f+16|0}function Mka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-80|0;fb=f;d=Rf(f+52|0);x[31609]=0;c=P(827,b|0,d|0)|0;e=x[31609];x[31609]=0;a:{b:{c:{if((e|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31609]=0;R(828,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break b}}break a}e=x[d+4>>2];x[31609]=0;c=f+12|0;e=$b(e);S(185,c|0,b|0,e|0);g=x[31609];x[31609]=0;if((g|0)==1){break a}g=hc(f+32|0,c);kd(d+8|0,g);ub(g);ub(c);d:{c=e&1;if(!c){break d}x[31609]=0;P(183,b|0,2-c|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break d}break a}Ok(a,d)}Hd(d);fb=f+80|0;return}a=N()|0;Hd(d);Q(a|0);p()}function aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);c=x[b>>2];e=c;d=x[b+4>>2];f=d;d=Hk(c,d);c=fb-16|0;fb=c;Rd(c+8|0,x[vb(c+4|0,a)>>2]);b:{c:{if(d){x[31609]=0;O(460,a|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break c}sA(a,e,f,d)}d=c+8|0;Qd(d);am(d);fb=c+16|0;break b}a=N()|0;am(c+8|0);Q(a|0);p()}x[a+20>>2]=x[b+20>>2];c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;x[31609]=0;c=P(921,a+24|0,b+24|0)|0;d=x[31609];x[31609]=0;d:{e:{if((d|0)!=1){x[31609]=0;P(71,a+36|0,b+36|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break e}x[a+48>>2]=x[b+48>>2];break a}b=N()|0;break d}b=N()|0;wc(c)}Mk(a);Q(b|0);p()}}function $aa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb+-64|0;fb=f;d=f+16|0;h=fb-16|0;fb=h;i=nP(h+8|0);l=f+4|0;while(1){if((j|0)==12){fb=h+16|0}else{g=fb+-64|0;fb=g;c=x[i+4>>2];e=x[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=HM(IM(g+8|0,32));break a}e=G(c);e=IM(g+8|0,(c<<e&2147483647?32:31)-e|0);while(1){k=HM(e);if(c>>>0<=k>>>0){continue}break}c=x[i>>2]+k|0}fb=g- -64|0;m=yb(d,j),n=c,x[m>>2]=n;j=j+1|0;continue}break}d=wP(l,d,zP(d));qP(a,d);Wm(d);fb=f- -64|0;d=wz(a+120|0,a,b);v[d+20|0]=1;x[31609]=0;O(1150,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){a=N()|0;uo(d);Q(a|0);p()}return a|0}function pta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=X_(c,d);g=fb-32|0;fb=g;f=b;b=x[a>>2];b=zk(f,wb(b))+b|0;a:{if((e|0)<=0){break a}h=x[Ab(a)>>2];f=x[a+4>>2];if((e|0)<=(h-f|0)){i=g,j=U_(c,e),x[i+12>>2]=j;h=f-b|0;if((e|0)>(h|0)){x[g+12>>2]=c;T_(g+12|0,h);yn(a,x[g+12>>2],d,e-h|0);if((h|0)<=0){break a}}S_(a,b,f,b+e|0);aE(c,x[g+12>>2],b);break a}d=Ab(a);f=pn(g+12|0,Vl(a,Xc(x[a>>2],f)+e|0),b-x[a>>2]|0,d);d=fb-16|0;fb=d;x[d+12>>2]=c;c=BC(d,f+8|0,e);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){qo(e,y[x[d+12>>2]]);e=x[c>>2]+1|0;x[c>>2]=e;we(d+12|0);continue}break}je(c);fb=d+16|0;b=R_(a,f,b);on(f)}wb(b);fb=g+32|0}function PO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;g=Nb(a);a=z[x[b+24>>2]+480192>>1];x[31609]=0;O(176,g|0,a|0);c=x[31609];x[31609]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480192>>1]){break b}c=RR(c,d);x[31609]=0;c=P(36,e+8|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){f=x[b+24>>2];x[31609]=0;d=e+20|0;S(1053,d|0,f|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}x[31609]=0;O(178,g|0,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break d}tb(d);tb(c);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(c);break a}fb=e+32|0;return}a=N()|0}Td(g);Q(a|0);p()}function qW(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;d=vb(f+12|0,x[a+4>>2]);c=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;fd(e+24|0,x[d>>2],x[c>>2]);j=e+16|0;c=x[e+24>>2];k=x[e+28>>2];d=fb-16|0;fb=d;x[d+8>>2]=g;x[d+12>>2]=c;while(1){if(Fd(c,k)){c=bl(c);g=bl(x[d+8>>2]);x[g+8>>2]=x[c+8>>2];l=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=l;c=jk(d+12|0);jk(d+8|0);c=x[c>>2];continue}break}qc(j,c,d+8|0);fb=d+16|0;d=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(i,d,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function iqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Hb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Hb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e)+i|0;a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=a+k|0;f=li(E(Pd(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(128)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=cY(g),v[m|0]=n;a=a+1|0;continue}}}_(17387,8999,27,9541);p()}_(17337,8999,28,9541);p()}fb=c+16|0}function rN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((xo(a)|0)>(b|0)){break d}}a=dc(8);x[31609]=0;d=P(36,d+4|0,10751)|0;b=x[31609];x[31609]=0;if((b|0)==1){break c}sc(a,d);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}if(c<0|c>1){a=dc(8);x[31609]=0;d=P(36,d+4|0,11768)|0;b=x[31609];x[31609]=0;if((b|0)!=1){sc(a,d);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}b=N()|0;lc(a);break b}e=(a+D(b,872)|0)+1075740|0,f=Si(c*64),x[e>>2]=f;fb=d+16|0;return}b=N()|0;lc(a)}Q(b|0)}p()}function Ofa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Qj(b),x[i+4>>2]=j;c=fb-16|0;fb=c;g=a;d=de(a);a:{if(d){f=gc(a);while(1){a=d;d=a+16|0;if(Uu(b,d)){f=a;d=x[a>>2];if(d){continue}break a}if(!Uu(d,b)){break a}f=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(g);f=a}x[c+12>>2]=a;b=x[f>>2];if(!b){a=fb-16|0;fb=a;b=gc(g);b=Dh(c,Ec(40),Og(a+8|0,b));Fb(Uc(x[b>>2]+16|0,x[e+4>>2])+12|0);i=gc(b),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[c+12>>2],f,x[c>>2]);b=ne(c);a=x[c>>2];x[c>>2]=0;if(a){if(y[gc(c)+4|0]){$m(a+16|0)}Db(a)}h=1}_g(e+8|0,x[vb(c,b)>>2],h);fb=c+16|0;a=ud(x[e+8>>2]);fb=e+16|0;return a+12|0}function CO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;g=Nb(a);a=z[x[b+24>>2]+480190>>1];x[31609]=0;O(176,g|0,a|0);c=x[31609];x[31609]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480190>>1]){break b}x[31609]=0;c=P(36,e+8|0,SR(c,d)|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){f=x[b+24>>2];x[31609]=0;d=e+20|0;S(1053,d|0,f|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}x[31609]=0;O(178,g|0,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break d}tb(d);tb(c);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+20|0)}tb(c);break a}fb=e+32|0;return}a=N()|0}Td(g);Q(a|0);p()}function FY(a){var b=0,c=0,d=0,e=0,f=0;b=fb-32|0;fb=b;e=b,f=$b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788|0,x[e>>2]=f;x[b+4>>2]=0;e=b,f=$b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),x[e+8>>2]=f;x[b+12>>2]=0;c=$b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24));x[b+16>>2]=c?c:52;x[b+20>>2]=0;e=b,f=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+80|0,x[e+24>>2]=f;x[b+28>>2]=0;a=b;d=Se(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Rw(x[a>>2],x[a+4>>2],x[c>>2],x[c+4>>2])?c:a;continue}}fb=b+32|0;c=x[a>>2];b=c-52|0;hb=x[a+4>>2]-(c>>>0<52)|0;return b}function Soa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;nd(b,0);f=d+8|0;dk(f,1,a);c=d+20|0;Cc(c,f);Be(b+43|0,c);tb(c);x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+24>>2]=y[a+62|0]|y[a+63|0]<<8;_l(b,+((y[a+60|0]^8)-120|0)/192);v[d+20|0]=y[a+61|0];v[d+8|0]=64;g=b,h=y[Qb(c,f)|0]<<2,w[g+30>>1]=h;w[b+34>>1]=0;c=y[a+47|0];if(c&4){w[b+34>>1]=1;x[b>>2]=x[b>>2]>>>1;e=1;c=y[a+47|0]}if(c&32){e=e|4;w[b+34>>1]=e;c=y[a+47|0]}if(c<<24>>24<0){w[b+34>>1]=e|2}fb=d+32|0}
function Mna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;a:{if(!(c&1024)){break a}i=g,j=zd(b),x[i+12>>2]=j;c=_c(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[ec(b,0)|0]!=43){if(y[ec(b,0)|0]!=45){break b}}d=d+1|0;hV(g+12|0)}if(c>>>0>=d>>>0){break a}e=x[vb(g+8|0,x[g+12>>2])>>2];c=d-_c(x[b+4>>2],y[b+11|0])|0;c:{e=zk(e,zd(b));d=Cb(x[b+4>>2],y[b+11|0]);if(e>>>0<=d>>>0){if(c){f=Mc(b);d:{if(c>>>0<=f-d>>>0){f=Kb(b);if((d|0)==(e|0)){break d}h=e+f|0;Ni(c+h|0,h,d-e|0);break d}UB(b,f,(c+d|0)-f|0,d,e,c);f=x[b>>2]}$l(e+f|0,c,48);c=c+d|0;lg(b,c);hd(c+f|0,0)}break c}dn();p()}zd(b)}Uc(a,b);fb=g+16|0}function sua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-208|0;fb=d;v0(c,a);u0(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}c=fb-16|0;fb=c;x[c+12>>2]=64;x[c+8>>2]=255;e=y[Hb(c+12|0,c+8|0)|0];fb=c+16|0;v[d+12|0]=e;fh(b,y[Qb(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;e=x[b>>2];f=Sd(e,x[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=y[d+18|0];c=yb(e,0);break b}g=z[yb(e,a-1|0)>>1];x[d+12>>2]=1;b=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[b+1|0]&1)<<8|y[b|0];h=Ye(d+12|0,d+8|0);c=yb(e,a);w[c>>1]=z[h>>1]+g;b=y[b+2|0]}v[c+2|0]=b;a=a+1|0;continue}}fb=d+208|0}function gn(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;j=1;i=d&2147483647;k=i;l=(i|0)==2147418112;a:{if(l&!c?a|b:l&(c|0)!=0|i>>>0>2147418112){break a}i=h&2147483647;if(!g&(i|0)==2147418112?e|f:(i|0)==2147418112&(g|0)!=0|i>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(i|k)))){return 0}j=d&h;if((j|0)>0){k=1}else{k=(j|0)>=0}if(k){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}j=(a^e|c^g|(b^f|d^h))!=0}return j}function dV(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+798|0]=0;return}v[a+798|0]=1;return}v[a+798|0]=2;return}v[a+798|0]=3;return}v[a+730|0]=y[a+730|0]&254;return}v[a+730|0]=y[a+730|0]|1;return}v[a+738|0]=y[a+738|0]&254;return}v[a+738|0]=y[a+738|0]|1;return}v[a+746|0]=y[a+746|0]&254;return}v[a+746|0]=y[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=y[a+746|0];v[c+746|0]=(b|0)==13?a&238|1:a|17}}function GK(a,b,c){var d=0,e=0;if(!b){return 0}a:{b:{if(!c){break b}d=y[b|0];e=d<<24>>24;if((e|0)>=0){if(a){x[a>>2]=d}return(e|0)!=0}if(!x[x[124115]>>2]){b=1;if(!a){break a}x[a>>2]=e&57343;return 1}d=d-194|0;if(d>>>0>50){break b}d=x[(d<<2)+120704>>2];if(d<<D(c,6)-6<0&c>>>0<=3){break b}c=y[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){b=2;if(!a){break a}x[a>>2]=c;return 2}d=y[b+2|0]-128|0;if(d>>>0>63){break b}e=d;d=c<<6;c=e|d;if((d|0)>=0){b=3;if(!a){break a}x[a>>2]=c;return 3}d=y[b+3|0]-128|0;if(d>>>0>63){break b}b=4;if(!a){break a}x[a>>2]=d|c<<6;return 4}x[31484]=25;b=-1}return b}function u3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(lh(a,x[b+8>>2],f)){Wx(b,c,d,e);return}h=y[b+53|0];g=x[a+12>>2];v[b+53|0]=0;i=y[b+52|0];v[b+52|0]=0;j=a+16|0;Sx(x[j>>2],x[a+20>>2],b,c,d,e,f);k=y[b+52|0];i=(i|k)!=0;l=y[b+53|0];h=(h|l)!=0;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(y[b+54|0]){break a}b:{if(k){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!l){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;Sx(x[g>>2],x[g+4>>2],b,c,d,e,f);l=y[b+53|0];h=(l|h)!=0;k=y[b+52|0];i=(k|i)!=0;g=g+8|0;if(j>>>0>g>>>0){continue}break}}v[b+53|0]=h;v[b+52|0]=i}function ksa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Rf(d+52|0);x[31609]=0;c=P(410,b|0,e|0)|0;f=x[31609];x[31609]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31609]=0;R(411,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break a}}break c}c=fb-16|0;fb=c;g=c,h=$b(x[e+4>>2]),x[g+12>>2]=h;x[c+8>>2]=8;f=bd(c+12|0,c+8|0);fb=c+16|0;c=x[f>>2]-8|0;x[31609]=0;S(185,d+12|0,b|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}a=N()|0;Hd(e);Q(a|0);p()}b=d+12|0;c=hc(d+32|0,b);kd(e+8|0,c);ub(c);ub(b);Ok(a,e)}Hd(e);fb=d+80|0}function Qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=c;e=fb-16|0;fb=e;h=b;d=de(b);a:{if(d){c=gc(b);while(1){b=d;d=b+16|0;if(xR(f,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!xR(d,f)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=gc(h);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=gc(h);d=Dh(e,Ec(28),Og(b+8|0,d));i=x[d>>2];x[31609]=0;O(889,i+16|0,f|0);f=x[31609];x[31609]=0;b:{if((f|0)!=1){j=gc(d),k=1,v[j+4|0]=k;fb=b+16|0;break b}a=N()|0;wR(d);Q(a|0);p()}$g(h,x[e+12>>2],c,x[e>>2]);b=ne(e);wR(e);i=1}c=g+8|0;_g(c,x[vb(e,b)>>2],i);fb=e+16|0;bV(a,c);fb=g+16|0}function fq(a,b,c,d){var e=0,f=0,g=0,h=0;g=d?d:497536;d=x[g>>2];a:{b:{c:{if(!b){if(d){break c}return 0}e=-2;if(!c){break b}d:{if(d){e=c;break d}d=y[b|0];f=d<<24>>24;if((f|0)>=0){if(a){x[a>>2]=d}return(f|0)!=0}if(!x[x[124115]>>2]){e=1;if(!a){break b}x[a>>2]=f&57343;return 1}d=d-194|0;if(d>>>0>50){break c}d=x[(d<<2)+120704>>2];e=c-1|0;if(!e){break a}b=b+1|0}f=y[b|0];h=f>>>3|0;if((h-16|(d>>26)+h)>>>0>7){break c}while(1){e=e-1|0;d=f-128|d<<6;if((d|0)>=0){x[g>>2]=0;if(a){x[a>>2]=d}return c-e|0}if(!e){break a}b=b+1|0;f=y[b|0];if((f&192)==128){continue}break}}x[g>>2]=0;x[31484]=25;e=-1}return e}x[g>>2]=d;return-2}function pQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;mh(e+8|0,b);f=fb-16|0;fb=f;lf(f+8|0,x[e+8>>2],x[e+12>>2]);g=x[f+8>>2];b=x[f+12>>2];h=fb-16|0;fb=h;l=h,m=wb(a),x[l+12>>2]=m;a=b;b=fb-16|0;fb=b;i=x[h+12>>2];c=i;d=x[c+8>>2];c=x[c+12>>2];a:{if((c|0)<0){break a}j=x[i+4>>2];k=d>>>0>j>>>0;if(k&!c|c){break a}x[b+8>>2]=j-d;x[b+12>>2]=0-(c+k|0);x[b>>2]=a;x[b+4>>2]=0;c=t0(b+8|0,b);if((Tu(x[c>>2],x[c+4>>2])|0)!=(a|0)){break a}xk(g,a+g|0,d+x[i>>2]|0);d=x[h+12>>2];g=d;c=x[d+8>>2];d=x[d+12>>2];i=a;a=a+c|0;d=i>>>0>a>>>0?d+1|0:d;x[g+8>>2]=a;x[g+12>>2]=d}fb=b+16|0;fb=h+16|0;fb=f+16|0;fb=e+16|0}function QA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;b=x[a>>2];if(!mc(b,x[a+4>>2])){b=wb(b);x[e+12>>2]=b;f=wb(x[a+4>>2]);while(1){if(Ib(b,f)){Fp(b,4194304,67108864);b=x[b>>2];d=b+d|0;c=b>>>0>d>>>0?c+1|0:c;b=x[Xe(e+12|0)>>2];continue}else{b=x[a>>2];f=oc(b,x[a+4>>2]);b=wb(b);x[e+8>>2]=b;g=f<<24;d=Cua(d,c,f,0);h=((hb&1)<<31|d>>>1)&2147483647;i=wb(x[a+4>>2]);while(1){if(Ib(b,i)){f=b;b=x[b>>2];c=b>>>8|0;b=h+(b<<24)|0;c=c+j|0;c=Bc(Cua(b,b>>>0<h>>>0?c+1|0:c,d,j),hb);x[f>>2]=c;g=g-c|0;b=x[Xe(e+8|0)>>2];continue}else{c=x[a>>2];if(!oc(c,x[a+4>>2])){Iw();p()}x[c>>2]=x[c>>2]+g}break}}break}}fb=e+16|0}function FD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;fh(b,Ld(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;f=((c|0)!=0)<<1;h=x[b>>2];j=Sd(h,x[b+4>>2]);k=(a+160|0)+(c<<6)|0;c=(c|0)==2?255:0;while(1){if((d|0)==(j|0)){ED(b,32);fb=e+16|0}else{a=k+(d<<2)|0;w[e+12>>1]=y[a|0]|y[a+1|0]<<8;g=qe(e+14|0,e+12|0);i=yb(h,d);g=z[g>>1];w[i>>1]=g;w[e+14>>1]=g+1;v[e+11|0]=(c^y[a+2|0])>>>f;v[e+10|0]=64;l=i,m=y[Qb(e+11|0,e+10|0)|0],v[l+2|0]=m;d=d+1|0;continue}break}}function H8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(mc(b,-1)){break c}e=b<<24>>24;v[c+23|0]=e;if(y[a+44|0]){d=-1;f=x[a+32>>2];a=fb-16|0;fb=a;v[a+15|0]=e;e=im(a+15|0,1,1,f);fb=a+16|0;if((e|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=pr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((im(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((im(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=Qy(b);break a}d=-1}fb=c+32|0;return d|0}function MB(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);g=x[vb(f+4|0,x[b+4>>2])>>2];h=fb-16|0;fb=h;i=h+8|0;e=fb-32|0;fb=e;fd(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=g;x[c+12>>2]=d;while(1){if(Fd(d,k)){d=Ip(d);g=Ip(x[c+8>>2]);l=x[d+4>>2];x[g>>2]=x[d>>2];x[g+4>>2]=l;d=gs(c+12|0);gs(c+8|0);d=x[d>>2];continue}break}qc(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(i,c,e+12|0);fb=e+32|0;fb=h+16|0;x[b+4>>2]=x[h+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Li(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=c*d;k=b*e;h=j+k;l=b*d;m=c*e;i=l-m;a:{if(!Oi(i)){break a}if(!Oi(h)){break a}f=Af(b);g=Af(c);n=f|g;b:{if((n|0)!=1){break b}b=ji(f?1:0,b);c=ji(g?1:0,c);if(Oi(d)){d=ji(0,d)}if(!Oi(e)){break b}e=ji(0,e)}f=Af(d);g=Af(e);c:{if(f|g){d=ji(f?1:0,d);e=ji(g?1:0,e);if(Oi(b)){b=ji(0,b)}if(!Oi(c)){break c}c=ji(0,c);break c}if(n){break c}d:{if(Af(l)){break d}if(Af(m)){break d}if(Af(k)){break d}if(!Af(j)){break a}}if(Oi(b)){b=ji(0,b)}if(Oi(c)){c=ji(0,c)}if(Oi(d)){d=ji(0,d)}if(!Oi(e)){break c}e=ji(0,e)}h=(b*e+d*c)*Infinity;i=(b*d-e*c)*Infinity}Pl(a,i,h)}function Ci(a,b,c,d){var e=0,f=0,g=0;e=fb-48|0;fb=e;f=x[x[a>>2]-12>>2]+a|0;g=x[f+16>>2]&-3;ig(f,g);a:{b:{if(Id(y[Gm(e+47|0,a,1)|0])){f=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31609]=0;Ns(86,e+24|0,f,b,c,d);b=x[31609];x[31609]=0;c:{if((b|0)!=1){b=ai(e+8|0,-1,-1);d=bo(x[e+32>>2],x[e+36>>2],x[b+8>>2],x[b+12>>2])?g|4:g;break c}Y(T(0)|0)|0;d=g|1;Em(x[x[a>>2]-12>>2]+a|0,d);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31609]=0;X(84);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}Wj(x[x[a>>2]-12>>2]+a|0,d)}fb=e+48|0;return a}T(0)|0;Sb()}p()}function Gqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Qj(b),x[i+4>>2]=j;f=z[b>>1];d=fb-16|0;fb=d;g=a;c=de(a);a:{if(c){b=gc(a);while(1){a=c;c=z[a+14>>1];if($o(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!$o(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=gc(g);f=Dh(d,Ec(20),Og(a+8|0,c));c=x[f>>2];h=z[x[e+4>>2]>>1];w[c+16>>1]=0;w[c+14>>1]=h;i=gc(f),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[d+12>>2],b,x[d>>2]);a=ne(d);Ik(d);h=1}_g(e+8|0,x[vb(d,a)>>2],h);fb=d+16|0;a=dp(x[e+8>>2]);fb=e+16|0;return a+2|0}function tL(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-208|0;fb=f;x[f+204>>2]=c;c=f+160|0;Rb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((sL(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]<0;g=x[a>>2];x[a>>2]=g&-33;b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(Uw(a)){break b}}c=sL(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){ib[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(i){break a}}fb=f+208|0;return e}function XZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Qj(b),x[i+4>>2]=j;f=x[b>>2];d=fb-16|0;fb=d;g=a;c=de(a);a:{if(c){b=gc(a);while(1){a=c;c=x[a+16>>2];if(sE(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!sE(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=gc(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=gc(g);f=Dh(d,Ec(24),Og(a+8|0,c));c=x[f>>2];h=x[x[e+4>>2]>>2];x[c+20>>2]=0;x[c+16>>2]=h;i=gc(f),j=1,v[i+4|0]=j;fb=a+16|0;$g(g,x[d+12>>2],b,x[d>>2]);a=ne(d);Ik(d);h=1}_g(e+8|0,x[vb(d,a)>>2],h);fb=d+16|0;a=ud(x[e+8>>2]);fb=e+16|0;return a+4|0}function Tt(a,b,c){var d=0,e=0;d=a,e=sj(E(E(B[c+1792>>2]*E(75038))+E(E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489))+E(E(E(B[c+1280>>2]+B[c+2304>>2])*E(6574))+E(E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153))+E(E(E(B[c+768>>2]+B[c+2816>>2])*E(2037))+E(E(E(B[c+3072>>2]-B[c+512>>2])*E(459))+E(E(E(B[c+256>>2]+B[c+3328>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))))))))),w[d>>1]=e;d=(b<<5)+a|0,e=sj(E(E(B[c+8>>2]*E(-5))+E(E(B[c+520>>2]*E(146))+E(E(B[c+1032>>2]*E(-45))+E(E(B[c+1544>>2]*E(-9975))+E(E(B[c+2056>>2]*E(64019))+E(E(B[c+2568>>2]*E(9727))+E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))))))))),w[d>>1]=e}function ES(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a:{if(x[a+480180>>2]!=1){break a}c=y[b+846|0];if(!c){break a}e=x[b+104>>2];if(!e){break a}if(!le(x[e>>2],x[e+20>>2])){break a}f=z[e+34>>1];if(!(f&10)){break a}c=y[b+847|0]+y[(c&15)+31600|0]|0;v[b+847|0]=c;if(c<<24>>24>=0){break a}v[b+847|0]=0;h=f&2;c=x[(h?4:12)+e>>2];g=b;b=x[b+760>>2]+1|0;b=b>>>0<x[(h?8:16)+e>>2]-c>>>0?b:0;x[g+760>>2]=b;g=x[e+20>>2];c=b+c|0;b=Zk(f);cc(d+8|0,g+D(c,b)|0,b);b=wb(x[d+8>>2]);x[d+4>>2]=b;f=Yj(x[d+8>>2],x[d+12>>2]);while(1){if(Ib(b,f)){v[b|0]=y[b|0]^-1;b=x[we(d+4|0)>>2];continue}else{Ij(e,a)}break}}fb=d+16|0}function hka(a){a=a|0;var b=0,c=0,d=0;b=1074992;while(1){if((b|0)==1298224){Du(a+484344|0);sf(a+1298308|0);sf(a+1298320|0);sf(a+1298332|0);Nc(a+1298412|0);c=484380;while(1){a:{b=900380;if((c|0)==900380){while(1){if((b|0)==901404){b=a+906300|0;c=uk(b);while(1){if((b|0)==(c|0)){break a}d0(b);b=b+160|0;continue}}c=a+b|0;d=x[c>>2];if(d){Db(Mv(d))}x[c>>2]=0;b=b+4|0;continue}}else{nn(a+c|0);c=c+104|0;continue}}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0}else{c=a+b|0;x[c+104>>2]=0;x[c+656>>2]=0;x[c+76>>2]=0;x[c+16>>2]=0;b=b+872|0;continue}break}}function $fa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=fb-80|0;fb=d;x[d+76>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];x[d+48>>2]=x[a+8>>2];x[d+52>>2]=f;x[d+40>>2]=c;x[d+44>>2]=e;a=Md(d+32|0);c=x[d+52>>2];x[d+16>>2]=x[d+48>>2];x[d+20>>2]=c;x[31609]=0;c=x[d+44>>2];x[d+8>>2]=x[d+40>>2];x[d+12>>2]=c;c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;a=d+56|0;S(980,a|0,d+8|0,d|0);c=x[31609];x[31609]=0;a:{b:{if((c|0)!=1){c=d+76|0;e=x[re(d+28|0,c)>>2];x[31609]=0;b=+pa(981,a|0,+b,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break b}ub(a);Wc(c);fb=d+80|0;return+b}a=N()|0;break a}a=N()|0;ub(d+56|0)}Wc(d+76|0);Q(a|0);p()}function hpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;a:{c=x[a+12>>2];b:{if((c|0)==(b|0)){break b}f=b>>>0>c>>>0;c=D(z[x[x[a+48>>2]+12>>2]+480188>>1],f?b-c|0:c-b|0);d=wb(x[a+4>>2]);c:{if(f){d=vb(e+28|0,d);w[e+24>>1]=0;x[e+20>>2]=0;d=x[d>>2];x[31609]=0;V(663,a|0,d|0,c|0,e+20|0);c=x[31609];x[31609]=0;if((c|0)!=1){break c}a=T(124540)|0;if((gb|0)!=($(124540)|0)){break a}Y(a|0)|0;Z();break b}c=vb(e+16|0,QD(d,c));d=x[vb(e+12|0,wb(x[a+4>>2]))>>2];f=x[c>>2];c=x[a>>2];c=D(wu(f,wb(c)),6)+c|0;if(Ib(f,d)){Jd(a,uA(c+D(wu(d,f),6)|0,x[a+4>>2],c))}wb(c)}x[a+12>>2]=b}fb=e+32|0;return}Q(a|0);p()}function P8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(ko(b)){break c}x[c+20>>2]=b;if(y[a+44|0]){d=-1;a=x[a+32>>2];d:{if(x[a+76>>2]<0){a=FK(b,a);break d}a=FK(b,a)}if((a|0)!=-1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=pr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((im(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((im(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=ko(b)?0:b;break a}d=-1}fb=c+32|0;return d|0}function nA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0);f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;fd(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(Fd(d,k)){d=xf(d);l=xf(x[c+8>>2]),m=B[d>>2],B[l>>2]=m;d=wj(c+12|0);wj(c+8|0);d=x[d>>2];continue}break}qc(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>18|0;n=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){g=(e<<1)+n|0;h=w[g>>1];x[(e<<2)+b>>2]=h+((D(w[g+4>>1]-h|0,m)|0)/16384|0);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function T7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+16|0;cd(a,x[c+28>>2]);x[31609]=0;b=R(1253,x[f+16>>2])|0;c=x[31609];x[31609]=0;b:{if((c|0)!=1){_b(a);c:{if(e){ei(a,b);break c}di(f+16|0,b)}g=f,h=zd(f+16|0),x[g+12>>2]=h;while(1){a=f+16|0;b=nl(a);c=x[f+12>>2];if(!Ib(c,b)){c=x[f+28>>2];Ub(a);break a}a=x[c>>2];x[31609]=0;P(1268,f+28|0,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){Xe(f+12|0);continue}break}c=N()|0;Ub(f+16|0);break b}c=N()|0;_b(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function qH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=g+4|0;v[e+8|0]=1;x[e+4>>2]=c;x[e>>2]=a;h=y[e+8|0];a=x[e>>2];i=x[e+4>>2];j=Kb(b);b=Cb(x[b+4>>2],y[b+11|0]);d=fb-16|0;fb=d;x[d+8>>2]=b;x[d+12>>2]=i;b=a;e=x[Hb(d+12|0,d+8|0)>>2];f=e;while(1){a:{if(!f){f=0;break a}c=y[j|0];v[b|0]=c;if(!c){break a}j=j+1|0;b=b+1|0;f=f-1|0;continue}break}b:{if((h-1&255)>>>0<=1){v[d+7|0]=0;Qm(b,((b+i|0)-e|0)+f|0,d+7|0);break b}if((h-3&255)>>>0>1){break b}v[d+6|0]=32;Qm(b,((b+i|0)-e|0)+f|0,d+6|0)}c:{switch(h-1|0){case 0:case 3:v[(x[d+12>>2]+a|0)-1|0]=0;break;default:break c}}fb=d+16|0;fb=g+16|0}function Dy(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;h=f+12|0;cd(h,b);x[31609]=0;b=R(1252,x[f+12>>2])|0;g=x[31609];x[31609]=0;a:{if((g|0)==1){break a}x[31609]=0;V(1263,b|0,95168,95200,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}x[31609]=0;b=R(1253,x[f+12>>2])|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;c=R(1264,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break a}x[d>>2]=c;x[31609]=0;c=R(1261,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}x[e>>2]=c;x[31609]=0;O(1262,a|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break a}_b(h);fb=f+16|0;return}a=N()|0;_b(f+12|0);Q(a|0);p()}function b8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+16|0;cd(a,x[c+28>>2]);x[31609]=0;b=R(1235,x[f+16>>2])|0;c=x[31609];x[31609]=0;b:{if((c|0)!=1){_b(a);c:{if(e){ei(a,b);break c}di(f+16|0,b)}g=f,h=zd(f+16|0),x[g+12>>2]=h;while(1){a=f+16|0;b=Df(a);c=x[f+12>>2];if(!Ib(c,b)){c=x[f+28>>2];tb(a);break a}a=v[c|0];x[31609]=0;P(30,f+28|0,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){we(f+12|0);continue}break}c=N()|0;tb(f+16|0);break b}c=N()|0;_b(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function Sm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;fd(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(Fd(d,k)){d=xf(d);l=xf(x[c+8>>2]),m=x[d>>2],x[l>>2]=m;d=wj(c+12|0);wj(c+8|0);d=x[d>>2];continue}break}qc(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function a4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{if(hi(b,14337)){d=_s(c+28|0,b);e=x[d>>2];if(!Ed(e)){x[31609]=0;b=P(36,c+4|0,b|0)|0;a=x[31609];x[31609]=0;c:{d:{e:{if((a|0)!=1){x[31609]=0;a=c+16|0;S(1011,a|0,17759,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break e}x[31609]=0;W(1367,a|0);a=x[31609];x[31609]=0;if((a|0)==1){break d}p()}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(c+16|0)}tb(b);break a}Zs(e);_p(a+8|0,16806,x[d>>2]);_p(a+12|0,22292,x[d>>2]);x[31609]=0;O(272,a+16|0,22292);a=x[31609];x[31609]=0;if((a|0)==1){break b}gl(d)}fb=c+32|0;return}a=N()|0}gl(d);Q(a|0);p()}function Hy(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;h=f+12|0;cd(h,b);x[31609]=0;b=R(28,x[f+12>>2])|0;g=x[31609];x[31609]=0;a:{if((g|0)==1){break a}x[31609]=0;V(1249,b|0,95168,95200,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}x[31609]=0;b=R(1235,x[f+12>>2])|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;c=R(1250,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break a}v[d|0]=c;x[31609]=0;c=R(1247,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}v[e|0]=c;x[31609]=0;O(1248,a|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break a}_b(h);fb=f+16|0;return}a=N()|0;_b(f+12|0);Q(a|0);p()}function fh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=fb-16|0;fb=c;b=xh(c+4|0,a,b);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){jc(b);fb=c+16|0}else{Ww(a);a=a+4|0;x[b+4>>2]=a;continue}break}break a}c=Ab(a);c=Zf(e+12|0,Lf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Fn(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Ww(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}je(b);fb=f+16|0;Zr(a,c);Yf(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<2)|0)}}function i3(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-32|0;fb=k;m=x[c>>2];l=x[c+8>>2];c=x[c+4>>2];x[k+8>>2]=c;x[k+12>>2]=l;x[k+24>>2]=c;x[k+28>>2]=l;x[k+20>>2]=m;x[k+16>>2]=d;x[31609]=0;c=x[k+20>>2];x[k>>2]=x[k+16>>2];x[k+4>>2]=c;a=Ia(1094,a|0,b|0,k|0)|0;b=x[31609];x[31609]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31609]=0;ga(979,10431,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}Z();a=-255}fb=k+32|0;break a}b=N()|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)!=1){Q(b|0);p()}T(0)|0;Sb();p()}return a|0}function Gm(a,b,c){var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;v[a|0]=0;a:{d=x[b>>2];e=x[d-12>>2]+b|0;b:{if(!x[e+16>>2]){e=x[e+72>>2];if(e){sp(e);d=x[b>>2]}c:{if(c){break c}c=x[d-12>>2]+b|0;if(!(y[c+5|0]&16)){break c}d=f+12|0;cd(d,x[c+28>>2]);x[31609]=0;e=R(28,x[f+12>>2])|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}_b(d);c=qp(f+8|0,b);d=tc(f+4|0);while(1){d:{if(th(c,d)){break d}g=tl(x[c>>2]);if(!Jf(x[e+8>>2],1,g)){break d}Fm(c);continue}break}if(th(c,d)){Wj(x[x[b>>2]-12>>2]+b|0,6)}d=x[b>>2]}v[a|0]=!x[(x[d-12>>2]+b|0)+16>>2];break b}Wj(e,4)}fb=f+16|0;return a}a=N()|0;_b(f+12|0);Q(a|0);p()}function AL(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[496352]){f=496353,g=Qa()|0,v[f|0]=g;v[496352]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[496353]){break c}d=+Ga();break a}x[31484]=28;return-1}d=+Xa()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=~~c>>>0;if(F(c)>=1){a=~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0}else{a=0}break e}a=-2147483648}x[b>>2]=e;x[b+4>>2]=a;c=(d-(+(Aua(e,a,1e3,0)>>>0)+ +(hb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function Yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>10&4194048;n=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){g=e+n|0;h=v[g|0];x[(e<<2)+b>>2]=((D(v[g+2|0]-h|0,m)|0)/16384|0)+(h<<8);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Pb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Dta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{b:{if(b){x[31609]=0;O(321,a|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break b}e=fb-16|0;fb=e;d=Cr(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){jc(d);fb=e+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4;b=b+6|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Qd(b);am(b);fb=c+16|0;break a}a=N()|0;am(c+8|0);Q(a|0);p()}v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function ae(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a=ai(a,-1,-1);a:{b:{if(Id(y[Gm(c+31|0,b,1)|0])){d=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31609]=0;Ns(86,c+8|0,d,0,0,1);d=x[31609];x[31609]=0;c:{if((d|0)!=1){d=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=d;d=x[c+20>>2];x[a+8>>2]=x[c+16>>2];x[a+12>>2]=d;break c}Y(T(0)|0)|0;e=1;Em(x[x[b>>2]-12>>2]+b|0,1);if(x[(x[x[b>>2]-12>>2]+b|0)+20>>2]&1){x[31609]=0;X(84);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}Wj(x[x[b>>2]-12>>2]+b|0,e)}fb=c+32|0;return}T(0)|0;Sb()}p()}function WM(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];x[a>>2]=b;if(c){x[31609]=0;W(853,c|0);a=x[31609];x[31609]=0;a:{if((a|0)!=1){d=x[c+4>>2];if(d){e=fb-16|0;fb=e;f=vb(e+12|0,d);a=x[f>>2];if(x[a>>2]){g=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(g|0)){b=b-4|0;mg(b);continue}break}x[a+4>>2]=g;a=x[f>>2];b=x[a>>2];Vg(a);Db(b)}fb=e+16|0;Db(d)}x[c+4>>2]=0;oS(c+1298412|0);YA(c+1298344|0);tb(c+1298332|0);tb(c+1298320|0);tb(c+1298308|0);XA(c+1298304|0);WA(c+1298300|0);Ru(c+1298264|0);kB(c+1074376|0);nS(c+906300|0);_B(c+484360|0);fS(c+484344|0);wc(c+480248|0);break a}T(0)|0;Sb();p()}Db(c)}}function Hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)==1){break c}x[31609]=0;W(997,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}e=x[a+24>>2];b=pc(d+12|0,b);x[31609]=0;c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;c=d+20|0;V(1009,c|0,e|0,d|0,1);b=x[31609];x[31609]=0;if((b|0)==1){break c}b=Cg(Kb(c));tb(c);break b}Y(T(0)|0)|0;b=0;x[31609]=0;V(983,5535,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z()}fb=d+32|0;return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function n4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a:{g=fb+-64|0;fb=g;h=g+16|0;ao(h,c);x[31609]=0;c=g+28|0;O(91,c|0,d|0);d=x[31609];x[31609]=0;b:{c:{d:{if((d|0)==1){break d}x[31609]=0;c=g+40|0;O(91,c|0,e|0);d=x[31609];x[31609]=0;if((d|0)==1){break d}x[31609]=0;c=g+52|0;O(91,c|0,f|0);d=x[31609];x[31609]=0;if((d|0)==1){break d}cy(g+8|0,h);x[31609]=0;V(92,a|0,b|0,x[g+8>>2],x[g+12>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}yI(h);fb=g- -64|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=N()|0;yI(g+16|0)}Q(a|0);p()}}function Rsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;c=65535;e=x[a>>2];a:{if($c(e,x[a+4>>2])>>>0<=b>>>0){break a}e=z[ac(e,b)>>1];b:{if(!Wi(a,b)){break b}c=x[a+24>>2];d=wb(x[c+484360>>2]);x[g+12>>2]=d;h=wb(x[c+484364>>2]);while(1){if(!Ib(d,h)){break b}f=0;i=cm(x[d>>2],x[d+4>>2]);while(1){if((f|0)!=(i|0)){c:{if(!((a|0)!=(d|0)|(b|0)!=(f|0))|(e|0)!=z[ac(x[d>>2],f)>>1]){break c}c=BX(x[a+24>>2]+484344|0,e);if((c|0)==65535){break c}j=ac(x[a>>2],b),k=c,w[j>>1]=k;break a}f=f+1|0;continue}break}d=x[Zq(g+12|0)>>2];continue}}c=e}fb=g+16|0;return c&65535}function al(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;f=a+36|0;c=x[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=x[a+20>>2];if(d>>>0>=A[a+24>>2]){wl(e,f,xG(f));sd(e+8|0,a,x[e>>2],x[e+4>>2]);c=x[e+12>>2];x[a+24>>2]=c;x[a+20>>2]=0;if(!c){break c}d=0;c=x[a+32>>2]}x[a+20>>2]=d+1;g=y[d+f|0];d=c+8|0;x[a+32>>2]=d;x[a+28>>2]=x[a+28>>2]|g<<c;c=d;continue}break}a=dc(8);x[31609]=0;b=R(161,a|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break a}b=N()|0;lc(a);Q(b|0);p()}x[a+32>>2]=c-b;d=a;a=x[a+28>>2];x[d+28>>2]=a>>>b;fb=e+16|0;return a&(-1<<b^-1)}da(b|0,28816,162);p()}function $g(a,b,c,d){var e=0,f=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;b=x[x[a>>2]>>2];if(b){x[a>>2]=b;d=x[c>>2]}f=x[gc(a)>>2];v[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=x[d+8>>2];if(y[c+12|0]){break a}b=x[c+8>>2];b:{if(mi(c)){e=x[b+4>>2];if(!(!e|y[e+12|0])){break b}if(!mi(d)){or(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;nr(b);break a}e=x[b>>2];if(!(!e|y[e+12|0])){break b}if(mi(d)){nr(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;or(b);break a}v[c+12|0]=1;v[b+12|0]=(b|0)==(f|0);v[e+12|0]=1;d=b;continue}break}a=Ab(a);x[a>>2]=x[a>>2]+1}function aG(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=D(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),5)+(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24));x[b+8>>2]=(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))+((y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))<<3);x[b+12>>2]=(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+((y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24))<<2);a=b+4|0;d=yb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Fk(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;return x[a>>2]-36|0}function g3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=fb-16|0;fb=c;x[31609]=0;W(996,a|0);e=x[31609];x[31609]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[31609]=0;W(997,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break d}e=x[a+24>>2];b=pc(c+8|0,b);x[31609]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;Ns(1017,e,c,f,d,1);d=x[31609];x[31609]=0;b=1;if((d|0)!=1){break c}}Y(T(0)|0)|0;x[31609]=0;V(983,8658,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break b}Z();b=0}fb=c+16|0;break a}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return b|0}function xr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;PE(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;v[b+31|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function lna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=kg(1,2);e=hb;j=e;Pb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=((((x[b+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=w[(f<<1)+g>>1];f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Pb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Ig(a,h,j);fb=b+16|0}function ML(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(ff(a)){bc(a,31);return 0}h=a,i=ff(a),v[h+1375|0]=i;d=rj(a);b=rj(a);rj(a);h=a,i=rj(a),x[h+1112>>2]=i;rj(a);c=ff(a);x[a+1116>>2]=c;e=a+1120|0;if(!ez(a,e,c)){bc(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[e+b|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){b=0;f=x[a+1116>>2];g=(f|0)>0?f:0;c=0;while(1){if((b|0)!=(g|0)){c=y[b+e|0]+c|0;b=b+1|0;continue}break}x[a+64>>2]=d;x[a+60>>2]=(x[a+56>>2]+(c+f|0)|0)+27}x[a+1380>>2]=0;return 1}function pha(a){a=a|0;var b=0,c=0,d=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2];b=Gc(Bua(Aua(b,b>>31,3840,0),hb,1e3,0),hb);x[a+4316>>2]=b;x[31609]=0;x[c+12>>2]=0;d=b;b=c+12|0;S(947,a+4264|0,d|0,b|0);d=x[31609];x[31609]=0;a:{b:{c:{if((d|0)!=1){d:{if(!y[a+4260|0]){break d}d=x[a+4316>>2];x[31609]=0;x[c+12>>2]=0;S(947,a+4276|0,d|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break d}b=T(124540)|0;break c}x[c+12>>2]=0;b=c+12|0;gQ(a+4288|0,b);x[c+12>>2]=0;gQ(a+4300|0,b);break b}b=T(124540)|0}if((gb|0)!=($(124540)|0)){break a}Y(b|0)|0;x[a+4316>>2]=0;Z()}fb=c+16|0;return}Q(b|0);p()}function FQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;fd(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(Fd(d,k)){d=DQ(d);zc(DQ(x[c+8>>2]),d,2048);d=CQ(c+12|0);CQ(c+8|0);d=x[d>>2];continue}break}qc(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function Wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;e=x[a+40>>2];f=x[a+36>>2];j=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;k=x[a+32>>2];l=x[a+28>>2];h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){i=x[b+12>>2]+j|0;g=v[i|0];g=((D(v[i+1|0]-g|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(g<<8)|0;f=f+l|0;x[c>>2]=x[c>>2]+D(g,f>>12);e=e+k|0;x[c+4>>2]=x[c+4>>2]+D(g,e>>12);Pb(b+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;fb=b+16|0}function p$(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;c=vb(f+12|0,x[a+4>>2]);d=vb(f+8|0,x[a>>2]);h=x[vb(f+4|0,x[b+4>>2])>>2];g=fb-16|0;fb=g;i=g+8|0;e=fb-32|0;fb=e;fd(e+24|0,x[c>>2],x[d>>2]);j=e+16|0;d=x[e+24>>2];k=x[e+28>>2];c=fb-16|0;fb=c;x[c+8>>2]=h;x[c+12>>2]=d;while(1){if(Fd(d,k)){d=gw(d);zc(gw(x[c+8>>2]),d,36);d=m$(c+12|0);m$(c+8|0);d=x[d>>2];continue}break}qc(j,d,c+8|0);fb=c+16|0;c=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(i,c,e+12|0);fb=e+32|0;fb=g+16|0;x[b+4>>2]=x[g+12>>2];Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function m6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=oc(c,x[a+4>>2]);if(d>>>0<b>>>0){h=fb-32|0;fb=h;e=b-d|0;b=x[Ab(a)>>2];c=x[a+4>>2];a:{if(e>>>0<=b-c>>2>>>0){Vq(a,e);break a}f=it(a);d=Lf(a,oc(x[a>>2],c)+e|0);g=oc(x[a>>2],x[a+4>>2]);c=fb-16|0;fb=c;b=h+12|0;Lg(b+12|0,f);b:{if(!d){f=0;d=0;break b}iJ(c+8|0,x[b+16>>2],d);f=x[c+12>>2];d=x[c+8>>2]}x[b>>2]=d;g=d+(g<<2)|0;x[b+8>>2]=g;x[b+4>>2]=g;i=nc(b),j=d+(f<<2)|0,x[i>>2]=j;fb=c+16|0;kA(b,e);Sm(a,b);VP(b);a=x[b>>2];if(a){ny(x[b+16>>2],a,Uz(b))}}fb=h+32|0;return}if(b>>>0<d>>>0){Jd(a,c+(b<<2)|0)}}function em(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;v[g+14|0]=d;v[g+15|0]=c;v[g+13|0]=e;v[g+12|0]=f;d=0;a:{b:{while(1){c=d&255;if(c>>>0>3){break b}e=y[g+15|0];uw(g+10|0,e,y[g+14|0],c>>>0>1);if(!(y[g+10|0]|!e)){d=d+1|0;rg(g+15|0,g+13|0);rg(g+14|0,g+12|0);continue}break}c=z[g+10>>1];v[b+2|0]=c;v[b+4|0]=c>>>8;c=y[g+13|0];v[b+5|0]=y[g+12|0];v[b+3|0]=c;v[g+9|0]=0;ee(a,0,g+9|0);break a}d=y[g+15|0];e=ri(d);c=y[g+13|0];if(e>>>0>ri(c)>>>0){rg(g+15|0,g+13|0);rg(g+14|0,g+12|0);d=y[g+15|0];c=y[g+13|0]}v[b+4|0]=0;v[b+2|0]=0;v[b+5|0]=y[g+12|0];v[b+3|0]=c;ee(a,d,g+14|0)}fb=g+16|0}function bja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=b;a:{if(Cu(a)>>>0>=b>>>0){e=x[a>>2];g=hm(e,x[a+4>>2]);x[f+8>>2]=g;d=x[Hb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=fR(e,c)+52|0;continue}break}if(b>>>0>g>>>0){qA(a,b-g|0,c);break a}dR(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){Du(a);d=x[a>>2];Cu(a);Db(d);h=Ab(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}e=cR(a,b);d=fb-16|0;fb=d;if(uh(82595524)>>>0<e>>>0){ed();p()}bR(d+8|0,e);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;h=Ab(a),i=e+D(x[d+12>>2],52)|0,x[h>>2]=i;fb=d+16|0;qA(a,b,c)}fb=f+16|0}function Vfa(a){a=a|0;var b=0;b=8016;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=22292;break a}b=8049;break a}b=18202;break a;case 0:b=5011;break a;case 9:b=8072;break a;case 10:b=8086;break a;case 11:b=5388;break a;case 12:b=5408;break a;case 19:b=8098;break a;case 20:b=8030;break a;case 21:b=12914;break a;case 22:b=12237;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6019;break a}b=7983}return Cg(b)|0}function kQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=Ji(a,b,c,d);v[a+4260|0]=e;x[a>>2]=44684;c=Nb(a+4264|0);d=Nb(a+4276|0);x[a+4328>>2]=0;b=a+4320|0;x[b>>2]=0;x[b+4>>2]=0;x[a+4312>>2]=0;x[a+4316>>2]=0;b=a+4208|0;f=yb(b,0),g=1056964608,x[f>>2]=g;f=yb(b,1),g=1036831949,x[f>>2]=g;f=yb(b,2),g=1038174126,x[f>>2]=g;f=yb(b,3),g=1065353216,x[f>>2]=g;f=yb(b,4),g=1061158912,x[f>>2]=g;f=yb(b,5),g=1059082943,x[f>>2]=g;f=yb(b,6),g=1061997773,x[f>>2]=g;x[31609]=0;O(941,a+44|0,2);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;wc(d);wc(c);_f(a);Q(b|0);p()}function Vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;h=w[e>>1];e=h+((D(w[e+2>>1]-h|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Pb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[31609]=0;W(996,a|0);e=x[31609];x[31609]=0;a:{b:{c:{if((e|0)==1){break c}x[31609]=0;W(997,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break c}e=x[a+24>>2];b=pc(d+8|0,b);x[31609]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;V(1014,e|0,d|0,(c|0)!=0|0,1);c=x[31609];x[31609]=0;b=1;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,10021,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function h3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[31609]=0;W(997,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break d}c=x[a+24>>2];b=pc(d+8|0,b);x[31609]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=bI(c,d,1);e=x[31609];x[31609]=0;c=hb;if((e|0)!=1){break c}}Y(T(0)|0)|0;x[31609]=0;V(983,8689,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break b}Z();b=0;c=0}fb=d+16|0;a=c;break a}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}gb=a;return b|0}function br(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);ts(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=ki(Cb(x[c+4>>2],y[c+11|0]));x[31609]=0;O(45,c|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31609]=0;O(46,c|0,b-d|0);b=x[31609];x[31609]=0;d:{if((b|0)!=1){x[31609]=0;O(303,g|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Qh(a,g);tb(g);fb=f+16|0}function Zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);ts(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=ki(Cb(x[c+4>>2],y[c+11|0]));x[31609]=0;O(45,c|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31609]=0;O(46,c|0,b-d|0);b=x[31609];x[31609]=0;d:{if((b|0)!=1){x[31609]=0;O(303,g|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Qh(a,g);tb(g);fb=f+16|0}function $qa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;c=x[a+8>>2];d=x[a>>2];x[31609]=0;c=U(150,d|0,c|0,1)|0;d=x[31609];x[31609]=0;a:{if((d|0)==1){break a}b:{if(!c){break b}x[31609]=0;W(517,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;c=R(197,a|0)|0;d=x[31609];x[31609]=0;c:{if((d|0)!=1){while(1){if(!(c&255)){break b}x[31609]=0;d=e+15|0;f=P(518,a|0,d|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break c}g=f;f=y[e+15|0];if(g&f>>>0<64){zc(SY(x[b>>2],f),d,33)}c=c-1|0;continue}}break a}break a}ub(a);fb=e+48|0;return}b=N()|0;ub(a);Q(b|0);p()}function nR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-16|0;fb=h;v[h+15|0]=b;v[h+14|0]=10;fh(g,y[Qb(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;j=x[g>>2];k=Sd(j,x[g+4>>2]);b=0;while(1){if((b|0)!=(k|0)){m=yb(j,b);l=D(b,3)+f|0;i=(y[l|0]|y[l+1|0]<<8)>>>4|0;w[m>>1]=i;a:{if(b){n=z[yb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break a}i=n+1|0}else{i=0}o=yb(j,b),p=i,w[o>>1]=p}o=m,p=Ld(y[l+2|0],0,64),v[o+2|0]=p;b=b+1|0;continue}break}v[g+12|0]=a>>>1&(d>>>0<=e>>>0?(d>>>0<=k>>>0)<<1:0)|(a<<1&(c>>>0<=k>>>0)<<2|(y[g+12|0]&248|a&1));fb=h+16|0}function Wv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);Aw(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,z[b>>1]);if(!x[e+16>>2]){break c}d=ki(Cb(x[c+4>>2],y[c+11|0]));x[31609]=0;O(45,c|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31609]=0;O(46,c|0,b-d|0);b=x[31609];x[31609]=0;d:{if((b|0)!=1){x[31609]=0;O(47,g|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Qh(a,g);tb(g);fb=f+16|0}function Op(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);ts(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=ki(Cb(x[c+4>>2],y[c+11|0]));x[31609]=0;O(45,c|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31609]=0;O(46,c|0,b-d|0);b=x[31609];x[31609]=0;d:{if((b|0)!=1){x[31609]=0;O(47,g|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Qh(a,g);tb(g);fb=f+16|0}function K_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);Aw(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=ki(Cb(x[c+4>>2],y[c+11|0]));x[31609]=0;O(45,c|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31609]=0;O(46,c|0,b-d|0);b=x[31609];x[31609]=0;d:{if((b|0)!=1){x[31609]=0;O(47,g|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Qh(a,g);tb(g);fb=f+16|0}function Mt(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0;h=fb-240|0;fb=h;x[h+236>>2]=d;x[h+232>>2]=c;x[h>>2]=a;m=!f;a:{b:{c:{d:{if((c|0)!=1){i=a;j=1;break d}i=a;j=1;if(d){break d}f=a;break c}while(1){k=(e<<2)+g|0;f=i-x[k>>2]|0;if((no(f,a,b)|0)<=0){f=i;break c}l=m^-1;m=1;e:{if(!((l|(e|0)<2)&1)){k=x[k-8>>2];l=i-4|0;if((no(l,f,b)|0)>=0){break e}if((no(l-k|0,f,b)|0)>=0){break e}}x[(j<<2)+h>>2]=f;c=yL(c,d);Nt(h+232|0,c);j=j+1|0;e=c+e|0;i=f;d=x[h+236>>2];c=x[h+232>>2];if(d|(c|0)!=1){continue}break b}break}f=i;break b}if(!m){break a}}xL(h,j);az(f,b,e,g)}fb=h+240|0}function wz(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{b:{if(c){x[31609]=0;O(1139,a|0,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break b}f=fb-16|0;fb=f;d=xh(f+4|0,a,c);c=x[d+4>>2];g=x[d+8>>2];while(1){if((c|0)==(g|0)){jc(d);fb=f+16|0}else{x[c>>2]=0;tc(c);c=c+4|0;x[d+4>>2]=c;continue}break}}c=e+8|0;Qd(c);bh(c);fb=e+16|0;break a}a=N()|0;bh(e+8|0);Q(a|0);p()}e=a;a=0;c=0;d=fb-16|0;fb=d;f=d+12|0;while(1){if(a>>>0<32){a=a+48|0;c=dS(b);continue}break}x[f>>2]=c;Do(f);fb=d+16|0;x[e+12>>2]=x[f>>2];return e}function pI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{if(a>>>0>131071){break a}g=a&255;c=(g>>>0)/3|0;f=x[((D(c,-3)+a&255)<<2)+108232>>2];e=c;c=a>>>8|0;d=x[(((D(f,y[(e+D(y[c+109616|0],86)|0)+109616|0])>>>11>>>0)%6|0)+y[c+112288|0]<<2)+108256>>2];c=d>>8;d=d&255;if(d>>>0<=1){return(c&0-(b^d))+a|0}d=c&255;if(!d){break a}c=c>>>8|0;while(1){h=d>>>1|0;e=h+c|0;f=(e<<1)+109216|0;i=y[f|0];if((i|0)==(g|0)){c=x[(y[f+1|0]<<2)+108256>>2];d=c&255;if(d>>>0<=1){return(0-(b^d)&c>>8)+a|0}return(b?-1:1)+a|0}f=e;e=g>>>0<i>>>0;c=e?c:f;d=e?h:d-h|0;if(d){continue}break}}return a}function mna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=kg(1,2);e=hb;j=e;Pb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=(((x[b+12>>2]&2147483647)<<1|g>>>31)&-2)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=v[f+g|0]<<8;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Pb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Ig(a,h,j);fb=b+16|0}function cV(a,b){var c=0,d=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;fC(a+48|0);fC(a+68|0);fC(a+88|0);ev(a+492|0);ev(a+524|0);ck(a,0,0);bk(a,0,0);x[a+40>>2]=0;x[a+44>>2]=0;Nv(a,b);b=a+108|0;d=PC(b);c=1;while(1){if((b|0)!=(d|0)){v[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function Dfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=fb-16|0;fb=e;x[31609]=0;W(996,a|0);d=x[31609];x[31609]=0;a:{b:{c:{if((d|0)==1){break c}x[31609]=0;W(997,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}d=x[a+24>>2];b=pc(e+8|0,b);x[31609]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Za(1016,d|0,e|0,+c,1);d=x[31609];x[31609]=0;b=1;if((d|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,5926,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=0}fb=e+16|0;return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function voa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31609]=0;O(710,a|0,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;c=f+4|0;x[c>>2]=a;e=x[a+4>>2];x[c+4>>2]=e;x[c+8>>2]=e+D(b,9);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){jc(c);fb=f+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;continue}break}}b=d+8|0;Qd(b);wv(b);fb=d+16|0;return a|0}a=N()|0;wv(d+8|0);Q(a|0);p()}function k6(a){a=a|0;if(y[499928]){return x[124981]}if(!y[501024]){v[501024]=1}wd(500736,103724);wd(500748,103756);wd(500760,103792);wd(500772,103816);wd(500784,103840);wd(500796,103856);wd(500808,103876);wd(500820,103896);wd(500832,103924);wd(500844,103964);wd(500856,103996);wd(500868,104032);wd(500880,104068);wd(500892,104084);wd(500904,104100);wd(500916,104116);wd(500928,103840);wd(500940,104132);wd(500952,104148);wd(500964,104164);wd(500976,104180);wd(500988,104196);wd(501e3,104212);wd(501012,104228);v[499928]=1;x[124981]=500736;return 500736}function AD(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=y[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!y[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=y[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=D(c>>>3|0,b);b=((d|0)==10)<<4}c=b+D(jr(y[a+1|0]),c)|0}return c}function Oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;h=If(a,c);ae(e,x[a+36>>2]);a:{b:{if(!h){Qc(e,a+32|0,5);c=-1;if(!Gb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}c=x[h+16>>2]}f=x[a+36>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){d=fb-16|0;fb=d;x[d+12>>2]=0;wq(f,d+12|0);B[b>>2]=B[d+12>>2];break c}d=fb-16|0;fb=d;x[d+12>>2]=c;x[d+8>>2]=4;c=x[Hb(d+12|0,d+8|0)>>2];g=fb-16|0;fb=g;xz(g+8|0,f);f=x[g+12>>2];if(ft(-1,2147483647,c,0)^1){i=ft(c,0,0,-2147483648)^1}else{i=0}if(i){Ci(f,c,0,1)}fb=g+16|0;x[b>>2]=0}fb=d+16|0;d=h}ef(a,d);fb=e+16|0}function Jja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-48|0;fb=d;c=d+28|0;Tj(c,b,1819307379);kd(a+40|0,c);ub(c);Tj(c,b,1953721961);kd(a+60|0,c);ub(c);Tj(c,b,543520099);kd(a+120|0,c);ub(c);Tj(c,b,1414744396);x[31609]=0;e=P(412,c|0,13891)|0;f=x[31609];x[31609]=0;a:{if((f|0)!=1){b:{if(e){x[31609]=0;e=d+8|0;S(807,e|0,c|0,2);c=x[31609];x[31609]=0;if((c|0)==1){break b}Cv(a+140|0,e);ke(e)}x[31609]=0;S(808,d+8|0,b|0,1634890872);b=x[31609];x[31609]=0;if((b|0)!=1){break a}}}a=N()|0;ub(d+28|0);Q(a|0);p()}b=a+80|0;a=d+8|0;kd(b,a);ub(a);ub(d+28|0);fb=d+48|0}function jna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=kg(1,2);e=hb;k=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=w[(x[b+12>>2]<<1)+j>>1];g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Pb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Ig(a,h,k);fb=b+16|0}function Bw(a,b){var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=rf(e+20|0,1,0);a:{b:{c:{while(1){d=Kb(c);Aw(e+12|0,d,Cb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=ki(Cb(x[c+4>>2],y[c+11|0]));x[31609]=0;O(45,c|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Kb(c);x[31609]=0;O(46,c|0,b-d|0);b=x[31609];x[31609]=0;d:{if((b|0)!=1){x[31609]=0;O(47,g|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Qh(a,g);tb(g);fb=f+16|0}function xla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;h=z[c>>1];i=c;e=fb-16|0;fb=e;g=b;d=de(b);a:{if(d){c=gc(b);while(1){b=d;d=z[b+14>>1];if(Yk(h,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!Yk(d,h)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=gc(g);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=gc(g);d=Dh(e,Ec(16),Og(b+8|0,d));mm(x[d>>2]+14|0,z[i>>1]);k=gc(d),l=1,v[k+4|0]=l;fb=b+16|0;$g(g,x[e+12>>2],c,x[e>>2]);b=ne(e);Ik(e);j=1}c=f+8|0;_g(c,x[vb(e,b)>>2],j);fb=e+16|0;bV(a,c);fb=f+16|0}function qF(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=y[a|0]|y[a+1|0]<<8;b:{if((b|0)!=26217){if((b|0)!=20042){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}b=2;while(1){if((b|0)==110){d=a+369|0;e=a+241|0;a=a+113|0;b=0;while(1){c=(b|0)==128;if(c){break a}f=v[a+b|0];if((f|0)<-2){break a}g=y[b+e|0];if(!g&(f|0)>=0|g>>>0>15){break a}f=b+d|0;b=b+1|0;if(y[f|0]<64){continue}break}break a}e=(y[a+b|0]-32&255)>>>0<225;d=c+1|0;if(e|(d&255)>>>0<=40){c=e?c:d;b=b+1|0;continue}else{return 0}}}return c}function lF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;x[f+8>>2]=e;x[f+12>>2]=d;sf(a);zs(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;x[f+4>>2]=i;g=x[Hb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=ys(Jt(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){x[f+4>>2]=i-g;e=h+1|0;d=x[Hb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=y[ec(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=ec(j,e),n=32,v[m|0]=n}e=e+1|0;continue}}break}fb=f+16|0}function Ifa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[31609]=0;W(996,a|0);d=x[31609];x[31609]=0;a:{b:{c:{if((d|0)==1){break c}x[31609]=0;W(997,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break c}d=x[a+24>>2];b=pc(c+8|0,b);x[31609]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+oa(1007,d|0,c|0,1);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,5963,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();e=0}fb=c+16|0;return+e}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function kna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=kg(1,2);e=hb;k=e;Pb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=v[x[b+12>>2]+j|0]<<8;g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Pb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Ig(a,h,k);fb=b+16|0}function Jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;a:{b:{c:{if((c|0)==1){break c}x[31609]=0;W(997,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break c}c=x[a+24>>2];b=pc(d+8|0,b);x[31609]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=U(1003,c|0,d|0,1)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,10052,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function rT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=-1;a:{if(!(y[b+851|0]&2)){break a}d=!(y[a+480209|0]&32);b:{c:{d:{c=x[b+656>>2];e:{if(c){e=y[c+22|0];if(vd(e)){g=b,h=Hh(e),v[g+838|0]=h;d=1}e=y[c+21|0];f:{if(vd(e)){g=b,h=Hh(e),v[g+837|0]=h;break f}if(!d){break d}}d=1;c=y[c+25|0];if((c|0)==255){break e}v[b+845|0]=c;break e}x[b+776>>2]=0;x[b+780>>2]=0}c=b+837|0;if(y[b+837|0]>=127){break c}if(d){break b}break a}if(y[b+837|0]<127){break a}d=0;c=b+837|0}if(!d|!Ob(a+1074312|0,36)){break a}}f=Kq(a,b,1,256);if((f|0)<0){break a}f=y[c|0]>>>1|0}return f}function fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-208|0;fb=e;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;iS(a+946304|0);f=a+906300|0;g=uk(f);d=e+48|0;Rb(d,0,160);d=kS(d);x[31609]=0;S(860,f|0,g|0,d|0);f=x[31609];x[31609]=0;a:{if((f|0)!=1){UA(d);d=He(e+28|0,b);x[31609]=0;f=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=f;x[e+24>>2]=x[d+16>>2];f=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=f;a=U(861,a|0,e+8|0,c|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){a=N()|0;break a}ub(b);fb=e+208|0;return a|0}a=N()|0;UA(d)}ub(b);Q(a|0);p()}function iz(a,b,c){var d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),j=0,k=E(0),l=E(0),m=E(0);e=fb-32|0;fb=e;g=B[a+24>>2];f=B[a+12>>2];h=B[a+48>>2];i=B[a+36>>2];OL(E(-B[a>>2]),E(g+f),E(h+i),e+20|0);OL(B[a+60>>2],E(h-i),E(g-f),e+8|0);B[e+12>>2]=-B[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=B[j>>2];f=B[d+(e+20|0)>>2];h=B[d+87424>>2];i=B[d+87436>>2];k=B[d+(e+8|0)>>2];B[j>>2]=E(f*h)-E(i*k);j=b+d|0;l=B[(0-a<<2)+87432>>2];d=5-a<<2;m=B[d+87424>>2];f=E(E(f*i)+E(k*h));B[j>>2]=E(g*l)-E(m*f);B[b+d>>2]=E(g*m)+E(f*l);a=a+1|0;continue}break}fb=e+32|0}function px(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;f=x[b>>2];g=ib[x[x[f>>2]+36>>2]](f,c,d)|0;a:{if(!g){Yh(a);break a}qm(e+32|0,x[b>>2],x[b+4>>2]);b=x[e+36>>2];x[e+16>>2]=x[e+32>>2];x[e+20>>2]=b;b=fb-16|0;fb=b;d=e+16|0;f=qm(b+8|0,x[d>>2],x[d+4>>2]);x[31609]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;V(166,e+40|0,b|0,c|0,g|0);c=x[31609];x[31609]=0;b:{if((c|0)!=1){me(d);fb=b+16|0;break b}a=N()|0;me(d);Q(a|0);p()}b=Md(e+24|0);c=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;Kp(a,e+8|0,e)}fb=e+48|0}function gC(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=x[a>>2];a:{if(!mc(c,x[a+4>>2])){w[c>>1]=0;Of(c+2|0,b);f=d,g=Ek(wb(x[a>>2]),1),x[f+12>>2]=g;while(1){e=wb(x[a+4>>2]);c=x[d+12>>2];if(Ib(c,e)){f=c,g=z[qe(c,Ek(c,-1))>>1],w[f>>1]=g;Of(c+2|0,b);gW(d+12|0);continue}else{Of(a+14|0,Sd(x[a>>2],x[a+4>>2])-1&255);Of(a+13|0,y[a+14|0]);Of(a+16|0,Sd(x[a>>2],x[a+4>>2])-1&255);Of(a+15|0,y[a+16|0]);if(y[a+17|0]==255){break a}Of(a+17|0,Sd(x[a>>2],x[a+4>>2])-1&255);break a}}}v[a+17|0]=255;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0}fb=d+16|0}function Ds(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;f=x[c>>2];g=e+52|0;jH(g,c,71);x[31609]=0;c=e+4|0;S(d|0,c|0,b|0,(f&2?16:10)|0);b=x[31609];x[31609]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;HV(b,c,x[e+52>>2]);x[31609]=0;d=e+28|0;V(299,d|0,b|0,x[e+52>>2],x[e+56>>2]);f=x[31609];x[31609]=0;if((f|0)==1){break d}x[31609]=0;f=e+40|0;S(300,f|0,d|0,g|0);h=x[31609];x[31609]=0;if((h|0)==1){break c}Qh(a,f);tb(f);tb(d);tb(b);tb(c);Jh(g);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Jh(e+52|0);Q(c|0);p()}function Ao(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){break c}f=c>>31;d=f;d=(d^c)-d|0;if(d>>>0<224){break c}Jb(e+8|0,a+1074312|0,3);if(Gb(x[x[e+8>>2]>>2],x[e+12>>2])){break c}if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break a}c=D(d&15,(c|0)!=0|f);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,872)+a|0)+1075843|0]&1){Jb(e+8|0,a+1074312|0,3);if(!Gb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=D(b,872)+a|0;d=x[f+1075648>>2];a=Eq(a,x[f+1075080>>2],d);if(!a){break a}ib[x[x[a>>2]+84>>2]](a,c,(d?y[d+33|0]:13)<<24>>24,b)}fb=e+16|0}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){f=x[c+4>>2];h=x[c+8>>2];g=Pj(f,h);i=fb-16|0;fb=i;a:{if(ap(d)>>>0>=g>>>0){j=x[d>>2];k=Xc(j,x[d+4>>2]);if(k>>>0<g>>>0){e=fb-16|0;fb=e;x[e+12>>2]=f;x[e+12>>2]=x[e+12>>2]+k;fb=e+16|0;e=x[e+12>>2];xk(f,e,j);yn(d,e,h,g-Xc(x[d>>2],x[d+4>>2])|0);break a}$B(i+8|0,f,h,j);Jd(d,x[i+12>>2]);break a}dw(d);Vk(d,Vl(d,g));yn(d,f,h,g)}fb=i+16|0}zc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function Ira(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=x[a>>2];d=Hk(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;d=b-d|0;b=x[Ab(a)>>2];f=x[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){xD(a,d,c);break a}b=Ab(a);b=kZ(e+12|0,tD(a,Hk(x[a>>2],f)+d|0),Hk(x[a>>2],x[a+4>>2]),b);jZ(b,d,c);c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);f=vb(c+8|0,x[a>>2]);g=vb(c+4|0,x[b+4>>2]);h=b,i=gZ(x[d>>2],x[f>>2],x[g>>2]),x[h+4>>2]=i;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0;iZ(b)}fb=e+32|0;return}if(b>>>0<d>>>0){Jd(a,e+D(b,6)|0)}}function Ima(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[f>>1],w[e+38082>>1])+D(w[f-2>>1],w[e+38080>>1])|0)+D(w[f+2>>1],w[e+38084>>1])|0)+D(w[f+4>>1],w[e+38086>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function j7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;e=Cb(x[a+4>>2],y[a+11|0]);d=sn(a);f=Sd(b,c);a:{if(!f){break a}b:{h=Kb(a);if(!H_(h,((Cb(x[a+4>>2],y[a+11|0])<<2)+h|0)+4|0,b)){if(d-e>>>0<f>>>0){rC(a,d,(e-d|0)+f|0,e,e,0)}d=Kb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}yd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=eq(g+4|0,b,c);c=Kb(b);e=y[b+11|0];d=x[b+4>>2];x[31609]=0;U(1289,a|0,c|0,Cb(d,e)|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){Ub(b);break a}a=N()|0;Ub(b);Q(a|0);p()}yd(d,0);lg(a,e+f|0)}fb=g+16|0;return a|0}function Wp(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-80|0;fb=e;f=x[c>>2];g=e+52|0;jH(g,c,3);x[31609]=0;c=e+4|0;S(d|0,c|0,b|0,(f&2?16:10)|0);b=x[31609];x[31609]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;HV(b,c,x[e+52>>2]);x[31609]=0;d=e+28|0;V(19,d|0,b|0,x[e+52>>2],x[e+56>>2]);f=x[31609];x[31609]=0;if((f|0)==1){break d}x[31609]=0;f=e+40|0;S(20,f|0,d|0,g|0);h=x[31609];x[31609]=0;if((h|0)==1){break c}Qh(a,f);tb(f);tb(d);tb(b);tb(c);Jh(g);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Jh(e+52|0);Q(c|0);p()}function Gha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{c=y[a+11|0];c:{d:{if(vd(c)){c=x[a+4>>2];d=Zi(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Hh(c);if((c|0)!=10){break b}}c=fb-16|0;fb=c;e:{if((d|0)!=2147483631){f=Kb(a);e=c+4|0;if(d>>>0<=1073741798){x[c+12>>2]=d<<1;x[c+4>>2]=d+1;g=Fh(x[bd(e,c+12|0)>>2])+1|0}else{g=2147483631}qg(e,g);e=x[c+4>>2];if(d){Dg(e,f,d)}if((d|0)!=10){Db(f)}yd(a,e);of(a,x[c+8>>2]);fb=c+16|0;break e}pf();p()}Bd(a,d);c=d}d=x[a>>2];Bd(a,c+1|0);break a}Ne(a,c+1|0);d=a}a=c+d|0;hd(a,b);hd(a+1|0,0)}function zja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{g=fb-32|0;fb=g;a=Nb(a);b:{c:{d:{e:{while(1){e=x[b+8>>2];f=x[b>>2];x[31609]=0;e=U(150,f|0,e|0,8)|0;f=x[31609];x[31609]=0;if((f|0)==1){break c}if(e){x[31609]=0;e=g+4|0;S(909,e|0,b|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}x[31609]=0;O(910,a|0,e|0);f=x[31609];x[31609]=0;if((f|0)==1){break d}Hd(e);f=e;e=Fr(x[a+4>>2]);qi(f,x[e>>2],x[e+4>>2]);if(x[g+4>>2]!=(d|0)){continue}}break}fb=g+32|0;break a}b=N()|0;break b}b=N()|0;Hd(g+4|0);break b}b=N()|0}ke(a);Q(b|0);p()}}function xX(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1196314451){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if(b>>>0<1108|((b-1108|0)!=(y[a+1104|0]|y[a+1105|0]<<8|(y[a+1106|0]<<16|y[a+1107|0]<<24))|b>>>0>262144)|(y[a+1094|0]|y[a+1095|0]<<8|(y[a+1096|0]|y[a+1097|0]<<8|(y[a+1098|0]<<16|y[a+1099|0]<<24))-5>>>0<4294967292)){break a}if(!Ev(a+8|0)){break a}b=40;while(1){d=(b|0)==1094;if(d){break a}c=a+b|0;if(y[c+32|0]>15|y[c+33|0]>64){break a}b=b+34|0;if(Ev(c)){continue}break}}return d}function vj(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;x[a+4>>2]=0;d=4;a:{b:{c:{if(!Id(y[Gm(e+15|0,a,1)|0])){break c}d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31609]=0;b=U(85,d|0,b|0,c|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}Y(T(0)|0)|0;d=1;Em(x[x[a>>2]-12>>2]+a|0,1);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31609]=0;X(84);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}Wj(x[x[a>>2]-12>>2]+a|0,d);fb=e+16|0;return a}T(0)|0;Sb()}p()}function ZR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=16777216;h=e+12|0;d=x[a>>2];c=oc(d,x[a+4>>2]);a:{if(c>>>0<b>>>0){f=fb-32|0;fb=f;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){XE(a,b,h);break b}c=Ab(a);c=Zf(f+12|0,Lf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);g=fb-16|0;fb=g;b=Fn(g+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){vq(d,x[h>>2]);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}je(b);fb=g+16|0;Sm(a,c);Yf(c)}fb=f+32|0;break a}if(b>>>0<c>>>0){Jd(a,d+(b<<2)|0)}}QA(a);fb=e+16|0}function Z0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;nd(b,0);f=e+8|0;dk(f,1,a+33|0);d=e+20|0;Cc(d,f);Be(b+43|0,d);tb(d);g=y[a+50|0]|y[a+51|0]<<8|(y[a+52|0]<<16|y[a+53|0]<<24);x[b>>2]=g;x[b+24>>2]=y[a+54|0]|y[a+55|0]<<8;v[e+20|0]=y[a+56|0];v[e+8|0]=64;h=b,i=y[Qb(d,f)|0]<<2,w[h+30>>1]=i;d=y[a+57|0]|y[a+58|0]<<8|(y[a+59|0]<<16|y[a+60|0]<<24);x[b+4>>2]=d;f=y[a+61|0]|y[a+62|0]<<8|(y[a+63|0]<<16|y[a+64|0]<<24);c=c?d?g:f:f;x[b+8>>2]=c;if(!(!y[a|0]|c>>>0<=d+2>>>0|c>>>0>g>>>0)){w[b+34>>1]=z[b+34>>1]|2}fb=e+32|0}function vQ(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0;_z(a);c=Pd(c,E(0));a:{switch(b|0){case 0:B[a+4220>>2]=c;return;case 1:B[a+4224>>2]=c;return;case 2:B[a+4228>>2]=c;ru(a);return;case 3:v[a+4240|0]=c>=E(.5);ru(a);return;case 4:b=fb-16|0;fb=b;e=b,f=Ll(E(c*E(32))),x[e+12>>2]=f;x[b+8>>2]=0;x[b+4>>2]=5;d=Zj(b+12|0,b+8|0,b+4|0);fb=b+16|0;x[a+4232>>2]=x[d>>2];return;case 5:v[a+4241|0]=c>=E(.5);return;case 6:v[a+4242|0]=c>=E(.5);return;case 7:v[a+4244|0]=c>=E(.5);return;case 8:if(c==E(0)){Yz(a)}C[a+4256>>3]=c;break;default:break a}}}function rpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;e=Rf(d+52|0);x[31609]=0;c=P(650,b|0,e|0)|0;f=x[31609];x[31609]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31609]=0;R(651,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break a}}break c}c=x[e+4>>2];x[31609]=0;S(185,d+12|0,b|0,(c>>>0>=9?c-8|0:0)|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}a=N()|0;Hd(e);Q(a|0);p()}b=d+12|0;c=hc(d+32|0,b);kd(e+8|0,c);ub(c);ub(b);Ok(a,e)}Hd(e);fb=d+80|0}function gZ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=e+8|0;d=fb-32|0;fb=d;fd(d+24|0,a,b);h=d+16|0;b=x[d+24>>2];i=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(Fd(b,i)){b=fZ(b);c=fZ(x[a+8>>2]);f=y[b+4|0]|y[b+5|0]<<8;v[c+4|0]=f;v[c+5|0]=f>>>8;b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;b=eZ(a+12|0);eZ(a+8|0);b=x[b>>2];continue}break}qc(h,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];qc(g,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function w1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=16384;d=x[Hb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=17;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=al(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}$r(c+4|0,al(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}$r(c+4|0,d-e|0);break b}QF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}QF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function Nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(x[a+4>>2]!=x[Ab(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+7;FT(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+7;jc(c);fb=d+16|0;return}f=fb-32|0;fb=f;g=Ab(a);h=f+12|0;e=GB(x[a>>2],x[a+4>>2])+1|0;c=fb-16|0;fb=c;x[c+12>>2]=e;a:{d=uh(613566756);if(e>>>0<=d>>>0){e=HB(a);if(e>>>0<d>>>1>>>0){x[c+8>>2]=e<<1;d=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;break a}ed();p()}c=IT(h,d,GB(x[a>>2],x[a+4>>2]),g);FT(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+7;HT(a,c);GT(c);fb=f+32|0}function Sqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=Rf(d+52|0);x[31609]=0;e=P(522,b|0,c|0)|0;f=x[31609];x[31609]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31609]=0;R(523,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break a}}break c}e=z[c+2>>1]|z[c+4>>1]<<16;x[31609]=0;S(185,d+12|0,b|0,e|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}a=N()|0;Hd(c);Q(a|0);p()}b=d+12|0;e=hc(d+32|0,b);kd(c+8|0,e);ub(e);ub(b);IY(a,c)}Hd(c);fb=d+80|0}function Jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[f|0],w[e+38082>>1])+D(v[f-1|0],w[e+38080>>1])|0)+D(v[f+1|0],w[e+38084>>1])|0)+D(v[f+2|0],w[e+38086>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function zW(a){var b=0,c=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=1297236819){break a}b=y[a+28|0]|y[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=y[a+42|0];if(b>>>0>64&(b|0)!=88|(y[a+48|0]|y[a+49|0]<<8)>>>0>64|(y[a+50|0]|y[a+51|0]<<8)>>>0>96){break a}b=y[a+52|0]|y[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(y[a+30|0]|y[a+31|0]<<8)|(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24)|(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1)){break a}c=CW(a+20|0)}return c}function v1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=32768;d=x[Hb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=9;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=al(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}$r(c+4|0,al(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}$r(c+4|0,d-e|0);break b}PF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}PF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function Esa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{e=fb-32|0;fb=e;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];d=x[b>>2];x[31609]=0;c=U(150,d|0,c|0,8)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}if(c){x[31609]=0;c=e+4|0;O(407,c|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break e}x[31609]=0;O(408,a|0,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break d}Hd(c);d=c;c=Fr(x[a+4>>2]);qi(d,x[c>>2],x[c+4>>2]);if(($b(x[e+4>>2])|0)!=1162757187){continue}}break}fb=e+32|0;break a}b=N()|0;break b}b=N()|0;Hd(e+4|0);break b}b=N()|0}ke(a);Q(b|0);p()}}function aP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;g=Nb(a);a=0;a:{b:{c:{d:{e:{while(1){c=x[b+24>>2];if(z[c+480188>>1]<=a>>>0){break a}x[31609]=0;f=d+8|0;O(1052,f|0,(c+(a<<5)|0)+480289|0);c=x[31609];x[31609]=0;if((c|0)!=1){e=x[b+24>>2];x[31609]=0;c=d+20|0;S(1053,c|0,e|0,f|0);e=x[31609];x[31609]=0;if((e|0)==1){break e}x[31609]=0;O(178,g|0,c|0);e=x[31609];x[31609]=0;if((e|0)==1){break d}a=a+1|0;tb(c);tb(f);continue}break}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d+20|0)}tb(d+8|0)}Td(g);Q(a|0);p()}fb=d+32|0}function Bta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;nd(b,0);g=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=g;e=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+12>>2]=e;f=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+16>>2]=f;c=y[a+12|0]|y[a+13|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=y[a+14|0];w[b+30>>1]=c?c+1|0:256;d=z[b+34>>1]&32767|!y[a+14|0]<<15;w[b+34>>1]=d;c=y[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;w[b+34>>1]=d;c=y[a+15|0]}if(c&2){x[b+16>>2]=f>>>1;x[b+12>>2]=e>>>1;x[b>>2]=g>>>1;w[b+34>>1]=d|1}}function Vc(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=d+4|0;x[b+8>>2]=0;x[b+4>>2]=1245;x[b>>2]=a;c=fb-16|0;fb=c;if(x[a>>2]!=-1){a:{b=vb(c+8|0,yf(c+12|0,b));while(1){if(x[a>>2]==1){continue}break}b:{if(!x[a>>2]){yd(a,1);b=x[x[b>>2]>>2];x[31609]=0;W(1246,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break b}x[a>>2]=-1}break a}Y(T(0)|0)|0;yd(a,0);x[31609]=0;X(84);a=x[31609];x[31609]=0;c:{if((a|0)==1){a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){break c}T(0)|0;Sb()}p()}Q(a|0);p()}}fb=c+16|0;fb=d+16|0;return x[a+4>>2]-1|0}function nN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];e=qq(a);d:{if(!e){if(pq(a)>>>0<=b>>>0){break d}a=ni(a,b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=dc(8);x[31609]=0;b=P(36,d+4|0,6e3)|0;c=x[31609];x[31609]=0;e:{if((c|0)!=1){sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;lc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];if(!a){break b}v[a+15|0]=y[a+15|0]&253|(c?2:0)}fb=d+16|0;return}p()}function dj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;o(+b);g=j(1)|0;c=j(0)|0;d=g&2147483647;f=d+-1048576|0;a:{if((f|0)==2145386495|f>>>0<2145386495){h=c<<28;c=(d&15)<<28|c>>>4;d=(d>>>4|0)+1006632960|0;break a}if((d|0)==2146435072|d>>>0>2146435072){h=c<<28;c=(g&15)<<28|c>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}f=c;c=d?G(d):G(c)+32|0;$f(e,f,d,0,0,c+49|0);i=x[e>>2];h=x[e+4>>2];f=15372-c<<16;c=x[e+8>>2];d=f|x[e+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;fb=e+16|0}function EH(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-256|0;fb=g;v[g+252|0]=0;v[g+253|0]=0;v[g+254|0]=0;v[g+255|0]=0;v[g+249|0]=0;v[g+250|0]=0;v[g+251|0]=0;v[g+252|0]=0;v[g+248|0]=37;st(g+249|0,10632,f,x[b+4>>2]);f=Od();x[g>>2]=d;x[g+4>>2]=e;d=g+224|0;e=ph(d,24,f,g+248|0,g)+d|0;h=jj(d,e,x[b+4>>2]);f=g+20|0;cd(f,x[b+28>>2]);x[31609]=0;i=d;d=g+32|0;ga(1269,i|0,h|0,e|0,d|0,g+28|0,g+24|0,f|0);e=x[31609];x[31609]=0;a:{if((e|0)!=1){_b(f);a=pt(a,d,x[g+28>>2],x[g+24>>2],b,c);fb=g+256|0;break a}a=N()|0;_b(g+20|0);Q(a|0);p()}return a}function GH(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-112|0;fb=g;v[g+108|0]=0;v[g+109|0]=0;v[g+110|0]=0;v[g+111|0]=0;v[g+105|0]=0;v[g+106|0]=0;v[g+107|0]=0;v[g+108|0]=0;v[g+104|0]=37;st(g+105|0,10632,f,x[b+4>>2]);f=Od();x[g>>2]=d;x[g+4>>2]=e;d=g+80|0;e=ph(d,24,f,g+104|0,g)+d|0;h=jj(d,e,x[b+4>>2]);f=g+20|0;cd(f,x[b+28>>2]);x[31609]=0;i=d;d=g+32|0;ga(1265,i|0,h|0,e|0,d|0,g+28|0,g+24|0,f|0);e=x[31609];x[31609]=0;a:{if((e|0)!=1){_b(f);a=tw(a,d,x[g+28>>2],x[g+24>>2],b,c);fb=g+112|0;break a}a=N()|0;_b(g+20|0);Q(a|0);p()}return a}function dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{e=fb-32|0;fb=e;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];d=x[b>>2];x[31609]=0;c=U(150,d|0,c|0,8)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}if(c){x[31609]=0;c=e+4|0;O(681,c|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break e}x[31609]=0;O(682,a|0,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break d}Hd(c);d=c;c=Fr(x[a+4>>2]);qi(d,x[c>>2],x[c+4>>2]);if(x[e+4>>2]!=1413891155){continue}}break}fb=e+32|0;break a}b=N()|0;break b}b=N()|0;Hd(e+4|0);break b}b=N()|0}ke(a);Q(b|0);p()}}function aga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a+4202|0]=1;c=Bk(E(E(A[x[a+16>>2]+24620>>2])*E(.04500000178813934)));d=Bk(E(E(c>>>0)*E(1.1892070770263672)));e=Bk(E(E(d>>>0)*E(1.1892070770263672)));h=Bk(E(E(e>>>0)*E(1.1892070770263672)));f=Bk(E(E(c+e>>>0)*E(.11546666920185089)));g=Bk(E(E(d+h>>>0)*E(.11546666920185089)));b=a+4272|0;i=yb(b,0),j=c-f|0,x[i>>2]=j;i=yb(b,1),j=e-f|0,x[i>>2]=j;i=yb(b,2),j=d-g|0,x[i>>2]=j;i=yb(b,3),j=h-g|0,x[i>>2]=j;i=yb(b,4),j=f,x[i>>2]=j;i=yb(b,5),j=g,x[i>>2]=j;KP(a);IP(a)}function Upa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-608|0;fb=b;c=fb-16|0;fb=c;d=b+8|0;QX(c+8|0,d);e=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){id(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){PX(d)}c=-1;a:{if(!e){break a}c=0;if(!SX(d)){break a}c=-1;if(!jh(a,1024)){break a}c=0;e=fb-1024|0;fb=e;d=fb-16|0;fb=d;SC(d+8|0,e);f=x[d+12>>2];qd(d,a,x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((f|0)==(g|0)){id(a,x[d+12>>2])}fb=d+16|0;if((f|0)==(g|0)){c=TC(e,0)>>>0<17}fb=e+1024|0}fb=b+608|0;return c|0}function y$(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{if(!d){break a}f=y[e|0];if(!f){break a}g=2240>>>d&d>>>0<12;i=D(c,-6);h=(d-2&255)>>>0>2;while(1){if(!b){break a}a=a+i|0;c=y[a+3|0];b:{c:{if(!((c-2&255)>>>0>2|h)){c=1;if(y[a+5|0]<224){break c}break a}c=!(1<<c&2240)|(!g|c>>>0>11)?(c|0)==(d|0):1;if(h){break b}}if((y[a+2|0]-11&255)>>>0>2){break b}if(y[a+4|0]){break a}}if(!(y[a+4|0]?!g|(y[a+2|0]-3&255)>>>0>3:1)){break a}b=b-1|0;if(!c){continue}c=y[a+5|0];if(c?(c|0)!=(f|0):0){break a}if((c|0)!=(f|0)){continue}break}v[e|0]=0}}function AB(a,b){var c=0;if(b>>>0<=999999){if(b>>>0<=9999){if(b>>>0<=99){if(b>>>0<=9){return Iq(a,b)}return Il(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Il(Iq(c,a),D(a,-100)+b|0)}return xB(a,b)}if(b>>>0<=99999){c=a;a=(b>>>0)/1e4|0;return xB(Iq(c,a),D(a,-1e4)+b|0)}return uB(a,b)}if(b>>>0<=99999999){if(b>>>0<=9999999){c=a;a=(b>>>0)/1e6|0;return uB(Iq(c,a),D(a,-1e6)+b|0)}return Qu(a,b)}if(b>>>0<=999999999){c=a;a=(b>>>0)/1e8|0;return Qu(Iq(c,a),D(a,-1e8)+b|0)}c=a;a=(b>>>0)/1e8|0;return Qu(Il(c,a),D(a,-1e8)+b|0)}function vta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;nd(b,0);e=c+8|0;dk(e,1,a);d=c+20|0;Cc(d,e);Be(b+43|0,d);tb(d);x[b+24>>2]=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);w[b+34>>1]=z[b+34>>1]&65533|(y[a+13|0]|y[a+14|0]<<8)<<1&2;x[b>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b+4>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[b+8>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);v[c+20|0]=y[a+15|0];v[c+8|0]=64;f=b,g=y[Qb(d,e)|0]<<2,w[f+30>>1]=g;fb=c+32|0}function Voa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=Rf(c+52|0);x[31609]=0;e=P(687,b|0,d|0)|0;f=x[31609];x[31609]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31609]=0;R(688,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[31609]=0;S(185,c+12|0,b|0,e|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}a=N()|0;Hd(d);Q(a|0);p()}b=c+12|0;e=hc(c+32|0,b);kd(d+8|0,e);ub(e);ub(b);Ok(a,d)}Hd(d);fb=c+80|0}function AS(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}c=b&240;e=x[a+480180>>2];b=e&1048580?c?c:b:b;c=b&15;b=b&255;b:{c:{d:{if(!((c|0)!=15|b>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=b>>>3&30;break d}f=x[a+480208>>2]&4096;g=b&240;if(!(!c|(g|0)!=240)){if(!f){break b}b=0-(c<<1)|0;break c}if(f){break b}if(g){if(e&59314208?c:0){break b}b=b>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}x[d+12>>2]=x[a+1074456>>2]+(b<<!(e&59314208));Ge(d+12|0,0,256);x[a+1074456>>2]=x[d+12>>2]}fb=d+16|0}function bsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{while(1){f=Kb(d);jC(e+12|0,f,Cb(x[d+4>>2],y[d+11|0])+f|0,z[b>>1],c);if(!x[e+16>>2]){break b}f=ki(Cb(x[d+4>>2],y[d+11|0]));x[31609]=0;O(45,d|0,f|0);f=x[31609];x[31609]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Kb(d);x[31609]=0;O(46,d|0,b-c|0);b=x[31609];x[31609]=0;c:{if((b|0)!=1){x[31609]=0;O(47,a|0,d|0);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function d6(a){a=a|0;if(y[499920]){return x[124979]}if(!y[500720]){v[500720]=1}ld(500432,5034);ld(500444,5025);ld(500456,10891);ld(500468,10635);ld(500480,5261);ld(500492,11668);ld(500504,5118);ld(500516,5609);ld(500528,8902);ld(500540,8885);ld(500552,8893);ld(500564,8912);ld(500576,10089);ld(500588,13330);ld(500600,8975);ld(500612,7714);ld(500624,5261);ld(500636,9778);ld(500648,10494);ld(500660,10903);ld(500672,9265);ld(500684,6463);ld(500696,5492);ld(500708,13248);v[499920]=1;x[124979]=500432;return 500432}function I9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=rf(e+20|0,1,0);a:{b:{while(1){f=Kb(d);EN(e+12|0,f,Cb(x[d+4>>2],y[d+11|0])+f|0,y[b|0],c);if(!x[e+16>>2]){break b}f=ki(Cb(x[d+4>>2],y[d+11|0]));x[31609]=0;O(45,d|0,f|0);f=x[31609];x[31609]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Kb(d);x[31609]=0;O(46,d|0,b-c|0);b=x[31609];x[31609]=0;c:{if((b|0)!=1){x[31609]=0;O(303,a|0,d|0);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function g1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;c=-1;d=b+12|0;a:{if(!eF(a,d)){break a}b:{if(dF(d)){if(id(a,32)){break b}break a}c=0;if(!cF(b+12|0)){break a}}e=b+7|0;d=bF(y[b+15|0]);c=fb-32|0;fb=c;x[c+28>>2]=d;x[c+8>>2]=5;d=x[Hb(c+28|0,c+8|0)>>2];if(!jh(a,d)){d=(ib[x[x[a>>2]+24>>2]](a)|0)-x[a+12>>2]|0}f=c+8|0;_j(f,e);g=Zb(c+16|0,x[c+8>>2],d);qd(c,a,x[g>>2],x[g+4>>2]);_j(f,e);Rb(x[c+8>>2]+d|0,0,5-d|0);id(a,x[c+28>>2]);fb=c+32|0;if(!d){c=-1;break a}c=aF(b+7|0,y[b+15|0])}fb=b+16|0;return c|0}function YU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=b?33:32;c=y[a+16|0];l=c?-1:1;m=c?1:-1;e=x[a+8>>2]-1|0;n=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;f=x[a+12>>2];o=(f|0)>0?f:0;p=c?0:e;h=x[a>>2]+D(f,62)|0;d=b?1:-1;q=D(f,d)<<1;c=e;a:while(1){if((i|0)!=(k|0)){g=x[a+4>>2]+(D(c,f)<<1)|0;b=0;while(1)if((b|0)==(o|0)){b:{if((c|0)==(e|0)){b=n;g=l;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?p:b;g=c?m:d}h=h+q|0;i=i+1|0;c=b;d=g;continue a}else{j=b<<1;w[j+h>>1]=z[g+j>>1];b=b+1|0;continue}}break}}function A3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(lh(a,x[b+8>>2],e)){Vx(b,c,d);return}a:{if(lh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];ib[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function DK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{h=x[31484];x[31484]=0;Od();f=BK(a,e+12|0,d);a=f;d=hb;d:{g=x[31484];if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)!=68){break d}x[c>>2]=4;a=2147483647;if(!!f&(d|0)>=0|(d|0)>0){break a}break b}x[31484]=h;if(x[e+12>>2]==(b|0)){break d}break c}if((d|0)<0&a>>>0<=2147483647|(d|0)<-1){x[c>>2]=4;break b}if((d|0)>=0&a>>>0>=2147483648|(d|0)>0){x[c>>2]=4;a=2147483647;break a}break a}}x[c>>2]=4;a=0;break a}a=-2147483648}fb=e+16|0;return a}function Uv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=0;x[g+8>>2]=a;h=fb-16|0;fb=h;c=Zb(h+8|0,x[g+8>>2],x[g+12>>2]);f=fb-16|0;fb=f;b=122;x[f+12>>2]=122;d=x[c+4>>2];a:{if(!d){d=x[c>>2];break a}e=32-d|0;x[f+8>>2]=e;b=x[c>>2];i=x[b>>2];j=e;e=x[Hb(f+8|0,f+12|0)>>2];x[b>>2]=(-1<<d&-1>>>j-e^-1)&i;i=x[f+12>>2];d=b+4|0;x[c>>2]=d;b=i-e|0}e=d;d=b>>>5|0;IF(e,d);b=b&31;x[f+12>>2]=b;if(b){e=c;c=x[c>>2]+(d<<2)|0;x[e>>2]=c;x[c>>2]=x[c>>2]&(-1>>>32-b^-1)}fb=f+16|0;fb=h+16|0;fb=g+16|0;return a}function pH(a,b,c,d){var e=0,f=0,g=0;e=fb-80|0;fb=e;f=Rf(e+52|0);x[31609]=0;d=P(d|0,b|0,f|0)|0;g=x[31609];x[31609]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31609]=0;R(c|0,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break a}}break c}c=x[f+4>>2];x[31609]=0;S(185,e+12|0,b|0,$b(c)|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}a=N()|0;Hd(f);Q(a|0);p()}b=e+12|0;c=hc(e+32|0,b);kd(f+8|0,c);ub(c);ub(b);Ok(a,f)}Hd(f);fb=e+80|0}function _H(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;h=Fb(a);a=0;a:{b:{c:{d:{while(1){f=x[b>>2];if(Ud(f,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){f=Vd(f,0);break e}x[31609]=0;P(d|0,h|0,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}f=Vd(x[b>>2],a)}x[31609]=0;i=g+4|0;O(e|0,i|0,f|0);f=x[31609];x[31609]=0;if((f|0)!=1){x[31609]=0;P(d|0,h|0,i|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break d}a=a+1|0;tb(i);continue}break}a=N()|0;break a}a=N()|0;tb(g+4|0);break a}fb=g+16|0;return}a=N()|0}tb(h);Q(a|0);p()}function QO(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-16|0;fb=b;a:{c=x[a+36>>2];d=x[a+40>>2];b:{if(Ib(c,d)){tc(b+12|0);break b}wo(b,a);x[31609]=0;c=R(1056,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}x[b+12>>2]=c;nf(b);d=x[a+40>>2];c=x[a+36>>2]}c=(f=a+36|0,g=x[b+12>>2],h=Ib(c,d),h?f:g);a=x[a+8>>2];c:{if((a|0)==-1){a=wb(x[c>>2]);x[b>>2]=a;c=wb(x[c+4>>2]);while(1){if(!Ib(a,c)){break c}e=e+C[a>>3];a=x[fA(b)>>2];continue}}e=C[wf(x[c>>2],a)>>3]}xl(b+12|0);fb=b+16|0;return+e}a=N()|0;nf(b);Q(a|0);p()}function FH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-144|0;fb=f;v[f+140|0]=0;v[f+141|0]=0;v[f+142|0]=0;v[f+143|0]=0;v[f+137|0]=0;v[f+138|0]=0;v[f+139|0]=0;v[f+140|0]=0;v[f+136|0]=37;st(f+137|0,10799,e,x[b+4>>2]);e=Od();x[f>>2]=d;d=f+123|0;e=ph(d,13,e,f+136|0,f)+d|0;h=jj(d,e,x[b+4>>2]);g=f+4|0;cd(g,x[b+28>>2]);x[31609]=0;i=d;d=f+16|0;ga(1269,i|0,h|0,e|0,d|0,f+12|0,f+8|0,g|0);e=x[31609];x[31609]=0;a:{if((e|0)!=1){_b(g);a=pt(a,d,x[f+12>>2],x[f+8>>2],b,c);fb=f+144|0;break a}a=N()|0;_b(f+4|0);Q(a|0);p()}return a}function Cpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;cc(c+8|0,b,26);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function Zm(a,b,c,d){var e=0;a:{e=a+1074312|0;if(Ob(e,84)){break a}b:{if(y[a+480209|0]&64){break b}if((d|0)!=8){if(!Ob(e,10)){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+784>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;if(!Ob(e,10)){break a}v[b+831|0]=0;w[b+778>>1]=0}}function AW(a,b,c,d,e,f){b=y[(b&15)+25408|0];v[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=y[a+5|0]&15;if(!b){break a}v[a+5|0]=b;return;case 3:b=y[a+5|0];b=D(b&240,10)|b&15;v[a+5|0]=b;d=b&255;b=z[e>>1];if(!(d|(b|0)==65535)){v[a+5|0]=b;v[a+3|0]=12;w[e>>1]=65535}xc(f,c);return;case 1:w[e>>1]=y[a+5|0];x[f>>2]=63;v[a+3|0]=0;return;case 5:b=y[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|D(c,-10)+b;v[a+5|0]=b}if(b&255){break a}v[a+3|0]=0;return;case 7:break a;default:break b}}if(y[a+5|0]){break a}v[a+3|0]=0}}function qs(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a=Fb(a);a:{b:{c:{switch(b-1|0){default:x[31609]=0;b=P(1,d+4|0,15924)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}break b;case 0:x[31609]=0;b=P(1,d+4|0,15949)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}break a;case 1:x[31609]=0;b=P(1,d+4|0,15897)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}break a;case 2:break c}}x[31609]=0;b=P(1,d+4|0,15871)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}}zb(a,b);tb(b);fb=d+16|0;return}b=N()|0;tb(a);Q(b|0);p()}function kra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=Cx(c+4|0,a);d=x[a+4>>2];x[31609]=0;O(501,d|0,b|0);b=x[31609];x[31609]=0;a:{if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+12;jc(a);fb=c+16|0;break a}b=N()|0;jc(a);Q(b|0);p()}return}d=fb-32|0;fb=d;c=Ab(a);c=ym(d+12|0,Qp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);e=x[c+8>>2];x[31609]=0;O(501,e|0,b|0);b=x[31609];x[31609]=0;b:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+12;Bx(a,c);ws(c);fb=d+32|0;break b}a=N()|0;ws(c);Q(a|0);p()}}function jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;fd(e+8|0,b,c);c=x[e+8>>2];f=x[e+12>>2];b=fb-48|0;fb=b;x[b+44>>2]=d;x[b+40>>2]=d;a=Ag(b+12|0,a,b+40|0,b+44|0);x[b+8>>2]=x[a+8>>2];d=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=d;zg(b+24|0,b);a:{while(1){if((c|0)==(f|0)){break a}x[31609]=0;O(1124,x[b+44>>2],c|0);a=x[31609];x[31609]=0;if((a|0)!=1){x[b+44>>2]=x[b+44>>2]+16;c=c+16|0;continue}break}a=N()|0;aN(b+24|0);Q(a|0);p()}a=b+24|0;yg(a);c=x[b+44>>2];aN(a);fb=b+48|0;fb=e+16|0;return c|0}function B4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{c:{if(b){if(Xs(a)){break c}}if(m){if(Ws(a)){break c}}if(l){if(Vs(a)){break c}}if(k){if(Us(a)){break c}}if(j){if(Ts(a)){break c}}if(i){if(Ss(a)){break c}}if(h){if(_n(a)){break c}}if(g){if(Rs(a)){break c}}if(f){if($n(a)){break c}}if(!e){break b}if(!Qs(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0);x[31609]=0;W(996,a|0);d=x[31609];x[31609]=0;a:{if((d|0)==1){break a}x[31609]=0;W(1068,c|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}d=x[a+24>>2];e=B[d+48>>2];d=x[d+24>>2];x[31609]=0;b=Ya(1069,d|0,E(e),b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}Y(T(0)|0)|0;x[31609]=0;V(983,10369,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Q9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;fd(e+8|0,b,c);c=x[e+8>>2];f=x[e+12>>2];b=fb-48|0;fb=b;x[b+44>>2]=d;x[b+40>>2]=d;a=Ag(b+12|0,a,b+40|0,b+44|0);x[b+8>>2]=x[a+8>>2];d=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=d;zg(b+24|0,b);a:{while(1){if((c|0)==(f|0)){break a}x[31609]=0;O(1208,x[b+44>>2],c|0);a=x[31609];x[31609]=0;if((a|0)!=1){x[b+44>>2]=x[b+44>>2]+12;c=c+12|0;continue}break}a=N()|0;$L(b+24|0);Q(a|0);p()}a=b+24|0;yg(a);c=x[b+44>>2];$L(a);fb=b+48|0;fb=e+16|0;return c|0}function Zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=fb-32|0;fb=e;nd(b,0);d=e+8|0;RD(d,a+1|0);c=e+20|0;Cc(c,d);Be(b+43|0,c);tb(c);x[b+24>>2]=y[a+73|0]|y[a+74|0]<<8|(y[a+75|0]<<16|y[a+76|0]<<24);c=y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);d=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);if(d){x[b+8>>2]=d+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;xc(b+8|0,c);xc(b+4|0,x[b+8>>2]);fb=e+32|0}function cn(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=d<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function iH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Kb(e);jC(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=ki(Cb(x[e+4>>2],y[e+11|0]));x[31609]=0;O(45,e|0,g|0);g=x[31609];x[31609]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Kb(e);x[31609]=0;O(46,e|0,b-c|0);b=x[31609];x[31609]=0;c:{if((b|0)!=1){x[31609]=0;O(d|0,a|0,e|0);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function $G(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Kb(e);EN(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=ki(Cb(x[e+4>>2],y[e+11|0]));x[31609]=0;O(45,e|0,g|0);g=x[31609];x[31609]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Kb(e);x[31609]=0;O(46,e|0,b-c|0);b=x[31609];x[31609]=0;c:{if((b|0)!=1){x[31609]=0;O(d|0,a|0,e|0);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function tH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=rf(f+20|0,1,0);a:{b:{while(1){g=Kb(e);jC(f+12|0,g,Cb(x[e+4>>2],y[e+11|0])+g|0,y[b|0],c);if(!x[f+16>>2]){break b}g=ki(Cb(x[e+4>>2],y[e+11|0]));x[31609]=0;O(45,e|0,g|0);g=x[31609];x[31609]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Kb(e);x[31609]=0;O(46,e|0,b-c|0);b=x[31609];x[31609]=0;c:{if((b|0)!=1){x[31609]=0;O(d|0,a|0,e|0);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function Ufa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{b:{if(!a){a=Cg(22292);break b}x[31609]=0;c=P(36,b+8|0,a|0)|0;a=x[31609];x[31609]=0;c:{d:{if((a|0)!=1){x[31609]=0;d=b+20|0;O(982,d|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break d}a=Cg(Kb(d));tb(d);tb(c);break b}a=T(0)|0;break c}a=T(0)|0;tb(c)}Y(a|0)|0;a=0;x[31609]=0;V(983,11031,0,0,0);c=x[31609];x[31609]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Js(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;a=fO(a);x[a+8>>2]=0;x[a>>2]=47628;x[31609]=0;i=R(852,104)|0;h=x[31609];x[31609]=0;a:{b:{c:{d:{if((h|0)!=1){x[31609]=0;d=R(1099,d|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break d}x[g+8>>2]=d;d=g+8|0;h=x[re(g+12|0,d)>>2];x[31609]=0;b=ha(f|0,i|0,b|0,c|0,h|0,e|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}x[a+8>>2]=b;Wc(d);b=x[a+8>>2];Bd(a,b?b+8|0:0);fb=g+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Wc(g+8|0)}Db(i)}Pm(a);Q(b|0);p()}function WF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=f;a:{if(!f){break a}c=b+80|0;d=x[b+84>>2];if(d>>>0<=15){d=x[c>>2]}else{x[e+12>>2]=d-16;d=x[bd(c,e+12|0)>>2]}x[a+8>>2]=d;c=x[b+88>>2];if(!(c&2)){break a}d=c;c=x[b+104>>2];b:{c:{if(!UF(d,c)){d=x[b+84>>2];break c}d=x[b+84>>2];if(x[b+80>>2]!=x[c+12>>2]){break c}b=1;if(x[c+16>>2]==(d|0)){break b}}b=0;if(x[c+8>>2]!=(d|0)){break a}}g=a,h=D((x[c>>2]-d|0)+(b?112:48)|0,Zk(z[c+34>>1]))+f|0,x[g+4>>2]=h}fb=e+16|0}function HH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb+-64|0;fb=f;v[f+60|0]=0;v[f+61|0]=0;v[f+62|0]=0;v[f+63|0]=0;v[f+57|0]=0;v[f+58|0]=0;v[f+59|0]=0;v[f+60|0]=0;v[f+56|0]=37;st(f+57|0,10799,e,x[b+4>>2]);e=Od();x[f>>2]=d;d=f+43|0;e=ph(d,13,e,f+56|0,f)+d|0;h=jj(d,e,x[b+4>>2]);g=f+4|0;cd(g,x[b+28>>2]);x[31609]=0;i=d;d=f+16|0;ga(1265,i|0,h|0,e|0,d|0,f+12|0,f+8|0,g|0);e=x[31609];x[31609]=0;a:{if((e|0)!=1){_b(g);a=tw(a,d,x[f+12>>2],x[f+8>>2],b,c);fb=f- -64|0;break a}a=N()|0;_b(f+4|0);Q(a|0);p()}return a}function Una(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{f=fb-48|0;fb=f;g=f+12|0;Gr(g,c);x[31609]=0;c=f+24|0;O(597,c|0,d|0);d=x[31609];x[31609]=0;b:{c:{d:{if((d|0)==1){break d}x[31609]=0;c=f+36|0;O(597,c|0,e|0);d=x[31609];x[31609]=0;if((d|0)==1){break d}wx(f+4|0,g);x[31609]=0;V(301,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Tn(g);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;Tn(f+12|0)}Q(a|0);p()}}function Po(a){var b=0,c=0,d=0,e=0;d=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;b=((d&3)<<4)+26192|0;x[a+40>>2]=b;e=z[a+24>>1];d=d>>>2|0;c=e+d|0;w[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;w[a+32>>1]=c;w[a+34>>1]=-1<<c^-1;if((e|0)==15){w[a+36>>1]=4095}x[a+52>>2]=b;x[a+64>>2]=b;b=d+z[a+26>>1]|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;w[a+44>>1]=c;b=d+z[a+30>>1]|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+46>>1]=-1<<c^-1;w[a+58>>1]=-1<<b^-1}function mN(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];c=qq(a);d:{if(!c){if(pq(a)>>>0<=b>>>0){break d}c=(y[ni(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=dc(8);x[31609]=0;b=P(36,d+4|0,6e3)|0;c=x[31609];x[31609]=0;e:{if((c|0)!=1){sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;lc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(y[a+15|0]&2)>>>1|0}fb=d+16|0;return c|0}p()}function F2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;a:{b:{c:{d:{if(g=Ad(x[b+4>>2],y[b+11|0]),h=1,i=x[b+12>>2],i?g:h){Fb(a);break d}c=Cb(x[b+4>>2],y[b+11|0]);e=d+20|0;f=es(14355);$l(Xg(Xg(Kb(Hz(e,c+f|0)),Kb(b),c)+c|0,14355,f)+f|0,1,0);x[31609]=0;c=d+8|0;O(126,c|0,b+12|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}x[31609]=0;S(2,a|0,e|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}tb(c);tb(e)}fb=d+32|0;return}b=N()|0;break a}b=N()|0;tb(d+8|0)}tb(d+20|0);Q(b|0);p()}function $O(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;e=Nb(a);ie(c+24|0);a=0;b=x[c+28>>2];d=x[c+24>>2];x[31609]=0;O(176,e|0,XL(d,b)|0);b=x[31609];x[31609]=0;a:{if((b|0)!=1){b:{while(1){b=x[c+24>>2];if((XL(b,x[c+28>>2])|0)<=(a|0)){fb=c+32|0;return}b=x[b+(a<<3)>>2];x[31609]=0;b=P(36,c+12|0,b|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){x[31609]=0;O(178,e|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break b}tb(b);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0}Td(e);Q(a|0);p()}function z2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{f=fb-48|0;fb=f;g=f+12|0;Op(g,c);x[31609]=0;c=f+24|0;O(133,c|0,d|0);d=x[31609];x[31609]=0;b:{c:{d:{if((d|0)==1){break d}x[31609]=0;c=f+36|0;O(133,c|0,e|0);d=x[31609];x[31609]=0;if((d|0)==1){break d}wx(f+4|0,g);x[31609]=0;V(92,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Tn(g);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;Tn(f+12|0)}Q(a|0);p()}}function Qia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);e=fb-16|0;fb=e;f=If(a,c);ae(e,x[a+36>>2]);h=a;a:{if(!f){Qc(e,a+32|0,5);c=0;if(Gb(x[x[e>>2]>>2],x[e+4>>2])){break a}}c=0;d=fb-16|0;fb=d;g=x[a+36>>2];ol(g,d+8|0);i=d,j=Bc(x[d+8>>2],x[d+12>>2]),x[i+4>>2]=j;x[d>>2]=256;Cl(b,x[Hb(d+4|0,d)>>2]);a=x[b>>2];while(1){if(oc(a,x[b+4>>2])>>>0<=c>>>0){fb=d+16|0}else{x[d+4>>2]=0;wq(g,d+4|0);a=x[b>>2];i=yb(a,c),k=B[d+4>>2],B[i>>2]=k;c=c+1|0;continue}break}c=f}ef(h,c);fb=e+16|0}function Is(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;a=fO(a);x[a+8>>2]=0;x[a>>2]=47628;x[31609]=0;h=R(852,104)|0;g=x[31609];x[31609]=0;a:{b:{c:{d:{if((g|0)!=1){x[31609]=0;c=R(1099,c|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break d}x[f+8>>2]=c;c=f+8|0;g=x[re(f+12|0,c)>>2];x[31609]=0;b=ba(e|0,h|0,b|0,g|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}x[a+8>>2]=b;Wc(c);b=x[a+8>>2];Bd(a,b?b+8|0:0);fb=f+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Wc(f+8|0)}Db(h)}Pm(a);Q(b|0);p()}function C4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{if(b){if(Xs(a)){break b}}if(m){if(Ws(a)){break b}}if(l){if(Vs(a)){break b}}if(k){if(Us(a)){break b}}if(j){if(Ts(a)){break b}}if(i){if(Ss(a)){break b}}if(h){if(_n(a)){break b}}if(g){if(Rs(a)){break b}}if(f){if($n(a)){break b}}if(e){if(Qs(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function hN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-32|0;fb=d;C[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=dc(8);x[31609]=0;d=P(36,d+8|0,10751)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,d);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=x[a+32>>2];x[d+8>>2]=0;x[d+12>>2]=-1074790400;x[d>>2]=0;x[d+4>>2]=1072693248;e=(D(b,872)+a|0)+1075684|0,f=Si(C[Yg(d+24|0,d+8|0,d)>>3]*128+128),x[e>>2]=f;fb=d+32|0;return}a=N()|0;lc(b)}Q(a|0)}p()}function tja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;e=d+8|0;Vi(e,2,a+2|0);f=d+20|0;Cc(f,e);Ac(b+492|0,f);e=b+236|0;g=c+1|0;h=a+31|0;tb(f);c=0;while(1){if((c|0)==120){x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;nR(y[a|0]&15,y[a+1|0]&15,y[a+2|0]&15,y[a+3|0]&15,y[a+4|0]&15,a+5|0,b+48|0);nR(y[a|0]>>>4|0,y[a+1|0]>>>4|0,y[a+2|0]>>>4|0,y[a+3|0]>>>4|0,y[a+4|0]>>>4|0,a+35|0,b+68|0);fb=d+32|0}else{i=ac(e,c),j=y[c+h|0]+g|0,w[i>>1]=j;c=c+1|0;continue}break}}function HM(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=x[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(A[a+12>>2]<=d>>>0)){while(1){f=TA(x[a>>2]);e=hb;c=x[a+36>>2];if((e|0)==(c|0)&A[a+32>>2]<=f>>>0|e>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){f=TA(x[a>>2]);d=hb;c=x[a+28>>2];if((d|0)==(c|0)&A[a+24>>2]<=f>>>0|d>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function ZU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;i=b?33:32;c=x[a+8>>2]-1|0;e=x[a+12>>2];f=x[a>>2]+D(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(i|0)){break b}while(1)if((b|0)>=(e|0)){b=x[a+8>>2]-1|0;c:{if(!((b|0)!=(c|0)|(d|0)<=0)){if(!y[a+16|0]){d=1;c=0;break c}d=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=y[a+16|0];d=c?1:-1;c=c?0:b;break c}c=c+d|0}f=D(e,g)+f|0;h=h+1|0;continue a}else{v[b+f|0]=y[(x[a+4>>2]+D(c,e)|0)+b|0];b=b+1|0;e=x[a+12>>2];continue}}break}}function $f(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){e=f+-64|0;f=b;d=e&31;if((e&63)>>>0>=32){e=f<<d;d=0}else{e=(1<<d)-1&f>>>32-d|c<<d;d=f<<d}b=0;c=0;break a}if(!f){break a}h=d;g=f&31;if((f&63)>>>0>=32){i=d<<g;h=0}else{i=(1<<g)-1&h>>>32-g|e<<g;h=h<<g}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;d=c>>>d|0}else{e=c>>>d|0;d=((1<<d)-1&c)<<32-d|g>>>d}d=h|d;e=e|i;h=b;g=f&31;if((f&63)>>>0>=32){i=b<<g;b=0}else{i=(1<<g)-1&h>>>32-g|c<<g;b=h<<g}c=i}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function rX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+8|0]){while(1){if((d|0)==8){x[c+24>>2]=0;x[c+28>>2]=0;d=Zb(c+8|0,c+24|0,8);e=x[d>>2];kc(c+16|0,x[a>>2],x[a+8>>2],e,x[d+4>>2]);d=0;if(!(x[c+24>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|x[c+28>>2]!=(y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24))|x[c+20>>2]!=8)){Vb(a,8);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17516,9095,602,13238);p()}_(17495,9095,600,13238);p()}return d|0}function p7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Cb(x[a+4>>2],y[a+11|0]);d=Mc(a);f=Pj(b,c);a:{if(!f){break a}b:{if(!I_(a,b)){if(d-e>>>0<f>>>0){an(a,d,(e-d|0)+f|0,e,e,0,0)}d=Kb(a)+e|0;while(1){if((b|0)==(c|0)){break b}hd(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=Xl(g+4|0,b,c);c=Kb(b);e=y[b+11|0];d=x[b+4>>2];x[31609]=0;U(1282,a|0,c|0,Cb(d,e)|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}hd(d,0);lg(a,e+f|0)}fb=g+16|0;return a|0}function tx(a){var b=0,c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){b=fb-16|0;fb=b;a=nG(b+4|0,a);c=x[a+4>>2];x[31609]=0;W(164,c|0);c=x[31609];x[31609]=0;a:{if((c|0)!=1){x[a+4>>2]=x[a+4>>2]+36;jc(a);fb=b+16|0;break a}b=N()|0;jc(a);Q(b|0);p()}return}c=fb-32|0;fb=c;b=Ab(a);b=lG(c+12|0,mG(a,fs(x[a>>2],x[a+4>>2])+1|0),fs(x[a>>2],x[a+4>>2]),b);d=x[b+8>>2];x[31609]=0;W(164,d|0);d=x[31609];x[31609]=0;b:{if((d|0)!=1){x[b+8>>2]=x[b+8>>2]+36;kG(a,b);ix(b);fb=c+32|0;break b}a=N()|0;ix(b);Q(a|0);p()}}function ep(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=xb(b,0);f=(y[h|0]&15)<<8|y[xb(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{i=e<<1;d=z[i+31040>>1];if(d>>>0<=f>>>0){if(!e|(f|0)==(d|0)|(z[i+31038>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}v[c|0]=d;e=xb(b,2);d=y[e|0];f=y[h|0];v[c+3|0]=0;v[c+1|0]=f&16|d>>>4;c=y[e|0];j=g,k=y[xb(b,3)|0],v[j+15|0]=k;ee(a,c&15,g+15|0);fb=g+16|0}function a1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;nd(b,0);e=d+8|0;dk(e,1,a+33|0);c=d+20|0;Cc(c,e);Be(b+43|0,c);tb(c);f=y[a+50|0]|y[a+51|0]<<8;x[b>>2]=f;x[b+24>>2]=y[a+52|0]|y[a+53|0]<<8;v[d+20|0]=y[a+54|0];v[d+8|0]=64;g=b,h=y[Qb(c,e)|0]<<2,w[g+30>>1]=h;e=y[a+55|0]|y[a+56|0]<<8;x[b+4>>2]=e;c=y[a+57|0]|y[a+58|0]<<8;x[b+8>>2]=c;a:{if((c|0)==65535){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(!y[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=d+32|0}function cS(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];d=(g<<3)+a|0;b=((g+7>>>0)%12<<3)+a|0;f=x[b>>2];e=x[b+4>>2];b=x[a+100>>2];j=b;h=x[a+96>>2];a:{if(!(b|h)){c=x[d+4>>2];b=x[d>>2];i=(c|0)==(e|0)&b>>>0>f>>>0|e>>>0<c>>>0;break a}c=x[d+4>>2];b=x[d>>2];i=!(e|f)|((c|0)==(e|0)&b>>>0>=f>>>0|e>>>0<c>>>0)}c=c+j|0;b=b+h|0;c=b>>>0<h>>>0?c+1|0:c;x[d>>2]=f-b;x[d+4>>2]=e-(c+(b>>>0>f>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=i;x[a+100>>2]=0;hb=x[d+4>>2];return x[d>>2]}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Si(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=(D(g,h)<<2)+k|0;e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e<<2)+m|0;f=x[i>>2];f=Bua(Aua(f,f>>31,d,j),hb,65536,0);n=i,o=Gc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;EM(a,c);fb=c+16|0}function Daa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Si(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=(D(g,h)<<2)+k|0;e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e<<2)+m|0;f=x[i>>2];f=Bua(Aua(f,f>>31,d,j),hb,65536,0);n=i,o=Gc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;yM(a,c);fb=c+16|0}function ira(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Qj(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=de(a);a:{if(d){b=gc(a);while(1){a=d;d=z[a+16>>1];if($o(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!$o(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){pZ(c,f,e+4|0);$g(f,x[c+12>>2],b,x[c>>2]);a=ne(c);oZ(c);h=1}_g(e+8|0,x[vb(c,a)>>2],h);fb=c+16|0;a=ud(x[e+8>>2]);fb=e+16|0;return a+4|0}function Sk(a,b,c){var d=0;d=z[a+34>>1];if(!b){if(d&512){xp(a);d=z[a+34>>1]}w[a+34>>1]=d&65023;return}x[a>>2]=4;w[a+34>>1]=d&64958|512;Gh(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}function AA(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;a:{if(!c){b=Yd(x[a>>2],b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;AA(a,b,f,e+16|0);g=C[d>>3];h=C[d+8>>3];d=Yd(x[a>>2],c);Li(e+32|0,g,h,C[d>>3],C[d+8>>3]);d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;AA(a,b|c,f,e)}fb=e+48|0}function TQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Qj(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=de(a);a:{if(d){b=gc(a);while(1){a=d;d=z[a+16>>1];if(Yq(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!Yq(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){pZ(c,f,e+4|0);$g(f,x[c+12>>2],b,x[c>>2]);a=ne(c);oZ(c);h=1}_g(e+8|0,x[vb(c,a)>>2],h);fb=c+16|0;a=ud(x[e+8>>2]);fb=e+16|0;return a+4|0}function ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);c=x[b>>2];e=c;d=x[b+4>>2];f=d;d=$c(c,d);c=fb-16|0;fb=c;Rd(c+8|0,x[vb(c+4|0,a)>>2]);b:{c:{if(d){x[31609]=0;O(641,a|0,d|0);g=x[31609];x[31609]=0;if((g|0)==1){break c}dv(a,e,f,d)}d=c+8|0;Qd(d);Rj(d);fb=c+16|0;break b}a=N()|0;Rj(c+8|0);Q(a|0);p()}x[31609]=0;P(3,a+12|0,b+12|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){x[a+24>>2]=x[b+24>>2];w[a+28>>1]=z[b+28>>1];break a}b=N()|0;od(a);Q(b|0);p()}}function Gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-48|0;fb=f;d=x[a+36>>2];ig(x[x[d>>2]-12>>2]+d|0,0);d=x[b>>2];g=x[d+8>>2];e=x[d+12>>2];if(g|e){h=x[a+36>>2];e=x[a+20>>2]+e|0;d=x[a+16>>2];g=g+d|0;e=ai(f+32|0,g,d>>>0>g>>>0?e+1|0:e);d=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=d;d=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=d;Tm(h,f)}d=f+16|0;ae(d,x[a+36>>2]);WB(x[a+36>>2],c,x[x[b>>2]+16>>2]);c=x[b>>2];b=rl(d,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);ef(a,c);Eb(b);fb=f+48|0}function Xpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb+-64|0;fb=d;b=-1;a:{if(!wm(a,1084)){break a}Wl(a,1080);c=d+60|0;aY(a,c);f=$X(d+40|0);b=0;if(!_X(c,f)){break a}Wl(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=A[f+4>>2]>=h>>>0}else{c=y[f+16|0];e=fb-16|0;fb=e;b:{g=d+10|0;if(!ZX(a,g)|!c){break b}Gv(e+8|0,g);c=0;while(1){if(c>>>0>=30){break b}i=x[e+8>>2];rg(xb(i,c),xb(i,c|1));c=c+2|0;continue}}fb=e+16|0;b=b+1|0;h=_C(g)+h|0;continue}break}}fb=d- -64|0;return b|0}function VH(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;x[31609]=0;W(996,a|0);j=x[31609];x[31609]=0;a:{b:{if((j|0)!=1){c:{j=x[a+24>>2];x[31609]=0;k=h;h=i+4|0;ga(k|0,h|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}b=Cg(Kb(h));tb(h);break b}}Y(T(0)|0)|0;b=0;x[31609]=0;V(983,g|0,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z()}fb=i+16|0;return b}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function pt(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b>>2;if((h|0)>0){if((np(a,b,h)|0)!=(h|0)){break b}}b=d-b>>2;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=Ay(i+4|0,b,f);g=Kb(f);x[31609]=0;g=U(1271,a|0,g|0,b|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}Ub(f);if((b|0)!=(g|0)){break b}}b=d-c>>2;if((b|0)>0){if((np(a,c,b)|0)!=(b|0)){break b}}vE(e);j=a}fb=i+16|0;return j|0}a=N()|0;Ub(f);Q(a|0);p()}function ON(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=c-b|0;a:{if((f|0)<=19){i=D(64-eu(d|1,e)|0,1233)>>>12|0;j=(i<<3)+121344|0;g=f;f=x[j+4>>2];h=61;if((g|0)<(((e|0)==(f|0)&d>>>0>=A[j>>2]|e>>>0>f>>>0)+i|0)){break a}}b:{if(!e){c=AB(b,d);break b}if((e|0)==2&d>>>0>=1410065408|e>>>0>2){c=Cua(d,e,1410065408,2);f=Aua(c,hb,-1410065408,-3);e=e+hb|0;g=d;d=d+f|0;e=g>>>0>d>>>0?e+1|0:e;b=AB(b,c)}c=Cua(d,e,1e8,0);e=hb;b=Il(b,c);c=Aua(c,e,-1e8,0)+d|0;c=Qu(b,c)}h=0}x[a+4>>2]=h;x[a>>2]=c}function rs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!vd(y[a+11|0])){c=y[b+11|0];if(!vd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Kb(b);b=Cb(x[b+4>>2],c);a:{if(b>>>0<=10){Ne(a,b);hd(Xg(a,d,b)+b|0,0);break a}e=a;a=Hh(y[a+11|0]);Uq(e,10,b-10|0,a,0,a,b,d)}return}d=Kb(b);b=Cb(x[b+4>>2],y[b+11|0]);c=Zi(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Bd(a,b);hd(Xg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];Uq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function UH(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;x[31609]=0;W(996,a|0);i=x[31609];x[31609]=0;a:{b:{if((i|0)!=1){c:{i=x[x[a+24>>2]+24>>2];x[31609]=0;j=g;g=h+4|0;ja(j|0,g|0,i|0,b|0,c|0,d|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}b=Cg(Kb(g));tb(g);break b}}Y(T(0)|0)|0;b=0;x[31609]=0;V(983,f|0,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z()}fb=h+16|0;return b}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function FE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!vd(y[a+11|0])){c=y[b+11|0];if(!vd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Kb(b);b=Cb(x[b+4>>2],c);a:{if(b>>>0<=10){Ne(a,b);hd(Dg(a,d,b)+b|0,0);break a}e=a;a=Hh(y[a+11|0]);Zp(e,10,b-10|0,a,0,a,b,d)}return}d=Kb(b);b=Cb(x[b+4>>2],y[b+11|0]);c=Zi(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Bd(a,b);hd(Dg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];Zp(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=fb-16|0;fb=b;d=x[a+20>>2];c=x[d+4>>2];a:{if(!((Xc(c,x[d+8>>2])|0)!=7|(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))!=1869112133)){d=wb(c);g=wb(x[x[a+20>>2]+8>>2]);Jr(b+8|0,a+4228|0);f=wb(x[b+8>>2]);e=fb-16|0;fb=e;c=fb-32|0;fb=c;fd(c+24|0,d,g);cv(c+16|0,x[c+24>>2],x[c+28>>2],f);d=P_(d,x[c+16>>2]);h=c,i=_D(f,x[c+20>>2]),x[h+12>>2]=i;qc(e+8|0,d,c+12|0);fb=c+32|0;fb=e+16|0;break a}bA(a,a)}mu(a);fb=b+16|0}function dY(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;e=z[c>>1];while(1){a:{e=e<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Bf(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!Bf(a,f+14|0)){break a}e=y[f+14|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;e=y[c|0];w[c>>1]=e;if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}fb=f+16|0}function Hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];ig(x[x[e>>2]-12>>2]+e|0,0);e=x[b>>2];h=x[e+8>>2];f=x[e+12>>2];if(h|f){i=x[a+36>>2];f=x[a+20>>2]+f|0;e=x[a+16>>2];h=h+e|0;f=ai(g+32|0,h,e>>>0>h>>>0?f+1|0:f);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;Tm(i,g)}e=g+16|0;ae(e,x[a+36>>2]);PQ(d,x[a+36>>2],c);c=x[b>>2];b=rl(e,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);ef(a,c);Eb(b);fb=g+48|0}function Fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];ig(x[x[e>>2]-12>>2]+e|0,0);e=x[b>>2];h=x[e+8>>2];f=x[e+12>>2];if(h|f){i=x[a+36>>2];f=x[a+20>>2]+f|0;e=x[a+16>>2];h=h+e|0;f=ai(g+32|0,h,e>>>0>h>>>0?f+1|0:f);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;Tm(i,g)}e=g+16|0;ae(e,x[a+36>>2]);LQ(c,x[a+36>>2],d);c=x[b>>2];b=rl(e,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);ef(a,c);Eb(b);fb=g+48|0}function x7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;c=fb-128|0;fb=c;x[c+12>>2]=c+116;d=c+16|0;dK(x[a+8>>2],d,c+12|0,e,f,g);f=fb-16|0;fb=f;h=f+8|0;a=fb-32|0;fb=a;fd(a+24|0,d,x[c+12>>2]);i=a+16|0;e=x[a+24>>2];g=x[a+28>>2];d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if((e|0)!=(g|0)){cL(d+12|0,v[e|0]);e=e+1|0;continue}break}qc(i,g,d+12|0);fb=d+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];qc(h,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=c+128|0;return x[f+12>>2]}function tw(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((np(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=rf(i+4|0,b,f);g=Kb(f);x[31609]=0;g=U(32,a|0,g|0,b|0)|0;h=x[31609];x[31609]=0;if((h|0)==1){break a}tb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((np(a,c,b)|0)!=(b|0)){break b}}vE(e);j=a}fb=i+16|0;return j|0}a=N()|0;tb(f);Q(a|0);p()}function zK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31484];x[31484]=0;Od();a=Iy(a,e+12|0,d);d=hb;g=x[31484];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}x[31484]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0<65536){break b}}x[c>>2]=4;a=65535;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a&65535}function Ota(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=jg(d+4|0,c+16|0);f=_c(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[ec(b,0)|0]==43){break c}if(y[ec(b,0)|0]==45){break c}}x[31609]=0;U(304,b|0,f-c|0,e|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}Uc(a,b);fb=d+16|0}function Mz(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}d=b&255;if(!((d|0)==y[a|0]|c>>>0<4)){d=D(d,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ji(a,b,c,d);x[a>>2]=42476;b=Nb(a+4208|0);x[a+4236>>2]=-1;x[a+4240>>2]=0;x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;v[a+4244|0]=0;Rb(a+4248|0,0,48);x[31609]=0;X(850);c=x[31609];x[31609]=0;a:{if((c|0)==1){break a}e=a,f=jS(),x[e+4296>>2]=f;ru(a);qu(a);x[31609]=0;O(941,a+44|0,2);c=x[31609];x[31609]=0;if((c|0)==1){break a}return a|0}c=N()|0;fc(b);_f(a);Q(c|0);p()}function fm(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if((db()|0)>0){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31609]=0;b=R(31,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[31609]=0;O(24,a+b|0,1);a=x[31609];x[31609]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break a}}return}T(0)|0;Sb();p()}function Jna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=vm(d+4|0,c+16|0);f=_c(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[ec(b,0)|0]==43){break c}if(y[ec(b,0)|0]==45){break c}}x[31609]=0;U(48,b|0,f-c|0,e|0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}Uc(a,b);fb=d+16|0}function eT(a,b){var c=0,d=0,e=0,f=0,g=0;a:{if(y[b+791|0]!=27){a=v[b+831|0];break a}e=a+1074312|0;c=Ob(e,21);d=a;a=y[b+821|0];a=KA(d,y[b+828|0],c?a:a+16>>>2|0);b:{if(!(!Ob(e,45)|y[b+828|0]!=3)){c=y[b+821|0];c:{if(!(!c|c>>>0>=y[b+829|0])){a=y[b+832|0];d=c+1|0;break c}v[b+832|0]=a;d=1}v[b+821|0]=d;a=a<<24>>24;break b}v[b+821|0]=y[b+821|0]+y[b+829|0]}if(!Ob(e,47)){break a}v[b+831|0]=a}if(a){f=b,g=Yb(x[b+684>>2]+((D(y[b+830|0],a)+2|0)/8|0)|0,0,256),x[f+684>>2]=g}}function eH(a,b,c,d,e,f){var g=0,h=0;a:{g=fb-48|0;fb=g;h=g+12|0;ao(h,c);x[31609]=0;c=g+24|0;O(f|0,c|0,d|0);d=x[31609];x[31609]=0;b:{c:{d:{if((d|0)==1){break d}x[31609]=0;c=g+36|0;O(91,c|0,e|0);d=x[31609];x[31609]=0;if((d|0)==1){break d}wx(g+4|0,h);x[31609]=0;V(92,a|0,b|0,x[g+4>>2],x[g+8>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Tn(h);fb=g+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+12|0)){continue}break}break b}a=N()|0;Tn(g+12|0)}Q(a|0);p()}}function YQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<=127){f=fb-32|0;fb=f;c=128-c|0;e=x[Ab(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){oA(a,c,b);break a}e=Ab(a);d=Zf(f+12|0,Lf(a,oc(x[a>>2],d)+c|0),oc(x[a>>2],x[a+4>>2]),e);g=fb-16|0;fb=g;c=Fn(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){tk(e,B[b>>2]);e=x[c>>2]+4|0;x[c>>2]=e;continue}break}je(c);fb=g+16|0;nA(a,d);Yf(d)}fb=f+32|0;return}if((c|0)!=128){Jd(a,d+512|0)}}function ER(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{if((c|0)<2){break a}i=c-2>>>1|0;e=d-a|0;if((i|0)<e>>1){break a}g=e+1|0;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=El(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(El(b,z[f>>1],z[d>>1])){break a}j=z[d>>1];while(1){b:{e=d;d=f;w[e>>1]=z[f>>1];if((g|0)>(i|0)){break b}e=g<<1;g=e|1;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=El(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(!El(b,z[f>>1],j)){continue}}break}w[d>>1]=j}}function roa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;jn(c+52|0,b);se(c+24|0,x[c+52>>2],x[c+56>>2]);b=Md(c+16|0);x[31609]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=hg(160,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31609];x[31609]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31609]=0;S(732,b|0,d|0,Xc(e,a)>>>5|0);a=x[31609];x[31609]=0;if((a|0)==1){a=N()|0;Qi(d);ub(b);break a}ub(b);fc(c+52|0);fb=c- -64|0;return}a=N()|0}fc(c+52|0);Q(a|0);p()}function ooa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;jn(c+52|0,b);se(c+24|0,x[c+52>>2],x[c+56>>2]);b=Md(c+16|0);x[31609]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=hg(160,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31609];x[31609]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31609]=0;S(733,b|0,d|0,Xc(e,a)>>>2|0);a=x[31609];x[31609]=0;if((a|0)==1){a=N()|0;wc(d);ub(b);break a}ub(b);fc(c+52|0);fb=c- -64|0;return}a=N()|0}fc(c+52|0);Q(a|0);p()}function noa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;jn(c+52|0,b);se(c+24|0,x[c+52>>2],x[c+56>>2]);b=Md(c+16|0);x[31609]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=hg(160,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31609];x[31609]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31609]=0;S(734,b|0,d|0,Xc(e,a)>>>8|0);a=x[31609];x[31609]=0;if((a|0)==1){a=N()|0;tv(d);ub(b);break a}ub(b);fc(c+52|0);fb=c- -64|0;return}a=N()|0}fc(c+52|0);Q(a|0);p()}function moa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;jn(c+52|0,b);se(c+24|0,x[c+52>>2],x[c+56>>2]);b=Md(c+16|0);x[31609]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=hg(160,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31609];x[31609]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31609]=0;S(735,b|0,d|0,Xc(e,a)>>>4|0);a=x[31609];x[31609]=0;if((a|0)==1){a=N()|0;kn(d);ub(b);break a}ub(b);fc(c+52|0);fb=c- -64|0;return}a=N()|0}fc(c+52|0);Q(a|0);p()}function Yoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;nd(b,0);e=d+8|0;RD(e,a+1|0);c=d+20|0;Cc(c,e);Be(b+43|0,c);tb(c);x[b+24>>2]=y[a+78|0]|y[a+79|0]<<8;c=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);x[b+8>>2]=y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;xc(b+8|0,c);xc(b+4|0,x[b+8>>2]);fb=d+32|0}function l1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;c=e+12|0;f=fb-16|0;fb=f;h=Ec(168);x[31609]=0;g=P(36,f+4|0,22292)|0;d=x[31609];x[31609]=0;a:{b:{c:{if((d|0)!=1){x[31609]=0;d=U(37,h|0,g|0,0)|0;i=x[31609];x[31609]=0;if((i|0)==1){break c}tb(g);x[c>>2]=d;pm(d);fb=f+16|0;break a}a=N()|0;break b}a=N()|0;tb(g)}Db(h);Q(a|0);p()}x[31609]=0;S(27,a|0,c|0,b|0);a=x[31609];x[31609]=0;if((a|0)!=1){_b(c);fb=e+16|0;return}a=N()|0;_b(c);Q(a|0);p()}function bra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=wb(x[b>>2]);h=wb(x[b+4>>2]);g=fb-16|0;fb=g;x[g+12>>2]=d;while(1){a:{if(!Ib(d,h)){break a}e=fb-16|0;fb=e;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e+10|0]=f;v[e+11|0]=f>>>8;v[e+12|0]=f>>>16;v[e+13|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8;v[e+14|0]=f;v[e+15|0]=f>>>8;fb=e+16|0;if(z[e+10>>1]==(c|0)){break a}d=x[dm(g+12|0)>>2];continue}break}fb=g+16|0;if(mc(d,wb(x[b+4>>2]))){Yh(a);return}mp(a,d)}function wK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){b:{c:{f=y[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=x[31484];x[31484]=0;Od();a=Iy(a,e+12|0,d);d=hb;d:{g=x[31484];if(g){if(x[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}x[c>>2]=4;a=-1;b=-1;break a}x[31484]=h;if(x[e+12>>2]==(b|0)){break d}break b}b=a;c=(f|0)==45;a=c?0-b|0:b;b=c?0-(d+((b|0)!=0)|0)|0:d;break a}}x[c>>2]=4;a=0;b=0}fb=e+16|0;hb=b;return a}function vT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=Qj(b),x[j+4>>2]=k;c=fb-16|0;fb=c;g=fB(a,c+12|0,y[b|0],x[b+4>>2]);b=x[g>>2];if(!b){e=fb-16|0;fb=e;b=gc(a);h=Dh(c,Ec(28),Og(e+8|0,b));b=x[h>>2];f=x[d+4>>2];i=x[f>>2];f=x[f+4>>2];x[b+24>>2]=0;x[b+16>>2]=i;x[b+20>>2]=f;j=gc(h),k=1,v[j+4|0]=k;fb=e+16|0;$g(a,x[c+12>>2],g,x[c>>2]);b=ne(c);Ik(c);e=1}_g(d+8|0,x[vb(c,b)>>2],e);fb=c+16|0;a=ud(x[d+8>>2]);fb=d+16|0;return a+8|0}function PR(a,b){var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{f=b-1&65535;if(f>>>0>3998){break a}b=D(b,104)+a|0;d=b+484380|0;if(!le(x[d>>2],x[b+484400>>2])){break a}b=1074992;while(1){if((b|0)==1298224){nn(d);x[d>>2]=0;w[d+34>>1]=z[d+34>>1]&65470;x[c+24>>2]=0;x[c+8>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Sk(d,0,c);break a}e=a+b|0;if(x[e+104>>2]==(d|0)){x[e+76>>2]=0;x[e>>2]=0;x[e+4>>2]=0;x[e+16>>2]=0}b=b+872|0;continue}}fb=c+32|0;return f>>>0<3999}function Jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=d+4|0;c=fb-32|0;fb=c;f=c+8|0;Uf(f,b);x[31609]=0;b=c+20|0;S(11,b|0,0,f|0);g=x[31609];x[31609]=0;a:{b:{c:{if((g|0)!=1){x[31609]=0;O(962,e|0,b|0);g=x[31609];x[31609]=0;if((g|0)==1){break c}Ub(b);tb(f);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}x[31609]=0;P(960,a|0,e|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){tb(e);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function QU(a,b,c,d){var e=0,f=0,g=0,h=0;h=fb-16|0;fb=h;g=x[a+4>>2];e=(g-d|0)+b|0;f=bj(h+4|0,a,c-e>>1);d=x[f+4>>2];a=e;while(1){if(a>>>0>=c>>>0){jc(f);c=fb-16|0;fb=c;a=fb-32|0;fb=a;fd(a+24|0,b,e);b=fb-16|0;fb=b;d=x[a+28>>2];e=x[a+24>>2];f=d-e|0;g=g-f|0;x[b+12>>2]=g;TU(g,e,f>>1);qc(a+16|0,d,b+12|0);fb=b+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];qc(c+8|0,b,a+12|0);fb=a+32|0;fb=c+16|0;fb=h+16|0}else{mm(d,z[a>>1]);d=d+2|0;x[f+4>>2]=d;a=a+2|0;continue}break}}function nI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(1073741806-b>>>0>=c>>>0){k=Kb(a);j=i+4|0;if(b>>>0<=536870886){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=rn(x[bd(j,i+12|0)>>2])+1|0}else{c=1073741807}Nj(j,c);c=x[i+4>>2];if(e){Ri(c,k,e)}if(g){Ri(c+(e<<2)|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){d=e<<2;Ri((d+c|0)+(g<<2)|0,(d+k|0)+(f<<2)|0,h)}if((b|0)!=1){Db(k)}yd(a,c);of(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Bd(b,a);yd(c+(a<<2)|0,0);fb=i+16|0;return}pf();p()}function w9(){var a=0,b=0,c=0,d=0,e=0,f=0;c=fb-48|0;fb=c;if(AL(1,c+24|0)){Ht(x[31484],12795);p()}b=ye(c+16|0,x[c+24>>2],x[c+28>>2]);f=ZA(c+8|0,x[c+32>>2]);d=fb-16|0;fb=d;e=fb-16|0;fb=e;a=ye(e+8|0,Aua(x[b>>2],x[b+4>>2],1e9,0),hb);b=x[a>>2];a=x[a+4>>2];fb=e+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];e=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=ye(d+8|0,e,a>>>0>e>>>0?f+1|0:f);a=x[b>>2];fb=d+16|0;b=ye(c+40|0,a,x[b+4>>2]);a=x[b>>2];fb=c+48|0;hb=x[b+4>>2];return a|0}function uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;d=fb-32|0;fb=d;fd(d+24|0,a,b);h=d+16|0;e=x[d+24>>2];g=x[d+28>>2];b=fb-16|0;fb=b;x[b+12>>2]=c;a:{while(1){if((e|0)==(g|0)){break a}c=Dc(b,x[e>>2]);x[31609]=0;P(1193,b+12|0,c|0)|0;i=x[31609];x[31609]=0;if((i|0)!=1){tb(c);e=e+4|0;continue}break}a=N()|0;tb(c);Q(a|0);p()}qc(h,g,b+12|0);fb=b+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];qc(f+8|0,lA(a,b),d+12|0);fb=d+32|0;fb=f+16|0}function _ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];k=x[a+12>>2];while(1){if(d){g=x[b+12>>2]+j|0;e=v[g|0];e=((D(v[g+1|0]-e|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;x[c>>2]=x[c>>2]+D(e,i);x[c+4>>2]=x[c+4>>2]+D(e,h);Pb(b+8|0,f,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function ZE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=$c(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){QE(a,b);break a}c=Ab(a);c=ek(e+12|0,fk(a,$c(x[a>>2],d)+b|0),$c(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Bp(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){_w(d);d=x[b>>2]+2|0;x[b>>2]=d;continue}break}je(b);fb=f+16|0;Ur(a,c);aj(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<1)|0)}}function yV(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0){f=1}else{f=(f|0)>=0}if(f){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function kta(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);f=d+8|0;Rd(f,x[vb(d+4|0,a)>>2]);x[31609]=0;W(344,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){g=fb-16|0;fb=g;b=g+4|0;x[b>>2]=a;e=x[a+4>>2];x[b+4>>2]=e;x[b+8>>2]=e+32768;c=x[b+4>>2];e=x[b+8>>2];while(1){if((c|0)==(e|0)){jc(b);fb=g+16|0}else{w[c>>1]=0;w[c+2>>1]=0;c=c+4|0;x[b+4>>2]=c;continue}break}Qd(f);bh(f);fb=d+16|0;return a|0}a=N()|0;bh(d+8|0);Q(a|0);p()}function S_(a,b,c,d){var e=0,f=0,g=0,h=0;h=fb-16|0;fb=h;g=x[a+4>>2];e=(g-d|0)+b|0;f=Yo(h+4|0,a,c-e|0);d=x[f+4>>2];a=e;while(1){if(a>>>0>=c>>>0){jc(f);c=fb-16|0;fb=c;a=fb-32|0;fb=a;fd(a+24|0,b,e);b=fb-16|0;fb=b;d=x[a+28>>2];e=x[a+24>>2];f=d-e|0;g=g-f|0;x[b+12>>2]=g;dC(g,e,f);qc(a+16|0,d,b+12|0);fb=b+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];qc(c+8|0,b,a+12|0);fb=a+32|0;fb=c+16|0;fb=h+16|0}else{qo(d,y[a|0]);d=d+1|0;x[f+4>>2]=d;a=a+1|0;continue}break}}function yua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{b:{if(!jh(a,7)){break b}c=0;if(!OE(a,18456)){break a}if(!jh(a,1)){break b}c=-1;if(!id(a,Kr(a))){break a}c=fb-16|0;fb=c;f=d+9|0;Jr(c+8|0,f);e=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){id(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){GE(f)}c=-1;if(!e){break a}c=0;if(!z0(y[d+9|0],y[d+10|0])){break a}c=xe(a,b,y0(f),hb);break a}c=-1}fb=d+16|0;return c|0}function W8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;x[d+16>>2]=b;e=x[a+48>>2];x[d+20>>2]=c-((e|0)!=0);g=x[a+44>>2];x[d+28>>2]=e;x[d+24>>2]=g;a:{b:{if(_y(cb(x[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=x[d+12>>2];if((e|0)>0){break b}b=e?32:16}x[a>>2]=b|x[a>>2];break a}f=e;g=x[d+20>>2];if(g>>>0>=e>>>0){break a}f=x[a+44>>2];x[a+4>>2]=f;x[a+8>>2]=f+(e-g|0);if(x[a+48>>2]){x[a+4>>2]=f+1;v[(b+c|0)-1|0]=y[f|0]}f=c}fb=d+32|0;return f|0}function V9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=x[b+276>>2];ig(x[x[e>>2]-12>>2]+e|0,0);ae(g+16|0,x[b+276>>2]);f=ai(g,-1,-1);e=x[g+24>>2];h=x[g+28>>2];a:{if(!bo(e,h,x[f+8>>2],x[f+12>>2])){b:{if((c|0)!=(e|0)|h){break b}break a}}Ci(x[b+276>>2],c,0,0)}e=x[d>>2];d=x[d+4>>2];c=0;while(1){if(d){f=x[b+276>>2];h=uh(d);vj(f,c+e|0,h);f=x[x[b+276>>2]+4>>2];d=d-f|0;c=c+f|0;if((f|0)==(h|0)){continue}}break}cc(a,e,c);fb=g+32|0}function Zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;f=w[e>>1];e=f+((D(w[e+2>>1]-f|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Pb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=w[a+30>>1];if(d){b=iA(b<<16>>16,d)}w[e+14>>1]=b;a=a+52|0;a:{if(!Ad(x[c+4>>2],y[c+11|0])){rs(TQ(a,e+14|0),c);break a}b=jA(a,e+14|0);if(!Zg(b,Pf(a))){break a}c=fb-16|0;fb=c;b=x[vb(c+8|0,b)>>2];d=fb-16|0;fb=d;f=ah(vb(d+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[f>>2]}g=Ab(a);x[g>>2]=x[g>>2]-1;aV(x[gc(a)>>2],b);a=x[f>>2];fb=d+16|0;Oj(ud(b));Db(b);vb(c+12|0,a);fb=c+16|0}fb=e+16|0}function ZG(a,b,c,d,e){var f=0,g=0,h=0;a:{g=fb-32|0;fb=g;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];f=x[b>>2];x[31609]=0;a=U(150,f|0,a|0,8)|0;f=x[31609];x[31609]=0;if((f|0)==1){break c}if(!a){break d}x[31609]=0;a=g+4|0;S(e|0,a|0,b|0,c|0);f=x[31609];x[31609]=0;if((f|0)!=1){x[31609]=0;O(d|0,h|0,a|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}Hd(a);continue}break}a=N()|0;break b}a=N()|0;Hd(g+4|0);break b}fb=g+32|0;break a}a=N()|0}ke(h);Q(a|0);p()}}function vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+28>>2]=c;c=e+28|0;f=x[re(e+24|0,c)>>2];x[31609]=0;g=x[b+12>>2];x[e+16>>2]=x[b+8>>2];x[e+20>>2]=g;g=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=g;ba(990,a+8|0,e+8|0,f|0,d|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){a=Fz(a);b=Ez(a+88|0);d=Dz(a+92|0);f=Cz(a+96|0);x[a>>2]=47708;x[b>>2]=47824;x[d>>2]=47904;x[f>>2]=47944;Wc(c);fb=e+32|0;return a|0}a=N()|0;Wc(e+28|0);Q(a|0);p()}function Z3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-32|0;fb=f;g=eq(f+20|0,b,c);x[31609]=0;e=U(1385,f+8|0,d|0,e|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){c=Kb(g);d=Kb(e);a=x[d>>2];b=x[c>>2];a:{if(!a|!b|(a|0)!=(b|0)){break a}while(1){a=x[d+4>>2];b=x[c+4>>2];if(!a|!b){break a}d=d+4|0;c=c+4|0;if((a|0)==(b|0)){continue}break}}Ub(e);Ub(g);fb=f+32|0;a=(a|0)>(b|0)?-1:(a|0)<(b|0);return((a|0)<0?-1:(a|0)!=0)|0}a=N()|0;Ub(g);Q(a|0);p()}function Vp(a,b,c,d,e){var f=0,g=0,h=0;a:{g=fb-32|0;fb=g;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];f=x[b>>2];x[31609]=0;a=U(150,f|0,a|0,e|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break c}if(!a){break d}x[31609]=0;a=g+4|0;O(d|0,a|0,b|0);f=x[31609];x[31609]=0;if((f|0)!=1){x[31609]=0;O(c|0,h|0,a|0);f=x[31609];x[31609]=0;if((f|0)==1){break e}Hd(a);continue}break}a=N()|0;break b}a=N()|0;Hd(g+4|0);break b}fb=g+32|0;break a}a=N()|0}ke(h);Q(a|0);p()}}function Jk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Xc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>>0){OX(a,b);break a}c=Ab(a);c=pn(e+12|0,Vl(a,Xc(x[a>>2],d)+b|0),Xc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=BC(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){qX(d);d=x[b>>2]+1|0;x[b>>2]=d;continue}break}je(b);fb=f+16|0;cr(a,c);on(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Jd(a,b+d|0)}}function D2(a,b){a=a|0;b=b|0;var c=0;a=Fb(a);a:{if(y[b+16|0]){x[31609]=0;P(127,a|0,4945)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[31609]=0;P(127,a|0,12624)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}}if(Ad(x[a+4>>2],y[a+11|0])){x[31609]=0;P(127,a|0,10083)|0;c=x[31609];x[31609]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[31609]=0;P(127,a|0,11143)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}}return}b=N()|0;tb(a);Q(b|0);p()}function rc(a,b){var c=0,d=0,e=0;c=x[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if(b>>>0>24){return rc(a,24)+(rc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=St(a);d=0;if((e|0)==-1){break a}d=x[a+1396>>2];c=d+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){_(10093,13274,1632,6865);p()}d=x[a+1392>>2];x[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}x[a+1396>>2]=c}return d}function ju(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(x[31480]){b=ju(x[31480])}if(!x[31406]){break a}c=b|c;a=x[31406];continue}break}d=x[a+76>>2]<0;b:{c:{if(x[a+20>>2]==x[a+28>>2]){break c}ib[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break c}b=-1;if(!d){break b}break a}b=x[a+8>>2];e=x[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;ib[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(d){break a}}}return b|c}function Ksa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31609]=0;O(374,a|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break a}f=fb-16|0;fb=f;e=bj(f+4|0,a,b);b=x[e+4>>2];g=x[e+8>>2];while(1){if((b|0)==(g|0)){jc(e);fb=f+16|0}else{$i(b,y[c|0]|y[c+1|0]<<8);b=b+2|0;x[e+4>>2]=b;continue}break}}b=d+8|0;Qd(b);Rj(b);fb=d+16|0;return a|0}a=N()|0;Rj(d+8|0);Q(a|0);p()}function sR(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;x[i+12>>2]=d;a:{if(!(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))){break a}x[i+8>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);j=b;b=x[Hb(i+8|0,i+12|0)>>2];x[j>>2]=b;b=Ld(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),b,d);x[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=z[e>>1]|f;w[e>>1]=b;if((y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1){break a}w[e>>1]=b|g}fb=i+16|0}function It(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[124115]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[31484]=25;a=-1}else{a=1}return a}v[a|0]=b;return 1}function aoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=Zc(c+12|0,16,1,1,0);x[c+8>>2]=0;nd(a,0);yc(b);a:{b:{if(Or(b,13883)){dd(b,12);if(!op(b)){wp(d,2)}dd(b,24);break b}if(ak(b,13770)){yc(b);x[c+8>>2]=4;e=1;break a}hd(d,8)}e=0}f=a,g=(jf(b)>>>0)/(D(y[d|0],jr(y[d+1|0]))>>>3>>>0)|0,x[f>>2]=g;b=dg(d,a,b);if(!(!b|!e)){d=x[a+20>>2];f=c,g=Qk(x[a>>2],z[a+34>>1]),x[f+4>>2]=g;Rb(d,0,x[Hb(c+8|0,c+4|0)>>2])}fb=c+16|0;return(b|0)!=0|0}function YY(a,b){var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){oD(a,b);break a}c=Ab(a);c=Zf(e+12|0,Lf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=Fn(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Cn(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}je(b);fb=f+16|0;WY(a,c);Yf(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<2)|0)}}function QT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;j=e,k=Qj(b),x[j+4>>2]=k;c=fb-16|0;fb=c;f=KB(a,c+12|0,z[b>>1],x[b+4>>2]);b=x[f>>2];if(!b){b=fb-16|0;fb=b;d=gc(a);g=Dh(c,Ec(36),Og(b+8|0,d));d=x[g>>2]+16|0;h=x[e+4>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Nb(d+8|0);j=gc(g),k=1,v[j+4|0]=k;fb=b+16|0;$g(a,x[c+12>>2],f,x[c>>2]);b=ne(c);WT(c);d=1}_g(e+8|0,x[vb(c,b)>>2],d);fb=c+16|0;a=ud(x[e+8>>2]);fb=e+16|0;return a+8|0}function z5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=x[b>>2];d=x[b+4>>2];b=Sd(c,d);e=fb-16|0;fb=e;a:{if(Vg(a)>>>0>=b>>>0){f=x[a>>2];g=oc(f,x[a+4>>2]);if(b>>>0>g>>>0){h=c;c=fD(c,g);tA(h,c,f);yq(a,c,d,b-oc(x[a>>2],x[a+4>>2])|0);break a}Iv(e+8|0,c,d,f);Jd(a,x[e+12>>2]);break a}if(x[a>>2]){Nc(a);ny(it(a),x[a>>2],Vg(a));i=Ab(a),j=0,x[i>>2]=j;x[a>>2]=0;x[a+4>>2]=0}AJ(a,Lf(a,b));yq(a,c,d,b)}fb=e+16|0}return a|0}function mfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[31609]=0;W(1021,a|0);f=x[31609];x[31609]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[31609]=0;b=Ta(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11314,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;h=e,i=Ec(56),x[h+8>>2]=i;c=sm(x[e+8>>2]);x[c>>2]=77232;g=nc(c);c=fb-16|0;fb=c;d=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=d;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=qM(g);x[d>>2]=77396;b=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=b;b=x[c+12>>2];x[d+32>>2]=x[c+8>>2];x[d+36>>2]=b;v[d+40|0]=0;fb=c+16|0;b=a;a=Rn(e);Qn(b,nc(a),a);tm(e);fb=f+16|0}function ol(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;gi(a,e+15|0);c=y[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){x[b>>2]=f;x[b+4>>2]=d;if(!h&(g|0)==(i|0)){fb=e+16|0}else{v[e+15|0]=0;gi(a,e+15|0);d=x[b>>2];j=x[b+4>>2];f=y[e+15|0];c=h;g=g+1|0;h=g?c:c+1|0;k=d;c=(g<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=f<<d;d=0}else{c=(1<<d)-1&f>>>32-d;d=f<<d}f=k|d;d=c|j;continue}break}}function tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Mg(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;a:{b:{d=b-d|0;b=x[Ab(a)>>2];f=x[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){ZB(a,d,c);break c}b=Ab(a);b=iv(e+12|0,Wq(a,Mg(x[a>>2],f)+d|0),Mg(x[a>>2],x[a+4>>2]),b);x[31609]=0;S(785,b|0,d|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}KU(a,b);YB(b)}fb=e+32|0;break a}a=N()|0;YB(b);Q(a|0);p()}return}if(b>>>0<d>>>0){LU(a,e+(b<<5)|0)}}function Wu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;i=NB(x[a+24>>2],y[a+32|0]);g=Hj(i);j=65535;a:{while(1){if((d|0)==(g|0)){d=g;a=-1;break a}b:{c:{if(!Wi(i,d&65535)){break c}e=x[a>>2];if(Ud(e,x[a+4>>2])>>>0<=d>>>0){break b}f=0;h=Vd(e,d);while(1){d:{e=x[h+4>>2];if(e>>>0>f>>>0){if(!EC(x[h>>2],f)){break d}e=x[h+4>>2]}if((f|0)==(e|0)){break b}break c}f=f+1|0;continue}}d=d+1|0;continue}break}j=d;a=0}w[b>>1]=j;x[c>>2]=a;return d>>>0<g>>>0}function Mf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;i=Aua(b,c,h,i);h=hb;e=Aua(d,e,f,g);i=e+i|0;d=hb+h|0;h=e>>>0>i>>>0?d+1|0:d;j=g;e=0;k=c;d=0;c=Aua(g,e,c,d);g=c+i|0;i=hb+h|0;l=g;c=c>>>0>g>>>0?i+1|0:i;g=Aua(f,0,b,0);h=hb;i=0;d=Aua(f,i,k,d);h=h+d|0;f=hb+i|0;f=d>>>0>h>>>0?f+1|0:f;i=f+l|0;d=c;f=f>>>0>i>>>0?d+1|0:d;b=Aua(b,m,j,e)+h|0;e=hb;e=b>>>0<h>>>0?e+1|0:e;h=e+i|0;i=f;x[a+8>>2]=h;x[a+12>>2]=e>>>0>h>>>0?i+1|0:i;x[a>>2]=g;x[a+4>>2]=b}function nna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=kg(1,2);e=hb;i=e;Pb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=w[(x[b+12>>2]<<1)+h>>1];x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Ig(a,f,i);fb=b+16|0}function poa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-4096|0;fb=d;jn(a,b);while(1){if(Xc(x[a>>2],x[a+4>>2])>>>12>>>0>f>>>0){g=f<<12;b=0;c=0;e=0;while(1){if((c|0)!=2048){h=xb(x[a>>2],c|g);i=xb(d,c<<1|1);e=y[h|0]+e|0;v[i|0]=e;c=c+1|0;continue}break}while(1){if((b|0)!=2048){c=xb(x[a>>2],b|g|2048);h=xb(d,b<<1);e=y[c|0]+e|0;v[h|0]=e;b=b+1|0;continue}break}rv(d,wC(d),vf(wb(x[a>>2]),g));f=f+1|0;continue}break}fb=d+4096|0}function pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31609]=0;W(1021,a|0);e=x[31609];x[31609]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[31609]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11459,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function xK(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31484];x[31484]=0;Od();a=Iy(a,e+12|0,d);d=hb;g=x[31484];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}x[31484]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d){break b}}x[c>>2]=4;a=-1;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a}function ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31609]=0;W(1021,a|0);e=x[31609];x[31609]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[31609]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11495,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Zp(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Kb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Fh(x[bd(j,i+12|0)>>2])+1|0}else{c=2147483631}qg(j,c);c=x[i+4>>2];if(e){Dg(c,k,e)}if(g){Dg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Dg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}yd(a,c);of(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Bd(b,a);hd(a+c|0,0);fb=i+16|0;return}pf();p()}function Uq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Kb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Fh(x[bd(j,i+12|0)>>2])+1|0}else{c=2147483631}qg(j,c);c=x[i+4>>2];if(e){Xg(c,k,e)}if(g){Xg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Xg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}yd(a,c);of(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Bd(b,a);hd(a+c|0,0);fb=i+16|0;return}pf();p()}function Or(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=c+24|0;f=Zb(c+8|0,e,7);kc(c+16|0,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(jd(e,b,7)){break b}Vb(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17516,9095,602,13238);p()}_(17495,9095,600,13238);p()}return d|0}function ona(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=kg(1,2);e=hb;i=e;Pb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=v[x[b+12>>2]+h|0]<<8;x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Pb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Ig(a,f,i);fb=b+16|0}function lc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{d=il(a);a=d;if(a>>>0<502256&a>>>0>=501744){b=a-4|0;e=x[125432];c=e;while(1){a=c;if(!(!a|(a|0)==502256)){if((jI(a)|0)==(b|0)){w[a+2>>1]=z[d-2>>1]+z[a+2>>1];break a}if((jI(b)|0)==(a|0)){c=d-2|0;w[c>>1]=z[a+2>>1]+z[c>>1];if(!f){x[125432]=b;w[b>>1]=z[a>>1];break a}g=f,h=Xx(b),w[g>>1]=h;break a}else{c=Yx(z[a>>1]);f=a;continue}}break}g=b,h=Xx(e),w[g>>1]=h;x[125432]=b;break a}Db(d)}}function iu(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=de(a);d=gc(a);f=fb-16|0;fb=f;while(1){if(c){g=Uu(c+16|0,b);d=g?d:c;c=x[(g?4:0)+c>>2];continue}break}c=x[vb(f+12|0,d)>>2];fb=f+16|0;a:{if(Ib(c,pg(a))){if(!Uu(b,ud(c))){break a}}c=pg(a)}if(!mc(c,pg(a))){b=x[vb(e+12|0,c)>>2];c=fb-16|0;fb=c;d=ah(vb(c+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[d>>2]}d=Ab(a);x[d>>2]=x[d>>2]-1;aV(x[gc(a)>>2],b);fb=c+16|0;$m(ud(b));Db(b)}fb=e+16|0}function yW(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=((y[a+48|0]|y[a+49|0]<<8)<<1)+((y[a+32|0]|y[a+33|0]<<8)<<4);x[b+8>>2]=((y[a+50|0]|y[a+51|0]<<8)<<1)+((y[a+34|0]|y[a+35|0]<<8)<<4);x[b+12>>2]=(D(y[a+52|0]|y[a+53|0]<<8,5)+((y[a+36|0]|y[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=yb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=_q(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;a=x[a>>2];hb=a>>31;return a}function KK(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;g=x[124115];if(x[b+72>>2]<=0){My(b)}x[124115]=x[b+136>>2];c=-1;if(x[b+4>>2]){d=0}else{At(b);d=!x[b+4>>2]}a:{if(d|(a|0)==-1){break a}d=It(e+12|0,a);if((d|0)<0){break a}f=x[b+4>>2];if(f>>>0<(x[b+44>>2]+d|0)-8>>>0){break a}b:{if(a>>>0<=127){c=f-1|0;x[b+4>>2]=c;v[c|0]=a;break b}c=f-d|0;x[b+4>>2]=c;zc(c,e+12|0,d)}x[b>>2]=x[b>>2]&-17;c=a}x[124115]=g;fb=e+16|0;return(c|0)!=-1}function kfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31609]=0;W(1021,a|0);d=x[31609];x[31609]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[31609]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,6695,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31609]=0;W(1021,a|0);d=x[31609];x[31609]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[31609]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,6749,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=sm(a);x[e>>2]=76732;d=nc(e);a=fb-16|0;fb=a;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;b=fb-16|0;fb=b;c=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=c;c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;d=jM(d,kM(b));x[d>>2]=76896;c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;c=x[a+12>>2];x[d+16>>2]=x[a+8>>2];x[d+20>>2]=c;fb=b+16|0;fb=a+16|0;return e|0}function Yqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=Sf(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;a:{b:{c=b-c|0;b=x[Ab(a)>>2];e=x[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){WE(a,c);break c}b=Ab(a);b=UD(d+12|0,VD(a,Sf(x[a>>2],e)+c|0),Sf(x[a>>2],x[a+4>>2]),b);x[31609]=0;O(521,b|0,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}TD(a,b);bw(b)}fb=d+32|0;break a}a=N()|0;bw(b);Q(a|0);p()}return}if(b>>>0<c>>>0){SE(a,d+D(b,20)|0)}}function vg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Oc(41356,d+14|0)>>1];e=x[a>>2];c=$c(e,x[a+4>>2]);a:{if(b>>>0>c>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];g=x[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){tp(a,b,f);break b}c=Ab(a);c=ek(e+12|0,fk(a,$c(x[a>>2],g)+b|0),$c(x[a>>2],x[a+4>>2]),c);rF(c,b,f);Ur(a,c);aj(c)}fb=e+32|0;break a}if(b>>>0<c>>>0){Jd(a,e+(b<<1)|0)}}fb=d+16|0}function qV(a,b,c,d){var e=0,f=0,g=0;a:{b:{if(!((c|0)==255|(b|0)!=11)){e=c+1|0;f=11;break b}if((b&254)==16){e=c&15|b<<4|-128;f=14;break b}if((b|0)==18){break b}e=c;f=b;if(b>>>0>18){break a}}Cf(a,f,e&255);b=y[a+3|0];c:{d:{if(!((d|0)!=4|(b|0)!=13)){b=y[a+5|0];if(b&3?(b|0)!=255:0){break d}v[a+5|0]=b+3>>>2;return 1}if((b&255)!=13){break c}}b=46;v[a+3|0]=46}g=1;if((d|0)==4|(b&255)!=17|y[a+5|0]!=32){break a}v[a+3|0]=16}return g}function xe(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=Lh(a);a:{b:{if(!b){i=e,j=Lh(a),x[i+8>>2]=j;x[e+12>>2]=0;break b}g=x[b>>2];b=x[b+4>>2];h=b;x[e+8>>2]=g;x[e+12>>2]=b;a=x[a+12>>2];x[e>>2]=2048;x[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Wr(e+8|0,e);c=x[a>>2];a=x[a+4>>2];if(!a&c>>>0>f>>>0|a){a=-1;if(!d&b>>>0<=f>>>0){break b}break a}a=0;if((d|0)==(h|0)&b>>>0>g>>>0|d>>>0>h>>>0){break a}}a=1}fb=e+16|0;return a}function su(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function osa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;a:{if(z[a+480192>>1]<b>>>0){break a}b=x[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+4|0;$Z(h,b);b=wb(x[g+4>>2]);x[g>>2]=b;i=a+484380|0;h=pg(h);j=z[a+480190>>1];while(1){if(!Ib(b,h)){Yv(g+4|0);break a}a=z[dp(b)>>1];if(a>>>0<=j>>>0){a=D(a,104)+i|0;v[a+41|0]=f;v[a+38|0]=c;v[a+40|0]=e;v[a+39|0]=d}b=x[ah(g)>>2];continue}}fb=g+16|0}function k3(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[31609]=0;m=a;a=0;a=aI(1093,m|a,b,c,d,a|e,f);b=x[31609];x[31609]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31609]=0;ga(979,8859,g|0,h|0,i|0,j|0,k|0,l|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return a|0}function IL(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;c=B[a>>2];i=a-16|0;d=B[i>>2];e=E(c+d);b=a-8|0;f=B[b>>2];j=a-24|0;g=B[j>>2];h=E(f+g);B[a>>2]=e+h;B[b>>2]=e-h;b=a-12|0;h=B[b>>2];k=a-28|0;l=B[k>>2];e=E(h+l);p=b;b=a-4|0;m=B[b>>2];a=a-20|0;n=B[a>>2];o=E(m+n);B[p>>2]=o-e;f=E(f-g);g=E(m-n);B[k>>2]=f+g;c=E(c-d);d=E(h-l);B[i>>2]=c+d;B[j>>2]=c-d;B[b>>2]=e+o;B[a>>2]=g-f}function xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0;c=fb-16|0;fb=c;h=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;uM(a,c);a:{f=C[a+24>>3];if(f==1){break a}i=E(f);d=x[b+4>>2];j=x[b+8>>2];b:while(1){if((e|0)==(j|0)){break a}k=x[a+12>>2]+(D(x[a+16>>2],e+h|0)<<2)|0;b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{g=(b<<2)+k|0;B[g>>2]=B[g>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function i9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;f=d;d=x[Cd(e+12|0,Cd(e+8|0,e+4|0))>>2];b=Ri(b,f,d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}fb=e+16|0;return g|0}function xO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=dc(8);x[31609]=0;b=P(36,h+4|0,8200)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Bl(a,b,4);c=tz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;lc(a)}Q(d|0)}p()}function qO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=dc(8);x[31609]=0;b=P(36,h+4|0,8200)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}Bl(a,b,4);c=uz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;lc(a)}Q(d|0)}p()}function gfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31609]=0;W(1021,a|0);d=x[31609];x[31609]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[31609]=0;ra(f|0,d|0,b|0,+c);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11694,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Yea(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31609]=0;W(1021,a|0);d=x[31609];x[31609]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+96>>2];x[31609]=0;ra(f|0,d|0,b|0,+c);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11632,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Wea(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31609]=0;W(1021,a|0);d=x[31609];x[31609]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+88>>2];x[31609]=0;ra(f|0,d|0,b|0,+c);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11082,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function R0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(eh(a,c+11|0)){x[c+4>>2]=y[c+11|0];g=x[Hb(c+4|0,c+12|0)>>2];d=fb+-64|0;fb=d;f=d+44|0;sg(f,a,g);h=x[d+44>>2];a=d+20|0;ug(a,3,Ze(f),h);x[31609]=0;e=d+32|0;O(218,e|0,a|0);a=x[31609];x[31609]=0;a:{if((a|0)!=1){a=d+12|0;Zb(a,b,11);nm(a,e);tb(e);Kc(f);fb=d- -64|0;e=!g|(h|0)!=0;break a}a=N()|0;Kc(d+44|0);Q(a|0);p()}}fb=c+16|0;return e|0}function Gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0;c=fb-16|0;fb=c;d=x[a+4>>2];x[c+8>>2]=x[b+8>>2];e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;AM(a,c);a:{g=C[a+24>>3];if(g==1){break a}i=E(g);e=x[b+4>>2];j=x[b+8>>2];d=d<<2;b:while(1){if((f|0)==(j|0)){break a}k=x[a+12>>2];b=0;while(1)if((b|0)==(e|0)){f=f+1|0;continue b}else{h=(d+x[(b<<2)+k>>2]|0)+(f<<2)|0;B[h>>2]=B[h>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function o3(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;b=uc(c+8|0,16806);x[31609]=0;S(98,c+20|0,a|0,b|0);a=x[31609];x[31609]=0;a:{if((a|0)!=1){tb(b);a=0;b=0;while(1){d=x[c+20>>2];if(!(b>>>0<=3&Ud(d,x[c+24>>2])>>>0>b>>>0)){Td(c+20|0);fb=c+32|0;return a|0}x[31609]=0;d=R(99,Vd(d,b)|0)|0;e=x[31609];x[31609]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=N()|0;Td(c+20|0);break a}a=N()|0;tb(b)}Q(a|0);p()}function d0(a){a=a|0;var b=0,c=0,d=0;b=x[a>>2];if(b){nQ(x[b+12>>2],b);b=x[a>>2];ib[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;Nc(a);b=fb-32|0;fb=b;a:{b:{d=ap(a);c=Xc(x[a>>2],x[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}x[31609]=0;c=ba(950,b+12|0,c|0,c|0,Ab(a)|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){cr(a,c);on(c);break c}Y(T(0)|0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break b}}fb=b+32|0;break a}T(0)|0;Sb();p()}}function K7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;a=fb-208|0;fb=a;g=Od();x[a>>2]=e;e=a+176|0;h=ph(e,20,g,9278,a);g=h+e|0;i=jj(e,g,x[c+4>>2]);f=a+12|0;cd(f,x[c+28>>2]);x[31609]=0;j=R(1252,x[a+12>>2])|0;k=x[31609];x[31609]=0;if((k|0)!=1){_b(f);f=e;e=a+16|0;nK(j,f,g,e);f=b;b=e+(h<<2)|0;b=pt(f,e,(g|0)==(i|0)?b:((i-a<<2)+a|0)-688|0,b,c,d);fb=a+208|0;return b|0}b=N()|0;_b(a+12|0);Q(b|0);p()}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+16>>2];d=x[a+12>>2];b:{if(g>>>0>d>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=g-d;x[e+4>>2]=c-f;g=d;d=x[Cd(e+12|0,Cd(e+8|0,e+4|0))>>2];b=Dg(b,g,d);x[a+12>>2]=x[a+12>>2]+d;b=b+d|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b|0]=d<<24>>24;d=1;b=b+1|0}f=d+f|0;continue}break}fb=e+16|0;return f|0}function qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-32|0;fb=e;d=e+8|0;Ue(d,2,a+6|0);f=e+20|0;Cc(f,d);Ac(b+492|0,f);d=b+236|0;g=c+1|0;h=a+38|0;tb(f);c=0;while(1){if((c|0)==128){x[b>>2]=(y[a+226|0]|y[a+227|0]<<8)<<5;wA(a+180|0,b+48|0,0);wA(a+228|0,b+88|0,2);wA(a+276|0,b+68|0,1);if(!(y[a+324|0]|y[a+325|0]<<8)){Rb(d,0,256)}fb=e+32|0}else{i=ac(d,c),j=y[c+h|0]+g|0,w[i>>1]=j;c=c+1|0;continue}break}}function k$(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=a+1068|0;b=x[a+1064>>2];a:{while(1){if((b|0)>255){break a}g=D(b,6)+c|0,h=al(a,7),v[g+4|0]=h;e=al(a,1);f=al(a,1);d=x[a+1060>>2];if((d|0)>255){break a}b=x[a+1064>>2]+1|0;x[a+1060>>2]=b;x[a+1064>>2]=b;b:{if(e){w[D(d,6)+c>>1]=b;k$(a);b=x[a+1064>>2];break b}w[D(d,6)+c>>1]=65535}x[a+1060>>2]=b;if(f){w[(D(d,6)+c|0)+2>>1]=b;continue}break}w[(D(d,6)+c|0)+2>>1]=65535}}function kha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ji(a,b,c,d);x[a>>2]=43556;c=Nb(a+4256|0);b=a+4208|0;e=yb(b,0),f=1056964608,x[e>>2]=f;e=yb(b,1),f=1017370378,x[e>>2]=f;e=yb(b,2),f=1028670828,x[e>>2]=f;e=yb(b,3),f=1059760811,x[e>>2]=f;e=yb(b,4),f=1017370378,x[e>>2]=f;e=yb(b,5),f=1065353216,x[e>>2]=f;x[31609]=0;O(941,a+44|0,2);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;wc(c);_f(a);Q(b|0);p()}function aU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;x[a+4>>2]=0;a:{if(b){b:{if(hv(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}e=To(d+20|0);x[31609]=0;f=P(759,a|0,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break a}x[31609]=0;O(760,e|0,f|0);f=x[31609];x[31609]=0;if((f|0)==1){break a}x[e+4>>2]=b;lC(a,e);tf(e)}mn(d+12|0,x[a>>2]);Vw(x[d+12>>2],x[d+16>>2],b,y[c|0])}fb=d+32|0;return}a=N()|0;tf(e);Q(a|0);p()}function _1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=g+4|0;x[f+4>>2]=1;j=f,k=Ec(32),x[j+8>>2]=k;e=sm(x[f+8>>2]);x[e>>2]=41368;h=nc(e);e=fb-16|0;fb=e;b=qm(e+8|0,x[b>>2],x[b+4>>2]);d=x[d>>2];c=x[c>>2];i=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=i;b=Pn(h);x[b>>2]=41504;qm(b+4|0,x[e>>2],x[e+4>>2]);x[b+16>>2]=d;x[b+12>>2]=c;me(e);fb=e+16|0;b=a;a=Rn(f);Qn(b,nc(a),a);tm(f);fb=g+16|0}function KA(a,b,c){if(Ob(a+1074312|0,21)){c=c&255;a:{switch((b&3)-1|0){default:return v[c+31808|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}return GR(Eo(a))+-64|0}if(z[a+480182>>1]&1032){return v[(c>>>1&31)+30464|0]}a=c&63;b:{switch((b&3)-1|0){default:return v[a+31680|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return v[a+31744|0]}function HL(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){bc(a,21);return-1}if(x[a+1396>>2]<=9){vl(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Im(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){bc(a,21)}return c}_(7566,13274,1793,5750);p()}function fz(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!Rt(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}bc(a,32);return 0}_(15819,13274,1564,6036);p()}function yD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=fb-16|0;fb=c;if(Mb(x[a>>2],x[a+8>>2],b)){while(1){if((d|0)==4){Lm(c+4|0,x[c+12>>2]);d=x[c+4>>2]}else{v[c+11|0]=0;b:{if(b>>>0>d>>>0){eh(a,c+11|0);e=v[c+11|0];g=e>>>31|0;break b}e=0-g|0}v[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}fb=c+16|0;c=d;break a}c=Rg(a);Vb(a,b-4|0)}v[f|0]=c}function bpa(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;v[b+15|0]=128;a=kw(a,127,b+15|0);x[31609]=0;v[b+14|0]=64;d=U(600,a+12|0,127,b+14|0)|0;c=x[31609];x[31609]=0;a:{b:{if((c|0)!=1){x[31609]=0;v[b+13|0]=0;P(680,a+24|0,b+13|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break b}x[a+44>>2]=0;x[a+48>>2]=0;x[a+36>>2]=-1;x[a+40>>2]=108855296;w[a+52>>1]=0;fb=b+16|0;return a|0}b=N()|0;break a}b=N()|0;fc(d)}fc(a);Q(b|0);p()}function Xsa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;x[h+12>>2]=d;g=Cb(x[a+4>>2],y[a+11|0]);f=Mc(a);a:{if(f-g>>>0>=b>>>0){f=Kb(a);if((c|0)==(g|0)){break a}i=c+f|0;Ni(i+b|0,i,g-c|0);break a}an(a,f,(b+g|0)-f|0,g,c,0,b);f=x[a>>2]}b=b+g|0;lg(a,b);hd(b+f|0,0);b=c+f|0;while(1){if(Ib(d,e)){hd(b,y[d|0]);b=b+1|0;d=x[we(h+12|0)>>2];continue}break}a=vf(zd(a),c);fb=h+16|0;return a|0}function MF(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;fd(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(Fd(b,h)){b=xf(b);c=xf(x[a+8>>2]);v[c+2|0]=y[b+2|0];w[c>>1]=z[b>>1];b=wj(a+12|0);wj(a+8|0);b=x[b>>2];continue}break}qc(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];qc(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[31609]=0;O(e|0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11324,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function _ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[31609]=0;O(e|0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,12863,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+84>>2];x[31609]=0;O(e|0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,12346,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Uea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+80>>2];x[31609]=0;O(e|0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11168,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function U7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;a=fb-96|0;fb=a;g=Od();x[a>>2]=e;e=a- -64|0;h=ph(e,20,g,9278,a);g=h+e|0;i=jj(e,g,x[c+4>>2]);f=a+12|0;cd(f,x[c+28>>2]);x[31609]=0;j=R(28,x[a+12>>2])|0;k=x[31609];x[31609]=0;if((k|0)!=1){_b(f);f=e;e=a+16|0;uK(j,f,g,e);f=b;b=e+h|0;b=tw(f,e,(g|0)==(i|0)?b:((i-a|0)+a|0)-48|0,b,c,d);fb=a+96|0;return b|0}b=N()|0;_b(a+12|0);Q(b|0);p()}function Tea(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+104>>2];x[31609]=0;la(e|0,c|0,+b);c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,15222,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31609]=0;X(26);d=x[31609];x[31609]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function hu(a,b,c,d,e){var f=0,g=0;a:{if(!Vt(b)){break a}f=x[a+484344>>2];if(!Je(f,x[a+484348>>2],b&65535)){break a}b=Wb(f,b);if(x[b+12>>2]<=(c|0)|e>>>0>5|z[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=md(x[b>>2],x[x[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e-1|0){case 0:b=b+1|0;break b;case 1:b=b+2|0;break b;case 2:b=b+3|0;break b;case 3:b=b+4|0;break b;case 4:break c;default:break b}}b=b+5|0}g=y[b|0]}return g}function efa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[31609]=0;la(e|0,c|0,+b);c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11732,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31609]=0;X(26);d=x[31609];x[31609]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Zea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+100>>2];x[31609]=0;d=+qa(e|0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11650,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function $ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[31609]=0;O(e|0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,9328,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function oU(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31609]=0;O(800,a|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}e=fb-16|0;fb=e;d=jv(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){jc(d);fb=e+16|0}else{Pl(b,0,0);b=b+16|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Qd(b);dU(b);fb=c+16|0;return a}a=N()|0;dU(c+8|0);Q(a|0);p()}function hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[31609]=0;d=+qa(e|0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11713,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function cfa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[31609]=0;la(e|0,c|0,+b);c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,7777,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31609]=0;X(26);d=x[31609];x[31609]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function afa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[31609]=0;la(e|0,c|0,+b);c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,7725,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31609]=0;X(26);d=x[31609];x[31609]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+92>>2];x[31609]=0;d=+qa(e|0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11102,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Rx(a,b,c){var d=0,e=0,f=0,g=0;e=Kb(a);a=Cb(x[a+4>>2],y[a+11|0]);d=Kb(b);b=Cb(x[b+4>>2],y[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}c=c+e|0;a=a+e|0;b=b+d|0;b:{if((b|0)==(d|0)){break b}c:{b=b-d|0;if((b|0)>(a-c|0)){break c}g=y[d|0];while(1){f=a-c|0;if((f|0)<(b|0)){break c}c=Eu(c,(f-b|0)+1|0,g);if(!c){break c}if(!TG(c,d,b)){break b}c=c+1|0;continue}}c=a}c=(a|0)==(c|0)?-1:c-e|0}else{c=-1}}return c}function zF(a){var b=0,c=0,d=0,e=0,f=0;a:{if((y[a|0]|y[a+1|0]<<8)!=26215|(y[a+514|0]-16&255)>>>0<241|y[a+515|0]>128){break a}b=2;while(1){if((b|0)==514){c=516;b=-1;while(1){f=(c|0)==772;if(f){break a}d=b;b=a+c|0;b=y[b|0]|y[b+1|0]<<8;e=(d|0)<(b|0);c=c+2|0;if(e){continue}break}break a}c=a+b|0;e=Ab(c);while(1){if((c|0)!=(e|0)){d=y[c|0];c=c+1|0;if(d>>>0>31){continue}break a}break}b=b+8|0;continue}}return f}function qda(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0;d=fb-48|0;fb=d;x[d+44>>2]=c;c=Md(d+16|0);x[31609]=0;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;c=d+24|0;S(1115,c|0,a|0,d|0);a=x[31609];x[31609]=0;a:{b:{if((a|0)!=1){a=d+44|0;e=x[re(d+12|0,a)>>2];x[31609]=0;b=+pa(981,c|0,+b,e|0);e=x[31609];x[31609]=0;if((e|0)==1){break b}ub(c);Wc(a);fb=d+48|0;return+b}c=N()|0;break a}c=N()|0;ub(d+24|0)}Wc(d+44|0);Q(c|0);p()}function mB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}wk(a,b,b+700|0,0-(c<<2)|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function lfa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[31609]=0;b=P(d|0,c|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,6722,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function jfa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31609]=0;W(1021,a|0);c=x[31609];x[31609]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[31609]=0;b=P(d|0,c|0,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,6773,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ak(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=Zb(c+8|0,c+28|0,4);kc(c+20|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);if(!(x[c+24>>2]!=4|x[c+28>>2]!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24)))){Vb(a,4);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17516,9095,602,13238);p()}_(17495,9095,600,13238);p()}return d|0}function s9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+28>>2];d=x[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=zf(v[b|0]),h=x[x[a>>2]+52>>2],ib[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=g-d;x[e+8>>2]=c-f;g=d;d=x[Cd(e+12|0,e+8|0)>>2];Dg(g,b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}fb=e+16|0;return f|0}function NF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;fd(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(Fd(b,h)){b=Gn(b);i=Gn(x[a+8>>2]),j=z[b>>1],w[i>>1]=j;b=Wk(a+12|0);Wk(a+8|0);b=x[b>>2];continue}break}qc(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];qc(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function $j(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c)){break a}xc(f+12|0,65535);vg(a,z[f+12>>1]);c=wb(x[a>>2]);x[f+4>>2]=c;h=wb(x[a+4>>2]);while(1){if(!Ib(c,h)){break a}a=f+11|0;if(!eh(b,a)){dh(a)}a=y[f+11|0];w[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}w[c>>1]=g}c=x[ge(f+4|0)>>2];continue}}fb=f+16|0}function yna(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=kC(c+4|0,a);Lm(x[a+4>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[a+4>>2]=x[a+4>>2]+4;jc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=Zf(d+12|0,Lf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Lm(x[c+8>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[c+8>>2]=x[c+8>>2]+4;WY(a,c);Yf(c);fb=d+32|0}function jO(a,b){var c=0;a:{b:{if((a^b)&3){c=y[b|0];break b}if(b&3){while(1){c=y[b|0];v[a|0]=c;if(!c){break a}a=a+1|0;b=b+1|0;if(b&3){continue}break}}c=x[b>>2];if((c^-1)&c-16843009&-2139062144){break b}while(1){x[a>>2]=c;c=x[b+4>>2];a=a+4|0;b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}v[a|0]=c;if(!(c&255)){break a}while(1){c=y[b+1|0];v[a+1|0]=c;a=a+1|0;b=b+1|0;if(c){continue}break}}}function RW(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=e+8|0;d=fb-32|0;fb=d;fd(d+24|0,a,b);g=d+16|0;b=x[d+24>>2];h=x[d+28>>2];a=fb-16|0;fb=a;x[a+8>>2]=c;x[a+12>>2]=b;while(1){if(Fd(b,h)){b=xW(b);i=xW(x[a+8>>2]),j=y[b|0],v[i|0]=j;b=sW(a+12|0);sW(a+8|0);b=x[b>>2];continue}break}qc(g,b,a+8|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];qc(f,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function IM(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=126480;x[a+24>>2]=0;x[a+28>>2]=65536;x[a+8>>2]=b;x[a+32>>2]=0;x[a+36>>2]=65536;c=(b|0)!=0;x[a+12>>2]=c;x[a+16>>2]=c;d=b^63;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}x[a+48>>2]=c;x[a+52>>2]=d;d=64-b|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}x[a+40>>2]=b?c:0;x[a+44>>2]=b?d:0;return a}function av(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[b+40>>2]=0;x[b+44>>2]=0;f=b- -64|0;x[f>>2]=0;x[f+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=wb(x[c>>2]);x[e+12>>2]=d;f=wb(x[c+4>>2]);while(1){if(!Ib(d,f)){break a}g=d,h=gU(b,C[d>>3]),C[g>>3]=h;d=x[OB(e+12|0)>>2];continue}}}else{gU(b,C[Se(x[c>>2],0)>>3]);d=d+1|0;continue}break}Tl(a,c);fb=e+16|0}function xra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;c=If(a,c);ae(e,x[a+36>>2]);a:{b:{if(!c){Qc(e,a+32|0,5);d=-1;if(!Gb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}d=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=fb-32|0;fb=d;v[d+31|0]=0;uj(d+8|0,d+31|0);Nm(d+20|0,f,x[d+8>>2],x[d+12>>2]);v[b|0]=y[d+31|0];fb=d+32|0;break c;default:break d}}nZ(f,b,d)}f=c}ef(a,f);fb=e+16|0}function oba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Ro(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31609]=0;O(110,a|0,yh(e,d)|0);d=x[31609];x[31609]=0;if((d|0)!=1){a:{while(1){if(yh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[ec(c+4|0,b)|0];x[31609]=0;O(111,a|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function lB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}wk(a,b,b+700|0,0-c|0,0);if(x[b+700>>2]<65536){break b}if(Ob(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function hS(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];x[a>>2]=b;if(c){b=fb-16|0;fb=b;d=wb(x[c>>2]);x[b+12>>2]=d;f=wb(x[c+4>>2]);while(1){a:{b:{if(Ib(d,f)){while(1){a=x[d>>2];e=x[a>>2];if(!e){break b}nQ(a,e);a=x[x[e>>2]+8>>2];x[31609]=0;W(a|0,e|0);a=x[31609];x[31609]=0;if((a|0)!=1){continue}break}T(0)|0;Sb();p()}a=wc(c);fb=b+16|0;break a}Eb(a+20|0);Eb(a+8|0);Db(a);d=x[Xe(b+12|0)>>2];continue}break}Db(a)}}function SA(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;v[a+1074368|0]=b;$R(a+1074332|0,b);a=a+906300|0;f=uk(a);while(1){if((a|0)!=(f|0)){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(ib[x[x[b>>2]+140>>2]](b)|0){d=x[b+16>>2];e=d+1074332|0;c=E(E(c/B[e+8>>2])*E(E(A[d+480232>>2])/B[e+20>>2]))}B[b+4196>>2]=c}a=a+160|0;continue}break}}function OE(a,b){var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=c+24|0;f=Zb(c+8|0,e,7);qd(c+16|0,a,x[f>>2],x[f+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(jd(e,b,7)){break b}id(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17516,9095,602,13238);p()}_(17495,9095,600,13238);p()}return d}function ro(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Tk(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31609]=0;O(110,a|0,yh(e,d)|0);d=x[31609];x[31609]=0;if((d|0)!=1){a:{b:{while(1){if(yh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=v[ec(c+4|0,b)|0];x[31609]=0;O(111,a|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function SH(a,b,c,d,e,f,g,h,i){var j=0;x[31609]=0;W(996,a|0);j=x[31609];x[31609]=0;a:{b:{if((j|0)!=1){j=x[a+24>>2];x[31609]=0;b=sa(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,h|0,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Gx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Tk(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31609]=0;O(110,a|0,yh(e,d)|0);d=x[31609];x[31609]=0;if((d|0)!=1){a:{while(1){if(yh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[ec(c+4|0,b)|0];x[31609]=0;O(111,a|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function wO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=dc(8);x[31609]=0;b=P(36,f+4|0,8200)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Bl(a,b,2);c=tz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;lc(a)}Q(e|0)}p()}function sna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;b=fb-16|0;fb=b;d=-1;a:{if(!jh(a,1)){break a}e=Kr(a);if((e-5&255)>>>0>=253){while(1){if((f|0)==127){d=1;break a}c=fb-16|0;fb=c;fE(c+8|0,b);g=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((h|0)==(g|0)){id(a,x[c+12>>2])}fb=c+16|0;c=(g|0)==(h|0);if(!c){Dr(b)}if(!c){break a}f=f+1|0;if(rV(b,e)){continue}break}}d=0}fb=b+16|0;return d|0}function qpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;b=-1;a:{if(!jh(a,8)){break a}b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;d=Zb(b+8|0,b+24|0,8);qd(b+16|0,a,x[d>>2],x[d+4>>2]);d=x[b+24>>2]==1096043343&x[b+28>>2]==1196314451&x[b+20>>2]==8;if(d){id(a,8)}fb=b+32|0;b=0;if(!d){break a}b=-1;if(!hk(a,c+8|0)){break a}b=0;if(!$b(x[c+12>>2])){break a}b=!($b(x[c+8>>2])&-2139062144)}fb=c+16|0;return b|0}function pO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=dc(8);x[31609]=0;b=P(36,f+4|0,8200)|0;c=x[31609];x[31609]=0;if((c|0)==1){break c}sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}Bl(a,b,2);c=uz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;lc(a)}Q(e|0)}p()}function ZH(a,b,c){a=Fb(a);x[31609]=0;O(c|0,a|0,4);c=x[31609];x[31609]=0;a:{b:{if((c|0)==1){break b}x[31609]=0;O(b|0,a|0,32);c=x[31609];x[31609]=0;if((c|0)==1){break b}x[31609]=0;O(b|0,a|0,10);c=x[31609];x[31609]=0;if((c|0)==1){break b}x[31609]=0;O(b|0,a|0,13);c=x[31609];x[31609]=0;if((c|0)==1){break b}x[31609]=0;O(b|0,a|0,9);b=x[31609];x[31609]=0;if((b|0)!=1){break a}}b=N()|0;tb(a);Q(b|0);p()}}function Rr(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(Uw(c)){break a}d=x[c+16>>2]}e=x[c+20>>2];if(d-e>>>0<b>>>0){return ib[x[c+36>>2]](c,a,b)|0}b:{c:{if(!b|x[c+80>>2]<0){break c}d=b;while(1){f=a+d|0;if(y[f-1|0]!=10){d=d-1|0;if(d){continue}break c}break}e=ib[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}b=b-d|0;e=x[c+20>>2];break b}f=a;d=0}zc(e,f,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function OZ(a){var b=0,c=0,d=0,e=0;a:{if((y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24))!=808537417|(y[a+32|0]|y[a+33|0]<<8)>>>0>256|(y[a+49|0]<32|(y[a+36|0]|y[a+37|0]<<8)>>>0>255)){break a}if(v[a+51|0]<4|y[a+50|0]>64){break a}d=a+15|0;a=64;while(1){if((a|0)==576){e=b;break a}c=1;b:{switch(y[a+d|0]){case 2:c=b;break;case 0:case 1:break b;default:break a}}a=a+16|0;b=c;continue}}return e&1}function Lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31609]=0;W(996,a|0);d=x[31609];x[31609]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31609]=0;S(1092,d|0,b|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,10337,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function $M(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Uf(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31609]=0;O(93,a|0,yh(e,d)|0);d=x[31609];x[31609]=0;if((d|0)!=1){a:{b:{while(1){if(yh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=y[ec(c+4|0,b)|0];x[31609]=0;O(95,a|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function wD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{e=Nb(a+8|0);x[31609]=0;c=R(202,b|0)|0;d=x[31609];x[31609]=0;b:{if((d|0)==1){break b}c:{if(!mZ(c)){x[31609]=0;X(507);a=x[31609];x[31609]=0;if((a|0)!=1){break c}break b}x[31609]=0;c=R(202,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}x[31609]=0;S(169,a|0,b|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}break a}p()}a=N()|0;fc(e);Q(a|0);p()}}function j3(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[31609]=0;a=Ha(1095,a|0,b|0,c|0,d|0)|0;b=x[31609];x[31609]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31609]=0;ga(979,11208,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}return a|0}function ffa(a){a=a|0;var b=0,c=0,d=0;x[31609]=0;W(1021,a|0);b=x[31609];x[31609]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[31609]=0;c=+ia(d|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,11750,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31609]=0;W(996,a|0);d=x[31609];x[31609]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31609]=0;e=+oa(1088,d|0,b|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,5350,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();e=0}return+e}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Gna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[b+12>>1]=0;w[b+14>>1]=1;Hf(b+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=fb-16|0;fb=d;c=z[b+14>>1];x[d+12>>2]=c;a:{if(Hn(a)>>>0>=c>>>0){g=x[a>>2];f=$c(g,x[a+4>>2]);x[d+8>>2]=f;Jv(g,x[Hb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){tp(a,c-f|0,e);break a}Jd(a,x[a>>2]+(c<<1)|0);break a}VU(a);JC(a,fk(a,c));tp(a,c,e)}fb=d+16|0;fb=b+16|0}
function dfa(a){a=a|0;var b=0,c=0,d=0;x[31609]=0;W(1021,a|0);b=x[31609];x[31609]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[31609]=0;c=+ia(d|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,7794,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function bfa(a){a=a|0;var b=0,c=0,d=0;x[31609]=0;W(1021,a|0);b=x[31609];x[31609]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[31609]=0;c=+ia(d|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,7742,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Vka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);e=c+8|0;Rd(e,x[vb(c+4|0,a)>>2]);x[31609]=0;W(805,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){f=fb-16|0;fb=f;d=bj(f+4|0,a,2304);b=x[d+4>>2];g=x[d+8>>2];while(1){if((b|0)==(g|0)){jc(d);fb=f+16|0}else{_w(b);b=b+2|0;x[d+4>>2]=b;continue}break}Qd(e);Rj(e);fb=c+16|0;return a|0}a=N()|0;Rj(c+8|0);Q(a|0);p()}function GY(a){var b=0;a:{if(jd(a,14321,3)|(y[a+3|0]-52&255)>>>0<252){break a}if($b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788>>>0<840){break a}if($b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))>>>0<52){break a}if($b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))-1>>>0<51){break a}b=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))>>>0<4294967216}return b}function oN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((xo(a)|0)>(b|0)){break d}}b=dc(8);x[31609]=0;c=P(36,c+4|0,10751)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return(x[(a+D(b,872)|0)+1075080>>2]&67109888)!=0|0}a=N()|0;lc(b)}Q(a|0)}p()}function bB(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;g=Ou(a,a+1074376|0,b,c);a:{if(!g){break a}Jb(d+8|0,a+1074312|0,117);if(Gb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}f=(D(b,872)+a|0)+1074992|0;e=x[f+656>>2];if(!e){break a}h=v[e+33|0];if(!h){break a}c=Eq(a,x[f+88>>2],e);if(!c){break a}a=y[f+799|0];if(!(!e|(!a|a>>>0>128))){a=y[xb(e+108|0,a-1|0)|0]}ib[x[x[c>>2]+88>>2]](c,g,a,h,b)}fb=d+16|0}function qta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{f=Zd(a);b:{if(f>>>0>1){break b}c:{if(f){x[31609]=0;d=e+4|0;S(334,d|0,a|0,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){zn(b,d);fc(d);break c}a=T(28816)|0;if((gb|0)!=($(28816)|0)){break a}Y(a|0)|0;Z();d=0;break b}if(!Mb(x[a>>2],x[a+8>>2],c)){break b}yw(a,b,c)}d=Xc(x[b>>2],x[b+4>>2])>>>0>=c>>>0}fb=e+16|0;return d|0}Q(a|0);p()}function Xv(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b>>31<<6|b>>>26;b=b<<6;a=Gc(Bua(b- -8192|0,a-((b>>>0<4294959104)-1|0)|0,16384,0),hb);break a;case 1:a=b>>31<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=Gc(Bua(b,a,4096,0),hb);break a;default:break b}}x[c+8>>2]=1;a=Si(rM(8192/+x[Ye(c+12|0,c+8|0)>>2])*24+8)}fb=c+16|0;a=(a|0)>=64?64:a;return((a|0)>0?a:0)&255}function I1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;if(!Mb(x[b>>2],x[b+8>>2],c)){c=jf(b)}x[a>>2]=c;c=x[b>>2];a:{if(ib[x[x[c>>2]+16>>2]](c)|0){c=a;a=x[b>>2];e=c,f=(ib[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;break a}Jk(a+8|0,x[a>>2]);c=x[a+8>>2];a=x[a+12>>2];if(mc(c,a)){break a}se(d+8|0,c,a);kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2])}fb=d+16|0}function pz(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;a:{if(y[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=x[a+16>>2];if(b>>>0<=c>>>0){break a}b=mM(b,4096);lM(a,b-c|0);c=x[a+16>>2];b=Zb(d+16|0,xb(x[a+4>>2],c),b-c|0);c=x[x[a>>2]+44>>2];e=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=e;ib[c|0](d+24|0,a,d+8|0);x[a+16>>2]=x[a+16>>2]+x[d+28>>2];if(!(ib[x[x[a>>2]+40>>2]](a)|0)){break a}v[a+20|0]=1}fb=d+32|0}function qN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((xo(a)|0)>(b|0)){break d}}b=dc(8);x[31609]=0;c=P(36,c+4|0,10751)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+x[(a+D(b,872)|0)+1075740>>2]*.015625)}a=N()|0;lc(b)}Q(a|0)}p()}function waa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=(D(e,f)<<3)+h|0;d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d<<3)+j|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;tM(a,c);fb=c+16|0}function pma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Kb(c);c=Cb(x[c+4>>2],y[c+11|0]);a:{d=Cb(x[a+4>>2],y[a+11|0]);if(d>>>0>=b>>>0){e=Mc(a);if(c>>>0<=e-d>>>0){if(!c){break a}e=Kb(a);h=e+b|0;if((b|0)!=(d|0)){g=b+e|0;Ni(c+g|0,g,d-b|0);f=(f>>>0>=g>>>0?d+e>>>0>f>>>0?c:0:0)+f|0}Ni(h,f,c);b=c+d|0;lg(a,b);hd(b+e|0,0);break a}Uq(a,e,(c+d|0)-e|0,d,b,0,c,f);break a}dn();p()}return a|0}function an(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;a:{if(2147483631-b>>>0>=c>>>0){j=Kb(a);i=h+4|0;if(b>>>0<=1073741798){x[h+12>>2]=b<<1;x[h+4>>2]=b+c;c=Fh(x[bd(i,h+12|0)>>2])+1|0}else{c=2147483631}qg(i,c);c=x[h+4>>2];if(e){Dg(c,j,e)}i=e+f|0;if((i|0)!=(d|0)){Dg((c+e|0)+g|0,(e+j|0)+f|0,d-i|0)}if((b|0)!=10){Db(j)}yd(a,c);of(a,x[h+8>>2]);fb=h+16|0;break a}pf();p()}Bd(a,(d-f|0)+g|0)}function Laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=(D(e,f)<<3)+h|0;d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d<<3)+j|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;DM(a,c);fb=c+16|0}function Faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=(D(e,f)<<3)+h|0;d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d<<3)+j|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;zM(a,c);fb=c+16|0}function Caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=(D(e,f)<<3)+h|0;d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d<<3)+j|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;xM(a,c);fb=c+16|0}function vK(a,b,c){var d=0,e=0,f=E(0),g=0,h=E(0);e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31484];x[31484]=0;Od();d=fb-16|0;fb=d;_x(d,a,e+12|0,0);f=XG(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31484];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31484]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function bta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;cc(c+8|0,b,15);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0}}function RH(a,b,c,d,e,f,g){var h=0;x[31609]=0;W(996,a|0);h=x[31609];x[31609]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[31609]=0;b=ha(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,f|0,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function IX(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function GV(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+30|0]=0;v[a+31|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function _qa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;cc(c+8|0,b,14);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0}}function Rda(a,b){a=a|0;b=b|0;var c=0,d=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31609]=0;O(1087,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,10916,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function via(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[31609]=0;O(287,b+4|0,8);b=x[31609];x[31609]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=T(124540)|0;if((gb|0)==($(124540)|0)){Y(b|0)|0;Nc(x[a+20>>2]+4|0);Z();return}Q(b|0);p()}function tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{c=x[b+4>>2];if(!c){break a}w[d>>1]=z[a+480190>>1];w[d+14>>1]=c-1;f=a+946304|0;c=z[Oc(d,d+14|0)>>1];while(1){if(!c){break a}b:{if(EC(x[b>>2],c)){break b}if(PR(a,c&65535)){e=Dc(d,22292);Ac((c<<5)+f|0,e);tb(e)}if((c|0)==1){break b}e=z[a+480190>>1];if((e|0)!=(c|0)){break b}w[a+480190>>1]=e-1}c=c-1|0;continue}}fb=d+16|0}function lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);c=x[b+4>>2];d=c;b=x[b+8>>2];e=b;c=Dk(c,b);b=fb-16|0;fb=b;Rd(b+8|0,x[vb(b+4|0,a)>>2]);a:{if(!c){break a}x[31609]=0;O(1121,a|0,c|0);f=x[31609];x[31609]=0;if((f|0)!=1){x[31609]=0;V(1122,a|0,d|0,e|0,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){break a}}a=N()|0;cN(b+8|0);Q(a|0);p()}a=b+8|0;Qd(a);cN(a);fb=b+16|0}function hj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(th(a,f+12|0)){break b}h=tl(x[a>>2]);g=4;if(!Jf(x[d+8>>2],64,h)){break b}b=ml(d,h);while(1){c:{b=b-48|0;h=Fm(a);if(th(h,f+12|0)|(e|0)<2){break c}g=tl(x[h>>2]);if(!Jf(x[d+8>>2],64,g)){break a}e=e-1|0;b=ml(d,g)+D(b,10)|0;continue}break}g=2;if(!th(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function f4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=v[e|0];f=4;if(!Jf(x[d+8>>2],64,e)){break b}f=4;g=ml(d,e);while(1){c:{e=x[a>>2]+1|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=v[e|0];if(!Jf(x[d+8>>2],64,e)){break a}f=f-1|0;g=ml(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}function yO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=dc(8);x[31609]=0;c=P(36,e+4|0,8200)|0;b=x[31609];x[31609]=0;if((b|0)==1){break c}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Bl(a,b,1);c=tz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;lc(a)}Q(b|0)}p()}function rO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=dc(8);x[31609]=0;c=P(36,e+4|0,8200)|0;b=x[31609];x[31609]=0;if((b|0)==1){break c}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Bl(a,b,1);c=uz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;lc(a)}Q(b|0)}p()}function rC(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;a:{if(1073741807-b>>>0>=c>>>0){i=Kb(a);h=g+4|0;if(b>>>0<=536870886){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=rn(x[bd(h,g+12|0)>>2])+1|0}else{c=1073741807}Nj(h,c);c=x[g+4>>2];if(e){Ri(c,i,e)}h=e+f|0;if((h|0)!=(d|0)){e=e<<2;Ri(e+c|0,(e+i|0)+(f<<2)|0,d-h|0)}if((b|0)!=1){Db(i)}yd(a,c);of(a,x[g+8>>2]);fb=g+16|0;break a}pf();p()}Bd(a,d-f|0)}function rfa(a){a=a|0;var b=0;x[31609]=0;W(1021,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31609]=0;V(983,5051,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Xoa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=CC(a,b);x[31609]=0;c=P(684,a+12|0,b+12|0)|0;d=x[31609];x[31609]=0;b:{c:{if((d|0)!=1){x[31609]=0;P(685,a+24|0,b+24|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}c=x[b+40>>2];x[a+36>>2]=x[b+36>>2];x[a+40>>2]=c;w[a+52>>1]=z[b+52>>1];c=x[b+48>>2];x[a+44>>2]=x[b+44>>2];x[a+48>>2]=c;break a}b=N()|0;break b}b=N()|0;fc(c)}fc(a);Q(b|0);p()}}function tK(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31484];x[31484]=0;Od();d=fb-16|0;fb=d;_x(d,a,e+12|0,1);f=Fx(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31484];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31484]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function fN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=dc(8);x[31609]=0;d=P(36,d+4|0,10751)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,d);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}e=(x[a+32>>2]+D(b,872)|0)+1075766|0,f=uC(c*32768),w[e>>1]=f;fb=d+16|0;return}a=N()|0;lc(b)}Q(a|0)}p()}function Wn(a,b,c,d,e,f){var g=0;x[31609]=0;W(996,a|0);g=x[31609];x[31609]=0;a:{b:{if((g|0)!=1){g=x[a+24>>2];x[31609]=0;b=ba(f|0,g|0,b|0,c|0,d|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,e|0,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function WX(a,b){var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{if(!y[b+5|0]){while(1){if((d|0)==5){d=0;v[c+28|0]=0;x[c+24>>2]=0;e=c+24|0;f=Zb(c+8|0,e,5);kc(c+16|0,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);b:{if(x[c+20>>2]!=5){break b}if(jd(e,b,5)){break b}Vb(a,5);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17516,9095,602,13238);p()}_(17495,9095,600,13238);p()}return d}function Vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ji(a,b,c,d);x[a>>2]=44176;b=Nb(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=x[c+24620>>2];x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;x[a+4228>>2]=1048550822;x[a+4232>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[31609]=0;O(941,a+44|0,2);c=x[31609];x[31609]=0;if((c|0)!=1){return a|0}c=N()|0;wc(b);_f(a);Q(c|0);p()}function UK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Dc(d+8|0,c);x[31609]=0;c=d+20|0;S(1230,c|0,b|0,e|0);f=x[31609];x[31609]=0;a:{b:{if((f|0)!=1){x[31609]=0;a=P(1231,a|0,c|0)|0;f=x[31609];x[31609]=0;if((f|0)==1){break b}tb(c);tb(e);x[a>>2]=123812;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;fb=d+32|0;return a|0}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(e);Q(c|0);p()}function g9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+24>>2];e=x[a+28>>2];if(d>>>0>=e>>>0){if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{x[f+12>>2]=e-d>>2;x[f+8>>2]=c-g;e=d;d=x[Cd(f+12|0,f+8|0)>>2];Ri(e,b,d);e=d<<2;x[a+24>>2]=e+x[a+24>>2];g=g+d|0;b=b+e|0}continue}break}fb=f+16|0;return g|0}function wja(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-16|0;fb=e;b=Ec(2500);c=fb-2496|0;fb=c;yQ(a,c,c+2496|0);a=0;while(1){if((a|0)==624){x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!x[b+d>>2]){continue}break a}break}x[b>>2]=-2147483648}fb=c+2496|0}else{d=a<<2;x[d+b>>2]=x[c+d>>2];a=a+1|0;continue}break}a=yf(e+12|0,b);fb=e+16|0;return x[a>>2]}function V0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=-1;a:{if(!jh(a,7)){break a}c=0;if(!OE(a,11790)){break a}c=fb-16|0;fb=c;f=e+5|0;Lw(c+8|0,f);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){LE(f)}c=-1;if(!d){break a}c=0;if(!NE(y[e+6|0])){break a}c=xe(a,b,ME(f),hb)}fb=e+16|0;return c|0}function Mda(a,b){a=a|0;b=+b;var c=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31609]=0;b=+Wa(1089,c|0,+b);c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,7606,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=0}return+b}a=N()|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Ox(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47588;i=Ec(80);x[31609]=0;d=R(1099,d|0)|0;h=x[31609];x[31609]=0;a:{b:{if((h|0)!=1){x[g+8>>2]=d;d=g+8|0;h=x[re(g+12|0,d)>>2];x[31609]=0;b=ha(f|0,i|0,b|0,c-b|0,h|0,e|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break b}x[a+4>>2]=b;Wc(d);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Wc(g+8|0)}Db(i);Q(a|0);p()}function fia(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function l6(a){a=a|0;if(y[499912]){return x[124977]}if(!y[500424]){v[500424]=1}wd(500256,103384);wd(500268,103412);wd(500280,103440);wd(500292,103472);wd(500304,103512);wd(500316,103548);wd(500328,103576);wd(500340,103612);wd(500352,103628);wd(500364,103644);wd(500376,103660);wd(500388,103676);wd(500400,103692);wd(500412,103708);v[499912]=1;x[124977]=500256;return 500256}function Gs(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47588;i=Ec(80);x[31609]=0;d=R(1099,d|0)|0;h=x[31609];x[31609]=0;a:{b:{if((h|0)!=1){x[g+8>>2]=d;d=g+8|0;h=x[re(g+12|0,d)>>2];x[31609]=0;b=ha(f|0,i|0,b|0,c|0,h|0,e|0)|0;c=x[31609];x[31609]=0;if((c|0)==1){break b}x[a+4>>2]=b;Wc(d);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Wc(g+8|0)}Db(i);Q(a|0);p()}function x9(){var a=0,b=0,c=0,d=0,e=0,f=0;b=fb-48|0;fb=b;if(AL(0,b+24|0)){Ht(x[31484],12758);p()}a=ye(b+16|0,x[b+24>>2],x[b+28>>2]);d=ZA(b+8|0,x[b+32>>2]/1e3|0);c=fb-16|0;fb=c;a=Gu(c,x[a>>2],x[a+4>>2]);e=x[a>>2];f=e+x[d>>2]|0;a=x[d+4>>2]+x[a+4>>2]|0;a=ye(c+8|0,f,f>>>0<e>>>0?a+1|0:a);d=x[a>>2];fb=c+16|0;c=ye(b+40|0,d,x[a+4>>2]);a=x[c>>2];fb=b+48|0;hb=x[c+4>>2];return a|0}function qea(a){a=a|0;var b=0,c=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31609]=0;b=R(1064,b|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,7278,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();b=0}return b|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function M_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=wb(x[b>>2]);x[d+28>>2]=a;f=wb(x[b+4>>2]);a:{while(1){if(Ib(a,f)){b=d+8|0;qi(b,x[a>>2],x[a+4>>2]);if(($b(x[d+8>>2])|0)==(c|0)){mp(b,a);x[31609]=0;O(360,e|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break a}ub(b)}a=x[dm(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Rc(e);Q(a|0);p()}function M2(a){a=a|0;var b=0,c=0,d=0,e=0;x[a+44>>2]=0;e=a+32|0;c=Kb(e);b=Cb(x[a+36>>2],y[a+43|0]);d=x[a+48>>2];if(d&8){d=b+c|0;x[a+44>>2]=d;Vn(a,c,c,d);d=x[a+48>>2]}a:{if(!(d&16)){break a}x[a+44>>2]=b+c;hC(e,Mc(e));Ex(a,c,Cb(x[a+36>>2],y[a+43|0])+c|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){As(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}As(a,b)}}function g_(a){var b=0,c=0;a:{if(jd(a,15320,3)){break a}c=y[a+3|0];if(c>>>0>9){break a}if((Bb(y[a+202|0]|y[a+203|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}if(!Bb(y[a+228|0]|y[a+229|0]<<8)){break a}if(!Bb(y[a+230|0]|y[a+231|0]<<8)){break a}b=0;if(Bb(y[a+232|0]|y[a+233|0]<<8)>>>0>4095){break b}b=Bb(y[a+234|0]|y[a+235|0]<<8)>>>0<100}return b}return 0}function cB(a,b,c){var d=0,e=0,f=0;f=Fb(a);d=y[b+11|0];e=x[b+4>>2];a=0;x[31609]=0;O(53,f|0,_c(e,d)|0);d=x[31609];x[31609]=0;if((d|0)!=1){a:{while(1){if(_c(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=65533;e=v[ec(b,a)|0];if((e|0)>=-96){d=x[((e&255)<<2)+c>>2]}x[31609]=0;O(35,f|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Ub(f);Q(a|0);p()}function zea(a){a=a|0;var b=0,c=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31609]=0;c=+ia(1055,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31609]=0;V(983,7678,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function q4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=x[e>>2];f=4;if(!oj(d,64,e)){break b}g=pk(d,e);f=4;while(1){c:{e=x[a>>2]+4|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=x[e>>2];if(!oj(d,64,e)){break a}f=f-1|0;g=pk(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}function Eia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Ec(64);x[31609]=0;e=R(875,c|0)|0;f=x[31609];x[31609]=0;a:{if((f|0)!=1){c=yf(d+8|0,e);e=x[c>>2];x[31609]=0;a=U(939,e|0,a|0,b|0)|0;b=x[31609];x[31609]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}tc(d+12|0);break b}a=N()|0;mg(c);break a}re(d+12|0,c)}mg(c);fb=d+16|0;return x[d+12>>2]}a=N()|0;Db(c)}Q(a|0);p()}function r5(a,b){a=a|0;b=b|0;var c=0,d=0;c=Kb(b);b=fb-32|0;fb=b;a=xd(a,0);x[a>>2]=96496;d=lk(c);x[a+8>>2]=d;if(!d){a=Dc(b+8|0,c);x[31609]=0;c=b+20|0;S(1011,c|0,17552,a|0);d=x[31609];x[31609]=0;a:{b:{if((d|0)!=1){x[31609]=0;W(1367,c|0);c=x[31609];x[31609]=0;if((c|0)==1){break b}p()}c=N()|0;break a}c=N()|0;tb(b+20|0)}tb(a);Q(c|0);p()}fb=b+32|0;x[a>>2]=102872;return a|0}function jV(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31609]=0;O(114,d|0,_c(e,a)|0);a=x[31609];x[31609]=0;a:{if((a|0)!=1){a=zd(b);x[c+12>>2]=a;b=Df(b);while(1){if(!Ib(a,b)){break a}a=y[a|0];x[31609]=0;O(115,d|0,((a|0)==13?10:a)<<24>>24);a=x[31609];x[31609]=0;if((a|0)!=1){a=x[we(c+12|0)>>2];continue}break}}a=N()|0;tb(d);Q(a|0);p()}fb=c+16|0}function Wz(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(A[x[a+16>>2]+24620>>2]);c=E(E(E(ib[x[x[a>>2]+208>>2]](a))*b)/E(1e3));d=a,e=E(E(c*E(ib[x[x[a>>2]+200>>2]](a)))*E(2048)),B[d+4248>>2]=e;d=a,f=Ll(E(E(c+E(2))*E(4096))),x[d+4256>>2]=f;c=E(ib[x[x[a>>2]+212>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(ib[x[x[a>>2]+196>>2]](a)|0)){b=bQ(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function hf(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){b=1;if(c>>>0<1044816030){break a}b=Xp(a,0);break a}b=a-a;if(c>>>0>=2146435072){break a}c=gI(a,d);a=C[d+8>>3];b=C[d>>3];b:{switch(c&3){case 0:b=Xp(b,a);break a;case 1:b=-Yp(b,a,1);break a;case 2:b=-Xp(b,a);break a;default:break b}}b=Yp(b,a,1)}fb=d+16|0;return b}function gj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(fi(a,f+12|0)){break b}g=4;h=sl(x[a>>2]);if(!oj(d,64,h)){break b}b=pk(d,h);while(1){c:{b=b-48|0;h=jo(a);if(fi(h,f+12|0)|(e|0)<2){break c}g=sl(x[h>>2]);if(!oj(d,64,g)){break a}e=e-1|0;b=pk(d,g)+D(b,10)|0;continue}break}g=2;if(!fi(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function xN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=dc(8);x[31609]=0;c=P(36,c+4|0,7854)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=Te(65536/b),x[e+480244>>2]=f;Cq(a);fb=c+16|0;return}d=N()|0;lc(a)}Q(d|0)}p()}function vN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=dc(8);x[31609]=0;c=P(36,c+4|0,7875)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=Te(b*65536),x[e+480240>>2]=f;Cq(a);fb=c+16|0;return}d=N()|0;lc(a)}Q(d|0)}p()}function QH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=dc(8);x[31609]=0;c=P(36,f+4|0,8200)|0;b=x[31609];x[31609]=0;if((b|0)==1){break c}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Bl(a,b,e);c=JH(a,c,e,d,75936,76708);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;lc(a)}Q(b|0)}p()}function PH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=dc(8);x[31609]=0;c=P(36,f+4|0,8200)|0;b=x[31609];x[31609]=0;if((b|0)==1){break c}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}Bl(a,b,e);c=JH(a,c,e,d,75140,75912);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;lc(a)}Q(b|0)}p()}function KO(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;a:{c=x[a+36>>2];d=x[a+40>>2];b:{if(Ib(c,d)){tc(b+12|0);break b}wo(b,a);x[31609]=0;c=R(1056,b|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break a}x[b+12>>2]=c;nf(b);d=x[a+40>>2];c=x[a+36>>2]}c:{if(Ib(c,d)){a=a+36|0;break c}a=x[b+12>>2];c=x[a>>2]}a=fj(c,x[a+4>>2]);xl(b+12|0);fb=b+16|0;return a|0}a=N()|0;nf(b);Q(a|0);p()}function Jm(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+88864|0]}if(a>>>0<=511){return v[(a>>>5|0)+88864|0]+5|0}return v[(a>>>10|0)+88864|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+88864|0]+15|0}return v[(a>>>20|0)+88864|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+88864|0]+25|0}a=v[(a>>>30|0)+88864|0]+30|0}else{a=0}return a}function Fs(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[a+4>>2]=0;x[a>>2]=47588;h=Ec(80);x[31609]=0;c=R(1099,c|0)|0;g=x[31609];x[31609]=0;a:{b:{if((g|0)!=1){x[f+8>>2]=c;c=f+8|0;g=x[re(f+12|0,c)>>2];x[31609]=0;b=ba(e|0,h|0,b|0,g|0,d|0)|0;d=x[31609];x[31609]=0;if((d|0)==1){break b}x[a+4>>2]=b;Wc(c);fb=f+16|0;return a}a=N()|0;break a}a=N()|0;Wc(f+8|0)}Db(h);Q(a|0);p()}function Pi(a){var b=0,c=0,d=0;c=fb-16|0;fb=c;o(+a);b=j(1)|0;j(0)|0;b=b&2147483647;a:{if(b>>>0<=1072243195){if(b>>>0<1045430272){break a}a=Yp(a,0,0);break a}if(b>>>0>=2146435072){a=a-a;break a}b=gI(a,c);a=C[c+8>>3];d=C[c>>3];b:{switch(b&3){case 0:a=Yp(d,a,1);break a;case 1:a=Xp(d,a);break a;case 2:a=-Yp(d,a,1);break a;default:break b}}a=-Xp(d,a)}fb=c+16|0;return a}function Ita(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+14|0;H$(c,a,b);Cf(b,y[d+14|0],y[Jc(c)|0]);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}v[b+3|0]=45;v[b+5|0]=a&15;break a}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;break a}v[b+3|0]=20;v[b+5|0]=a&15|160;break a}v[b+3|0]=0}fb=d+16|0}function Gsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-240|0;fb=d;c=fb-16|0;fb=c;f=d+4|0;e_(c+8|0,f);e=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){id(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){d_(f)}c=-1;a:{if(!e){break a}c=0;if(!g_(f)){break a}c=xe(a,b,f_(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24)),hb)}fb=d+240|0;return c|0}function vm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!vd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Nk(d)){Ne(a,d);break c}if(d>>>0>=2147483632){break b}qg(e+8|0,Fh(d)+1|0);b=x[e+8>>2];yd(c,b);of(c,x[e+12>>2]);Bd(c,d);c=b}Xg(c,f,d+1|0);fb=e+16|0;break a}pf();p()}return a|0}function qt(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function kN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=dc(8);x[31609]=0;c=P(36,c+4|0,10751)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=x[a+32>>2]+D(b,872)|0;x[a+1075008>>2]=0;x[a+1075068>>2]=0;fb=c+16|0;return}a=N()|0;lc(b)}Q(a|0)}p()}function jg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!vd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Nk(d)){Ne(a,d);break c}if(d>>>0>=2147483632){break b}qg(e+8|0,Fh(d)+1|0);b=x[e+8>>2];yd(c,b);of(c,x[e+12>>2]);Bd(c,d);c=b}Dg(c,f,d+1|0);fb=e+16|0;break a}pf();p()}return a|0}function aq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!vd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(fr(d)){Ne(a,d);break c}if(d>>>0>=1073741808){break b}Nj(e+8|0,rn(d)+1|0);b=x[e+8>>2];yd(c,b);of(c,x[e+12>>2]);Bd(c,d);c=b}Ri(c,f,d+1|0);fb=e+16|0;break a}pf();p()}return a|0}function Y$(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){a=fb-16|0;fb=a;c=dc(16);b=fb-16|0;fb=b;if(!y[496496]){v[496496]=1}Zb(b+8|0,1,125628);d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;fb=b+16|0;b=x[a+12>>2];a=x[a+8>>2];x[31609]=0;a=Ca(1232,c|0,8959,a|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){da(a|0,94316,1233);p()}a=N()|0;lc(c);Q(a|0);p()}}function UP(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(E(B[a+4228>>2]*E(1999))+E(1))/E(1e3))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;b=E(E(E(E(B[a+4232>>2]*E(1999))+E(1))/E(1e3))*d);b:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break b}c=0}x[a+4252>>2]=c}function UB(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;a:{if(2147483631-b>>>0>=c>>>0){h=Kb(a);i=g+4|0;if(b>>>0<=1073741798){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=Fh(x[bd(i,g+12|0)>>2])+1|0}else{c=2147483631}qg(i,c);c=x[g+4>>2];if(e){Xg(c,h,e)}if((d|0)!=(e|0)){Xg((c+e|0)+f|0,e+h|0,d-e|0)}if((b|0)!=10){Db(h)}yd(a,c);of(a,x[g+8>>2]);fb=g+16|0;break a}pf();p()}Bd(a,d+f|0)}function HC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=wb(x[b>>2]);x[d+28>>2]=a;f=wb(x[b+4>>2]);a:{while(1){if(Ib(a,f)){b=d+8|0;qi(b,x[a>>2],x[a+4>>2]);if(x[d+8>>2]==(c|0)){mp(b,a);x[31609]=0;O(360,e|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break a}ub(b)}a=x[dm(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Rc(e);Q(a|0);p()}function wra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;c=If(a,c);ae(f,x[a+36>>2]);a:{if(!c){Qc(f,a+32|0,5);e=0;if(Gb(x[x[f>>2]>>2],x[f+4>>2])){break a}}h=x[a+36>>2];g=fb-16|0;fb=g;e=Fb(g+4|0);x[31609]=0;ba(469,b|0,h|0,e|0,d|0)|0;b=x[31609];x[31609]=0;b:{if((b|0)!=1){tb(e);fb=g+16|0;break b}a=N()|0;tb(e);Q(a|0);p()}e=c}ef(a,e);fb=f+16|0}function gN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=dc(8);x[31609]=0;c=P(36,c+4|0,10751)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+(x[(x[a+32>>2]+D(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=N()|0;lc(b)}Q(a|0)}p()}function P0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;b:{c:{d:{e:{if((b|0)==4){Uf(a,c);break e}e=d+8|0;Uf(e,c);x[31609]=0;c=d+20|0;S(123,c|0,b|0,e|0);b=x[31609];x[31609]=0;if((b|0)==1){break d}x[31609]=0;S(244,a|0,4,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(c);tb(e)}fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function OQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0);c=fb-16|0;fb=c;d=0;a:{if(x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){break a}x[c+12>>2]=0;Gk(a,c+12|0);e=x[c+12>>2];d=0;if(e>>>0>65535){break a}Cl(b,e);while(1){if((f|0)==(e|0)){d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}else{x[c+8>>2]=0;wq(a,c+8|0);g=yb(x[b>>2],f),h=B[c+8>>2],B[g>>2]=h;f=f+1|0;continue}break}}a=d;fb=c+16|0;return a}function eN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=dc(8);x[31609]=0;c=P(36,c+4|0,10751)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+w[(x[a+32>>2]+D(b,872)|0)+1075766>>1]*30517578125e-15)}a=N()|0;lc(b)}Q(a|0)}p()}function wpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-1120|0;fb=d;c=fb-16|0;fb=c;e=d+12|0;vX(c+8|0,e);f=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){id(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((f|0)!=(g|0)){break a}c=0;if(!xX(e)){break a}c=xe(a,b,wX(y[d+1116|0]|y[d+1117|0]<<8|(y[d+1118|0]<<16|y[d+1119|0]<<24)),hb)}fb=d+1120|0;return c|0}function YW(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28486832|y[a+63|0]!=26){break a}b=y[a+65|0];if(y[a+66|0]|(b|0)!=16&(b|0)!=1|(y[a+64|0]&3|(y[a+78|0]|y[a+79|0]<<8)>>>0>127)){break a}if((y[a+80|0]|y[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=Yk(y[a|0]|y[a+1|0]<<8,y[b|0]|y[b+1|0]<<8)?b:a;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function VW(a){var b=0;a:{if((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1179472976|y[a+28|0]!=26|(y[a+40|0]|y[a+41|0]<<8|y[a+30|0]>2)){break a}if(((y[a+38|0]|y[a+39|0]<<8)-33&65535)>>>0<65504|((y[a+32|0]|y[a+33|0]<<8)-257&65535)>>>0<65280|((y[a+34|0]|y[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((y[a+36|0]|y[a+37|0]<<8)-1&65535)>>>0<128}return b}function Io(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+810|0]=y[b+810|0]&15|c<<4;break a}c=y[b+810|0]>>>4|0;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function D4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=x[b>>2];a:{b:{if(a>>>0<=127){a=x[(a<<2)+95344>>2];break b}e=(Xs(a)|0)!=0;e=Ws(a)?e|2:e;e=Vs(a)?e|4:e;e=Us(a)?e|8:e;e=Ts(a)?e|16:e;e=Ss(a)?e|32:e;e=_n(a)?e|64:e;e=Rs(a)?e|128:e;e=$n(a)?e|256:e;x[d>>2]=e;if(!Qs(a)){break a}a=e|512}x[d>>2]=a}d=d+4|0;b=b+4|0;continue}break}return c|0}function bha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ji(a,b,c,d);x[a>>2]=43796;b=a+4208|0;e=yb(b,0),f=1060320051,x[e>>2]=f;e=yb(b,1),f=1041865114,x[e>>2]=f;e=yb(b,2),f=1065353216,x[e>>2]=f;e=yb(b,3),f=1049951732,x[e>>2]=f;e=yb(b,4),f=1049951732,x[e>>2]=f;x[31609]=0;O(941,a+44|0,2);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;_f(a);Q(b|0);p()}function dN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<32|b>512){a=dc(8);x[31609]=0;c=P(36,c+4|0,9379)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}e=x[a+32>>2],f=Te(b*1e4),x[e+1074420>>2]=f;fb=c+16|0;return}d=N()|0;lc(a)}Q(d|0)}p()}function T9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(!c){break a}x[31609]=0;O(1205,a|0,c|0);e=x[31609];x[31609]=0;if((e|0)!=1){x[31609]=0;V(1206,a|0,b|0,Vd(b,c)|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}}a=N()|0;aM(d+8|0);Q(a|0);p()}b=d+8|0;Qd(b);aM(b);fb=d+16|0;return a|0}function ov(a,b){var c=0,d=0;c=fb-32|0;fb=c;d=c+16|0;UV(d,a,a+1|0,a+2|0,a+3|0);UV(c,b,b+1|0,b+2|0,b+3|0);a=nv(y[x[d>>2]],y[x[c>>2]]);a:{if(!Lj(a)){break a}a=y[x[d+4>>2]];b=y[x[c+4>>2]];a=(a|0)!=(b|0)?a<<24>>24<b<<24>>24?-1:1:0;if(!Lj(a)){break a}a=nv(y[x[d+8>>2]],y[x[c+8>>2]]);if(!Lj(a)){break a}a=nv(y[x[d+12>>2]],y[x[c+12>>2]])}a=vd(a);fb=c+32|0;return a}function tN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<0|b>1){a=dc(8);x[31609]=0;c=P(36,c+4|0,11768)|0;d=x[31609];x[31609]=0;if((d|0)==1){break c}sc(a,c);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}e=x[a+32>>2],f=Te(b*256),x[e+1074456>>2]=f;fb=c+16|0;return}d=N()|0;lc(a)}Q(d|0)}p()}function Uma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Fb(a);c=y[b+11|0];e=x[b+4>>2];a=0;x[31609]=0;O(49,d|0,_c(e,c)|0);c=x[31609];x[31609]=0;if((c|0)!=1){a:{b:{while(1){if(_c(x[b+4>>2],y[b+11|0])>>>0<=a>>>0){break b}c=v[ec(b,a)|0];x[31609]=0;O(50,d|0,zf(zf(c))|0);c=x[31609];x[31609]=0;if((c|0)!=1){a=a+1|0;continue}break}break a}return}}a=N()|0;tb(d);Q(a|0);p()}function Bfa(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){b=x[a+24>>2];if(b){Db(tq(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31609]=0;V(983,5078,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=b;c=fb-16|0;fb=c;d=Ec(223888);x[31609]=0;b=P(842,d|0,b+1074376|0)|0;e=x[31609];x[31609]=0;a:{if((e|0)!=1){b=yf(c+12|0,b);fb=c+16|0;b=x[b>>2];break a}a=N()|0;Db(d);Q(a|0);p()}x[a+4>>2]=b;b=Nb(a+8|0);x[31609]=0;W(607,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){return a|0}c=N()|0;Ce(b);WS(a+4|0);Q(c|0);p()}function Tg(a,b){var c=0,d=0,e=0,f=0,g=0;e=Kb(a);d=Cb(x[a+4>>2],y[a+11|0]);c=Ef(b);a=0;a:{if(!c){break a}a=e;d=d+a|0;c=b+c|0;b:{if((c|0)==(b|0)){break b}c:{c=c-b|0;if((c|0)>(d-a|0)){break c}g=y[b|0];while(1){f=d-a|0;if((c|0)>(f|0)){break c}a=sq(a,(f-c|0)+1|0,g);if(!a){break c}if(!ot(a,b,c)){break b}a=a+1|0;continue}}a=d}a=(a|0)==(d|0)?-1:a-e|0}return a}function AK(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){g=x[31484];x[31484]=0;Od();a=BK(a,e+12|0,d);d=hb;f=x[31484];b:{if(f){if(x[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}x[c>>2]=4;b=!!a&(d|0)>=0|(d|0)>0;a=b?-1:0;d=b?2147483647:-2147483648;break a}x[31484]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;a=0;d=0}fb=e+16|0;hb=d;return a}function bq(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=d+12|0;cd(f,b);x[31609]=0;b=R(1253,x[d+12>>2])|0;e=x[31609];x[31609]=0;a:{if((e|0)==1){break a}x[31609]=0;e=R(1261,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break a}x[c>>2]=e;x[31609]=0;O(1262,a|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break a}_b(f);fb=d+16|0;return}a=N()|0;_b(d+12|0);Q(a|0);p()}function xT(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;i=x[d+20>>2];h=x[d+52>>2];g=!h|e;v[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;j=d+616|0;c=0;while(1){if((c|0)==(g|0)){break a}x[(D(c,872)+j|0)+764>>2]=0;c=c+1|0;continue}}x[d+24>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+48>>2]=h;w[d+72>>1]=z[d+74>>1];ee(a,i>>>0>1&e&(b|0)==1,f+15|0);fb=f+16|0}function dq(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=d+12|0;cd(f,b);x[31609]=0;b=R(1235,x[d+12>>2])|0;e=x[31609];x[31609]=0;a:{if((e|0)==1){break a}x[31609]=0;e=R(1247,b|0)|0;g=x[31609];x[31609]=0;if((g|0)==1){break a}v[c|0]=e;x[31609]=0;O(1248,a|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break a}_b(f);fb=d+16|0;return}a=N()|0;_b(d+12|0);Q(a|0);p()}function xfa(a,b){a=a|0;b=b|0;var c=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31609]=0;V(983,5660,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function _r(a,b,c){var d=0,e=0,f=0,g=0;a:{d=zk(b,zd(a));b=zk(c,b);if(Cb(x[a+4>>2],y[a+11|0])>>>0>=d>>>0){if((b|0)==-1){UT(a,d);break a}c=a;e=fb-16|0;fb=e;x[e+12>>2]=b;if(b){f=Cb(x[a+4>>2],y[a+11|0]);g=Kb(a);b=f-d|0;x[e+8>>2]=b;a=x[Hb(e+12|0,e+8|0)>>2];b:{if((b|0)==(a|0)){a=b;break b}d=d+g|0;Ni(d,a+d|0,b-a|0)}Xu(c,g,f-a|0)}fb=e+16|0;break a}dn();p()}}function R3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){zc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){zc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function Oga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=kQ(a,b,c,d,e^1);x[b>>2]=44408;a=b+4208|0;f=yb(a,0),g=1056964608,x[f>>2]=g;f=yb(a,1),g=1065353216,x[f>>2]=g;f=yb(a,2),g=1020054733,x[f>>2]=g;f=yb(a,3),g=1065353216,x[f>>2]=g;f=yb(a,4),g=1056964608,x[f>>2]=g;f=yb(a,5),g=1048406533,x[f>>2]=g;f=yb(a,6),g=1056964608,x[f>>2]=g;return b|0}function yN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=dc(8);x[31609]=0;c=P(36,c+4|0,9379)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);fb=c+16|0;return}a=N()|0;lc(b)}Q(a|0)}p()}function jsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-576|0;fb=d;c=fb-16|0;fb=c;MZ(c+8|0,d);e=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){id(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){LZ(d)}c=-1;a:{if(!e){break a}c=0;if(!OZ(d)){break a}c=xe(a,b,NZ(y[d+34|0]|y[d+35|0]<<8,y[d+36|0]|y[d+37|0]<<8),hb)}fb=d+576|0;return c|0}function MH(a,b,c){var d=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=dc(8);x[31609]=0;c=P(36,d+4|0,10751)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=(x[a+32>>2]+D(b,872)|0)+1075080|0;x[a>>2]=x[a>>2]|c;fb=d+16|0;return}a=N()|0;lc(b)}Q(a|0)}p()}function JR(a,b){var c=0,d=0,e=0,f=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{c=(D(b,872)+a|0)+1074992|0;d=y[c+791|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;d=v[c+793|0];d:{if((d|0)>=0){c=Pe(a+901692|0,y[c+844|0]);break d}c=Pe(a+902204|0,d&127)}fT(a,e,b,f,c,d&255)}}function e6(a){a=a|0;if(y[499904]){return x[124975]}if(!y[500248]){v[500248]=1}ld(500080,5240);ld(500092,5247);ld(500104,5213);ld(500116,5221);ld(500128,5204);ld(500140,5254);ld(500152,5231);ld(500164,9774);ld(500176,9980);ld(500188,11310);ld(500200,12946);ld(500212,5503);ld(500224,10813);ld(500236,6622);v[499904]=1;x[124975]=500080;return 500080}function msa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;a=xh(d+4|0,a,1);TZ(x[a+4>>2],z[b>>1],y[c|0]);x[a+4>>2]=x[a+4>>2]+4;jc(a);fb=d+16|0;return}e=fb-32|0;fb=e;d=Ab(a);d=Zf(e+12|0,Lf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),d);TZ(x[d+8>>2],z[b>>1],y[c|0]);x[d+8>>2]=x[d+8>>2]+4;Zr(a,d);Yf(d);fb=e+32|0}function m_(a){var b=0,c=0;a:{if(jd(a,13968,3)|(y[a+3|0]-1&255)>>>0>3){break a}if(Bb(y[a+196|0]|y[a+197|0]<<8)>>>0>255){break a}if((Bb(y[a+198|0]|y[a+199|0]<<8)-1&65535)>>>0>255){break a}if((Bb(y[a+200|0]|y[a+201|0]<<8)-1&65535)>>>0>31){break a}b=Bb(y[a+202|0]|y[a+203|0]<<8);if(b>>>0>256){break a}c=Bb(y[a+204|0]|y[a+205|0]<<8)>>>0<b>>>0}return c}function mR(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1163089229){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))}return c}function Pta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if(!(c&1024)){break a}f=e,g=zd(b),x[f+12>>2]=g;c=_c(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[ec(b,0)|0]!=43){if(y[ec(b,0)|0]!=45){break b}}d=d+1|0;hV(e+12|0)}if(c>>>0>=d>>>0){break a}JE(b,x[vb(e+8|0,x[e+12>>2])>>2],d-_c(x[b+4>>2],y[b+11|0])|0,48)}Uc(a,b);fb=e+16|0}function Ho(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+810|0];if(c){v[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function vw(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if(!(y[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=42;break b}if((f|0)!=10|(e|0)!=20|y[b|0]!=159){break a}v[a|0]=42;v[b|0]=y[d|0]}v[c|0]=0}}function Wx(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function zN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=dc(8);x[31609]=0;c=P(36,c+4|0,5848)|0;a=x[31609];x[31609]=0;if((a|0)==1){break c}sc(b,c);x[31609]=0;S(97,b|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074416>>2]=b;fb=c+16|0;return}a=N()|0;lc(b)}Q(a|0)}p()}function kM(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}d=x[a+12>>2];if(!d){break b}a=ib[d|0](b)|0;e=hb;if((e|0)<0){break b}if((ib[c|0](b,0,0,0)|0)<0){break a}if((ib[c|0](b,0,0,2)|0)<0){break a}d=ib[d|0](b)|0;f=hb;ib[c|0](b,a,e,0)|0;if((f|0)<0){break b}g=Tu(d,f)}return g}ib[c|0](b,a,e,0)|0;return 0}function Vf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Cb(x[a+4>>2],y[a+11|0])|(c-b|0)<5){break a}vt(b,c);e=c-4|0;c=Kb(a);g=c+Cb(x[a+4>>2],y[a+11|0])|0;b:{while(1){c:{a=y[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=x[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>x[e>>2]-1>>>0){break a}}x[d>>2]=4}}function C3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb+-64|0;fb=d;e=1;a:{if(lh(a,b,0)){break a}e=0;if(!b){break a}b=hB(b,124148,124196);e=0;if(!b){break a}Rb(d+12|0,0,52);x[d+56>>2]=1;x[d+20>>2]=-1;x[d+16>>2]=a;x[d+8>>2]=b;ib[x[x[b>>2]+28>>2]](b,d+8|0,x[c>>2],1);a=x[d+32>>2];if((a|0)==1){x[c>>2]=x[d+24>>2]}e=(a|0)==1}a=e;fb=d- -64|0;return a|0}function AF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<3){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==2){$i(c+10|0,z[c+14>>1]);d=z[c+10>>1];break a}else{v[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){eh(a,c+13|0);e=y[c+13|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11251,9095,325,14260);p()}fb=c+16|0;return d&65535}function T0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;HE(f,c);c=y[d|0];x[31609]=0;O(243,e+20|0,c|0);c=x[31609];x[31609]=0;b:{c:{if((c|0)!=1){kk(e,f);x[31609]=0;V(92,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Bg(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Bg(e+8|0)}Q(a|0);p()}}function Afa(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31609]=0;V(983,8932,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function XI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=wJ(a,c);x[a>>2]=96376;c=lk(Kb(b));x[a+16>>2]=c;a:{b:{c:{if(!c){x[31609]=0;c=d+4|0;S(1002,c|0,18013,b|0);b=x[31609];x[31609]=0;if((b|0)==1){break c}x[31609]=0;W(1367,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}b=N()|0;tb(c);break b}fb=d+16|0;return a|0}b=N()|0}et(a);Q(b|0)}p()}function Raa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a:{b:{if((sk(y[a+140|0])|0)!=1){break b}if((RM(a)|0)!=(b|0)){break b}d=a+120|0;bu(y[d+20|0]);b=fb-16|0;fb=b;x[b+12>>2]=c+15;a=fb-16|0;fb=a;x[a+12>>2]=1151;x[a+8>>2]=1152;x[a+4>>2]=1153;x[a>>2]=1154;ib[x[lq(a,sk(y[d+20|0]))>>2]](b+12|0,d);fb=a+16|0;fb=b+16|0;break a}QM(a,1,b)}fb=c+16|0}function yfa(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return Cg(a)|0}Y(T(0)|0)|0;x[31609]=0;V(983,12259,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();return 0}return Cg(22292)|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function pv(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;c=D(a,b);Aua(b,0,a,0);a=hb?0:c}else{a=0}a:{if(!a){break a}x[31609]=0;b=R(781,a|0)|0;c=x[31609];x[31609]=0;b:{c:{if((c|0)==1){Y(T(0)|0)|0;x[31609]=0;X(26);c=x[31609];x[31609]=0;b=0;if((c|0)==1){break c}}break b}T(0)|0;Sb();p()}if(!b){break a}d=Rb(b,0,a)- -64|0}return d}function ok(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function i2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;f=fb-16|0;fb=f;g=fb-16|0;fb=g;e=g+4|0;x[e+4>>2]=1;h=e,i=Ec(24),x[h+8>>2]=i;b=sm(x[e+8>>2]);x[b>>2]=78312;AG(nc(b),x[d>>2],x[d+4>>2]);c=f+8|0;b=Rn(e);Qn(c,nc(b),b);tm(e);fb=g+16|0;Ff(a,c);me(c);fb=f+16|0;fb=d+16|0}function eba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=x[b+1298404>>2];b=fb-32|0;fb=b;e=b+8|0;Uf(e,c);x[31609]=0;c=b+20|0;S(502,c|0,d|0,e|0);d=x[31609];x[31609]=0;b:{c:{if((d|0)!=1){x[31609]=0;S(244,a|0,0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(c);tb(e);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Ub(b+20|0)}tb(b+8|0);Q(a|0);p()}}function Vsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-112|0;fb=d;c=fb-16|0;fb=c;f=d+14|0;C_(c+8|0,f);e=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){id(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){B_(f)}c=-1;a:{if(!e){break a}c=0;if(!E_(f)){break a}c=xe(a,b,D_(y[d+61|0]|y[d+62|0]<<8),hb)}fb=d+112|0;return c|0}function IG(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1129474426|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1634291279|(y[a+8|0]|y[a+9|0]<<8)!=14|(!(y[a+12|0]|y[a+13|0]<<8)|(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))<=0))){b=(y[a+18|0]|y[a+19|0]<<8|(y[a+20|0]<<16|y[a+21|0]<<24))>>>0>23}return b}function lea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[31609]=0;W(996,a|0);f=x[31609];x[31609]=0;if((f|0)!=1){return hu(x[x[a+24>>2]+24>>2],b,c,d,e)|0}Y(T(0)|0)|0;x[31609]=0;V(983,12502,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function gf(a,b,c){var d=0,e=0,f=0;e=Fb(a);d=y[b+11|0];f=x[b+4>>2];a=0;x[31609]=0;O(53,e|0,_c(f,d)|0);d=x[31609];x[31609]=0;if((d|0)!=1){a:{while(1){if(_c(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=x[(y[ec(b,a)|0]<<2)+c>>2];x[31609]=0;O(35,e|0,d|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Ub(e);Q(a|0);p()}function V6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=fb-16|0;fb=g;k=rh(g+12|0,x[a+8>>2]);i=fq(0,c,d-c|0,b?b:501716);qh(k);fb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function QB(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function k1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-512|0;fb=d;c=fb-16|0;fb=c;f=d+15|0;nF(c+8|0,f);e=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){id(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){mF(f)}c=-1;a:{if(!e){break a}c=0;if(!qF(f)){break a}c=xe(a,b,pF(y[d+125|0],y[d+126|0]),hb)}fb=d+512|0;return c|0}function T1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;f=x[b+16>>2];a:{if(f>>>0<=c>>>0){cc(a,x[d>>2],0);break a}g=x[b+12>>2];b=x[b+4>>2];x[e+20>>2]=x[d+4>>2];x[e+16>>2]=f-c;cc(e+24|0,x[d>>2],x[Hb(e+20|0,e+16|0)>>2]);d=x[x[b>>2]+28>>2];f=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=f;ib[d|0](a,b,c+g|0,e+8|0)}fb=e+32|0}function RJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[gc(a)>>2]==1274;f=x[c>>2];g=f-h|0;f=g>>>0>=2147483647?-1:(h|0)==(f|0)?4:g<<1;g=Vv(e?0:h,f);if(g){if(!e){ne(a)}x[d+4>>2]=1239;e=De(d+8|0,g,d+4|0);a=OJ(a,e);Lc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=x[a>>2]+(f&-4);fb=d+16|0;return}Tv();p()}function MK(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=ib[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((im(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=ju(x[a+32>>2])?-1:0}fb=b+16|0;return d|0}function yqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;Gr(f,c);x[31609]=0;O(597,e+20|0,d|0);c=x[31609];x[31609]=0;b:{c:{if((c|0)!=1){kk(e,f);x[31609]=0;V(301,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Bg(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Bg(e+8|0)}Q(a|0);p()}}function xta(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-32|0;fb=b;d=b+20|0;c=-1;a:{if(!dE(a,d)){break a}c=0;if(!j$(d)){break a}if((y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))==1179472708){c=-1;if(!id(a,4)){break a}}c=-1;if(!hk(a,b+12|0)){break a}c=(y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24))==1196314451}fb=b+32|0;return c|0}function eR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;if((a|0)!=(b|0)){c=x[b>>2];d=x[b+4>>2];b=Sd(c,d);e=fb-16|0;fb=e;a:{if(Vg(a)>>>0>=b>>>0){f=x[a>>2];g=oc(f,x[a+4>>2]);if(b>>>0>g>>>0){h=c;c=fD(c,g);tA(h,c,f);yq(a,c,d,b-oc(x[a>>2],x[a+4>>2])|0);break a}Iv(e+8|0,c,d,f);Jd(a,x[e+12>>2]);break a}qr(a);jm(a,Lf(a,b));yq(a,c,d,b)}fb=e+16|0}return a}function Gja(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;x[b+16>>2]=0;x[b+20>>2]=0;d=b+16|0;c=Zb(b,d,15);kc(b+8|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);c=0;a:{if(x[b+12>>2]!=15){break a}if(jd(d,8525,15)){break a}Vb(a,15);c=1}fb=b+32|0;return c|0}function BF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<5){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==4){Lm(c+4|0,x[c+12>>2]);d=x[c+4>>2];break a}else{v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){eh(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11251,9095,325,14260);p()}fb=c+16|0;return d}function tqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(!b){break a}x[31609]=0;O(590,a|0,b|0);d=x[31609];x[31609]=0;if((d|0)!=1){x[31609]=0;O(591,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}}a=N()|0;fY(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);fY(b);fb=c+16|0;return a|0}function maa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=x[d+4>>2];pz(b,c,g);f=x[b+16>>2];a:{if(f>>>0<=c>>>0){cc(a,x[d>>2],0);break a}x[e+12>>2]=f-c;x[e+8>>2]=g;d=x[d>>2];f=x[Hb(e+12|0,e+8|0)>>2];wr(e,d,g,0,f);h=x[e>>2];i=x[e+4>>2];aE(vf(wb(x[b+4>>2]),c),vf(wb(x[b+4>>2]),c+i|0),h);wr(a,d,g,0,f)}fb=e+16|0}function $ia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);c=x[b>>2];d=c;b=x[b+4>>2];e=b;c=oc(c,b);b=fb-16|0;fb=b;Rd(b+8|0,x[vb(b+4|0,a)>>2]);a:{b:{if(c){x[31609]=0;O(225,a|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break b}yq(a,d,e,c)}c=b+8|0;Qd(c);bh(c);fb=b+16|0;break a}a=N()|0;bh(b+8|0);Q(a|0);p()}return a|0}function zsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;QZ(f,c);x[31609]=0;O(91,e+20|0,d|0);c=x[31609];x[31609]=0;b:{c:{if((c|0)!=1){kk(e,f);x[31609]=0;V(92,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Bg(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Bg(e+8|0)}Q(a|0);p()}}function sP(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;a=Nb(a);x[31609]=0;c=b+4|0;W(986,c|0);d=x[31609];x[31609]=0;a:{b:{if((d|0)!=1){d=wb(x[b+4>>2]);e=wb(x[b+8>>2]);f=x[vb(b,a)>>2];x[31609]=0;S(987,d|0,e|0,f|0);d=x[31609];x[31609]=0;if((d|0)==1){break b}wc(c);fb=b+16|0;return}c=N()|0;break a}c=N()|0;wc(b+4|0)}Td(a);Q(c|0);p()}
function c1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(!b){break a}x[31609]=0;O(226,a|0,b|0);d=x[31609];x[31609]=0;if((d|0)!=1){x[31609]=0;O(227,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}}a=N()|0;VE(c+8|0);Q(a|0);p()}b=c+8|0;Qd(b);VE(b);fb=c+16|0;return a|0}function Ir(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=wb(x[b>>2]);g=wb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,g)){break a}f=fb-16|0;fb=f;qi(f+8|0,x[d>>2],x[d+4>>2]);h=$b(x[f+8>>2]);fb=f+16|0;if((c|0)==(h|0)){break a}d=x[dm(e+12|0)>>2];continue}break}fb=e+16|0;if(mc(d,wb(x[b+4>>2]))){Yh(a);return}mp(a,d)}function CC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);c=x[b>>2];d=c;b=x[b+4>>2];e=b;c=Xc(c,b);b=fb-16|0;fb=b;Rd(b+8|0,x[vb(b+4|0,a)>>2]);a:{b:{if(c){x[31609]=0;O(322,a|0,c|0);f=x[31609];x[31609]=0;if((f|0)==1){break b}yn(a,d,e,c)}c=b+8|0;Qd(c);Xi(c);fb=b+16|0;break a}a=N()|0;Xi(b+8|0);Q(a|0);p()}return a|0}function v4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;ao(f,c);x[31609]=0;O(91,e+20|0,d|0);c=x[31609];x[31609]=0;b:{c:{if((c|0)!=1){kk(e,f);x[31609]=0;V(92,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Bg(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Bg(e+8|0)}Q(a|0);p()}}function ad(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;pm(b);e=a+8|0;f=yf(d+12|0,b);a:{b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0<=c>>>0){x[31609]=0;O(1328,e|0,c+1|0);a=x[31609];x[31609]=0;if((a|0)==1){break a}b=x[e>>2]}a=yb(b,c);b=x[a>>2];if(b){um(b);a=yb(x[e>>2],c)}g=a,h=ne(f),x[g>>2]=h;jJ(f);fb=d+16|0;return}a=N()|0;jJ(f);Q(a|0);p()}function Tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=4925421;x[c+8>>2]=2147483647;e=Hb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){ed();p()}if(b>>>0>=4925422){Sj();p()}c=Ec(D(b,872));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=Ab(a),g=b+D(x[d+12>>2],872)|0,x[f>>2]=g;fb=d+16|0}function EE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;Bw(f,c);x[31609]=0;O(91,e+20|0,d|0);c=x[31609];x[31609]=0;b:{c:{if((c|0)!=1){kk(e,f);x[31609]=0;V(92,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Bg(f);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;Bg(e+8|0)}Q(a|0);p()}}function Bha(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[x[a+20>>2]+148>>2]=-1;Jr(b+8|0,a+4228|0);c=x[a+20>>2];d=wb(x[b+8>>2]);e=Yj(x[b+8>>2],x[b+12>>2]);x[31609]=0;S(965,c+4|0,d|0,e|0);c=x[31609];x[31609]=0;a:{if((c|0)==1){c=T(124540)|0;if((gb|0)!=($(124540)|0)){break a}Y(c|0)|0;Nc(x[a+20>>2]+4|0);Z()}fb=b+16|0;return}Q(c|0);p()}function nd(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;nn(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;d=z[a+34>>1]&-25279;w[a+34>>1]=(b|0)==4?d|32:d;b=Dc(c+4|0,22292);Be(a+43|0,b);tb(b);ZV(a);fb=c+16|0}function fua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;cc(c+8|0,b,10);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0}return a|0}function sM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=x[a>>2];a:{if(!c){break a}d=x[a+8>>2];if(!d){break a}e=x[a+12>>2];if(!e){break a}a=ib[e|0](c)|0;f=hb;if((f|0)<0){break a}b=0;b:{if((ib[d|0](c,0,0,0)|0)<0){break b}b=0;if((ib[d|0](c,0,0,2)|0)<0){break b}ib[e|0](c)|0;b=hb;if((b|0)>0){b=1}else{b=(b|0)>=0}}ib[d|0](c,a,f,0)|0}return b|0}function qla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Wv(e,c);x[31609]=0;O(474,d+20|0,41612);c=x[31609];x[31609]=0;b:{c:{if((c|0)!=1){kk(d,e);x[31609]=0;V(92,a|0,b|0,x[d>>2],x[d+4>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Bg(e);fb=d+32|0;break a}a=N()|0;tb(d+8|0);break b}a=N()|0;Bg(d+8|0)}Q(a|0);p()}}function ZP(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2]/5|0;b=Gc(b,b>>31);x[a+4272>>2]=b;x[31609]=0;x[c+12>>2]=0;S(947,a+4256|0,b<<1,c+12|0);b=x[31609];x[31609]=0;a:{if((b|0)==1){b=T(124540)|0;if((gb|0)!=($(124540)|0)){break a}Y(b|0)|0;x[a+4272>>2]=0;Z()}x[a+4276>>2]=0;x[a+4268>>2]=0;fb=c+16|0;return}Q(b|0);p()}function Oq(a){var b=0,c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;b=wb(x[a>>2]);f=wb(x[a+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=b;while(1){if(Ib(b,f)){c=c+C[b>>3];b=x[OB(e+12|0)>>2];continue}break}fb=e+16|0;b=wb(x[a>>2]);x[d+12>>2]=b;c=-c;a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){c=c+C[b>>3];C[b>>3]=c;b=x[OB(d+12|0)>>2];continue}else{fb=d+16|0}break}}function Ks(a,b,c,d,e,f){var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=d;d=g+12|0;h=x[re(g+8|0,d)>>2];x[31609]=0;ha(f|0,a+8|0,b|0,c|0,h|0,e|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){a=Fz(a);b=Ez(a+88|0);c=Dz(a+92|0);e=Cz(a+96|0);x[a>>2]=47708;x[b>>2]=47824;x[c>>2]=47904;x[e>>2]=47944;Wc(d);fb=g+16|0;return a}a=N()|0;Wc(g+12|0);Q(a|0);p()}function Eha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ji(a,b,c,d);x[a>>2]=43296;c=Nb(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=1056964608;b=a+4228|0;v[b+6|0]=1;v[b+4|0]=0;v[b+5|0]=4;v[b|0]=69;v[b+1|0]=99;v[b+2|0]=104;v[b+3|0]=111;x[31609]=0;O(941,a+44|0,2);b=x[31609];x[31609]=0;if((b|0)!=1){mu(a);return a|0}b=N()|0;wc(c);_f(a);Q(b|0);p()}function r7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[gc(a)>>2]==1274;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g>>>0<=1?1:g;g=Vv(e?0:h,f);if(g){if(!e){ne(a)}x[d+4>>2]=1239;e=De(d+8|0,g,d+4|0);a=OJ(a,e);Lc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=f+x[a>>2];fb=d+16|0;return}Tv();p()}function Yra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{e=Mb(x[b>>2],x[b+8>>2],c<<2);if(!e){break a}xc(d+12|0,65535);vg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}f=d+8|0;if(!Nn(b,f)){Cn(f)}w[c>>1]=x[d+8>>2];c=x[ge(d+4|0)>>2];continue}}fb=d+16|0;return e|0}function zR(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{while(1){x[e+12>>2]=b;x[e+8>>2]=d;if(A[Hb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=Lq(v[xb(a,f)|0]);h=Lq(v[xb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}fb=e+16|0;return a}function d9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=x[a+44>>2];c=x[a+24>>2];if(e>>>0<c>>>0){x[a+44>>2]=c;e=c}g=x[a+8>>2];f=x[a+12>>2];d=-1;a:{if(g>>>0>=f>>>0){break a}if(mc(b,-1)){Vn(a,g,f-1|0,e);return Qy(b)|0}c=b<<24>>24;if(!(x[a+48>>2]&16)){d=-1;if(!mc(c,v[f-1|0])){break a}}Vn(a,g,f-1|0,e);v[x[a+12>>2]]=c;d=b}return d|0}function mla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=d;c=If(a,c);d=e+8|0;ae(d,x[a+36>>2]);f=a;a:{if(!c){Qc(d,a+32|0,5);d=0;if(Gb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}d=x[a+36>>2];a=0;ZE(b,x[e+28>>2]);while(1){if(A[e+28>>2]>a>>>0){IU(d,ac(x[b>>2],a));a=a+1|0;continue}break}d=c}ef(f,d);fb=e+32|0}function _ja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(!Ed(x[a+1298300>>2])){b=x[a+24620>>2];d=fb-16|0;fb=d;e=Ec(536);x[31609]=0;f=P(874,e|0,b|0)|0;b=x[31609];x[31609]=0;a:{if((b|0)!=1){b=yf(d+12|0,f);fb=d+16|0;b=x[b>>2];break a}a=N()|0;Db(e);Q(a|0);p()}x[c+12>>2]=b;b=a+1298300|0;a=c+12|0;gS(b,ne(a));WA(a)}fb=c+16|0}function Roa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-608|0;fb=d;c=fb-16|0;fb=c;TW(c+8|0,d);e=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){id(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){SW(d)}c=-1;a:{if(!e){break a}c=0;if(!VW(d)){break a}c=xe(a,b,UW(y[d+34|0]|y[d+35|0]<<8),hb)}fb=d+608|0;return c|0}function Lia(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=xh(c+4|0,a,1);tk(x[a+4>>2],B[b>>2]);x[a+4>>2]=x[a+4>>2]+4;jc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=Zf(d+12|0,Lf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);tk(x[c+8>>2],B[b>>2]);x[c+8>>2]=x[c+8>>2]+4;nA(a,c);Yf(c);fb=d+32|0}function JE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=zk(b,zd(a));a:{f=Cb(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=Mc(a);b:{if(e-f>>>0>=c>>>0){e=Kb(a);if((b|0)==(f|0)){break b}g=b+e|0;Ni(g+c|0,g,f-b|0);break b}an(a,e,(c+f|0)-e|0,f,b,0,c);e=x[a>>2]}$l(b+e|0,c,d);b=c+f|0;lg(a,b);hd(b+e|0,0)}break a}dn();p()}zd(a)}function w0(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=bj(c+4|0,a,1);mm(x[a+4>>2],z[b>>1]);x[a+4>>2]=x[a+4>>2]+2;jc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=ek(d+12|0,fk(a,$c(x[a>>2],x[a+4>>2])+1|0),$c(x[a>>2],x[a+4>>2]),c);mm(x[c+8>>2],z[b>>1]);x[c+8>>2]=x[c+8>>2]+2;Ur(a,c);aj(c);fb=d+32|0}function n1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-784|0;fb=e;c=fb-16|0;fb=c;f=e+12|0;xF(c+8|0,f);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){wF(f)}c=-1;a:{if(!d){break a}c=0;if(!zF(f)){break a}c=xe(a,b,yF(y[e+527|0]),0)}fb=e+784|0;return c|0}function Yia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;f=x[a+8>>2];d=e+4|0;x[d+8>>2]=a+8;x[d>>2]=f;x[d+4>>2]=D(b,52)+f;b=x[d>>2];a:{while(1){if(x[d+4>>2]==(b|0)){break a}x[31609]=0;O(920,b|0,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){b=x[d>>2]+52|0;x[d>>2]=b;continue}break}a=N()|0;je(d);Q(a|0);p()}je(d);fb=e+16|0}function Nra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Xc(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;b=b-d|0;d=x[Ab(a)>>2];f=x[a+4>>2];a:{if(b>>>0<=d-f>>>0){Ap(a,b,c);break a}d=Ab(a);d=pn(e+12|0,Vl(a,Xc(x[a>>2],f)+b|0),Xc(x[a>>2],x[a+4>>2]),d);dZ(d,b,c);cr(a,d);on(d)}fb=e+32|0;return}if(b>>>0<d>>>0){Jd(a,b+e|0)}}function eq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=Sd(b,c);f=fb-16|0;fb=f;a:{if(e>>>0<1073741808){b:{if(fr(e)){Ne(d,e);break b}Nj(f+8|0,rn(e)+1|0);g=x[f+8>>2];yd(d,g);of(d,x[f+12>>2]);Bd(d,e);d=g}while(1){if((b|0)!=(c|0)){yd(d,x[b>>2]);d=d+4|0;b=b+4|0;continue}break}yd(d,0);fb=f+16|0;break a}pf();p()}return a|0}function Qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31609]=0;W(996,a|0);d=x[31609];x[31609]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}Y(T(0)|0)|0;x[31609]=0;V(983,13123,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function i1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;c=fb-16|0;fb=c;f=e+10|0;hF(c+8|0,f);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){gF(f)}c=-1;a:{if(!d){break a}c=0;if(!jF(f)){break a}c=xe(a,b,iF(y[e+45|0]),hb)}fb=e+48|0;return c|0}function Xl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=Pj(b,c);f=fb-16|0;fb=f;a:{if(e>>>0<2147483632){b:{if(Nk(e)){Ne(d,e);break b}qg(f+8|0,Fh(e)+1|0);g=x[f+8>>2];yd(d,g);of(d,x[f+12>>2]);Bd(d,e);d=g}while(1){if((b|0)!=(c|0)){hd(d,y[b|0]);d=d+1|0;b=b+1|0;continue}break}hd(d,0);fb=f+16|0;break a}pf();p()}return a|0}function V$(a,b,c,d){var e=0,f=0,g=0,h=0;e=Cb(x[a+4>>2],y[a+11|0]);if(e>>>0>=b>>>0){f=Mc(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=Kb(a);h=f+b|0;if((b|0)!=(e|0)){g=b+f|0;Ni(g+d|0,g,e-b|0);c=(c>>>0>=g>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}Ni(h,c,d);b=d+e|0;lg(a,b);hd(b+f|0,0);return a}Zp(a,f,(d+e|0)-f|0,e,b,0,d,c)}return a}dn();p()}function R2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;cd(a,x[b+28>>2]);x[31609]=0;d=e+12|0;S(108,d|0,b|0,c|0);f=x[31609];x[31609]=0;a:{if((f|0)==1){break a}_b(d);b=x[b+24>>2];if(b){x[31609]=0;d=e+8|0;S(109,d|0,b|0,c|0);b=x[31609];x[31609]=0;if((b|0)==1){break a}_b(d)}fb=e+16|0;return}b=N()|0;_b(a);Q(b|0);p()}function M$(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){c=fb-16|0;fb=c;b=vb(c+12|0,x[x[a+8>>2]>>2]);e=x[vb(c+8|0,x[x[a+4>>2]>>2])>>2];d=fb-16|0;fb=d;a=x[b>>2];x[d+12>>2]=a;while(1){if(wi(a,e)){b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+12>>2]=x[b+12>>2]+28;fb=b+16|0;Hd(pE(x[b+12>>2]));a=x[dm(d+12|0)>>2];continue}break}fb=d+16|0;fb=c+16|0}}function Hs(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;x[f+12>>2]=c;c=f+12|0;g=x[re(f+8|0,c)>>2];x[31609]=0;ba(e|0,a+8|0,b|0,g|0,d|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){a=Fz(a);b=Ez(a+88|0);d=Dz(a+92|0);e=Cz(a+96|0);x[a>>2]=47708;x[b>>2]=47824;x[d>>2]=47904;x[e>>2]=47944;Wc(c);fb=f+16|0;return a}a=N()|0;Wc(f+12|0);Q(a|0);p()}function Hj(a){var b=0,c=0,d=0,e=0,f=0;b=x[a+4>>2];if(mc(x[a>>2],b)){a=0}else{b=Ti(b);e=Ti(x[a>>2]);c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){a:{if(!Zg(b,e)){break a}d=fb-16|0;fb=d;x[d+12>>2]=b;f=Wk(d+12|0);fb=d+16|0;if(z[x[f>>2]>>1]!=65535){break a}b=x[Wk(c+12|0)>>2];continue}break}fb=c+16|0;a=rE(wb(x[a>>2]),b)}return a&65535}function nsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=1;a:{if(Vg(a)){d=x[a>>2];f=oc(d,x[a+4>>2]);x[c+8>>2]=f;e=x[Hb(c+12|0,c+8|0)>>2];while(1){if(e){w[d>>1]=z[b>>1];v[d+2|0]=y[b+2|0];e=e-1|0;d=d+4|0;continue}break}if(!f){VZ(a,b);break a}Jd(a,x[a>>2]+4|0);break a}qr(a);jm(a,Lf(a,1));VZ(a,b)}fb=c+16|0}function Hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=fb-32|0;fb=d;e=d+8|0;Ro(e,c);x[31609]=0;c=d+20|0;O(14,c|0,e|0);f=x[31609];x[31609]=0;b:{c:{if((f|0)!=1){x[31609]=0;S(841,a|0,b|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;b=b-c|0;c=x[Ab(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Vq(a,b);break a}c=Ab(a);c=Zf(d+12|0,Lf(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);kA(c,b);Sm(a,c);Yf(c)}fb=d+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<2)|0)}}function YF(a){var b=0,c=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179340888|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1213419859){break a}b=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24));if(!b){break a}c=($b(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function Tha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=33;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;nD(e,b);f=Zb(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);nD(e,b);Rb(x[d+8>>2]+c|0,0,33-c|0);Vb(a,x[d+28>>2]);fb=d+32|0;return c|0}function L9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Ro(e,c);x[31609]=0;c=d+20|0;S(502,c|0,b|0,e|0);b=x[31609];x[31609]=0;b:{c:{if((b|0)!=1){x[31609]=0;S(244,a|0,0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function H3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{e=x[b>>2];if(Ed(e)){f=d+4|0;if(!Ad(x[c+4>>2],y[c+11|0])){rP(c,18407);e=x[b>>2]}b=x[b+4>>2];ib[x[x[b>>2]+24>>2]](f,b,e);x[31609]=0;P(838,c|0,f|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}tb(f)}Uc(a,c);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function FX(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808604749|((y[a+8|0]|y[a+9|0]<<8)-768&65535)>>>0<65280|(((y[a+112|0]|y[a+113|0]<<8)-65&65535)>>>0<65472|(y[a+106|0]|y[a+107|0]<<8)>>>0>256)){break a}if((y[a+122|0]|y[a+123|0]<<8)>>>0>255){break a}b=(y[a+124|0]|y[a+125|0]<<8)>>>0<4e3}return b}function Tsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-224|0;fb=d;c=fb-16|0;fb=c;e=d+6|0;u_(c+8|0,e);f=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){id(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((f|0)!=(g|0)){break a}c=0;if(!w_(e)){break a}c=xe(a,b,v_(y[d+222|0],y[d+223|0]),hb)}fb=d+224|0;return c|0}function RS(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=(D(b,872)+a|0)+616|0;b=0;e=x[a+16>>2];b=e?y[d+813|0]:b;f=x[a+40>>2];v[d+851|0]=y[d+851|0]|64;h=x[d+852>>2];g=(+(e>>>0)+1)*+(c|0)/+(f>>>0);a:{if(F(g)<2147483648){a=~~g;break a}a=-2147483648}x[d+852>>2]=h+(a+((c|0)<0?b:0-b|0)|0);b=(f|0)==(e+1|0)?c:a;a=b>>31;v[d+813|0]=(a^b)-a}function Qqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb+-64|0;fb=f;c=fb-16|0;fb=c;e=f+12|0;EY(c+8|0,e);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){DY(e)}c=-1;a:{if(!d){break a}c=0;if(!GY(e)){break a}c=xe(a,b,FY(e),hb)}fb=f- -64|0;return c|0}function Lqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;c=yb(b,c);e=c;c=Sd(b,c);d=fb-16|0;fb=d;a:{if(Vg(a)>>>0>=c>>>0){f=x[a>>2];g=oc(f,x[a+4>>2]);if(c>>>0>g>>>0){h=b;b=fD(b,g);Kv(h,b,f);rY(a,b,e,c-oc(x[a>>2],x[a+4>>2])|0);break a}tY(d+8|0,b,e,f);Jd(a,x[d+12>>2]);break a}qr(a);jm(a,Lf(a,c));rY(a,b,e,c)}fb=d+16|0}function Hqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;zp(e,b,c);x[31609]=0;b=d+20|0;S(123,b|0,28,e|0);c=x[31609];x[31609]=0;b:{c:{if((c|0)!=1){x[31609]=0;O(12,a|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(b);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function v3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(lh(a,x[b+8>>2],e)){Vx(b,c,d);return}a:{if(!lh(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function nM(a){var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;if(!y[a+20|0]){while(1){if(!(ib[x[x[a>>2]+40>>2]](a)|0)){lM(a,65536);c=Zb(b+16|0,xb(x[a+4>>2],x[a+16>>2]),65536);d=x[x[a>>2]+44>>2];e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;ib[d|0](b+24|0,a,b+8|0);x[a+16>>2]=x[a+16>>2]+x[b+28>>2];continue}break}v[a+20|0]=1}fb=b+32|0}function lua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-1968|0;fb=e;c=fb-16|0;fb=c;f=e+14|0;o0(c+8|0,f);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){n0(f)}c=-1;a:{if(!d){break a}c=0;if(!q0(f)){break a}c=xe(a,b,1024,0)}fb=e+1968|0;return c|0}function Xja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[a>>1]=0;c=Nb(a+4|0);d=Nb(a+16|0);x[a+32>>2]=0;x[a+36>>2]=0;x[a+28>>2]=65472;e=Fb(a+40|0);f=og(a+52|0);x[31609]=0;x[b+12>>2]=1065353216;O(879,c|0,b+12|0);g=x[31609];x[31609]=0;if((g|0)!=1){fb=b+16|0;return a|0}a=N()|0;sZ(f);tb(e);wc(d);wc(c);Q(a|0);p()}function Vpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Ro(e,c);x[31609]=0;c=d+20|0;S(123,c|0,b|0,e|0);b=x[31609];x[31609]=0;b:{c:{if((b|0)!=1){x[31609]=0;O(12,a|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function BU(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;if(y[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){v[a+534|0]=0}else{Ej(a,d,1);c=c+1|0;continue}break}}v[b+15|0]=0;Sh(a+8|0,18,b+15|0);Jv(a+26|0,18,27530);v[b+14|0]=255;Sh(a+62|0,256,b+14|0);Ah(x[a>>2],x[a+4>>2],65535,261,1);Ah(x[a>>2],x[a+4>>2],65535,260,0);fb=b+16|0}function vZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Uf(e,c);x[31609]=0;c=d+20|0;S(502,c|0,b|0,e|0);b=x[31609];x[31609]=0;b:{c:{if((b|0)!=1){x[31609]=0;O(12,a|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(c);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function nga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ji(a,b,c,d);x[a+4272>>2]=1065353216;x[a>>2]=45440;b=a+4208|0;e=yb(b,0),f=1056880300,x[e>>2]=f;e=yb(b,1),f=1050733080,x[e>>2]=f;e=yb(b,2),f=1056964608,x[e>>2]=f;x[31609]=0;O(941,a+44|0,2);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;_f(a);Q(b|0);p()}function fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ji(a,b,c,d);x[a>>2]=45676;b=a+4208|0;e=yb(b,0),f=1065353216,x[e>>2]=f;e=yb(b,1),f=1065353216,x[e>>2]=f;e=yb(b,2),f=1051372203,x[e>>2]=f;e=yb(b,3),f=0,x[e>>2]=f;x[31609]=0;O(941,a+44|0,2);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;_f(a);Q(b|0);p()}function az(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-240|0;fb=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((no(a,f,b)|0)>=0){if((no(a,e,b)|0)>=0){break a}}j=f;f=(no(f,e,b)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}xL(g,h);fb=g+240|0}function Nsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-208|0;fb=f;c=fb-16|0;fb=c;e=f+2|0;k_(c+8|0,e);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){j_(e)}c=-1;a:{if(!d){break a}c=0;if(!m_(e)){break a}c=xe(a,b,l_(e),hb)}fb=f+208|0;return c|0}function IQ(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=dA(a);b=gk(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31609]=0;b=ba(945,c+12|0,b|0,b|0,Ab(a)|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){FQ(a,b);EQ(b);break b}Y(T(0)|0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Sb();p()}function HQ(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=Vg(a);b=oc(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31609]=0;b=ba(946,c+12|0,b|0,b|0,Ab(a)|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){Sm(a,b);Yf(b);break b}Y(T(0)|0)|0;x[31609]=0;X(26);a=x[31609];x[31609]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Sb();p()}function mpa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=Dw(c+4|0,a,1);oX(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;jc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=UD(d+12|0,VD(a,Sf(x[a>>2],x[a+4>>2])+1|0),Sf(x[a>>2],x[a+4>>2]),c);oX(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;TD(a,c);bw(c);fb=d+32|0}function XR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;VR(d,b+80|0);x[31609]=0;b=c+20|0;S(123,b|0,0,d|0);e=x[31609];x[31609]=0;b:{c:{if((e|0)!=1){x[31609]=0;O(12,a|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}}function rla(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=mC(c+4|0,a,1);XB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+32;jc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=iv(d+12|0,Wq(a,Mg(x[a>>2],x[a+4>>2])+1|0),Mg(x[a>>2],x[a+4>>2]),c);XB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;KU(a,c);YB(c);fb=d+32|0}function nE(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=t$(c+4|0,a,1);s$(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+40;jc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=q$(d+12|0,r$(a,Br(x[a>>2],x[a+4>>2])+1|0),Br(x[a>>2],x[a+4>>2]),c);s$(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+40;p$(a,c);o$(c);fb=d+32|0}function Ysa(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=Dw(c+4|0,a,1);WD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;jc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=UD(d+12|0,VD(a,Sf(x[a>>2],x[a+4>>2])+1|0),Sf(x[a>>2],x[a+4>>2]),c);WD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;TD(a,c);bw(c);fb=d+32|0}function Gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;b=jg(d+8|0,b);x[31609]=0;e=d+20|0;S(837,e|0,b|0,c|0);f=x[31609];x[31609]=0;a:{b:{if((f|0)!=1){x[31609]=0;S(72,a|0,e|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}tb(e);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function woa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=Cx(c+4|0,a);xC(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;jc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=ym(d+12|0,Qp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);xC(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;qW(a,c);pW(c);fb=d+32|0}function Pda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31609]=0;W(996,a|0);d=x[31609];x[31609]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:977;return}Y(T(0)|0)|0;x[31609]=0;V(983,13153,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Nea(a,b){a=a|0;b=b|0;var c=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){return E(_O(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31609]=0;V(983,6229,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Mpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-128|0;fb=e;c=fb-16|0;fb=c;f=e+2|0;EX(c+8|0,f);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){DX(f)}c=-1;a:{if(!d){break a}c=0;if(!FX(f)){break a}c=xe(a,b,256,0)}fb=e+128|0;return c|0}function ME(a){var b=0,c=0,d=0,e=0;c=y[a+9|0]|y[a+10|0]<<8;d=Aua(y[a+3|0],0,18,0);c=c+d|0;b=hb;e=d>>>0>c>>>0?b+1|0:b;d=y[a+6|0]|y[a+7|0]<<8;b=d>>>31|0;d=d<<1;c=d+c|0;b=b+e|0;d=d>>>0>c>>>0?b+1|0:b;a=y[a+4|0]|y[a+5|0]<<8;b=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+3|0;hb=b>>>0<3?a+1|0:a;return b}function Lea(a,b){a=a|0;b=b|0;var c=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){return E(ZO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31609]=0;V(983,9393,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Kea(a,b){a=a|0;b=b|0;var c=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){return E(YO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31609]=0;V(983,6272,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Jea(a,b){a=a|0;b=b|0;var c=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){return E(XO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31609]=0;V(983,6174,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Iea(a,b){a=a|0;b=b|0;var c=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){return E(WO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31609]=0;V(983,6130,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function BA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=c>=.999?.999:c;h=c*3.141592653589793;i=$u(b);while(1){if((e|0)!=32768){f=(e<<12&28672|e>>>3)^28672;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Pi(g)*$u(M(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=uC(c*d*32768),w[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function wna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=4896;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;pD(e,b);f=Zb(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);pD(e,b);Rb(x[d+8>>2]+c|0,0,4896-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function t2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;b=vm(d+8|0,b);x[31609]=0;e=d+20|0;S(148,e|0,b|0,c|0);f=x[31609];x[31609]=0;a:{b:{if((f|0)!=1){x[31609]=0;S(4,a|0,e|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}tb(e);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function Tqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;e=x[a+8>>2];c=d+4|0;x[c+8>>2]=a+8;x[c>>2]=e;x[c+4>>2]=D(b,20)+e;b=x[c>>2];a:{while(1){if(x[c+4>>2]==(b|0)){break a}x[31609]=0;W(228,b|0);a=x[31609];x[31609]=0;if((a|0)!=1){b=x[c>>2]+20|0;x[c>>2]=b;continue}break}a=N()|0;je(c);Q(a|0);p()}je(c);fb=d+16|0}function Mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Uf(d,b);x[31609]=0;b=c+20|0;O(958,b|0,d|0);e=x[31609];x[31609]=0;b:{c:{if((e|0)!=1){x[31609]=0;S(959,a|0,0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}}function sta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;c=fb-16|0;fb=c;f=e+15|0;B0(c+8|0,f);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){IE(f)}c=-1;a:{if(!d){break a}c=0;if(!$_(f)){break a}c=xe(a,b,72,0)}fb=e+32|0;return c|0}function nH(a,b,c,d,e){var f=0,g=0;a:{f=fb-32|0;fb=f;g=f+8|0;Op(g,c);x[31609]=0;O(e|0,f+20|0,d|0);c=x[31609];x[31609]=0;b:{c:{if((c|0)!=1){kk(f,g);x[31609]=0;V(92,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Bg(g);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;Bg(f+8|0)}Q(a|0);p()}}function kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Tk(d,b);x[31609]=0;b=c+20|0;O(14,b|0,d|0);e=x[31609];x[31609]=0;b:{c:{if((e|0)!=1){x[31609]=0;S(244,a|0,0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}}function gH(a,b,c,d,e){var f=0,g=0;a:{f=fb-32|0;fb=f;g=f+8|0;K_(g,c);x[31609]=0;O(e|0,f+20|0,d|0);c=x[31609];x[31609]=0;b:{c:{if((c|0)!=1){kk(f,g);x[31609]=0;V(92,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31609];x[31609]=0;if((a|0)==1){break c}Bg(g);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;Bg(f+8|0)}Q(a|0);p()}}function aua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}xc(d+12|0,65535);vg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}ww(b,d+10|0);e=c,f=Bb(z[d+10>>1]),w[e>>1]=f;c=x[ge(d+4|0)>>2];continue}}fb=d+16|0}function D1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Uf(d,b);x[31609]=0;b=c+20|0;S(123,b|0,22,d|0);e=x[31609];x[31609]=0;b:{c:{if((e|0)!=1){x[31609]=0;O(12,a|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}}function Cja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-32|0;fb=c;d=c+8|0;Ro(d,b);x[31609]=0;b=c+20|0;O(14,b|0,d|0);e=x[31609];x[31609]=0;b:{c:{if((e|0)!=1){x[31609]=0;S(244,a|0,0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(b);tb(d);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Ub(c+20|0)}tb(c+8|0);Q(a|0);p()}}function C1(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=nG(c+4|0,a);gx(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+36;jc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=lG(d+12|0,mG(a,fs(x[a>>2],x[a+4>>2])+1|0),fs(x[a>>2],x[a+4>>2]),c);gx(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+36;kG(a,c);ix(c);fb=d+32|0}function yX(a){var b=0,c=0,d=0,e=0,f=0;f=y[a+28|0]|y[a+29|0]<<8;c=Aua(y[a+30|0],0,37,0);d=hb;b=Aua(y[a+24|0]|y[a+25|0]<<8,0,192,0);c=b+c|0;d=hb+d|0;b=b>>>0>c>>>0?d+1|0:d;a=y[a+26|0];d=a>>>26|0;e=c;c=a<<6;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+f|0;a=b>>>0<e>>>0?a+1|0:a;b=b+192|0;hb=b>>>0<192?a+1|0:a;return b}function tsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=102;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;WZ(e,b);f=Zb(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);WZ(e,b);Rb(x[d+8>>2]+c|0,0,102-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function qra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);c=b+c|0;e=c;d=Pj(b,c);c=fb-16|0;fb=c;Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{b:{if(d){x[31609]=0;O(345,a|0,d|0);f=x[31609];x[31609]=0;if((f|0)==1){break b}yn(a,b,e,d)}a=c+8|0;Qd(a);Xi(a);fb=c+16|0;break a}a=N()|0;Xi(c+8|0);Q(a|0);p()}}function jA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;h=z[b>>1];c=de(a);e=gc(a);f=fb-16|0;fb=f;while(1){if(c){g=Yq(z[c+16>>1],h);e=g?e:c;c=x[(g?4:0)+c>>2];continue}break}c=x[vb(f+12|0,e)>>2];fb=f+16|0;a:{if(Ib(c,pg(a))){if(!Yq(z[b>>1],z[ud(c)>>1])){break a}}c=pg(a)}a=vb(d+12|0,c);fb=d+16|0;return x[a>>2]}function I2(a){a=a|0;var b=0,c=0,d=0,e=0;a:{b=fb-32|0;fb=b;c=b+8|0;Dc(c,13592);x[31609]=0;d=b+20|0;S(123,d|0,1,c|0);e=x[31609];x[31609]=0;b:{c:{if((e|0)!=1){x[31609]=0;O(12,a|0,d|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(d);tb(c);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Ub(b+20|0)}tb(b+8|0);Q(a|0);p()}}function Ena(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=263;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;sV(e,b);f=Zb(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);sV(e,b);Rb(x[d+8>>2]+c|0,0,263-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function qA(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(b,52);b=x[d+4>>2];f=x[d+8>>2];a:{while(1){if((b|0)==(f|0)){break a}x[31609]=0;O(920,b|0,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){b=b+52|0;x[d+4>>2]=b;continue}break}a=N()|0;jc(d);Q(a|0);p()}jc(d);fb=e+16|0}function Mqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=22;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;cw(e,b);f=Zb(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);cw(e,b);Rb(x[d+8>>2]+c|0,0,22-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function Kqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=40;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;gD(e,b);f=Zb(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);gD(e,b);Rb(x[d+8>>2]+c|0,0,40-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function dl(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;x[h+8>>2]=a;x[h+12>>2]=b;j=x[a+8>>2]+120|0;bu(y[j+20|0]);i=fb-16|0;fb=i;x[i+12>>2]=h+8;g=fb-16|0;fb=g;x[g+12>>2]=f;x[g+8>>2]=e;x[g+4>>2]=d;x[g>>2]=c;ib[x[lq(g,sk(y[j+20|0]))>>2]](i+12|0,j);fb=g+16|0;fb=i+16|0;x[a+4>>2]=x[a+4>>2]+x[b+8>>2];fb=h+16|0}function _0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=65;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;Cw(e,b);f=Zb(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Cw(e,b);Rb(x[d+8>>2]+c|0,0,65-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function SP(a){var b=0,c=E(0),d=0,e=0;e=x[x[a+16>>2]+24620>>2];b=fb-16|0;fb=b;x[b+12>>2]=0;x[b+8>>2]=1065353216;c=li(E(B[Rv(a+4208|0,b+12|0,b+8|0)>>2]*E(999)));a:{if(c<E(4294967296)&c>=E(0)){d=~~c>>>0;break a}d=0}fb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;xc(a+4224|0,b)}function E4(a,b,c){a=a|0;b=b|0;c=c|0;a=0;if(b&1){a=(Xs(c)|0)!=0}if(b&2){a=(Ws(c)|0)!=0|a}if(b&4){a=(Vs(c)|0)!=0|a}if(b&8){a=(Us(c)|0)!=0|a}if(b&16){a=(Ts(c)|0)!=0|a}if(b&32){a=(Ss(c)|0)!=0|a}if(b&64){a=(_n(c)|0)!=0|a}if(b&128){a=(Rs(c)|0)!=0|a}if(b&256){a=($n(c)|0)!=0|a}if(b&512){a=(Qs(c)|0)!=0|a}return a|0}function Cl(a,b){var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;b=b-c|0;c=x[Ab(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Vq(a,b);break a}c=Ab(a);c=Zf(d+12|0,Lf(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);kA(c,b);nA(a,c);Yf(c)}fb=d+32|0;return}if(b>>>0<c>>>0){Jd(a,d+(b<<2)|0)}}function rQ(a){a=a|0;var b=0,c=0,d=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];a:{if(F(b)<0x8000000000000000){d=~~b>>>0;if(F(b)>=1){c=~~(b>0?H(J(b*2.3283064365386963e-10),4294967295):K((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0}else{c=0}break a}c=-2147483648}C[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function mea(a,b){a=a|0;b=b|0;var c=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){return GO(x[x[a+24>>2]+24>>2],b)|0}Y(T(0)|0)|0;x[31609]=0;V(983,6659,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function NQ(a,b){var c=0,d=0,e=0,f=0,g=E(0);c=fb-16|0;fb=c;if(!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){w[c+14>>1]=0;ng(a,c+14|0);e=z[c+14>>1];Cl(b,e);while(1){if((d|0)!=(e|0)){x[c+8>>2]=0;wq(a,c+8|0);f=yb(x[b>>2],d),g=B[c+8>>2],B[f>>2]=g;d=d+1|0;continue}break}d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}fb=c+16|0;return d}function Kda(a,b){a=a|0;b=b|0;var c=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){mO(x[x[a+24>>2]+24>>2],b);return 1}Y(T(0)|0)|0;x[31609]=0;V(983,5784,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Jsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=5;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;_j(e,b);f=Zb(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);_j(e,b);Rb(x[d+8>>2]+c|0,0,5-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function xQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[31609]=0;x[c+12>>2]=0;S(947,a+4208|0,b<<1,c+12|0);b=x[31609];x[31609]=0;a:{if((b|0)==1){b=T(124540)|0;if((gb|0)!=($(124540)|0)){break a}Y(b|0)|0;x[a+4220>>2]=0;Z()}x[a+4224>>2]=0;fb=c+16|0;return}Q(b|0);p()}function X6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;g=fb-16|0;fb=g;x[e>>2]=c;b=g+12|0;a=qy(b,0,x[a+8>>2]);f=2;a:{if(a+1>>>0<2){break a}c=a-1|0;f=1;if(c>>>0>d-x[e>>2]>>>0){break a}while(1){if(c){a=y[b|0];d=x[e>>2];x[e>>2]=d+1;v[d|0]=a;c=c-1|0;b=b+1|0;continue}break}f=0}a=f;fb=g+16|0;return a|0}function Kn(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=x[d>>2];if(e|x[c>>2]){while(1){if((b|0)==(g|0)){break a}f=x[c>>2];h=c,i=f-rd((rd(0-f|0,31)&255)+f|0,8)|0,x[h>>2]=i;h=d,i=x[d>>2]-rd((rd(0-e|0,31)&255)+e|0,8)|0,x[h>>2]=i;e=(g<<3)+a|0;x[e>>2]=x[c>>2];f=e;e=x[d>>2];x[f+4>>2]=e;g=g+1|0;continue}}Rb(a,0,b<<3)}}function Cea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return x[x[x[a+24>>2]+24>>2]+1074416>>2]}Y(T(0)|0)|0;x[31609]=0;V(983,12881,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function ru(a){var b=0,c=0,d=0;b=Ai(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b>45e-5){c=mq(b)/.6931471805599453;b=c-J(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Ai(d+c)*.5}else{b=0}C[a+4248>>3]=b}qu(a)}function asa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-192|0;fb=d;c=fb-16|0;fb=c;sw(c+8|0,d);e=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){id(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){GZ(d)}c=-1;a:{if(!e){break a}c=0;if(!IZ(d)){break a}c=xe(a,b,HZ(d),hb)}fb=d+192|0;return c|0}function R_(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;e=x[b+4>>2];f=vb(d+12|0,c);g=vb(d+8|0,x[a>>2]);h=vb(d+4|0,x[b+4>>2]);i=b,j=RW(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=Q_(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=d+16|0;return e}function PU(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;e=x[b+4>>2];f=vb(d+12|0,c);g=vb(d+8|0,x[a>>2]);h=vb(d+4|0,x[b+4>>2]);i=b,j=NF(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=SU(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=d+16|0;return e}function GQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=2097152){Sj();p()}d=Ec(b<<11);x[e+12>>2]=b;x[e+8>>2]=d;d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<11)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<11)|0,x[f>>2]=g;fb=e+16|0;return a|0}function Dea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return x[x[x[a+24>>2]+24>>2]+1074424>>2]}Y(T(0)|0)|0;x[31609]=0;V(983,5319,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function tQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=X_(b,c);e=fb-16|0;fb=e;a:{if(ap(a)>>>0>=d>>>0){f=x[a>>2];g=Xc(f,x[a+4>>2]);if(g>>>0<d>>>0){h=b;b=U_(b,g);aE(h,b,f);yn(a,b,c,d-Xc(x[a>>2],x[a+4>>2])|0);break a}$D(e+8|0,b,c,f);Jd(a,x[e+12>>2]);break a}dw(a);Vk(a,Vl(a,d));yn(a,b,c,d)}fb=e+16|0}function uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=477218588;x[c+8>>2]=2147483647;e=Hb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){ed();p()}c=Ec(D(b,9));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=Ab(a),g=b+D(x[d+12>>2],9)|0,x[f>>2]=g;fb=d+16|0}function st(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function P1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=c+8|0;Tk(d,b);x[31609]=0;b=c+20|0;O(14,b|0,d|0);e=x[31609];x[31609]=0;a:{b:{if((e|0)!=1){x[31609]=0;O(15,a|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}Ub(b);tb(d);fb=c+32|0;return}b=N()|0;break a}b=N()|0;Ub(c+20|0)}tb(c+8|0);Q(b|0);p()}function Ina(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=fb-16|0;fb=c;aZ(c+8|0,d);e=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){id(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){rD(d)}c=-1;a:{if(!e){break a}c=0;if(!wV(d)){break a}c=xe(a,b,vV(d),hb)}fb=d+80|0;return c|0}function qka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=b+616|0;c=zc(a,b,614);f=c+616|0;a=0;while(1){d=D(a,872);Gq(d+f|0,e+d|0);a=a+1|0;if((a|0)!=256){continue}break}a=CC(c+223848|0,b+223848|0);x[31609]=0;P(843,c+223860|0,b+223860|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){return c|0}b=N()|0;fc(a);Q(b|0);p()}function lla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=If(a,c);ae(d,x[a+36>>2]);a:{b:{if(!c){Qc(d,a+32|0,5);e=-1;if(!Gb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:Ei(f,b);break c;default:break d}}nZ(f,b,e)}f=c}ef(a,f);fb=d+16|0}function jU(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=Qt(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);Pl(e,b,+n());return}a:{if(!Af(b)){break a}d=F(c)<Infinity;if(b<0){c=d?c:1;break a}if(d){break a}Pl(a,b,Af(c)?NaN:c);return}b=Qt(b);g=Pi(c);Pl(a,b*hf(c),g*b)}function pV(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;e=c+14|0;b=fb-16|0;fb=b;d=x[a+24>>2];a:{if(!d){rp(e);break a}hE(b+8|0,Yb(Si(mq(+(d>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);d=x[b+8>>2];v[b+7|0]=x[b+12>>2];ee(e,d,b+7|0)}fb=b+16|0;b=c+4|0;ZD(b,a+36|0,a+37|0);YD(b,e);fb=c+16|0}function lH(a,b,c,d){var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;Cc(f,c);x[31609]=0;c=e+20|0;S(d|0,c|0,b|0,f|0);b=x[31609];x[31609]=0;b:{c:{if((b|0)!=1){x[31609]=0;O(12,a|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(c);tb(f);fb=e+32|0;break a}a=N()|0;break b}a=N()|0;Ub(e+20|0)}tb(e+8|0);Q(a|0);p()}}function dr(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[124097]!=(b&1073741823)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=zt(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=zt(a)}ne(b)}return a}function Ay(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;f=fb-16|0;fb=f;a:{if(b>>>0<1073741808){b:{if(fr(b)){Ne(d,b);break b}Nj(f+8|0,rn(b)+1|0);e=x[f+8>>2];yd(d,e);of(d,x[f+12>>2]);Bd(d,b);d=e}e=fb-16|0;fb=e;x[e+12>>2]=c;JF(d,b,e+12|0);fb=e+16|0;yd((b<<2)+d|0,0);fb=f+16|0;break a}pf();p()}return a|0}function rt(a,b,c,d){var e=0,f=0,g=0;e=fb-160|0;fb=e;f=b?a:e+158|0;x[e+148>>2]=f;a=-1;g=b-1|0;x[e+152>>2]=b>>>0>=g>>>0?g:0;e=Rb(e,0,144);x[e+76>>2]=-1;x[e+36>>2]=1266;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+148;a:{if((b|0)<0){x[31484]=61;break a}v[f|0]=0;a=tL(e,c,d,1218,1219)}fb=e+160|0;return a}function SI(a){a=a|0;var b=0,c=0,d=0;c=a+12|0;Ub(c+520|0);Ub(c+508|0);Ub(c+496|0);b=484;Ub(c+484|0);while(1){b=b-12|0;Ub(b+c|0);d=460;if((b|0)!=460){continue}break}while(1){d=d-12|0;Ub(d+c|0);b=172;if((d|0)!=172){continue}break}while(1){b=b-12|0;Ub(b+c|0);if((b|0)!=4){continue}break}ct(c);return a|0}function II(a){a=a|0;var b=0,c=0,d=0;c=a+12|0;tb(c+520|0);tb(c+508|0);tb(c+496|0);b=484;tb(c+484|0);while(1){b=b-12|0;tb(b+c|0);d=460;if((b|0)!=460){continue}break}while(1){d=d-12|0;tb(d+c|0);b=172;if((d|0)!=172){continue}break}while(1){b=b-12|0;tb(b+c|0);if((b|0)!=4){continue}break}ct(c);return a|0}function tha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Pd(c,E(0));a:{b:{switch(b-3|0){case 0:c=li(c);if(c==B[yb(a+4208|0,3)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 1:break b;default:break a}}c=E(li(E(c*E(4)))*E(.25))}d=yb(a+4208|0,b),e=c,B[d>>2]=e;Wz(a)}}function r_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28490681|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(y[a+76|0]|((y[a+71|0]|y[a+72|0]<<8|(y[a+73|0]<<16|y[a+74|0]<<24))!=1397116231|y[a+75|0]!=1)){break a}b=((y[a+116|0]|y[a+117|0]<<8)-1&65535)>>>0<9}return b}function rH(a,b,c){var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Dc(e,b);x[31609]=0;b=d+20|0;S(123,b|0,c|0,e|0);c=x[31609];x[31609]=0;b:{c:{if((c|0)!=1){x[31609]=0;O(12,a|0,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break c}Ub(b);tb(e);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Ub(d+20|0)}tb(d+8|0);Q(a|0);p()}}function cua(a){a=a|0;var b=0,c=0,d=0;c=fb-32|0;fb=c;b=255;a:{if(Gj(x[a>>2],x[a+4>>2])>>>0<=49){b=bC(c,x[a+12>>2]);x[31609]=0;O(291,a|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}Ak(b);Vj(a,Gj(x[a>>2],x[a+4>>2])-1&255);b=Gj(x[a>>2],x[a+4>>2])-1|0}fb=c+32|0;return b&255}a=N()|0;Ak(b);Q(a|0);p()}function Mga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Pd(c,E(0));a:{b:{switch(b-1|0){case 0:c=li(c);if(c==B[yb(a+4208|0,1)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 3:break b;default:break a}}c=E(li(E(c*E(4)))*E(.25))}d=yb(a+4208|0,b),e=c,B[d>>2]=e;Wz(a)}}function yG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;e=c+8|0;Yw(e,b);x[31609]=0;d=c+20|0;S(11,d|0,1,e|0);b=x[31609];x[31609]=0;a:{if((b|0)!=1){x[31609]=0;O(12,a|0,d|0);a=x[31609];x[31609]=0;if((a|0)==1){b=N()|0;Ub(d);break a}Ub(c+20|0);tb(c+8|0);fb=c+32|0;return}b=N()|0}tb(c+8|0);Q(b|0);p()}function oea(a,b){a=a|0;b=b|0;var c=0;x[31609]=0;W(996,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){return IO(x[a+24>>2],b)|0}Y(T(0)|0)|0;x[31609]=0;V(983,9817,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function vea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return xo(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31609]=0;V(983,7133,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function uea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return qq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31609]=0;V(983,6822,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function tea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return MO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31609]=0;V(983,6940,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function sea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return LO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31609]=0;V(983,7008,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function rea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return pq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31609]=0;V(983,7480,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function nm(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=Kb(b);e=c,f=_c(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;x[c+8>>2]=x[a+4>>2]-1;xk(d,d+x[Hb(c+12|0,c+8|0)>>2]|0,x[a>>2]);d=x[a>>2];e=c,f=_c(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;a=x[a+4>>2];x[c+8>>2]=a-1;Qm(d+x[Hb(c+12|0,c+8|0)>>2]|0,a+d|0,78544);fb=c+16|0}function lr(a){var b=0,c=0;b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;c=a+288|0;iC(c,mV(c),b);x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;a=a+800|0;iC(a,wC(a),b);fb=b+32|0}function iea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return DO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31609]=0;V(983,5816,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{if(!x[b+12>>2]){c=x[d>>2];break a}e=ib[x[b+16>>2]](x[b+8>>2],c,0,0)|0;c=x[d>>2];if((e|0)<0){break a}d=x[d+4>>2];e=c;while(1){if(!d){break a}f=ib[x[b+12>>2]](x[b+8>>2],e,d)|0;if(!f){break a}g=f+g|0;d=d-f|0;e=e+f|0;continue}}cc(a,c,g)}function Gea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return VO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31609]=0;V(983,8812,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Eea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return TO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31609]=0;V(983,7165,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Bea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return SO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31609]=0;V(983,9346,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function dB(a,b,c,d){a:{if(x[a+1074392>>2]!=(c|0)){break a}c=(D(b,872)+a|0)+1074992|0;b:{if(d){x[c+696>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;d=x[c+88>>2]|4096;break b}x[c+688>>2]=0;d=x[c+88>>2]}x[c+88>>2]=d|2097152;Xm(a,b,255,0);if(!(y[c+89|0]&2)){break a}a=x[a+1298300>>2];if(!Ed(a)){break a}Ej(a,b,0)}}function Hea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return+PA(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31609]=0;V(983,10165,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function Aea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return+RO(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31609]=0;V(983,15241,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function lE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+8>>2]=c;g=f,h=jf(b),x[g+28>>2]=h;c=f+8|0;sg(c,b,x[Hb(c,f+28|0)>>2]);b=Ze(c);x[31609]=0;aa(236,a|0,b|0,x[f+8>>2],d|0,e|0);a=x[31609];x[31609]=0;if((a|0)!=1){Kc(c);fb=f+32|0;return}a=N()|0;Kc(f+8|0);Q(a|0);p()}function SK(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a=Pt(a);x[a+32>>2]=b;x[a>>2]=94604;e=d+12|0;cd(e,x[a+4>>2]);x[31609]=0;b=R(1234,x[d+12>>2])|0;f=x[31609];x[31609]=0;if((f|0)!=1){_b(e);x[a+40>>2]=c;x[a+36>>2]=b;g=a,h=io(b),v[g+44|0]=h;fb=d+16|0;return}b=N()|0;_b(d+12|0);ho(a);Q(b|0);p()}function s0(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=d+8|0;Uf(e,c);x[31609]=0;c=d+20|0;S(123,c|0,b|0,e|0);b=x[31609];x[31609]=0;a:{b:{if((b|0)!=1){x[31609]=0;O(12,a|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}Ub(c);tb(e);fb=d+32|0;return}c=N()|0;break a}c=N()|0;Ub(d+20|0)}tb(d+8|0);Q(c|0);p()}function Ef(a){var b=0,c=0,d=0;a:{b:{b=a;if(!(b&3)){break b}if(!y[b|0]){return 0}while(1){b=b+1|0;if(!(b&3)){break b}if(y[b|0]){continue}break}break a}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function wW(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=860902483){break a}if(Bb(y[a+4|0]|y[a+5|0]<<8)>>>0>2|y[a+6|0]>128){break a}if(Bb(y[a+200|0]|y[a+201|0]<<8)>>>0>3999){break a}if(!Bb(y[a+140|0]|y[a+141|0]<<8)){break a}b=(Bb(y[a+148|0]|y[a+149|0]<<8)|0)==50}return b}function kh(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);$f(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;fb=d+16|0}function QK(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a=aL(a);x[a+32>>2]=b;x[a>>2]=94972;e=d+12|0;cd(e,x[a+4>>2]);x[31609]=0;b=R(38,x[d+12>>2])|0;f=x[31609];x[31609]=0;if((f|0)!=1){_b(e);x[a+40>>2]=c;x[a+36>>2]=b;g=a,h=io(b),v[g+44|0]=h;fb=d+16|0;return}b=N()|0;_b(d+12|0);Dt(a);Q(b|0);p()}function u0(a,b,c){var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=192;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;sw(e,b);f=Zb(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);sw(e,b);Rb(x[d+8>>2]+c|0,0,192-c|0);Vb(a,x[d+28>>2]);fb=d+32|0}function cq(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c+12|0;cd(d,a);x[31609]=0;a=R(1252,x[c+12>>2])|0;e=x[31609];x[31609]=0;a:{b:{if((e|0)==1){break b}x[31609]=0;V(1263,a|0,95168,95194,b|0);a=x[31609];x[31609]=0;if((a|0)==1){break b}_b(d);fb=c+16|0;break a}a=N()|0;_b(c+12|0);Q(a|0);p()}return b}function x3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(lh(a,x[b+8>>2],0)){Ux(b,c,d);return}e=x[a+12>>2];f=a+16|0;iI(x[f>>2],x[a+20>>2],b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){iI(x[a>>2],x[a+4>>2],b,c,d);if(y[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function kea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return+C[x[a+24>>2]+16>>3]}Y(T(0)|0)|0;x[31609]=0;V(983,7642,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function gea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return x[x[a+24>>2]+8>>2]}Y(T(0)|0)|0;x[31609]=0;V(983,10946,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function O0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}xc(d+12|0,65535);vg(a,z[d+12>>1]);c=wb(x[a>>2]);x[d+4>>2]=c;a=wb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}ww(b,d+10|0);w[c>>1]=z[d+10>>1];c=x[ge(d+4|0)>>2];continue}}fb=d+16|0}function Bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ji(a,b,c,d);x[a>>2]=42236;b=Nb(a+4208|0);x[a+4228>>2]=0;x[a+4220>>2]=0;x[a+4224>>2]=0;x[a+4232>>2]=x[c+24620>>2];b0(a+4260|0,80,150,80,255);x[31609]=0;O(941,a+44|0,2);c=x[31609];x[31609]=0;if((c|0)!=1){return a|0}c=N()|0;wc(b);_f(a);Q(c|0);p()}function $V(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[e+12>>2]=6553600;i=e,j=$b(b),x[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=vr(f*+A[Hb(g,b)>>2]);x[e+8>>2]=6553600;i=e,j=$b(c),x[i+4>>2]=j;i=e,j=vr(f*+A[Hb(b,e+4|0)>>2]),x[i+12>>2]=j;x[e+8>>2]=d-h;qn(a,h,Hb(b,g));fb=e+16|0}function ux(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function _x(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-160|0;fb=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;Bi(f,0,0);wI(e,f,d,1);d=x[e+8>>2];g=x[e+12>>2];f=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=x[e+136>>2]+((x[e+20>>2]-x[e+60>>2]|0)+b|0)}x[a+8>>2]=d;x[a+12>>2]=g;x[a>>2]=f;x[a+4>>2]=h;fb=e+160|0}function N_(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function uia(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=x[a+20>>2];b=x[c+4>>2];if((Xc(b,x[c+8>>2])|0)!=8){break b}d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if((d|0)!=1869112133){break b}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=d;x[a+4264>>2]=c;break a}bA(a,a)}su(a)}function nB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}wk(a,b,b+700|0,c<<2,0)}}function XF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=x[a+92>>2];e=x[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){x[a+96>>2]=e;x[a+92>>2]=d}else{f=(g<<3)+b|0;h=x[f>>2];d=d-rd((rd(0-d|0,31)&255)+d|0,8)|0;x[f>>2]=h+d;h=x[f+4>>2];e=e-rd((rd(0-e|0,31)&255)+e|0,8)|0;x[f+4>>2]=h+e;g=g+1|0;continue}break}}}function TP(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[31609]=0;x[c+12>>2]=0;S(947,a+4208|0,b<<2,c+12|0);b=x[31609];x[31609]=0;a:{if((b|0)==1){b=T(124540)|0;if((gb|0)!=($(124540)|0)){break a}Y(b|0)|0;x[a+4240>>2]=0;Z()}x[a+4244>>2]=0;fb=c+16|0;return}Q(b|0);p()}function jra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;sf(b);x[d+12>>2]=0;a:{if(!Gk(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}v[d+11|0]=0;if(gi(a,d+11|0)){Rp(b,v[d+11|0]);e=e+1|0;continue}break}e=0}fb=d+16|0;return e|0}function ZN(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;x[a+4>>2]=0;x[a>>2]=47588;a=dc(8);x[31609]=0;b=P(36,b+4|0,12149)|0;c=x[31609];x[31609]=0;a:{b:{if((c|0)!=1){sc(a,b);x[31609]=0;S(97,a|0,48428,1e3);a=x[31609];x[31609]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;lc(a)}Q(c|0)}p()}function Fea(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return UO(x[a+24>>2])|0}Y(T(0)|0)|0;x[31609]=0;V(983,9782,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function $Z(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=og(a);b=b+236|0;e=ur(b);a:{while(1){if((b|0)!=(e|0)){d=z[b>>1];w[c+14>>1]=d;if(d){x[31609]=0;S(401,c+4|0,a|0,c+14|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}fb=c+16|0;return}b=N()|0;Yv(a);Q(b|0);p()}function oka(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Id(y[b+24|0])){a=og(a);c=Ti(x[b>>2]);d=Pf(b);x[31609]=0;S(846,a|0,c|0,d|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}x[31609]=0;P(845,a+12|0,b+12|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}v[a+24|0]=1}return}b=N()|0;US(a);Q(b|0);p()}function oB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}wk(a,b,b+700|0,c,0)}}function zC(a,b,c,d,e){var f=0;a:{f=x[a>>2];if(!le(f,x[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}nn(b);b=Xo(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!Gh(b)){break a}if(x[a>>2]!=(d|0)){cs(b+68|0)}zc(x[b+20>>2],x[a+20>>2]+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}}function jH(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=Fb(a+16|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[31609]=0;b=P(c|0,d+8|0,b+16|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){a=d+20|0;Qh(a,b);zb(e,a);tb(a);tb(b);fb=d+32|0;return}b=N()|0;Jh(a);Q(b|0);p()}function ik(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=x[a+4>>2];e=x[a+12>>2];i=x[a+8>>2];d=x[a>>2];while(1){if((b|0)!=(f|0)){if(!d){x[a>>2]=8;c=i;if((e|0)!=(c|0)){c=e-1|0;x[a+12>>2]=c}d=8;e=c;c=y[c|0]}g=c;d=d-1|0;x[a>>2]=d;c=g>>>1|0;x[a+4>>2]=c;h=g&1|h<<1;f=f+1|0;continue}break}return h}function bba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=d+4|0;wo(c,a);if(x[b>>2]){Nc(b);a=x[b>>2];jt(b);Db(a);e=Ab(b),f=0,x[e>>2]=f;x[b>>2]=0;x[b+4>>2]=0}x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=Ab(c);e=Ab(b),f=x[a>>2],x[e>>2]=f;x[a>>2]=0;x[c>>2]=0;x[c+4>>2]=0;nf(c);fb=d+16|0}function SQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(Vg(a)>>>0>=b>>>0){f=x[a>>2];e=oc(f,x[a+4>>2]);x[d+8>>2]=e;RQ(f,x[Hb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){oA(a,b-e|0,c);break a}Jd(a,x[a>>2]+(b<<2)|0);break a}qr(a);jm(a,Lf(a,b));oA(a,b,c)}fb=d+16|0}function Yh(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;g=c,h=Ec(16),x[g+8>>2]=h;b=sm(x[c+8>>2]);x[b>>2]=41128;g=Pn(nc(b)),h=41260,x[g>>2]=h;b=d+8|0;f=Rn(c);Qn(b,nc(f),f);tm(c);fb=e+16|0;Ff(a,b);me(b);fb=d+16|0;x[a+8>>2]=0;Md(a+12|0);return a}function Xm(a,b,c,d){var e=0,f=0,g=0;a:{f=D(b,872)+a|0;e=x[f+1075648>>2];if(!e){break a}if(!Jj(y[e+31|0])){break a}g=y[e+34|0]-1|0;if((g&255)>>>0>249){break a}a=x[$d(a+906300|0,g)>>2];if(!a){break a}ib[x[x[a>>2]+96>>2]](a,e,c,d,b);if(c>>>0>250){break a}w[(f+1074992|0)+842>>1]=65535}}function Sea(a){a=a|0;var b=0;x[31609]=0;W(1021,a|0);b=x[31609];x[31609]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31609]=0;V(983,11990,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)==1){break a}Z();a=0}return a|0}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function zfa(a){a=a|0;var b=0;x[31609]=0;W(996,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return x[a+16>>2]}Y(T(0)|0)|0;x[31609]=0;V(983,5690,a|0,0,0);a=x[31609];x[31609]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Sb();p()}function cE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+8>>2]=c;f=e,g=jf(b),x[f+28>>2]=g;c=e+8|0;sg(c,b,x[Hb(c,e+28|0)>>2]);b=Ze(c);x[31609]=0;V(343,a|0,b|0,x[e+8>>2],d|0);a=x[31609];x[31609]=0;if((a|0)!=1){Kc(c);fb=e+32|0;return}a=N()|0;Kc(e+8|0);Q(a|0);p()}function Ipa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31609]=0;O(641,a|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break a}tp(a,b,c)}b=d+8|0;Qd(b);Rj(b);fb=d+16|0;return a|0}a=N()|0;Rj(d+8|0);Q(a|0);p()}function B7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;cd(b,x[d+28>>2]);x[31609]=0;d=R(1252,x[g+8>>2])|0;h=x[31609];x[31609]=0;if((h|0)!=1){_b(b);hK(a,f+24|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;_b(g+8|0);Q(a|0);p()}function A7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;cd(b,x[d+28>>2]);x[31609]=0;d=R(1252,x[g+8>>2])|0;h=x[31609];x[31609]=0;if((h|0)!=1){_b(b);fK(a,f+16|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;_b(g+8|0);Q(a|0);p()}function d1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31609]=0;O(225,a|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break a}XE(a,b,c)}b=d+8|0;Qd(b);bh(b);fb=d+16|0;return a|0}a=N()|0;bh(d+8|0);Q(a|0);p()}function Y9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=sm(a);x[d>>2]=77652;a=jM(nc(d),fM(b));x[a>>2]=77984;W_(a+8|0,65536);c=20;Rb(a+20|0,0,192);while(1){e=a+c|0;x[e>>2]=0;x[e+4>>2]=0;v[e+8|0]=0;c=c+12|0;if((c|0)!=212){continue}break}Rb(a+212|0,0,64);x[a+276>>2]=b;x[a>>2]=77796;return d|0}function GP(a,b,c){v[a+12|0]=0;x[c>>2]=0;x[b>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;w[a+24>>1]=0;x[a+36>>2]=0;x[a+40>>2]=0;x[a+44>>2]=0;x[a+48>>2]=0;FP(a+60|0);FP(a+52|0);Dq(a+49956|0);Dq(a+58148|0);Dq(a+66340|0);Dq(a+74532|0);Rb(a+228|0,0,32768);Rb(a+32996|0,0,512);Rb(a+33508|0,0,16384)}function EZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31609]=0;O(460,a|0,b|0);e=x[31609];x[31609]=0;if((e|0)==1){break a}xD(a,b,c)}b=d+8|0;Qd(b);am(b);fb=d+16|0;return a|0}a=N()|0;am(d+8|0);Q(a|0);p()}function lra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{if(oc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!Ed(b)){break a}x[31609]=0;d=a;a=c+12|0;O(500,d|0,a|0);e=x[31609];x[31609]=0;d=b;if((e|0)!=1){break a}b=N()|0;mg(a);Q(b|0);p()}mg(c+12|0);fb=c+16|0;return d|0}function ij(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=d;g=rh(e+8|0,b);b=fb-16|0;fb=b;d=x[e+12>>2];x[b+12>>2]=d;x[b+8>>2]=d;f=-1;d=rt(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Gd(d);x[h>>2]=a;if(!a){break a}f=rt(a,d,c,x[b+12>>2])}fb=b+16|0;qh(g);fb=e+16|0;return f}function eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=If(a,c);ae(d,x[a+36>>2]);a:{b:{if(!c){Qc(d,a+32|0,5);e=-1;if(!Gb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){Gk(f,b);break c}AN(f,b,e)}f=c}ef(a,f);fb=d+16|0}function Xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(ap(a)>>>0>=b>>>0){f=x[a>>2];e=Xc(f,x[a+4>>2]);x[d+8>>2]=e;Sh(f,x[Hb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Ap(a,b-e|0,c);break a}Jd(a,x[a>>2]+b|0);break a}dw(a);Vk(a,Vl(a,b));Ap(a,b,c)}fb=d+16|0}function Tp(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=f>>>0){Sj();p()}d=Ec(D(b,e));x[g+12>>2]=b;x[g+8>>2]=d;d=x[g+12>>2];b=x[g+8>>2]}x[a>>2]=b;c=b+D(c,e)|0;x[a+8>>2]=c;x[a+4>>2]=c;h=nc(a),i=b+D(d,e)|0,x[h>>2]=i;fb=g+16|0;return a}function Ku(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!b){break a}i=Ob(a+1074312|0,73)?c- -64|0:c;c=120;g=zj(a);j=g^-1;e=1;while(1){if(!c){break a}k=c;c=c>>>1|0;h=e+c|0;f=zh(a,h,i,d);if(!(f>>>0>b>>>0&j)&(!(!f|g)|b>>>0<=f>>>0)){continue}e=h+1|0;c=(c^-1)+k|0;continue}}return e}function H7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;cd(b,x[d+28>>2]);x[31609]=0;d=R(28,x[g+8>>2])|0;h=x[31609];x[31609]=0;if((h|0)!=1){_b(b);kK(a,f+24|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;_b(g+8|0);Q(a|0);p()}function G7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+12>>2]=b;b=g+8|0;cd(b,x[d+28>>2]);x[31609]=0;d=R(28,x[g+8>>2])|0;h=x[31609];x[31609]=0;if((h|0)!=1){_b(b);jK(a,f+16|0,g+12|0,c,e,d);fb=g+16|0;return x[g+12>>2]}a=N()|0;_b(g+8|0);Q(a|0);p()}function zZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb+-64|0;fb=c;e=c+44|0;sg(e,a,32);a=x[c+44>>2];d=c+20|0;ug(d,2,Ze(e),a);x[31609]=0;a=c+32|0;O(218,a|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){d=c+12|0;En(d,b);nm(d,a);tb(a);Kc(e);fb=c- -64|0;break a}a=N()|0;Kc(c+44|0);Q(a|0);p()}}function li(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function Ys(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=y[b|0];a:{if(!d){d=0;break a}b:{if(!y[b+1|0]){v[a|0]=d;break b}d=0;if(!_p(e+12|0,b,c)){break a}f=x[e+12>>2];b=dy(f,c);c:{if((b|0)!=-1){break c}b=32;if((f|0)==8239){break c}if((f|0)!=160){break a}}v[a|0]=b}d=1}fb=e+16|0;return d}function S2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=Ut(c);x[a>>2]=94064;x[d>>2]=94084;x[a+60>>2]=94124;x[a>>2]=94104;x[a+4>>2]=0;e=c;c=a+8|0;po(e,c);x[a>>2]=94064;x[d>>2]=94084;x[31609]=0;P(107,c|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}a=N()|0;ul(d);Q(a|0);p()}function qP(a,b){var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;yQ(b,c,c+96|0);b=0;while(1){if((b|0)==12){x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;fb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;continue}break}x[a+112>>2]=0}function QF(a,b,c,d){var e=0,f=0,g=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;e=d;d=x[a+1068>>2];w[e+(d<<1)>>1]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;f=a,g=_d(z[x[a+1060>>2]+34>>1])+d|0,x[f+1068>>2]=g;x[a+1072>>2]=x[a+1072>>2]-1}function wY(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=Te(+(D(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){xc(e+12|0,10);a=D(y[x[e+12>>2]+25200|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Te(733.8401379310345/f*1e4);break a}a=Te(f/.264*1e4)}fb=e+16|0;return a}function Uia(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;x[c+12>>2]=-1;x[c+16>>2]=0;x[c+4>>2]=0;Fb(c+20|0);x[31609]=0;x[c+4>>2]=x[c+4>>2]&-1332|1058;x[c+8>>2]=1;d=a;a=c+4|0;S(79,d|0,b|0,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){Jh(a);fb=c+32|0;return}a=N()|0;Jh(c+4|0);Q(a|0);p()}function z7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=fb-16|0;fb=a;x[a+12>>2]=b;b=a+8|0;cd(b,x[d+28>>2]);x[31609]=0;d=R(1252,x[a+8>>2])|0;g=x[31609];x[31609]=0;if((g|0)!=1){_b(b);eK(f+20|0,a+12|0,c,e,d);fb=a+16|0;return x[a+12>>2]}b=N()|0;_b(a+8|0);Q(b|0);p()}function Ve(a){var b=0,c=0;b=fb-32|0;fb=b;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;kF(b+9|0);x[a>>2]=x[b>>2];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;c=x[b+24>>2];x[a+20>>2]=x[b+20>>2];x[a+24>>2]=c;v[a+28|0]=y[b+28|0];fb=b+32|0}function IZ(a){var b=0,c=0;b=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{b:{if((b|0)!=1297108297){if((b|0)!=778924148){break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0<=255){break b}break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0>255){break a}}c=(y[a+36|0]|y[a+37|0]<<8)>>>0<4e3}return c}function Ht(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=dc(16);if(!y[501721]){v[501721]=1}a=Zb(c+8|0,a,125928);x[31609]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a=U(1220,d|0,c|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){da(a|0,123848,1221);p()}a=N()|0;lc(d);Q(a|0);p()}function vH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=c;c=g+12|0;xc(c,f);xc(c,65535);h=z[g+12>>1];vg(a,h);c=0;while(1){if((c|0)==(h|0)){fb=g+16|0}else{f=y[b+c|0];i=Sr(x[a>>2],x[a+4>>2],c),j=(d|0)==(f|0)?-1:(e|0)==(f|0)?-2:f,w[i>>1]=j;c=c+1|0;continue}break}}function lQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+1074404>>2];x[31609]=0;x[c+12>>2]=0;S(947,a+4208|0,D(b,254)|0,c+12|0);b=x[31609];x[31609]=0;a:{if((b|0)==1){b=T(124540)|0;if((gb|0)!=($(124540)|0)){break a}Y(b|0)|0;Z()}x[a+4220>>2]=0;fb=c+16|0;return}Q(b|0);p()}function dM(a,b,c){var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=fb-32|0;fb=d;fd(d+24|0,a,b);a=fb-16|0;fb=a;e=c;b=x[d+28>>2];c=x[d+24>>2];g=b-c|0;e=e-g|0;x[a+12>>2]=e;ZC(e,c,g>>2);qc(d+16|0,b,a+12|0);fb=a+16|0;a=x[d+16>>2];x[d+12>>2]=x[d+20>>2];qc(f+8|0,a,d+12|0);fb=d+32|0;fb=f+16|0}function F7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=fb-16|0;fb=a;x[a+12>>2]=b;b=a+8|0;cd(b,x[d+28>>2]);x[31609]=0;d=R(28,x[a+8>>2])|0;g=x[31609];x[31609]=0;if((g|0)!=1){_b(b);iK(f+20|0,a+12|0,c,e,d);fb=a+16|0;return x[a+12>>2]}b=N()|0;_b(a+8|0);Q(b|0);p()}function sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=IV(d+4|0,a+8|0,b);b=x[a>>2];a:{while(1){if(x[a+4>>2]==(b|0)){break a}x[31609]=0;O(784,b|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){b=x[a>>2]+32|0;x[a>>2]=b;continue}break}b=N()|0;je(a);Q(b|0);p()}je(a);fb=d+16|0}function r$(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=107374182;x[c+8>>2]=2147483647;e=Hb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=n$(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[bd(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}ed();p()}function Yna(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(vd(c)){c=x[a+4>>2];d=Zi(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=1;c=Hh(c);if((c|0)!=1){break b}}rC(a,d,1,d,d,0);c=d}d=x[a>>2];Bd(a,c+1|0);break a}Ne(a,c+1|0);d=a}a=(c<<2)+d|0;yd(a,b);yd(a+4|0,0)}function P$(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=153391689;x[c+8>>2]=2147483647;e=Hb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=tE(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[bd(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}ed();p()}function wqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31609]=0;O(589,a|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}oD(a,b)}b=c+8|0;Qd(b);bh(b);fb=c+16|0;return a|0}a=N()|0;bh(c+8|0);Q(a|0);p()}function sd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;g=x[b+8>>2];f=x[b>>2];lf(e+16|0,c,d);c=x[x[f>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,f,g,e+8|0);lf(a,x[e+24>>2],x[e+28>>2]);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];fb=e+32|0}function nY(a,b){var c=0,d=0;a:{c=x[b>>2];d=x[b+20>>2];if(!le(c,d)){break a}if(x[a+20>>2]==(d|0)){x[a+20>>2]=0;c=x[b>>2]}xc(a,c);c=z[a+34>>1]&-2|w[b+34>>1]&1;w[a+34>>1]=c;w[a+34>>1]=c&65471|z[b+34>>1]&64;if(!Gh(a)){break a}zc(x[a+20>>2],x[b+20>>2],Qk(x[a>>2],z[a+34>>1]))}}function cM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;lf(e+24|0,b,c);b=Ff(e+16|0,d);x[31609]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;hg(163,a,x[e+24>>2],x[e+28>>2],e+8|0);a=x[31609];x[31609]=0;if((a|0)!=1){me(d);fb=e+32|0;return}a=N()|0;me(d);Q(a|0);p()}function Uoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+14|0;XW(c+8|0,d);f=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){WW(d)}if(a){e=YW(d)}fb=b+160|0;return e|0}function Mta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-624|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+14|0;K$(c+8|0,d);f=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){J$(d)}if(a){e=L$(d)}fb=b+624|0;return e|0}function Bna(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(c+8|0,x[vb(c+4|0,a)>>2]);a:{if(b){x[31609]=0;O(225,a|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}Vq(a,b)}b=c+8|0;Qd(b);bh(b);fb=c+16|0;return a|0}a=N()|0;bh(c+8|0);Q(a|0);p()}function lo(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Cua(a,b,10,0);e=hb;a=Aua(d,e,246,0)+a|0;c=c-1|0;v[c|0]=a|48;f=b>>>0>9;a=d;b=e;if(f){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;v[c|0]=D(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function aqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=CJ(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31609]=0;W(598,b|0);e=x[31609];x[31609]=0;if((e|0)!=1){b=b+24|0;x[a+4>>2]=b;continue}break}b=N()|0;jc(a);Q(b|0);p()}jc(a);fb=c+16|0}function Rp(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(vd(c)){c=x[a+4>>2];d=Zi(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Hh(c);if((c|0)!=10){break b}}an(a,d,1,d,d,0,0);c=d}d=x[a>>2];Bd(a,c+1|0);break a}Ne(a,c+1|0);d=a}a=c+d|0;hd(a,b);hd(a+1|0,0)}function Qsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+3|0;q_(c+8|0,d);f=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){p_(d)}if(a){e=r_(d)}fb=b+160|0;return e|0}function PF(a,b,c,d){var e=0,f=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;v[x[a+1068>>2]+d|0]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;e=a,f=x[a+1068>>2]+_d(z[x[a+1060>>2]+34>>1])|0,x[e+1068>>2]=f;x[a+1072>>2]=x[a+1072>>2]-1}function Coa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-208|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+4|0;vW(c+8|0,d);f=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){uW(d)}if(a){e=wW(d)}fb=b+208|0;return e|0}function B8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function z_(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=d+12|0;xc(c,256);xc(c,65535);f=z[d+12>>1];vg(a,f);c=0;while(1){if((c|0)==(f|0)){fb=d+16|0}else{e=y[b+c|0];g=Sr(x[a>>2],x[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,w[g>>1]=h;c=c+1|0;continue}break}}function hta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+10|0;cw(c+8|0,d);f=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){N_(d)}if(a){e=O_(d)}fb=b+32|0;return e|0}function era(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=-1;c=fb-16|0;fb=c;d=b+11|0;_j(c+8|0,d);f=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){TY(d)}if(a){e=UY(d)}fb=b+16|0;return e|0}function _ka(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(vd(c)){c=x[a+4>>2];d=Zi(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Hh(c);if((c|0)!=10){break b}}UB(a,d,1,d,d,0);c=d}d=x[a>>2];Bd(a,c+1|0);break a}Ne(a,c+1|0);d=a}a=c+d|0;hd(a,b);hd(a+1|0,0)}function WE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=Dw(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31609]=0;W(228,b|0);e=x[31609];x[31609]=0;if((e|0)!=1){b=b+20|0;x[a+4>>2]=b;continue}break}b=N()|0;jc(a);Q(b|0);p()}jc(a);fb=c+16|0}function Kx(a,b,c,d,e){var f=0,g=0;a:{f=fb+-64|0;fb=f;g=f+44|0;sg(g,a,e);a=x[f+44>>2];e=f+20|0;ug(e,d,Ze(g),a);x[31609]=0;a=f+32|0;O(218,a|0,e|0);d=x[31609];x[31609]=0;if((d|0)!=1){d=f+12|0;Zb(d,b,c);nm(d,a);tb(a);Kc(g);fb=f- -64|0;break a}a=N()|0;Kc(f+44|0);Q(a|0);p()}}function Fe(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function v9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;e=d+8|0;c=x[b+52>>2];a:{if(c&16){c=x[b+48>>2];f=x[b+28>>2];if(c>>>0<f>>>0){x[b+48>>2]=f;c=f}wl(e,x[b+24>>2],c);break a}if(c&8){wl(e,x[b+12>>2],x[b+20>>2]);break a}Md(e)}lK(a,x[d+8>>2],x[d+12>>2]);fb=d+16|0}function oF(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c+12|0;cd(d,a);x[31609]=0;a=R(28,x[c+12>>2])|0;e=x[31609];x[31609]=0;a:{if((e|0)==1){break a}x[31609]=0;a=P(29,a|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}_b(d);fb=c+16|0;return a}a=N()|0;_b(c+12|0);Q(a|0);p()}function mu(a){var b=0,c=0,d=E(0);c=y[a+4232|0];if(c>>>0>=5){v[a+4232|0]=0;c=0}if(v[a+4233|0]<0){v[a+4233|0]=127}b=v[a+4234|0];if((b|0)<0){v[a+4234|0]=127;b=127}a:{if((c|0)==3){d=E(E(1)-Ee(E(2),E(-E((b+1&255)>>>0))));break a}d=Ee(E(2),E(-E((b&255)>>>0)))}B[a+4224>>2]=d}function Sha(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=4104;a=0;d=x[b+8>>2];a:{if(d>>>0<4096){break a}c=x[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}x[b+12>>2]=e;x[b+8>>2]=d-c;a=e}if(!a){_(6053,9030,88,7400);p()}fb=b+16|0;return a|0}function BW(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=wb(x[a>>2]);x[c+12>>2]=b;e=wb(x[a+4>>2]);while(1){a:{d=Ib(b,e);if(!d){break a}a=z[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){w[b>>1]=65535;break b}if(a>>>0>63){break a}}b=x[ge(c+12|0)>>2];continue}break}fb=c+16|0;return d^1}function Tj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=wb(x[b>>2]);f=wb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,f)){break a}if(u$(c,x[d>>2],x[d+4>>2])){break a}d=x[dm(e+12|0)>>2];continue}break}fb=e+16|0;if(mc(d,wb(x[b+4>>2]))){Yh(a);return}mp(a,d)}function Ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;sf(b);e=d+28|0;sg(e,a,c);a=x[d+28>>2];c=d+4|0;ug(c,1,Ze(e),a);x[31609]=0;a=d+16|0;O(218,a|0,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){zb(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function iaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(y[b+40|0]){break a}b:{if(!x[b+28>>2]){break b}d=x[c+4>>2];f=x[c>>2];while(1){if(!d){break a}e=ib[x[b+28>>2]](x[b+24>>2],f,d)|0;if(!e){break b}g=e+g|0;d=d-e|0;f=f+e|0;continue}}v[b+40|0]=1}cc(a,x[c>>2],g)}function LF(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=x[a+4>>2];f=e+b|0;x[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=x[a>>2];break a}a=x[a>>2];x[a+((f>>>0>=33?g>>>5|0:0)<<2)>>2]=0}yp(d+8|0,a,e);Vw(x[d+8>>2],x[d+12>>2],b,c);fb=d+16|0}function z$(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[cf(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[cf(d+13|0,d+12|0)|0]}fb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function fM(a){var b=0,c=0,d=0;b=fb-48|0;fb=b;ig(x[x[a>>2]-12>>2]+a|0,0);ae(b+32|0,a);a=Ci(a,0,0,2);ae(b+16|0,a);c=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=c;c=x[b+36>>2];x[b>>2]=x[b+32>>2];x[b+4>>2]=c;c=x[b+28>>2];d=x[b+24>>2];Tm(a,b);a=Tu(d,c);fb=b+48|0;return a}function f0(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=b-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function Yp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function I8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=zf(v[b|0]),e=x[x[a>>2]+52>>2],ib[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=im(b,1,c,x[a+32>>2])}return c|0}function EJ(a){var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;e=tc(a+8|0),f=0,v[e+128|0]=f;c=b+8|0;Rd(c,x[vb(b+4|0,a)>>2]);x[31609]=0;O(1327,a|0,30);d=x[31609];x[31609]=0;if((d|0)!=1){Vq(a,30);Qd(c);zJ(c);fb=b+16|0;return a}a=N()|0;zJ(b+8|0);Q(a|0);p()}function $_(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=320012546|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=184619540|y[a+8|0]>1|((y[a+9|0]-1&255)>>>0>7|(y[a+10|0]|y[a+11|0]<<8)>>>0>4096))){b=(y[a+12|0]|y[a+13|0]<<8)>>>0<4097}return b}function wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];d=y[b+1|0]<<8;e=y[b+2|0]<<16|y[b+3|0]<<24;if((y[b|0]|d|e)!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4228>>2]=e|(d|y[b|0]);x[a+4232>>2]=c;mu(a)}}function mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];d=y[b+1|0]<<8;e=y[b+2|0]<<16|y[b+3|0]<<24;if((y[b|0]|d|e)!=1869112133){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=e|(d|y[b|0]);x[a+4264>>2]=c;su(a)}}function Un(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(!b){b=0;break a}d=b;b=G(b);$f(c,d,0,0,0,112-(b^31)|0);d=0+x[c+8>>2]|0;b=(x[c+12>>2]^65536)+(16414-b<<16)|0;f=e>>>0>d>>>0?b+1|0:b;e=x[c+4>>2];b=x[c>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+8>>2]=d;x[a+12>>2]=f;fb=c+16|0}function Pq(a,b,c,d){var e=0,f=0,g=0;a:{e=Ql(a,b);if((e|0)==255){break a}g=x[a>>2];if(Fj(g)){break a}f=Vd(a+318|0,e);e=AU(e);if(v[xb(f,10)|0]&1|d){Ah(g,x[a+4>>2],b,e- -64&65535,zU(c,y[xb(f,2)|0]))}if(d){break a}Ah(x[a>>2],x[a+4>>2],b,e+67&65535,zU(c,y[xb(f,3)|0]))}}function yv(a,b){a:{b:{if((b|0)!=31){if((b|0)!=15){break b}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1196314451){break b}break a}b=0;if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=825446227){break a}}b=Bb(y[a+4|0]|y[a+5|0]<<8)>>>0>177}return b}function ZB(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a=mC(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[31609]=0;O(784,b|0,c|0);f=x[31609];x[31609]=0;if((f|0)!=1){b=b+32|0;x[a+4>>2]=b;continue}break}b=N()|0;jc(a);Q(b|0);p()}jc(a);fb=d+16|0}function iP(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=126444;x[a+20>>2]=0;x[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;x[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;x[a+8>>2]=d;x[a+32>>2]=d>>>0>=31?-1:-1>>>(d^31)|0;x[a+28>>2]=b>>>0>=c>>>0?-1>>>32-d|0:0;x[a+16>>2]=(D(c,d)-b|0)+c;return a}function e9(a){a=a|0;var b=0,c=0,d=0;c=x[a+44>>2];b=x[a+24>>2];if(c>>>0<b>>>0){x[a+44>>2]=b;c=b}d=-1;a:{if(!(y[a+48|0]&8)){break a}b=x[a+16>>2];if(b>>>0<c>>>0){Vn(a,x[a+8>>2],x[a+12>>2],c);b=x[a+16>>2]}a=x[a+12>>2];if(a>>>0>=b>>>0){break a}d=zf(v[a|0])}return d|0}function A0(a,b,c){var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;sf(b);f=d+28|0;sg(f,a,c);a=x[d+28>>2];e=d+4|0;ug(e,3,Ze(f),a);x[31609]=0;g=d+16|0;O(218,g|0,e|0);e=x[31609];x[31609]=0;if((e|0)!=1){zb(b,g);tb(g);Kc(f);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Kc(d+28|0);Q(a|0);p()}function om(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}if((d|0)!=3){d=D(c,872)+b|0;f=MS(x[d+720>>2],x[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return LS(a,b,c,e)}f=LS(a,b,c,e);if((f+5&255)>>>0>5){break a}a=D(c,872)+b|0;f=MS(x[a+720>>2],x[a+1272>>2],e)}return f}function Ura(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;sg(e,a,c);a=x[d+28>>2];c=d+4|0;ug(c,2,Ze(e),a);x[31609]=0;a=d+16|0;O(218,a|0,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){gm(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function Mh(a,b,c,d,e,f){var g=0;g=fb-32|0;fb=g;x[g+12>>2]=-1;x[g+16>>2]=0;x[g+4>>2]=0;Fb(g+20|0);x[g+8>>2]=f;x[31609]=0;x[g+4>>2]=x[g+4>>2]&e|d;d=a;a=g+4|0;S(c|0,d|0,b|0,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){Jh(a);fb=g+32|0;return}a=N()|0;Jh(g+4|0);Q(a|0);p()}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;sg(e,a,c);a=x[d+28>>2];c=d+4|0;ug(c,1,Ze(e),a);x[31609]=0;a=d+16|0;O(218,a|0,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){Be(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function fo(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]<0;b:{c=x[b+4>>2];c:{if(!c){At(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function I$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;sg(e,a,c);a=x[d+28>>2];c=d+4|0;ug(c,2,Ze(e),a);x[31609]=0;a=d+16|0;O(218,a|0,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){Ac(b,a);tb(a);Kc(e);fb=d+48|0;break a}a=N()|0;Kc(d+28|0);Q(a|0);p()}}function $1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;x[e+24>>2]=d;x[e+28>>2]=c;x[31609]=0;c=e+8|0;V(167,c|0,b|0,e+28|0,e+24|0);d=x[31609];x[31609]=0;if((d|0)!=1){d=e+16|0;Jp(d,c);Ff(a,d);me(d);me(c);me(b);fb=e+32|0;return}a=N()|0;me(b);Q(a|0);p()}function vl(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=St(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function un(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=a;c=QC(b);e=fb-16|0;fb=e;a:{if(c>>>0<1073741808){b:{if(fr(c)){Ne(d,c);break b}Nj(e+8|0,rn(c)+1|0);f=x[e+8>>2];yd(d,f);of(d,x[e+12>>2]);Bd(d,c);d=f}yd(Ri(d,b,c)+(c<<2)|0,0);fb=e+16|0;break a}pf();p()}return a|0}function Ix(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+12>>2]=-1;x[f+16>>2]=0;x[f+4>>2]=0;x[f+8>>2]=0;Fb(f+20|0);x[31609]=0;x[f+4>>2]=x[f+4>>2]&e|d;d=a;a=f+4|0;S(c|0,d|0,b|0,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){Jh(a);fb=f+32|0;return}a=N()|0;Jh(f+4|0);Q(a|0);p()}function Iha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;x[a+4>>2]=b;x[a>>2]=0;b=nu(a+8|0,d);x[31609]=0;P(961,a+20|0,c|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&224|25;return a|0}a=N()|0;Eb(b);Q(a|0);p()}function sH(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(e+8|0,x[vb(e+4|0,a)>>2]);a:{if(b){x[31609]=0;O(d|0,a|0,b|0);d=x[31609];x[31609]=0;if((d|0)==1){break a}Ap(a,b,c)}b=e+8|0;Qd(b);Xi(b);fb=e+16|0;return a}a=N()|0;Xi(e+8|0);Q(a|0);p()}function Y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=eq(e+4|0,c,d);c=BI(0,Kb(b),0);x[31609]=0;a=U(1386,a|0,c|0,0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){BI(Kb(a),Kb(b),Cb(x[a+4>>2],y[a+11|0])+1|0);Ub(b);fb=e+16|0;return}a=N()|0;Ub(b);Q(a|0);p()}function VC(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-1024|0;fb=e;d=fb-16|0;fb=d;SC(d+8|0,e);f=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((f|0)==(g|0)){h=TC(e,c)>>>0<=b>>>0}fb=e+1024|0;return h}function Hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-48|0;fb=c;e=c+28|0;sg(e,a,32);a=x[c+28>>2];d=c+4|0;ug(d,1,Ze(e),a);x[31609]=0;a=c+16|0;O(218,a|0,d|0);d=x[31609];x[31609]=0;if((d|0)!=1){Ac(b,a);tb(a);Kc(e);fb=c+48|0;break a}a=N()|0;Kc(c+28|0);Q(a|0);p()}}function HZ(a){var b=0,c=0,d=0,e=0;d=y[a+32|0]|y[a+33|0]<<8;e=y[a+38|0]|y[a+39|0]<<8;c=y[a+34|0]|y[a+35|0]<<8;b=c+(y[a+36|0]|y[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=(c>>>0>b>>>0?a+1|0:a)<<2|b>>>30;c=d;d=b<<2;b=c+d|0;hb=b>>>0<d>>>0?a+1|0:a;return b}function U3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=Xl(e+4|0,c,d);c=zI(0,Kb(b),0);x[31609]=0;a=U(542,a|0,c|0,0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){zI(Kb(a),Kb(b),Cb(x[a+4>>2],y[a+11|0])+1|0);tb(b);fb=e+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function KB(a,b,c,d){var e=0,f=0,g=0;e=de(a);a:{if(e){f=gc(a);while(1){a=e;e=z[a+16>>1];g=x[a+20>>2];if(Ol(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Ol(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=gc(a);f=a}x[b>>2]=a;return f}function B1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-48|0;fb=c;d=-1;e=a;a=c+12|0;a:{if(!ZF(e,a)){break a}d=0;if(!YF(a)){break a}if(b){a=x[b>>2];if(!x[b+4>>2]&a>>>0<$b(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))-8>>>0){break a}}d=1}fb=c+48|0;return d|0}function fB(a,b,c,d){var e=0,f=0,g=0;e=de(a);a:{if(e){f=gc(a);while(1){a=e;e=y[a+16|0];g=x[a+20>>2];if(Bo(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Bo(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=gc(a);f=a}x[b>>2]=a;return f}function cH(a,b,c,d,e){var f=0,g=0;a:{f=fb-48|0;fb=f;sf(b);g=f+28|0;sg(g,a,d);a=x[f+28>>2];d=f+4|0;ug(d,e,Ze(g),a);x[31609]=0;a=f+16|0;S(599,a|0,c|0,d|0);c=x[31609];x[31609]=0;if((c|0)!=1){zb(b,a);tb(a);Kc(g);fb=f+48|0;break a}a=N()|0;Kc(f+28|0);Q(a|0);p()}}function RM(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=a+120|0;bu(y[b+20|0]);c=fb-16|0;fb=c;x[c+12>>2]=d+15;a=fb-16|0;fb=a;x[a+12>>2]=1142;x[a+8>>2]=1143;x[a+4>>2]=1144;x[a>>2]=1145;b=ib[x[lq(a,sk(y[b+20|0]))>>2]](c+12|0,b)|0;fb=a+16|0;fb=c+16|0;fb=d+16|0;return b}function D0(a,b,c){var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;f=d+28|0;sg(f,a,c);a=x[d+28>>2];e=d+4|0;ug(e,3,Ze(f),a);x[31609]=0;g=d+16|0;O(218,g|0,e|0);e=x[31609];x[31609]=0;if((e|0)!=1){Ac(b,g);tb(g);Kc(f);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Kc(d+28|0);Q(a|0);p()}function hra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;sf(b);v[c+15|0]=0;a:{if(!gi(a,c+15|0)){break a}f=y[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}v[c+14|0]=0;if(gi(a,c+14|0)){Rp(b,v[c+14|0]);e=e+1|0;continue}break}d=0}fb=c+16|0;return d|0}function y8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function y5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=yJ(a,c);x[a>>2]=95232;c=lk(Kb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Mm(a,17890,b);x[31609]=0;W(1367,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=d+16|0;return a|0}p()}function w5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=xJ(a,c);x[a>>2]=95264;c=lk(Kb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Mm(a,18071,b);x[31609]=0;W(1367,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=d+16|0;return a|0}p()}function hH(a,b,c){var d=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);Rd(d+8|0,x[vb(d+4|0,a)>>2]);a:{if(b){x[31609]=0;O(c|0,a|0,b|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}OX(a,b)}b=d+8|0;Qd(b);Xi(b);fb=d+16|0;return a}a=N()|0;Xi(d+8|0);Q(a|0);p()}function WI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=vJ(a,c);x[a>>2]=96428;c=lk(Kb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Mm(a,17952,b);x[31609]=0;W(1367,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=d+16|0;return a|0}p()}function UO(a){var b=0,c=0;b=x[a+24>>2];c=z[b+1074448>>1];if(c>>>0>=Hj(Xb(x[b+484360>>2],y[b+484376|0]))>>>0){return z[x[a+24>>2]+1074446>>1]}a=x[a+24>>2];b=z[ac(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],c)>>1];return Bn(x[a+484344>>2],x[a+484348>>2],b)?b:-1}function ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=fb-16|0;fb=d;b=If(a,c);ae(d,x[a+36>>2]);a:{b:{if(!b){Qc(d,a+32|0,5);c=-1;if(!Gb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}WB(x[a+36>>2],e,c);f=1;g=b}ef(a,g);fb=d+16|0;return f|0}function jR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;fd(e+24|0,b,c);b=fb-16|0;fb=b;f=x[e+28>>2];g=x[e+24>>2];c=f-g|0;h=b,i=iR(d,g,(c|0)/6|0)+c|0,x[h+12>>2]=i;qc(e+16|0,f,b+12|0);fb=b+16|0;b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(a,b,e+12|0);fb=e+32|0}function IH(a,b,c,d){var e=0,f=0,g=0,h=0;a:{f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;g=e,h=Ec(d),x[g+8>>2]=h;d=x[e+8>>2];x[31609]=0;P(c|0,d|0,b|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){b=a;a=Rn(e);Qn(b,nc(a),a);tm(e);fb=f+16|0;break a}a=N()|0;tm(e);Q(a|0);p()}}function At(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){ib[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function Uh(a,b){var c=0,d=0,e=0;a:{if(!(v[a+480180|0]&1|b)){break a}c=a+480280|0;d=x[a+24616>>2]&524288;a=0;while(1){if((a|0)==127){break a}b=(a<<5)+c|0;w[b+6>>1]=64;x[b>>2]=x[b>>2]&-257;e=b;b=(a&3)-1>>>0<2;w[e+4>>1]=d?b<<8:b?192:64;a=a+1|0;continue}}}function B$(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[cf(d+15|0,d+14|0)|0]}a=e;fb=d+16|0;return a&255}function rf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;e=fb-16|0;fb=e;a:{if(b>>>0<2147483632){b:{if(Nk(b)){Ne(d,b);break b}qg(e+8|0,Fh(b)+1|0);f=x[e+8>>2];yd(d,f);of(d,x[e+12>>2]);Bd(d,b);d=f}hd($l(d,b,c)+b|0,0);fb=e+16|0;break a}pf();p()}return a|0}function jD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;CY(a,b);dd(a,$b(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))+504|0);BY(a,d);a:{b=$b(y[b+32|0]|y[b+33|0]<<8|(y[b+34|0]<<16|y[b+35|0]<<24));if(!b){break a}if(!dd(a,b)){break a}lD(a,c);return}Rb(c,0,80)}function dP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=Pj(b,c);d=Mc(a);if(e>>>0>d>>>0){f=d;g=e-d|0;d=Cb(x[a+4>>2],y[a+11|0]);an(a,f,g,d,0,d,0)}d=Kb(a);while(1){if((b|0)!=(c|0)){hd(d,y[b|0]);b=b+1|0;d=d+1|0;continue}break}hd(d,0);lg(a,e);return a|0}function aN(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(Fd(a,e)){Oj(Bz(a));a=x[Xq(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function _$(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;f=xb(a,31),g=0,v[f|0]=g;c=Fi(a,So(a),0);v[b+15|0]=0;c=Pj(a,c);Qm(c+a|0,So(a),b+15|0);while(1){if((c|0)!=(d|0)){e=xb(a,d);if((y[e|0]-127&255)>>>0<=160){v[e|0]=32}d=d+1|0;continue}break}fb=b+16|0}function V3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-32|0;fb=a;b=Xl(a+20|0,b,c);x[31609]=0;c=U(1387,a+8|0,d|0,e|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){d=hi(Kb(b),Kb(c));tb(c);tb(b);fb=a+32|0;return((d|0)<0?-1:(d|0)!=0)|0}a=N()|0;tb(b);Q(a|0);p()}function PG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Dc(b+4|0,14821);a:{if(!_c(x[a+4>>2],y[a+11|0])){break a}c=1;if((Tg(a,14690)|0)!=-1){break a}if((Tg(a,16834)|0)!=-1){break a}if((Tg(a,13834)|0)!=-1){break a}c=(Tg(a,13877)|0)!=-1}tb(a);fb=b+16|0;return c|0}function Naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[b>>2];e=x[b+8>>2];f=x[b+4>>2];a=0;a:while(1){if((a|0)!=(f|0)){g=(a<<2)+d|0;b=0;while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=x[g>>2]+(b<<3)|0;x[c>>2]=0;x[c+4>>2]=0;b=b+1|0;continue}}break}}function Gga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Ji(a,b,c,d);x[a>>2]=44912;b=a+4208|0;e=yb(b,0),f=1017370378,x[e>>2]=f;e=yb(b,1),f=0,x[e>>2]=f;x[31609]=0;O(941,a+44|0,2);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;_f(a);Q(b|0);p()}function $L(a){var b=0,c=0,d=0,e=0;if(!y[a+12|0]){b=fb-16|0;fb=b;d=vb(b+12|0,x[x[a+8>>2]>>2]);e=x[vb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(Fd(a,e)){Eb(Pp(a));a=x[jk(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0}}function Zf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Nj(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<2)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<2)|0,x[f>>2]=g;fb=e+16|0;return a|0}function Cm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=Sd(b,c);d=sn(a);if(e>>>0>d>>>0){f=d;g=e-d|0;d=Cb(x[a+4>>2],y[a+11|0]);rC(a,f,g,d,0,d)}d=Kb(a);while(1){if((b|0)!=(c|0)){yd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}break}yd(d,0);lg(a,e);return a|0}function tY(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;fd(e+24|0,b,c);b=fb-16|0;fb=b;f=x[e+28>>2];g=x[e+24>>2];c=f-g|0;h=b,i=sY(d,g,c>>2)+c|0,x[h+12>>2]=i;qc(e+16|0,f,b+12|0);fb=b+16|0;b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(a,b,e+12|0);fb=e+32|0}function g5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=sJ(a,0);x[a>>2]=101336;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Kb(b);x[31609]=0;O(1370,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function e5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=rJ(a,0);x[a>>2]=101440;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Kb(b);x[31609]=0;O(1371,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function c5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=qJ(a,0);x[a>>2]=101544;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Kb(b);x[31609]=0;O(1372,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}a=N()|0;Ub(f);Ub(e);Ub(d);tb(c);Q(a|0);p()}function a5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=pJ(a,0);x[a>>2]=101648;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Kb(b);x[31609]=0;O(1373,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}a=N()|0;Ub(f);Ub(e);Ub(d);tb(c);Q(a|0);p()}function pK(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[b>>2]=0;v[c+15|0]=0;gi(a,c+15|0);d=y[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){x[b>>2]=e;if((d|0)==(f|0)){fb=c+16|0}else{v[c+15|0]=0;gi(a,c+15|0);d=d+1|0;e=x[b>>2]|y[c+15|0]<<(d<<3)-2;continue}break}}function rL(a){var b=0,c=0,d=0,e=0,f=0;d=x[a>>2];b=v[d|0]-48|0;if(b>>>0>9){return 0}while(1){e=-1;if(c>>>0<=214748364){c=D(c,10);e=(c^2147483647)>>>0<b>>>0?-1:c+b|0}b=d+1|0;x[a>>2]=b;f=v[d+1|0];c=e;d=b;b=f-48|0;if(b>>>0<10){continue}break}return c}function pL(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=pL(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}
function _P(a,b,c){var d=0,e=0;if(E(F(a))<E(0x8000000000000000)){e=~~a>>>0}else{e=0}d=e>>31;d=(e^d)-d|0;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return E(((e|0)<0?b^-1|-2147483648:b)|0)}function aT(a,b,c,d){var e=0;e=-2147483648;e=!c|!(v[c+15|0]&1)?e:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){e=z[d+28>>1];break b}if((e|0)==-2147483648){break a}}Sq(b,e,a);if(!Ob(a+1074312|0,10)|y[a+480209|0]&64){break a}x[b+88>>2]=x[b+88>>2]&-257}}function WN(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;f=d,g=eO(c),x[f+8>>2]=g;c=d+8|0;e=x[re(d+12|0,c)>>2];x[31609]=0;b=+pa(1114,a|0,+b,e|0);a=x[31609];x[31609]=0;if((a|0)!=1){Wc(c);fb=d+16|0;return+b}a=N()|0;Wc(d+8|0);Q(a|0);p()}function nra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{c=x[a>>2];if(oc(c,x[a+4>>2])>>>0>d>>>0){f=e+4|0;vm(f,x[yb(c,d)>>2]+40|0);c=ir(f,b);tb(f);if(!c){break a}g=x[yb(x[a>>2],d)>>2]}fb=e+16|0;return g|0}d=d+1|0;continue}}function kH(a,b,c,d){var e=0,f=0;a:{e=fb-48|0;fb=e;f=e+28|0;sg(f,a,d);a=x[e+28>>2];d=e+4|0;ug(d,c,Ze(f),a);x[31609]=0;a=e+16|0;O(218,a|0,d|0);c=x[31609];x[31609]=0;if((c|0)!=1){Be(b,a);tb(a);Kc(f);fb=e+48|0;break a}a=N()|0;Kc(e+28|0);Q(a|0);p()}}function D7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;x[g+24>>2]=37;x[g+28>>2]=83;x[g+16>>2]=77;x[g+20>>2]=58;x[g+8>>2]=58;x[g+12>>2]=37;x[g>>2]=37;x[g+4>>2]=72;h=b;b=g+32|0;a=qk(a,h,c,d,e,f,g,b);fb=b;return a|0}function hba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=d+4|0;Gx(e,c);c=d+16|0;x[c>>2]=b;Uc(c+4|0,e);x[31609]=0;O(1125,a+4|0,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){Oj(c);tb(e);fb=d+32|0;return}a=N()|0;Oj(d+16|0);tb(d+4|0);Q(a|0);p()}function gja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;c=If(a,c);ae(e,x[a+36>>2]);a:{b:{if(!c){Qc(e,a+32|0,5);f=-1;if(!Gb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}f=x[c+16>>2]}ib[d|0](x[a+36>>2],b,f);g=c}ef(a,g);fb=e+16|0}function J7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;v[g+8|0]=37;v[g+9|0]=72;v[g+10|0]=58;v[g+11|0]=37;v[g+12|0]=77;v[g+13|0]=58;v[g+14|0]=37;v[g+15|0]=83;h=a;a=g+16|0;b=rk(h,b,c,d,e,f,g+8|0,a);fb=a;return b|0}function $$(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;sf(b);e=d+28|0;sg(e,a,c);a=x[d+28>>2];c=d+4|0;ug(c,2,Ze(e),a);x[31609]=0;a=d+16|0;O(218,a|0,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){zb(b,a);tb(a);Kc(e);fb=d+48|0;return}a=N()|0;Kc(d+28|0);Q(a|0);p()}function nT(a,b){var c=0,d=0;a:{if(!(v[a+851|0]&1)){break a}c=x[a+104>>2];if(!c){break a}d=x[c>>2];if(!d){break a}x[a+76>>2]=d;x[a>>2]=0;x[a+4>>2]=d-1;c=x[a+88>>2];if(!b){x[a+88>>2]=c&-135|128;return}x[a+84>>2]=d;x[a+80>>2]=0;x[a+88>>2]=c|134}}function UC(a,b,c){var d=0;d=fb-16|0;fb=d;w[d+12>>1]=c;w[d+14>>1]=b;b=wb(x[a>>2]);c=wb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,c)){if(z[b>>1]==z[d+14>>1]){w[b>>1]=z[d+12>>1]}b=x[ge(a+12|0)>>2];continue}break}fb=a+16|0;fb=d+16|0}function SV(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(b,872);b=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)==(b|0)){jc(c);fb=d+16|0}else{RV(Rb(b,0,872));b=b+872|0;x[c+4>>2]=b;continue}break}}function yl(a,b,c){var d=0,e=0,f=0,g=0,h=0;while(1){a:{if((a|0)!=(b|0)){e=x[c>>2];g=x[c+4>>2];d=fb-16|0;fb=d;f=pc(d+8|0,x[a>>2]);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;e=Ic(e,g,d);fb=d+16|0;if(!e){break a}}else{a=b}return a}a=a+8|0;continue}}function mja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=-1;e=a;a=c+8|0;a:{if(!JG(e,a)){break a}d=0;if(!mR(a)){break a}if(b){if(x[b>>2]!=(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))|x[b+4>>2]){break a}}d=1}fb=c+32|0;return d|0}function kx(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function cr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=RW(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function Zr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=MF(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function Ur(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=vb(c+12|0,x[a+4>>2]);e=vb(c+8|0,x[a>>2]);f=vb(c+4|0,x[b+4>>2]);g=b,h=NF(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;Tb(a,b+4|0);Tb(a+4|0,b+8|0);Tb(Ab(a),nc(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function Mca(a,b){a=a|0;b=b|0;var c=0;a:{if((a|0)==(b|0)){break a}c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22292}c=Gd(Ef(b)+1|0);x[a+4>>2]=c;if(!c){break a}zc(c,b,Ef(b)+1|0)}return a|0}function Zra(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;v[b+30|0]=0;w[b+28>>1]=0;c=b+28|0;d=Zb(b+8|0,c,3);kc(b+20|0,x[a>>2],x[a+8>>2],x[d>>2],x[d+4>>2]);a:{if(x[b+24>>2]!=3){break a}if(jd(c,14783,3)){break a}Vb(a,3);e=1}fb=b+32|0;return e|0}function Xp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function Xna(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;w[b+28>>1]=0;x[b+24>>2]=0;c=b+24|0;d=Zb(b+8|0,c,6);kc(b+16|0,x[a>>2],x[a+8>>2],x[d>>2],x[d+4>>2]);a:{if(x[b+20>>2]!=6){break a}if(jd(c,3856,6)){break a}Vb(a,6);e=1}fb=b+32|0;return e|0}function qS(a,b){a=mS(a);mS(a+368680|0);if(b){lS(a,1);return}if(!y[495312]){qS(126608,1);v[495312]=1}yu(257720,323256,a+131112|0);yu(323256,388792,a+196648|0);yu(388792,454328,a+262184|0);yu(126632,257720,a+24|0);zc(a+327720|0,454328,40960)}function pn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}qg(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+c|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+d|0,x[f>>2]=g;fb=e+16|0;return a|0}function oT(a,b){var c=0,d=0;d=fb-16|0;fb=d;c=x[a+104>>2];a:{if(!c){break a}c=x[c>>2];if(!c){break a}x[a+76>>2]=c;x[a+88>>2]=x[a+88>>2]&-131|128;x[d+12>>2]=b<<8;x[d+8>>2]=c-1;b=c+(x[Hb(d+12|0,d+8|0)>>2]^-1)|0;x[a>>2]=0;x[a+4>>2]=b}fb=d+16|0}function oh(a,b){var c=0,d=0,e=0;d=y[a+11|0];c=Cb(x[a+4>>2],d);a:{if((c|0)!=(Cb(x[b+4>>2],y[b+11|0])|0)){break a}a=Kb(a);b=Kb(b);if(!vd(d)){while(1){e=!c;if(!c|y[a|0]!=y[b|0]){break a}b=b+1|0;a=a+1|0;c=c-1|0;continue}}e=!ot(a,b,c)}return e}function kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=jv(e+4|0,a,d);f=x[d+4>>2];x[31609]=0;a=ba(1123,Ab(a)|0,b|0,c|0,f|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){x[d+4>>2]=a;jc(d);fb=e+16|0;return}a=N()|0;jc(d);Q(a|0);p()}function bW(a){var b=0,c=0;a=a*4294967296;if(F(a)<0x8000000000000000){c=~~a>>>0;if(F(a)>=1){b=~~(a>0?H(J(a*2.3283064365386963e-10),4294967295):K((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0}else{b=0}hb=b;return c}hb=-2147483648;return 0}function ve(a,b){var c=0,d=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if(x[a+8>>2]>=(d|0)){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=y[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function mH(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=c;c=e+12|0;xc(c,d);xc(c,65535);d=z[e+12>>1];vg(a,d);c=0;while(1){if((c|0)==(d|0)){fb=e+16|0}else{f=y[b+c|0];g=Sr(x[a>>2],x[a+4>>2],c),h=f,w[g>>1]=h;c=c+1|0;continue}break}}function R9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=uv(e+4|0,a,d);f=x[d+4>>2];x[31609]=0;a=ba(1207,Ab(a)|0,b|0,c|0,f|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){x[d+4>>2]=a;jc(d);fb=e+16|0;return}a=N()|0;jc(d);Q(a|0);p()}function FT(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+3|0]|y[b+4|0]<<8|(y[b+5|0]<<16|y[b+6|0]<<24);v[a+3|0]=b;v[a+4|0]=b>>>8;v[a+5|0]=b>>>16;v[a+6|0]=b>>>24}function F0(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;e=d+28|0;sg(e,a,c);a=x[d+28>>2];c=d+4|0;ug(c,3,Ze(e),a);x[31609]=0;a=d+16|0;O(218,a|0,c|0);c=x[31609];x[31609]=0;if((c|0)!=1){gm(b,a);tb(a);Kc(e);fb=d+48|0;return}a=N()|0;Kc(d+28|0);Q(a|0);p()}function EW(a){var b=0,c=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=CW(a+20|0)}return c}function nx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;lf(e+8|0,b,c);x[31609]=0;Ma(165,a|0,x[e+8>>2],x[e+12>>2]);b=x[31609];x[31609]=0;if((b|0)!=1){x[a+8>>2]=0;Ff(a+12|0,d);me(d);fb=e+16|0;return a|0}a=N()|0;me(d);Q(a|0);p()}function YC(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];lf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);lf(a,x[e+24>>2],x[e+28>>2]);x[b+12>>2]=x[b+12>>2]+x[a+4>>2];fb=e+32|0}function WB(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:IU(a,b);return;default:break a}}d=fb-32|0;fb=d;x[d+28>>2]=c;w[d+26>>1]=0;x[d+12>>2]=2;c=d+16|0;sz(c,a,d+26|0,x[Hb(d+28|0,d+12|0)>>2]);$i(c,z[d+26>>1]);w[b>>1]=z[d+16>>1];fb=d+32|0}function By(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;w[b>>1]=0;v[c+15|0]=0;gi(a,c+15|0);d=y[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){w[b>>1]=e;if(d>>>0>=f>>>0){fb=c+16|0}else{v[c+15|0]=0;gi(a,c+15|0);e=z[b>>1]|y[c+15|0]<<7;d=1;continue}break}}function y0(a){var b=0,c=0,d=0,e=0;c=y[a+2|0];b=c+(y[a+5|0]|y[a+6|0]<<8)|0;c=(b>>>0<c>>>0?1:d)<<1|b>>>31;d=b<<1;b=c;a=y[a+3|0]|y[a+4|0]<<8;c=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+47|0;hb=b>>>0<47?a+1|0:a;return b}function pA(a,b){var c=0,d=0,e=0,f=0;c=a&16711680;d=c>>>8|0;e=c<<24;c=a&-16777216;f=c>>>24|0;c=e|c<<8;e=d|f|(a<<24|(a&65280)<<8);d=0;hb=e|(d|d);return((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|c}function kU(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=x[a>>2];e=Dk(b,x[a+4>>2]);b=wb(b);x[c+12>>2]=b;d=+(e>>>0);a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){C[b>>3]=C[b>>3]/d;C[b+8>>3]=C[b+8>>3]/d;b=x[Vo(c+12|0)>>2];continue}else{fb=c+16|0}break}}function YS(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function qv(a){var b=0;a:{if(y[a+4|0]|(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1414687062){break a}if(Bb(y[a+6|0]|y[a+7|0]<<8)>>>0>1){break a}if(Bb(y[a+12|0]|y[a+13|0]<<8)){break a}b=(Bb(y[a+16|0]|y[a+17|0]<<8)|0)==20}return b}function Wta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Gr(e,c);uj(d+12|0,e);x[31609]=0;V(301,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31609];x[31609]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=fb-16|0;fb=d;b=If(a,c);ae(d,x[a+36>>2]);a:{b:{if(!b){Qc(d,a+32|0,5);c=-1;if(!Gb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}WB(x[a+36>>2],e,c);f=b}ef(a,f);fb=d+16|0}function Hpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;br(e,c);uj(d+12|0,e);x[31609]=0;V(301,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31609];x[31609]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Eta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;dx(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b+2|0]=0;v[b|0]=0;v[b+1|0]=0}}function Bi(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function be(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;g=a+26|0;d=z[a+22>>1];h=d+z[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(h|0)){e=((c&127)<<2)+g|0;f=z[e+2>>1]+b|0;w[e+2>>1]=f;if((f&65535)>>>0<2048){break a}w[a+20>>1]=c-d}return}c=c+1|0;continue}}function Kra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Wv(e,c);uj(d+12|0,e);x[31609]=0;V(92,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31609];x[31609]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Fra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Op(e,c);uj(d+12|0,e);x[31609]=0;V(92,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31609];x[31609]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function CE(a,b,c){var d=0,e=0;d=(a&65535)>>>D(c,3)|0;a=y[b+12|0]&-4|d>>>2&1;e=a|d<<1&2;a:{b:{if(d&2){a=e;break b}v[b+12|0]=e&251;if(!(d&1)|!(d>>>9-(c<<1)&1)){break a}c=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=c;v[b+16|0]=c>>>8}v[b+12|0]=a|4}}function Aoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;QZ(e,c);uj(d+12|0,e);x[31609]=0;V(92,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31609];x[31609]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function lV(a){var b=0,c=0,d=0;d=So(a);while(1){if((a|0)!=(d|0)){b=y[a|0];a:{b:{if((b-97&255)>>>0<=5){c=b-32|0;break b}if(!(b-88>>>0<2|b-120>>>0<2)){c=99;if((b|0)==75|(b|0)==107){break b}break a}c=122}v[a|0]=c}a=a+1|0;continue}break}}function _E(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Bw(e,c);uj(d+12|0,e);x[31609]=0;V(92,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31609];x[31609]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Z_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;HE(e,c);uj(d+12|0,e);x[31609]=0;V(92,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31609];x[31609]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function KG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;ao(e,c);uj(d+12|0,e);x[31609]=0;V(92,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31609];x[31609]=0;if((a|0)!=1){Eb(e);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function Fg(a,b){var c=0,d=0,e=0,f=0;d=a+26|0;c=z[a+22>>1];e=c+z[a+20>>1]|0;a=z[a+24>>1]<<17;while(1){if((c|0)==(e|0)){a=(a|0)/32768|0}else{f=a;a=((c&127)<<2)+d|0;a=f-D(x[yb(b,z[a+2>>1])>>2],w[a>>1])|0;c=c+1|0;continue}break}return a}function wT(a,b,c){var d=0;d=x[b+48>>2]+1|0;x[b+52>>2]=d;a:{if(A[Wb(x[a+484344>>2],z[b+70>>1])+12>>2]>d>>>0){break a}if(!c){w[b+74>>1]=z[b+72>>1]+1}x[b+52>>2]=0;if(!Ob(a+1074312|0,63)){break a}a=x[b+56>>2];x[b+56>>2]=0;x[b+52>>2]=a}}function sg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Nb(a+8|0);x[31609]=0;S(169,a|0,b|0,c|0);c=x[31609];x[31609]=0;a:{if((c|0)!=1){a=x[a>>2];x[31609]=0;P(183,b|0,a|0)|0;a=x[31609];x[31609]=0;if((a|0)!=1){break a}}a=N()|0;fc(d);Q(a|0);p()}}function Vra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;pD(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,4896)}return a|0}function qZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=sn(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Kb(a);Ri(d+(e<<2)|0,b,c);b=c+e|0;lg(a,b);yd(d+(b<<2)|0,0);return a|0}nI(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a|0}function Xf(a,b,c){var d=0;a:{if(A[b+8>>2]<c>>>0){x[31609]=0;V(1164,17433,9126,435,6381);a=x[31609];x[31609]=0;if((a|0)==1){break a}p()}d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return}T(0)|0;Sb();p()}function Q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=im(b,4,c,x[a+32>>2])}return c|0}function qC(a,b){var c=0,d=0,e=0,f=0;w[a+24>>1]=0;x[a+20>>2]=0;x[a>>2]=0;x[a+4>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(F(d)<2147483648){b=~~d;break a}b=-2147483648}x[a+16>>2]=b;e=a,f=bW(c-+(b<<2)),x[e+8>>2]=f;x[a+12>>2]=hb;return a}function gB(a,b,c){var d=0,e=0;d=de(a);a:{if(d){e=gc(a);while(1){a=d;d=y[a+16|0];if(Co(c,d)){e=a;d=x[a>>2];if(d){continue}break a}if(!Co(d,c)){break a}e=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=gc(a);e=a}x[b>>2]=a;return e}function Uqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;nD(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,33)}return a|0}function tua(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){dh(a+b|0);a=a+1|0;continue}break}break a}cc(c+8|0,b,120);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function e1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Cw(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Rb(b,0,65)}return a|0}function Oaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[b>>2];d=x[b+8>>2];e=x[b+4>>2];a=0;a:while(1){if((a|0)!=(e|0)){f=(a<<2)+c|0;b=0;while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{x[x[f>>2]+(b<<2)>>2]=0;b=b+1|0;continue}}break}}function Ki(a){var b=0,c=0,d=0,e=0;b=Zd(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=Zd(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}return(e|0)<0?(c|0)<0?-2147483648:0-c|0:c}function $Q(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=e>>>8|0;g=(e&255)<<24|d>>>8;d=(((y[b|0]^d)&255)<<3)+22328|0;e=x[d>>2];d=x[d+4>>2]^f;x[a>>2]=e^g;x[a+4>>2]=d;b=b+1|0;continue}break}return a}function g2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=x[d>>2];g=x[b+8>>2];if(g>>>0>c>>>0){x[e+12>>2]=g-c;x[e+8>>2]=x[d+4>>2];b=x[b+4>>2]+c|0;h=x[Hb(e+12|0,e+8|0)>>2];xk(b,b+h|0,f)}cc(a,f,h);fb=e+16|0}function ym(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}VG(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,12)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,12)|0,x[f>>2]=g;fb=e+16|0;return a}function jE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=x[a>>2];f=hm(e,x[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=_i(e,c);if(!Ib(x[c>>2],x[c+4>>2])){break a}d=d+1|0;continue}break}return(Pg(a,d&65535,b)?d:-1)&65535}function UD(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}RE(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,20)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,20)|0,x[f>>2]=g;fb=e+16|0;return a}function Kr(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=fb-16|0;fb=b;Vr(b+8|0,c+15|0);d=x[b+12>>2];qd(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(d|0)){id(a,x[b+12>>2])}fb=b+16|0;fb=c+16|0;return((d|0)==(e|0)?y[c+15|0]:0)&255}function CR(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Gc(Bua(Aua(d,d>>31,g,h),hb,256,0),hb);x[a+4>>2]=f-d;x[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function uT(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!c){break a}x[b+40>>2]=c;if(!c|x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[bd(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=AC(c&255),x[e+44>>2]=f}fb=d+16|0}function fpa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-32|0;fb=b;d=b+20|0;c=-1;a:{if(!dE(a,d)){break a}c=0;if(!iX(d)){break a}c=-1;if(!hk(a,b+12|0)){break a}c=0;if(!x[b+16>>2]){break a}c=!(x[b+12>>2]&-2139062144)}fb=b+32|0;return c|0}function fla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;sU(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){QB(b)}return a|0}function bqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(uh(178956970)>>>0<b>>>0){ed();p()}d=Ec(D(b,24));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+D(x[c+12>>2],24)|0,x[e>>2]=f;fb=c+16|0}function Vna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(uh(119304647)>>>0<b>>>0){ed();p()}d=Ec(D(b,36));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+D(x[c+12>>2],36)|0,x[e>>2]=f;fb=c+16|0}function Bua(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Cua(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;hb=(g^hb)-((a>>>0<f>>>0)+g|0)|0;return b}function zw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Lw(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){LE(b)}return a|0}function kZ(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}hZ(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,6)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+D(d,6)|0,x[f>>2]=g;fb=e+16|0;return a}function js(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}qG(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<3)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<3)|0,x[f>>2]=g;fb=e+16|0;return a}function jj(a,b,c){c=c&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function iv(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}JV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<5)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<5)|0,x[f>>2]=g;fb=e+16|0;return a}function ek(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Zw(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<1)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<1)|0,x[f>>2]=g;fb=e+16|0;return a}function aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;f=c,g=Ec(40),x[f+8>>2]=g;d=sm(x[c+8>>2]);x[d>>2]=78040;d=qM(nc(d));x[d+24>>2]=b;x[d>>2]=78188;b=a;a=Rn(c);Qn(b,nc(a),a);tm(c);fb=e+16|0}function Nq(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(C[Ip(b)>>3]-C[a>>3]);b=0;while(1){if((b|0)!=2048){d=-Fe(f*C[Se(a,b)>>3]);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=yb(c,b),h=e,x[g>>2]=h;b=b+1|0;continue}break}}function MV(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Lg(a+12|0,d);a:{if(!b){d=0;b=0;break a}LV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<4)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=nc(a),g=b+(d<<4)|0,x[f>>2]=g;fb=e+16|0;return a}function Dv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;jX(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){kX(b)}return a|0}function zta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(uh(715827882)>>>0<b>>>0){ed();p()}d=Ec(D(b,6));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+D(x[c+12>>2],6)|0,x[e>>2]=f;fb=c+16|0}function zka(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],16);a:{if(!d){a=0;while(1){if((a|0)!=16){dh(a+b|0);a=a+1|0;continue}break}break a}fE(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function j$(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1179011410|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1179472708)){return 1}return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179472708}function eta(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=64){rp(a+b|0);a=a+2|0;continue}break}break a}mw(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function _ra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a+480180>>2]=b;sr(c,tr(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;Bu(a+8|0,tr(a));fb=c+16|0}
function Bu(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=42220;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=42072;break a;case 2:c=42068;break a;case 1:break b;case 0:break c}}c=42064;break a}c=42060}x[a>>2]=x[c>>2]}function l_(a){var b=0,c=0,d=0;c=y[a+3|0];b=Aua(c>>>0<3?48:64,0,Bb(y[a+196|0]|y[a+197|0]<<8),0);d=b;b=Aua(Aua(Bb(y[a+198|0]|y[a+199|0]<<8),0,c>>>0<4?4:5,0),hb,Bb(y[a+200|0]|y[a+201|0]<<8),0);a=d+b|0;a=a+512|0;hb=0;return a}function ir(a,b){var c=0,d=0;c=fb-32|0;fb=c;fe(c+24|0,a);fe(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=x[c+24>>2];b=x[c+28>>2];d=x[c+12>>2];if((b|0)==(d|0)){a=rZ(a,b,x[c+8>>2],d)}else{a=1}fb=c+32|0;return!a}function QR(a){var b=0,c=0,d=0;c=fb-544|0;fb=c;a:{if(!(y[a+480210|0]&128)|!x[a+24668>>2]){break a}d=a+112|0;b=1074992;a=qC(c,x[a+24620>>2]);while(1){if((b|0)==1298224){break a}zc(b+d|0,a,538);b=b+872|0;continue}}fb=c+544|0}function Hsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(uh(2147483647)>>>0<b>>>0){ed();p()}d=Ec(b<<1);x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+(x[c+12>>2]<<1)|0,x[e>>2]=f;fb=c+16|0}function HV(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!(c&32)){break a}c=zd(b);x[d+12>>2]=c;f=Df(b);while(1){if(!Ib(c,f)){break a}e=y[c|0];if((e-97&255)>>>0<=25){v[c|0]=e-32}c=x[we(d+12|0)>>2];continue}}Uc(a,b);fb=d+16|0}function uH(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+24>>2]=a;x[f+28>>2]=b;x[f+16>>2]=d;x[f+20>>2]=e;x[f+8>>2]=c;x[f+12>>2]=0;a=t0(f+24|0,f+8|0);b=f+16|0;a=ft(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?a:b;fb=f+32|0;return x[a>>2]}function Jt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Kb(a);Dg(d+e|0,b,c);b=c+e|0;lg(a,b);hd(b+d|0,0);return a|0}Zp(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a|0}function Epa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){dh(a+b|0);a=a+1|0;continue}break}break a}XD(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function au(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=x[b>>2];b=oc(d,x[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){fb=c+16|0}else{x[c+12>>2]=0;e=tc(c+12|0);f=yb(d,a),g=x[e>>2],x[f>>2]=g;a=a+1|0;continue}break}}function Cv(a,b){var c=0,d=0,e=0;if(x[a>>2]){Z$(a);c=x[a>>2];tE(a);Db(c);d=Ab(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0}function qha(a){a=a|0;var b=0;ib[x[x[a>>2]+132>>2]](a);Wz(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=ib[x[x[a>>2]+196>>2]](a)|0;x[a+4328>>2]=0;x[a+4312>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4324>>2]=b;x[a+4320>>2]=b}function SS(a,b){var c=0,d=0,e=0,f=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];d=Ab(a);c=gc(a);a:{if(!x[d>>2]){x[a>>2]=c;break a}x[x[c>>2]+8>>2]=c;c=gc(b);x[b>>2]=c;x[c>>2]=0;e=Ab(b),f=0,x[e>>2]=f}return a}function Qx(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;g=Ff(f+8|0,d);x[31609]=0;h=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=h;a=hg(e,a,b,c,f);b=x[31609];x[31609]=0;if((b|0)!=1){me(d);fb=f+16|0;return a}a=N()|0;me(d);Q(a|0);p()}function NA(a,b){var c=0;c=x[b+24>>2];c=c>>>0<=1?1:c;x[a+24628>>2]=c>>>0>=512?512:c;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}zc(a+24604|0,b,40);LR(a,c)}function GW(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){v[d+14|0]=(z[(b<<1)+30990>>1]-z[(c<<1)+30990>>1]|0)/5;a=y[Qb(d+15|0,d+14|0)|0]}fb=d+16|0;return a&255}function jta(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(uh(1073741823)>>>0<=8191){ed();p()}c=Ec(32768);x[b+12>>2]=8192;x[b+8>>2]=c;c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=Ab(a),e=c+(x[b+12>>2]<<2)|0,x[d>>2]=e;fb=b+16|0}function gX(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=vb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-56|0;ar(b);continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];dX(a);Db(b)}fb=c+16|0}function fra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=-1;a:{if(!hk(a,d+8|0)){break a}e=x[d+12>>2];c=0;if(!(x[d+8>>2]==(Dn(8994)|0)&e>>>0>255&e>>>0<260)){break a}c=xe(a,b,e>>>0<259?80:76,0)}fb=d+16|0;return c|0}function _h(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;cc(d+8|0,b,c);e=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(a,x[d+12>>2])}fb=d+16|0;a=(e|0)==(f|0);if(!a){Rb(b,0,c)}return a}function St(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!fz(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=ff(a)}return b}_(15776,13274,1578,5429);p()}function PY(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function O_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=777268804){break a}if($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Bb(y[a+8|0]|y[a+9|0]<<8)}return b}function Ada(a,b){a=a|0;b=b|0;var c=0;a=x[a+8>>2];a:{if(Ad(x[b+4>>2],y[b+11|0])){c=0}else{c=a;if(Nd(b,47296)){break a}c=a+88|0;if(Nd(b,47308)){break a}c=a+92|0;if(Nd(b,47320)){break a}c=Nd(b,47333)?a+96|0:0}}return c|0}function wB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=x[b+480180>>2];if(f&64671904){b=y[(d&15)+42144|0];v[a+2|0]=0;w[a>>1]=b;return}g=a;a=(c&255)==4&(f|0)==4;c=(d&255)<<a<<4;Yl(g,(h=Ob(b+1074312|0,66)?0:c,i=c,j=e,j?h:i),a)}function EF(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;eh(a,c+15|0);d=v[c+15|0]}fb=c+16|0;a=d<<24>>24;break a}_(11251,9095,325,14260);p()}return a}function DU(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function rr(a,b,c){var d=0,e=0;e=z[a+480192>>1];a:{if(e){if(!Tc(b)|c>>>0>e>>>0){break a}c=x[((c<<2)+a|0)+900380>>2];if(!c){break a}d=z[ac(c+236|0,b-1|0)>>1];break a}d=c}return(z[a+480190>>1]>=(d&65535)>>>0?d:0)&65535}function Aua(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;hb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function xL(a,b){var c=0,d=0,e=0;c=fb-256|0;fb=c;if((b|0)>=2){x[(b<<2)+a>>2]=c;zc(c,x[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;zc(x[e>>2],x[(d<<2)+a>>2],4);x[e>>2]=x[e>>2]+4;if((b|0)!=(d|0)){continue}break}}fb=c+256|0}function jZ(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;f=x[a+8>>2];d=e+4|0;x[d+8>>2]=a+8;x[d>>2]=f;x[d+4>>2]=D(b,6)+f;b=x[d>>2];while(1){if(x[d+4>>2]!=(b|0)){sD(b,c);b=x[d>>2]+6|0;x[d>>2]=b;continue}break}je(d);fb=e+16|0}function fba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=d+4|0;$M(e,c);a=x[a+1298472>>2];x[31609]=0;S(385,a|0,b|0,e|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(e);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function dz(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!Rt(a)){break a}if(!(v[a+1375|0]&1)){continue}break}bc(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function gU(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=e*C[a+16>>3]+(C[a>>3]*b+c*C[a+8>>3])-d*C[a+24>>3]-f*C[a+32>>3];C[a+56>>3]=b;return b}function mo(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function fV(a){var b=0;b=w[a+784>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+784>>1]=0}b=y[a+795|0];if(b){v[a+795|0]=0;v[a+838|0]=b-1}b=y[a+796|0];if(b){v[a+796|0]=0;v[a+837|0]=b-1}}function VI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=a;a=lk(Kb(b));x[d>>2]=a;a:{if(!a){a=c+4|0;Mm(a,17634,b);x[31609]=0;W(1367,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=c+16|0;return}p()}function LS(a,b,c,d){var e=0,f=0;b=D(c,872)+b|0;e=x[b+704>>2];a:{if(!(!(e&67109888)|(d|0)!=1)|e&33554432){break a}b=z[(b+616|0)+786>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=y[((b<<5)+a|0)+480288|0]}return f}function Gq(a,b){a=zc(a,b,88);x[a+88>>2]=x[b+88>>2];zc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];zc(a+672|0,b+672|0,52);jB(a+724|0,b+724|0);jB(a+732|0,b+732|0);jB(a+740|0,b+740|0);zc(a+748|0,b+748|0,123);return a}function vra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=If(a,c);ae(e,x[a+36>>2]);a:{if(!c){Qc(e,a+32|0,5);f=0;if(Gb(x[x[e>>2]>>2],x[e+4>>2])){break a}}wZ(x[a+36>>2],b,d,0);f=c}ef(a,f);fb=e+16|0}function UI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=lk(Kb(b));x[a>>2]=d;a:{if(!d){a=c+4|0;Mm(a,17675,b);x[31609]=0;W(1367,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}fb=c+16|0;return a}p()}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Vg(a)>>>0<b>>>0){if(uh(1073741823)>>>0<b>>>0){break a}d=Ab(a);e=a;a=Zf(c+12|0,b,oc(x[a>>2],x[a+4>>2]),d);Sm(e,a);Yf(a)}fb=c+32|0;return}ed();p()}function xoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(cl(a)>>>0<b>>>0){if(uh(357913941)>>>0<b>>>0){break a}d=Ab(a);e=a;a=ym(c+12|0,b,Ud(x[a>>2],x[a+4>>2]),d);qW(e,a);pW(a)}fb=c+32|0;return}ed();p()}function xY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Hn(a)>>>0<b>>>0){if(uh(2147483647)>>>0<b>>>0){break a}d=Ab(a);e=a;a=ek(c+12|0,b,$c(x[a>>2],x[a+4>>2]),d);Ur(e,a);aj(a)}fb=c+32|0;return}ed();p()}function fG(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Nk(c)){Ne(a,c);break a}qg(d+8|0,Fh(c)+1|0);e=x[d+8>>2];yd(a,e);of(a,x[d+12>>2]);Bd(a,c);a=e}hd(Xg(a,b,c)+c|0,0);fb=d+16|0;return}pf();p()}function Zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Sn(a)>>>0<b>>>0){if(uh(536870911)>>>0<b>>>0){break a}d=Ab(a);e=a;a=js(c+12|0,b,ih(x[a>>2],x[a+4>>2]),d);MB(e,a);is(a)}fb=c+32|0;return}ed();p()}function Vm(a,b){var c=E(0),d=0,e=0;c=E(1);d=w[a+28>>1];a:{if((d|0)>(b|0)){break a}e=x[a+4>>2];if((oc(e,x[a+8>>2])+d|0)-1<<16>>16<(b|0)){break a}c=B[yb(e,b-d|0)>>2];c=c<=E(10000000036274937e-31)?E(1):c}return c}function Uk(a){xc(a+16|0,x[a>>2]);xc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function Sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=If(a,c);ae(e,x[a+36>>2]);a:{if(!c){Qc(e,a+32|0,5);f=0;if(Gb(x[x[e>>2]>>2],x[e+4>>2])){break a}}PQ(d,x[a+36>>2],b);f=c}ef(a,f);fb=e+16|0}function SD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;x_(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){y_(b)}return a}function Pka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(HB(a)>>>0<b>>>0){if(uh(613566756)>>>0<b>>>0){break a}d=Ab(a);e=a;a=IT(c+12|0,b,GB(x[a>>2],x[a+4>>2]),d);HT(e,a);GT(a)}fb=c+32|0;return}ed();p()}function Nja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(cl(a)>>>0<b>>>0){if(uh(357913941)>>>0<b>>>0){break a}d=Ab(a);e=a;a=ym(c+12|0,b,Ud(x[a>>2],x[a+4>>2]),d);Bx(e,a);ws(a)}fb=c+32|0;return}ed();p()}function Fu(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Nk(c)){Ne(a,c);break a}qg(d+8|0,Fh(c)+1|0);e=x[d+8>>2];yd(a,e);of(a,x[d+12>>2]);Bd(a,c);a=e}hd(Dg(a,b,c)+c|0,0);fb=d+16|0;return}pf();p()}function CY(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;EY(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){DY(b)}return a}function aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=xj(a);if(d){e=x[b+4>>2];b=x[b>>2];x[c+8>>2]=b;x[c+12>>2]=e;a=x[x[d>>2]+72>>2];x[c>>2]=b;x[c+4>>2]=e;a=ib[a|0](d,c)|0}else{a=1}fb=c+16|0;return a|0}function ZK(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=ib[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!ko(b)){break a}x[a>>2]=0}return a|0}function YM(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=e+8|0;xz(f,b);while(1){if(d){b=x[f+4>>2];h=uh(d);vj(b,c+g|0,h);b=x[x[f+4>>2]+4>>2];d=d-b|0;g=b+g|0;if((b|0)==(h|0)){continue}}break}cc(a,c,g);fb=e+16|0}function LA(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;KR(a+24648|0);QR(a)}function _9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=x[c>>2];c=x[c+4>>2];while(1){if(c){d=x[b+24>>2];g=uh(c);vj(d,e+f|0,g);d=x[x[b+24>>2]+4>>2];c=c-d|0;e=e+d|0;if((d|0)==(g|0)){continue}}break}cc(a,f,e)}function Ux(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function KJ(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;fd(d+24|0,a,b);cD(d+16|0,x[d+24>>2],x[d+28>>2],c);a=lA(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];qc(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function HA(a,b,c){var d=0,e=0;d=x[b+656>>2];if(!d){return 0}d=Nw(d,c);a=a+1074312|0;if(!Ob(a,31)){e=Ob(a,93)^1}a:{if(!(v[FR(b,c)+6|0]&1)){a=0;if(!(v[d+12|0]&1)|e){break a}}a=mc(x[d>>2],x[d+4>>2])^1}return a}
function iga(a){a=a|0;var b=0;b=fb-16|0;fb=b;a:{if(!Nd(a,10281)){b=b+4|0;Mm(b,18221,a);a=Kb(b);x[31609]=0;O(67,44,a|0);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;tb(b);Q(a|0);p()}fb=b+16|0;return}p()}function TC(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=xG(a);a:while(1){if((a|0)!=(e|0)){f=ud(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((y[xb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function rv(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;fd(d+24|0,a,b);cv(d+16|0,x[d+24>>2],x[d+28>>2],c);a=x[d+16>>2];f=d,g=_D(c,x[d+20>>2]),x[f+12>>2]=g;qc(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0}function qoa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;jn(a,b);b=wb(x[a>>2]);x[c+12>>2]=b;a=wb(x[a+4>>2]);while(1){if(Ib(b,a)){d=y[b|0]+(d&255)|0;v[b|0]=d;b=x[we(c+12|0)>>2];continue}else{fb=c+16|0}break}}function IE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function HS(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function xi(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;cc(d+8|0,b,c);e=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Vb(a,x[d+12>>2])}fb=d+16|0;if((e|0)!=(f|0)){Rb(b,0,c)}}function qd(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];lf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);lf(a,x[e+24>>2],x[e+28>>2]);fb=e+32|0}function Opa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;w[b+30>>1]=0;c=Zb(b+8|0,b+30|0,2);kc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);if(!(x[b+24>>2]!=2|z[b+30>>1]!=21584)){Vb(a,2);d=1}fb=b+32|0;return d|0}function Kd(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;eh(a,c+15|0);d=y[c+15|0]}fb=c+16|0;break a}_(11251,9095,325,14260);p()}return d}function Gda(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;$M(d,b);a=x[a+1298472>>2];x[31609]=0;S(385,a|0,1,d|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(d);fb=c+16|0;return}a=N()|0;tb(c+4|0);Q(a|0);p()}function $ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Nb(a);d=og(a+12|0);v[a+32|0]=c;x[a+28>>2]=0;x[a+24>>2]=b;x[31609]=0;O(801,a|0,1);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;_T(d);cU(a);Q(b|0);p()}function ela(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],27)){a=0;while(1){if((a|0)!=27){dh(a+b|0);a=a+1|0;continue}break}break a}sU(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Jta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],64)){a=0;while(1){if((a|0)!=64){dh(a+b|0);a=a+1|0;continue}break}break a}mw(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function IO(a,b){var c=0,d=0;c=-1;a:{if((b|0)<0){break a}d=x[a+24>>2];if(Hj(Xb(x[d+484360>>2],y[d+484376|0]))>>>0<=b>>>0){break a}a=x[a+24>>2];c=z[ac(x[Xb(x[a+484360>>2],y[a+484376|0])>>2],b)>>1]}return c}function FU(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=x[c>>2];if(d){Po(d);EU(x[c>>2])}b=b+1|0;continue}break}}function zga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;b=Gc(Bua(Aua(d,d>>31,b,0),hb,1e3,0),hb);x[a+16>>2]=0;x[a+12>>2]=b+c;RP(a,e);b=x[a+12>>2];x[f+12>>2]=0;SQ(a,b,f+12|0);fb=f+16|0}function eG(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=808603728|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function Wf(a,b,c,d,e){var f=0;f=fb-256|0;fb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Rb(f,b&255,c?d:256);if(!c){while(1){Kf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}Kf(a,f,d)}fb=f+256|0}function Jz(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=fb-32|0;fb=b;x[b+24>>2]=e;x[b+28>>2]=f;c=Zb(b+16|0,c,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a=Au(a,b+8|0,b+24|0);fb=b+32|0;return a|0}function Gw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],32)){a=0;while(1){if((a|0)!=32){dh(a+b|0);a=a+1|0;continue}break}break a}PE(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function E3(a){a=a|0;var b=0;a:{b:{if(!a){break b}b=il(a);if(lI(b,-1)|y[b+13|0]){break b}b=x[b+8>>2];if(b){x[31609]=0;R(b|0,a|0)|0;b=x[31609];x[31609]=0;if((b|0)==1){break a}}lc(a)}return}T(0)|0;Sb();p()}function ue(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Gd(b)}return c}function to(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(ap(a)>>>0<b>>>0){if(uh(-1)>>>0<b>>>0){break a}d=Ab(a);e=a;a=pn(c+12|0,b,Xc(x[a>>2],x[a+4>>2]),d);cr(e,a);on(a)}fb=c+32|0;return}ed();p()}function dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;c=If(a,c);ae(d,x[a+36>>2]);a:{if(!c){Qc(d,a+32|0,5);e=0;if(Gb(x[x[d>>2]>>2],x[d+4>>2])){break a}}AZ(x[a+36>>2],b,a);e=c}ef(a,e);fb=d+16|0}function Xh(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;_k(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function Uca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=x[a+4>>2];b=jg(d+4|0,b);x[31609]=0;V(1012,a|0,b|0,c|0,1);a=x[31609];x[31609]=0;if((a|0)!=1){tb(b);fb=d+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function RX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=wb(a);x[c+12>>2]=d;b=Yj(a,b);a=0;while(1){if(Ib(d,b)){e=a;a=v[d|0];a=e+((a&255)!=0&(a|0)<32)|0;d=x[we(c+12|0)>>2];continue}else{fb=c+16|0}break}return a}function Lna(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if((b|0)>=0){d=2147483647;a=hv(a);if(a>>>0<=1073741822){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[bd(c+12|0,c+8|0)>>2]}fb=c+16|0;return d|0}ed();p()}function JY(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;XD(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function GN(a,b){a=a|0;b=b|0;var c=0;a=Dj(a);x[a+4>>2]=0;x[a>>2]=47568;if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22292}c=Gd(Ef(b)+1|0);x[a+4>>2]=c;if(c){zc(c,b,Ef(b)+1|0)}return a|0}function ki(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;c=2;if(a>>>0>=2){x[b+12>>2]=a>>>1;x[b+8>>2]=a^-1;d=b,e=x[Hb(b+12|0,b+8|0)>>2]+a|0,x[d+12>>2]=e;x[b+8>>2]=-1;c=x[Hb(b+12|0,b+8|0)>>2]}fb=b+16|0;return c}function e0(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],8)){a=0;while(1){if((a|0)!=8){dh(a+b|0);a=a+1|0;continue}break}break a}_k(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function dK(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){rg(g+13|0,g+14|0)}h=c,i=(fa(b|0,Xc(b,x[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,x[h>>2]=i;fb=g+16|0}function Kha(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{if(Vg(a)>>>0<=12){if(uh(1073741823)>>>0<=12){break a}c=Ab(a);d=a;a=Zf(b+12|0,13,oc(x[a>>2],x[a+4>>2]),c);Sm(d,a);Yf(a)}fb=b+32|0;return}ed();p()}function ul(a){a=a|0;var b=0;x[a>>2]=94580;x[31609]=0;O(113,a|0,0);b=x[31609];x[31609]=0;if((b|0)!=1){_b(a+28|0);Db(x[a+32>>2]);Db(x[a+36>>2]);Db(x[a+48>>2]);Db(x[a+60>>2]);return a|0}T(0)|0;Sb();p()}function l9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;f=x[x[b>>2]+20>>2];e=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=e;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;ib[f|0](a,b,d,8);fb=d+16|0}function ce(a,b){var c=0,d=0,e=0;d=z[a+24>>1];if((d|0)!=(b&65535)){c=z[a+22>>1]-1&127;w[a+22>>1]=c;e=z[a+20>>1];if(e>>>0<=127){w[a+20>>1]=e+1}c=(a+26|0)+(c<<2)|0;w[c>>1]=b-d;w[c+2>>1]=0;w[a+24>>1]=b}}function bS(a,b,c){var d=0,e=0;d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Kb(a);Xg(d+e|0,b,c);b=c+e|0;lg(a,b);hd(b+d|0,0);return a}Uq(a,d,(c-d|0)+e|0,e,e,0,c,b)}return a}function Wba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;b=x[b+4>>2];c=jg(d+4|0,c);x[31609]=0;S(998,a|0,b|0,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){tb(c);fb=d+16|0;return}a=N()|0;tb(c);Q(a|0);p()}function BX(a,b){a=a|0;b=b|0;var c=0,d=0;d=x[a>>2];c=65535;a:{if(!Je(d,x[a+4>>2],b)){break a}d=jE(a,x[_i(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=x[a>>2];a=_i(c,b);fR(_i(c,d),a);c=d}return c|0}function AJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(1073741823)>>>0<b>>>0){ed();p()}iJ(c+8|0,it(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function zx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Cb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){dn();p()}b=Kb(b);x[e+8>>2]=d-c;Fu(a,b+c|0,x[Hb(e+12|0,e+8|0)>>2]);fb=e+16|0}function c$(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=443372356|y[a+4|0]!=32|(!y[a+46|0]|(y[a+45|0]-17&255)>>>0<240)){break a}if(!y[a+47|0]){break a}b=y[a+49|0]<101}return b}function VZ(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=xh(d+4|0,a,1);a=x[c+4>>2];e=x[c+8>>2];while(1){if((a|0)==(e|0)){jc(c);fb=d+16|0}else{cp(a,z[b>>1]|z[b+2>>1]<<16);a=a+4|0;x[c+4>>2]=a;continue}break}}function V2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Cb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){dn();p()}b=Kb(b);x[e+8>>2]=d-c;fG(a,b+c|0,x[Hb(e+12|0,e+8|0)>>2]);fb=e+16|0}function P2(a,b){a=a|0;b=b|0;var c=0;a=Pt(a);x[a>>2]=93384;b=Uc(a+32|0,b);x[a+44>>2]=0;x[a+48>>2]=8;x[31609]=0;W(112,a|0);c=x[31609];x[31609]=0;if((c|0)!=1){return a|0}c=N()|0;tb(b);ho(a);Q(c|0);p()}function Hw(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],256)){a=0;while(1){if((a|0)!=256){dh(a+b|0);a=a+1|0;continue}break}break a}cc(c+8|0,b,256);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function w_(a){var b=0,c=0,d=0;a:{if(jd(a,22281,11)){break a}b=63;while(1){d=(b|0)==215;if(d){break a}c=a+b|0;if(y[c+16|0]>3|y[c+17|0]>3){break a}b=b+19|0;if(y[c+18|0]<16){continue}break}}return d}function iU(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function ys(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(b){d=Mc(a);e=Cb(x[a+4>>2],y[a+11|0]);if(d-e>>>0<b>>>0){an(a,d,(b-d|0)+e|0,e,e,0,0)}d=Kb(a);$l(d+e|0,b,c);b=b+e|0;lg(a,b);hd(b+d|0,0)}return a|0}function sj(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[d+8>>2]=b;x[d+12>>2]=a;f=x[c>>2];c=x[c+4>>2];x[d>>2]=b;x[d+4>>2]=a;Nz(e,d,f,c,1);fb=d+16|0}function oV(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15|0;b=1;if((a&255)>>>0>2){break a}b=131842>>>(a<<3&248)|0}return b&255}function nX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;jX(c+8|0,b);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){kX(b)}return a}function hk(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;_k(c+8|0,b);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){$k(b)}return a}function dE(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;zr(c+8|0,b);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){i$(b)}return a}function d$(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;mw(c+8|0,b);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){fw(b)}return a}function cqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(1073741823)>>>0<b>>>0){ed();p()}KF(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function ZO(a,b){var c=E(0),d=E(0);if(!((b|0)<0|z[a+480188>>1]<=b>>>0)){a=D(b,872)+a|0;c=E(E(y[a+1075834|0])*E(.0078125));d=E(c*c);c=E(E(y[a+1075835|0])*E(.0078125));c=E(M(E(d+E(c*c))))}return c}function ZF(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;bs(c+8|0,b);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){cs(b)}return a}function XX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(!Nn(b,a)|!c){break a}mh(d+8|0,a);a=0;while(1){if(a>>>0>=4){break a}b=x[d+8>>2];rg(xb(b,a),xb(b,a|1));a=a+2|0;continue}}fb=d+16|0}function TR(a){var b=0,c=0;a=a+906300|0;c=uk(a);while(1){if((a|0)!=(c|0)){b=x[a>>2];a:{if(!b){break a}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break a}ib[x[x[b>>2]+100>>2]](b)}a=a+160|0;continue}break}}function KW(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;jx(c+8|0,b);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){kx(b)}return a}function JG(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;HG(c+8|0,b);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){ux(b)}return a}function G$(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;lw(c+8|0,b);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){oE(b)}return a}function FW(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;x_(c+8|0,b);d=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){y_(b)}return a}function Dr(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Bja(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;a:{if(!hk(a,b+8|0)){break a}c=0;if(!qR(x[b+8>>2],x[b+12>>2])){break a}c=-1;if(!eF(a,b+4|0)){break a}c=pR(x[b+4>>2])}fb=b+16|0;return c|0}function sia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);d=fb-16|0;fb=d;e=d,f=E(E(ib[x[x[a>>2]+48>>2]](a,b))+c),B[e+12>>2]=f;zT(d+12|0,E(0),E(1));ib[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);fb=d+16|0}function m0(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],512)){a=0;while(1){if((a|0)!=512){Cn(a+b|0);a=a+4|0;continue}break}break a}zE(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function jm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(1073741823)>>>0<b>>>0){ed();p()}Nj(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function gE(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Yb(128/(D(x[Ye(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=cf(c+7|0,c+6|0);fb=c+16|0;return y[a|0]|b<<4&240}function X0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(214748364)>>>0<b>>>0){ed();p()}RE(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+D(x[c+12>>2],20)|0,x[d>>2]=e;fb=c+16|0}function Tka(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(uh(2147483647)>>>0<=2303){ed();p()}Zw(b+8|0,2304);c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=Ab(a),e=(x[b+12>>2]<<1)+c|0,x[d>>2]=e;fb=b+16|0}function S9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(357913941)>>>0<b>>>0){ed();p()}VG(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+D(x[c+12>>2],12)|0,x[d>>2]=e;fb=c+16|0}function JC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(2147483647)>>>0<b>>>0){ed();p()}Zw(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<1)|0,x[d>>2]=e;fb=c+16|0}function xZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(715827882)>>>0<b>>>0){ed();p()}hZ(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+D(x[c+12>>2],6)|0,x[d>>2]=e;fb=c+16|0}function fU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(536870911)>>>0<b>>>0){ed();p()}qG(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<3)|0,x[d>>2]=e;fb=c+16|0}function eU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(268435455)>>>0<b>>>0){ed();p()}LV(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<4)|0,x[d>>2]=e;fb=c+16|0}function _p(a,b,c){var d=0;d=fb-16|0;fb=d;if(y[b|0]){x[d+8>>2]=0;x[d+12>>2]=0;b=py(d+4|0,b,Ef(b),d+8|0,c);if(b>>>0<=4294967293){x[a>>2]=x[d+4>>2]}a=b>>>0<4294967294}else{a=0}fb=d+16|0;return a}function SL(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=B[e>>2];c=c+h|0;g=B[c>>2];B[e>>2]=f+g;B[c>>2]=f-g;d=d+1|0;continue}break}}function JS(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=hs(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){jc(a);fb=d+16|0}else{IS(b,x[c>>2],x[c+4>>2]);b=b+8|0;x[a+4>>2]=b;continue}break}}function AZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;ng(a,d+14|0);e=z[d+14>>1];ZR(b,e);c=0;while(1){if((c|0)==(e|0)){QA(b);fb=d+16|0}else{Gk(a,yb(x[b>>2],c));c=c+1|0;continue}break}}function faa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=x[d+4>>2];g=x[d>>2];x[e+8>>2]=g;x[e+12>>2]=f;d=x[x[b>>2]+40>>2];x[e>>2]=g;x[e+4>>2]=f;ib[d|0](a,b,c,e);fb=e+16|0}function Vja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=z[a+28>>1];w[d+12>>1]=e;f=d,g=(oc(x[a+4>>2],x[a+8>>2])+e|0)-1|0,w[f+14>>1]=g;a=UQ(a,b,c,d+12|0);fb=d+16|0;return a|0}function OA(a,b){var c=0;a=iW(a,b);v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function kc(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;lf(f+16|0,d,e);d=x[x[b>>2]+28>>2];e=x[f+20>>2];x[f+8>>2]=x[f+16>>2];x[f+12>>2]=e;ib[d|0](f+24|0,b,c,f+8|0);lf(a,x[f+24>>2],x[f+28>>2]);fb=f+32|0}function fk(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(2147483647);if(d>>>0<=b>>>0){a=Hn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function ZI(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=95212;d=a+8|0;while(1){b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0>c>>>0){b=x[yb(b,c)>>2];if(b){um(b)}c=c+1|0;continue}break}tb(a+152|0);oy(d);return a|0}function Lf(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(1073741823);if(d>>>0<=b>>>0){a=Vg(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function Ej(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Ql(a,b);if((d|0)==255){break a}yk(a,b);Pq(a,b,0,0);if(!c){break a}e=ac(a+26|0,d),f=65535,w[e>>1]=f;a=xb(a+62|0,b);v[a|0]=y[a|0]|128}}function tD(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(715827882);if(d>>>0<=b>>>0){a=hw(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function mG(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(119304647);if(d>>>0<=b>>>0){a=hx(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function ks(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(536870911);if(d>>>0<=b>>>0){a=Sn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function ZM(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=Ec(1298480);x[31609]=0;c=R(1127,b|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){b=yf(a+12|0,c);fb=a+16|0;return x[b>>2]}a=N()|0;Db(b);Q(a|0);p()}function Wq(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(134217727);if(d>>>0<=b>>>0){a=Zo(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function VD(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(214748364);if(d>>>0<=b>>>0){a=TE(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function Qp(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(357913941);if(d>>>0<=b>>>0){a=cl(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function NV(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(268435455);if(d>>>0<=b>>>0){a=kv(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function JD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=(mq(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),C[d+8>>3]=e;AT(c+8|0,127);a=Zl(C[c+8>>3]);fb=c+16|0;return a}function IJ(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(178956970);if(d>>>0<=b>>>0){a=jt(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function zu(a){var b=0;x[31609]=0;a=R(852,a|0)|0;b=x[31609];x[31609]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31609]=0;X(26);b=x[31609];x[31609]=0;a=0;if((b|0)==1){break a}}return a}T(0)|0;Sb();p()}function xI(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function x$(a,b){var c=0,d=0;c=fb-16|0;fb=c;fE(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function vV(a){var b=0,c=0,d=0;c=y[a+64|0]|y[a+65|0]<<8;b=y[a+72|0]|y[a+73|0]<<8;a=y[a+70|0]|y[a+71|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<2|b>>>30;b=b<<2;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function tX(a,b){var c=0,d=0;c=fb-16|0;fb=c;gD(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function lx(a,b){var c=0,d=0;c=fb-16|0;fb=c;jx(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function l$(a,b){var c=0,d=0;c=fb-16|0;fb=c;lw(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function gG(a,b){var c=0,d=0;c=fb-16|0;fb=c;HG(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function gA(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Ab(a);c=Zf(d+12|0,Lf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);vq(x[c+8>>2],x[b>>2]);x[c+8>>2]=x[c+8>>2]+4;Sm(a,c);Yf(c);fb=d+32|0}function g$(a,b){var c=0,d=0;c=fb-16|0;fb=c;mw(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function eh(a,b){var c=0,d=0;c=fb-16|0;fb=c;Vr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function e$(a,b){var c=0,d=0;c=fb-16|0;fb=c;zr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function cR(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(82595524);if(d>>>0<=b>>>0){a=Cu(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function bZ(a,b){var c=0,d=0;c=fb-16|0;fb=c;aZ(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function _F(a,b){var c=0,d=0;c=fb-16|0;fb=c;bs(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function Uw(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function TX(a,b){var c=0,d=0;c=fb-16|0;fb=c;Gv(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function RC(a,b){var c=0,d=0;c=fb-16|0;fb=c;WC(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function PW(a){var b=0,c=0,d=0;c=y[a+32|0]|y[a+33|0]<<8;b=y[a+36|0]|y[a+37|0]<<8;a=y[a+34|0]|y[a+35|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<1|b>>>31;b=b<<1;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function Nn(a,b){var c=0,d=0;c=fb-16|0;fb=c;mh(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function Jx(a,b,c){var d=0;d=fb-16|0;fb=d;cc(d+8|0,b,c);b=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);c=x[d+4>>2];if((b|0)==(c|0)){Vb(a,x[d+12>>2])}fb=d+16|0;return(b|0)==(c|0)}function EB(a,b,c,d){var e=0,f=0,g=0;e=c-b|0;a:{if((e|0)<=9){g=e;e=D(32-G(d|1)|0,1233)>>>12|0;f=61;if((g|0)<(e+(A[(e<<2)+121088>>2]<=d>>>0)|0)){break a}}c=AB(b,d);f=0}x[a+4>>2]=f;x[a>>2]=c}function Dp(a,b){var c=0,d=0;c=fb-16|0;fb=c;Cp(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function C0(a,b){var c=0,d=0;c=fb-16|0;fb=c;B0(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function BE(a,b){var c=0,d=0;c=fb-16|0;fb=c;_j(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function AE(a,b){var c=0,d=0;c=fb-16|0;fb=c;Jr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Vb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function qT(a,b,c,d){a:{if((a|0)!=67108864){break a}a=c+616|0;c=a+D(d,872)|0;x[c+88>>2]=x[c+88>>2]&-129;c=b&65535;b=d^1;if(c>>>0<=b>>>0){break a}a=a+D(b,872)|0;x[a+88>>2]=x[a+88>>2]&-129}}function bM(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Ab(a);c=pn(d+12|0,Vl(a,Xc(x[a>>2],x[a+4>>2])+1|0),Xc(x[a>>2],x[a+4>>2]),c);qo(x[c+8>>2],y[b|0]);x[c+8>>2]=x[c+8>>2]+1;cr(a,c);on(c);fb=d+32|0}function OU(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;v[a+16|0]=0;c=bC(b,x[a+12>>2]);x[31609]=0;O(783,a|0,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){Ak(c);fb=b+32|0;return}a=N()|0;Ak(c);Q(a|0);p()}function Gz(a,b,c,d,e,f,g,h,i){var j=0;j=fb-16|0;fb=j;Ug(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;fb=j+16|0}function Tf(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb+-64|0;fb=c;d=rA(c+12|0,a);x[31609]=0;S(199,a|0,b|0,d|0);a=x[31609];x[31609]=0;if((a|0)!=1){vk(d);fb=c- -64|0;return}a=N()|0;vk(d);Q(a|0);p()}function zg(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;x[a+8>>2]=x[c+8>>2];v[a+12|0]=0;fb=c+16|0}function rZ(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=TG(a,c,x[Hb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}fb=e+16|0;return c}function o_(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=ot(a,c,x[Hb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}fb=e+16|0;return c}function hi(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function S3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=Mz(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;zc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function Pfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=oP(f,b,c,d,0,0,0,0,e);fb=f+16|0;return a|0}function Gk(a,b){var c=0,d=0;c=fb-32|0;fb=c;x[c+28>>2]=0;cy(c+8|0,c+28|0);d=c+20|0;Nm(d,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];Lm(d,x[c+28>>2]);x[b>>2]=x[c+20>>2];fb=c+32|0;return(a|0)==4}function uo(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(!PM(y[a+20|0])){x[31609]=0;O(1134,b+15|0,a|0);c=x[31609];x[31609]=0;if((c|0)==1){break a}}v[a+20|0]=255;fb=b+16|0;return}T(0)|0;Sb();p()}function Yt(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=x[a+4>>2];d=((b<<2)+(Sw(x[a>>2],1)^270549120)|0)+2019860093|0;x[a>>2]=d;b=b+D(Sw(d,16),5)|0;x[a+4>>2]=b;continue}break}return b}function WG(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Ab(a);c=ym(d+12|0,Qp(a,Ud(x[a>>2],x[a+4>>2])+1|0),Ud(x[a>>2],x[a+4>>2]),c);xs(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;Bx(a,c);ws(c);fb=d+32|0}function Sra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],12);a:{if(!d){v[c|0]=0;Sh(b,12,c);break a}zr(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function tp(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=bj(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){jc(a);fb=d+16|0}else{mm(b,z[c>>1]);b=b+2|0;x[a+4>>2]=b;continue}break}}function oA(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=xh(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){jc(a);fb=d+16|0}else{tk(b,B[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function XE(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=xh(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){jc(a);fb=d+16|0}else{vq(b,x[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function Vl(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=uh(-1);if(d>>>0<=b>>>0){a=ap(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[bd(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}ed();p()}function Th(a,b){var c=0;b=Vc(b);c=x[a+8>>2];if(oc(c,x[a+12>>2])>>>0>b>>>0){a=x[yb(c,b)>>2]!=0}else{a=0}if(!a){a=Dj(dc(4));x[a>>2]=124996;da(a|0,125132,1229);p()}return x[yb(c,b)>>2]}function Ll(a){var b=0;a=li(a);b=2147483647;a:{if(a>=E(2147483648)){break a}b=-2147483648;if(a<=E(-2147483648)){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function EP(a){var b=0,c=0;if(!a){return 1}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(F(c)<2147483648){a=~~c;break a}a=-2147483648}b=Ai(b-+(a|0))}else{b=0}return b}function C7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Kb(a);return qk(g,h,c,d,e,f,b,b+(Cb(x[a+4>>2],y[a+11|0])<<2)|0)|0}function Xra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;YY(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<2);if(c){XY(d+8|0,x[b>>2],x[b+4>>2]);sd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function Xr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if((b|0)<0){ed();p()}KF(c+8|0,(b-1>>>5|0)+1|0);b=x[c+8>>2];x[a+4>>2]=0;x[a>>2]=b;d=Ab(a),e=x[c+12>>2],x[d>>2]=e;fb=c+16|0}function Wna(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){v[c|0]=0;f$(b,4,c);break a}mh(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Km(a,b){x[a+28>>2]=0;w[a+24>>1]=65535;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;v[a|0]=0;x[a+32>>2]=11;x[a+36>>2]=b;Nb(a+40|0);Nb(a+52|0);Rb(a- -64|0,0,48);return a}function BP(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=AP(f,b,c,d,e,0,0,0,0);fb=f+16|0;return+c}function Ap(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Yo(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){jc(a);fb=d+16|0}else{qo(b,y[c|0]);b=b+1|0;x[a+4>>2]=b;continue}break}}function n2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;sG(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<3);if(c){rG(d+8|0,x[b>>2],x[b+4>>2]);sd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function c2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=ib[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function Zt(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+12>>2]=12;while(1){x[b+8>>2]=32;if(A[Hb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&4095}else{c=c+15|0;d=Do(a);continue}break}return a}function Vk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(uh(-1)>>>0<b>>>0){ed();p()}qg(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+x[c+12>>2]|0,x[d>>2]=e;fb=c+16|0}function LB(a){var b=0,c=0;b=x[a>>2];c=x[b>>2];a:{if(!c){while(1){c=mi(b);b=x[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=x[b+4>>2];if(c){continue}break}}x[a>>2]=b;return a}function Hu(a,b){var c=0;a=uS(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c}function m2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(Xc(x[c>>2],x[c+4>>2])>>>0>=a>>>0){break a}Jk(c,a)}return!d|0}function _na(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;hW(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<8)){c=x[b>>2];cc(d+8|0,c,Rh(c,x[b+4>>2])<<8);sd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function toa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;d=b+8|0;c=-1;a:{if(!hk(a,d)){break a}c=0;if(!jW(d)){break a}c=-1;if(!jh(a,4)){break a}c=IW(a)>>>31|0}fb=b+16|0;return c|0}function sD(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+4|0]|y[b+5|0]<<8;v[a+4|0]=b;v[a+5|0]=b>>>8}function Yz(a){var b=0,c=0,d=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Do(d)|b<<15;continue}break}C[c+4280>>3]=+(b|0)*-4.656612873077393e-10}function Kh(a,b,c){a:{if(b>>>0<=c>>>0){a=dc(8);x[31609]=0;b=R(188,a|0)|0;c=x[31609];x[31609]=0;if((c|0)!=1){break a}b=N()|0;lc(a);Q(b|0);p()}return y[a+c|0]}da(b|0,24472,162);p()}function GR(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;while(1){x[b+12>>2]=7;x[b+8>>2]=32;if(A[Hb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&127}else{c=c+15|0;d=Do(a);continue}break}return a}function xj(a){var b=0,c=0;b=x[a+20>>2];b=In(y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24));if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[$d(x[a+16>>2]+906300|0,b)>>2]}return c}function sga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=12){c=Pd(c,E(0));d=a+4208|0;if((b|0)==12){c=E(li(E(c*E(3)))/E(3));b=12}e=yb(d,b),f=c,B[e>>2]=f;v[a+5046|0]=1}}function hp(a){var b=0,c=0;b=x[31366];c=a+7&-8;a=b+c|0;a:{if(!(a>>>0<=b>>>0?c:0)){if(a>>>0<=jb()<<16>>>0){break a}if(eb(a|0)|0){break a}}x[31484]=48;return-1}x[31366]=a;return b}function Tl(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function T5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+95344>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function Jra(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;zZ(b,c);yZ(a,c);fb=c+32|0}function I7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Kb(a);return rk(g,h,c,d,e,f,b,Cb(x[a+4>>2],y[a+11|0])+b|0)|0}function xD(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Cr(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){jc(a);fb=d+16|0}else{sD(b,c);b=b+6|0;x[a+4>>2]=b;continue}break}}function kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;pz(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+8|0,d+12|0)>>2]}fb=d+16|0;return c|0}function d3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;a=x[a+4>>2];f=x[b+4>>2];b=x[b>>2];x[e>>2]=b;x[e+4>>2]=f;x[e+8>>2]=b;x[e+12>>2]=f;Oz(a,e,c,d,1);fb=e+16|0}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=x[c>>2];if(f>>>0<Xc(a,b)>>>0){a=rl(e+4|0,xb(a,f),z[c+20>>1]);g=Jy(d,a);Eb(a)}fb=e+16|0;return g|0}function tq(a){var b=0;b=x[a+24>>2];x[31609]=0;W(853,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){Td(a+68|0);nf(a+36|0);Al(a+32|0);wh(a+24|0);vh(a+4|0);return Wc(a)}T(0)|0;Sb();p()}function e3(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b>>2];b=x[b+4>>2];x[c>>2]=d;x[c+4>>2]=b;x[c+8>>2]=d;x[c+12>>2]=b;a=gP(a,c,1);fb=c+16|0;gb=hb;return a|0}function dta(a,b){a=a|0;b=b|0;if(!e$(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0}}function bY(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-24|0;ub(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];jt(a);Db(b)}}function bN(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-16|0;Oj(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];kv(a);Db(b)}}function ST(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;while(1){if(c){f=Ol(z[c+16>>1],x[c+20>>2],a,b);d=f?d:c;c=x[(f?4:0)+c>>2];continue}break}a=vb(e+12|0,d);fb=e+16|0;return x[a>>2]}function KH(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-12|0;Eb(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];cl(a);Db(b)}}function Nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if(Ib(b,c)){x[d+8>>2]=x[b>>2];yA(a,d+8|0);b=x[Xe(d+12|0)>>2];continue}else{fb=d+16|0}break}}function AN(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+24>>2]=0;x[d+12>>2]=4;c=d+16|0;sz(c,a,d+24|0,x[Hb(d+28|0,d+12|0)>>2]);Lm(c,x[d+24>>2]);x[b>>2]=x[d+16>>2];fb=d+32|0}function sc(a,b){a=a|0;b=b|0;var c=0;a=Dj(a);x[a+4>>2]=0;x[a>>2]=47568;c=Gd(_c(x[b+4>>2],y[b+11|0])+1|0);x[a+4>>2]=c;if(c){zc(c,Kb(b),_c(x[b+4>>2],y[b+11|0])+1|0)}return a|0}function s4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;while(1){if((b|0)!=(c|0)){f=dy(x[b>>2],x[a+8>>2]);v[e|0]=(f|0)==-1?d:f;e=e+1|0;b=b+4|0;continue}break}return c|0}function yw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;Jk(b,c);if(Mb(x[a>>2],x[a+8>>2],c)){c=x[b>>2];cc(d+8|0,c,Xc(c,x[b+4>>2]));sd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function wd(a,b){var c=0,d=0,e=0;a:{c=QC(b);d=sn(a);if(c>>>0<=d>>>0){b=ZC(Kb(a),b,c);lg(a,c);yd((c<<2)+b|0,0);break a}e=a;a=Cb(x[a+4>>2],y[a+11|0]);nI(e,d,c-d|0,a,0,a,c,b)}}function oD(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=xh(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){jc(a);fb=c+16|0}else{Cn(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function hca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;e=hP(a,c,1);fb=c+16|0;return+e}function ZX(a,b){var c=0,d=0;c=fb-16|0;fb=c;Gv(c+8|0,b);b=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function W6(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;c=rh(b+12|0,x[a+8>>2]);d=GK(0,0,4);qh(c);fb=b+16|0;if(d){a=-1}else{a=x[a+8>>2];if(!a){return 1}a=(FJ(a)|0)==1}return a|0}function Vq(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=xh(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){jc(a);fb=c+16|0}else{tV(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function Qg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Kh(x[d>>2],x[d+4>>2],a);return((Kh(x[d>>2],x[d+4>>2],a+1|0)<<8|e<<16|Kh(x[d>>2],x[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function QE(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=bj(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){jc(a);fb=c+16|0}else{_w(b);b=b+2|0;x[a+4>>2]=b;continue}break}}function OX(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Yo(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){jc(a);fb=c+16|0}else{qX(b);b=b+1|0;x[a+4>>2]=b;continue}break}}function Hz(a,b){var c=0,d=0;if(b>>>0<2147483632){if(Nk(b)){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;Ne(a,b);return a}c=Fh(b)+1|0;d=Ec(c);of(a,c);yd(a,d);Bd(a,b);return a}pf();p()}function $E(a,b){var c=0,d=0;c=fb-16|0;fb=c;mh(c+8|0,b);b=x[c+12>>2];qd(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){id(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function yq(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;d=xh(e+4|0,a,d);f=x[d+4>>2];a=fb-16|0;fb=a;fd(a+8|0,b,c);b=tA(x[a+8>>2],x[a+12>>2],f);fb=a+16|0;x[d+4>>2]=b;jc(d);fb=e+16|0}function yn(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;d=Yo(e+4|0,a,d);f=x[d+4>>2];a=fb-16|0;fb=a;fd(a+8|0,b,c);b=Q_(x[a+8>>2],x[a+12>>2],f);fb=a+16|0;x[d+4>>2]=b;jc(d);fb=e+16|0}function sA(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;d=Cr(e+4|0,a,d);f=x[d+4>>2];a=fb-16|0;fb=a;fd(a+8|0,b,c);b=hR(x[a+8>>2],x[a+12>>2],f);fb=a+16|0;x[d+4>>2]=b;jc(d);fb=e+16|0}function rY(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;d=xh(e+4|0,a,d);f=x[d+4>>2];a=fb-16|0;fb=a;fd(a+8|0,b,c);b=qY(x[a+8>>2],x[a+12>>2],f);fb=a+16|0;x[d+4>>2]=b;jc(d);fb=e+16|0}function gi(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;v[c+31|0]=0;uj(c+8|0,c+31|0);Nm(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];v[b|0]=y[c+31|0];fb=c+32|0;return(a|0)==1|0}function dv(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;d=bj(e+4|0,a,d);f=x[d+4>>2];a=fb-16|0;fb=a;fd(a+8|0,b,c);b=SU(x[a+8>>2],x[a+12>>2],f);fb=a+16|0;x[d+4>>2]=b;jc(d);fb=e+16|0}function SG(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&255)!=0}return b}function M3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;ib[x[x[a>>2]+12>>2]](d+8|0,a,b);a=x[d+8>>2];b=x[c>>2];c=mc(x[d+12>>2],x[c+4>>2]);fb=d+16|0;return(a|0)==(b|0)&c}function E_(a){var b=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=-28163770){break a}if(jd(a+44|0,18464,3)){break a}b=(y[a+47|0]|y[a+48|0]<<8)>>>0>97}return b}function rF(a,b,c){var d=0;d=fb-16|0;fb=d;a=Bp(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){mm(b,z[c>>1]);b=x[a>>2]+2|0;x[a>>2]=b;continue}break}je(a);fb=d+16|0}function qf(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+8>>2]=c;x[d+4>>2]=31;e=d,f=X$(b,c),x[e+12>>2]=f;c=b;b=uE(d+4|0);xk(c,c+b|0,a);e=xb(a,b),f=0,v[e|0]=f;_$(a);fb=d+16|0}function cka(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Ec(1);x[31609]=0;X(58);c=x[31609];x[31609]=0;if((c|0)!=1){b=yf(a+12|0,b);fb=a+16|0;return x[b>>2]}a=N()|0;Db(b);Q(a|0);p()}function R5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+95344>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function Ica(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;a=jP(a,c,1);fb=c+16|0;return a|0}function Fta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;_k(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);if((b|0)==x[c+4>>2]){Vb(a,x[c+12>>2])}fb=c+16|0}function ysa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(a){ib[x[x[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}aS(d,9169,10907,172,42);LG(d,b,c)}fb=d+16|0}function ng(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;w[c+30>>1]=0;kk(c+8|0,c+30|0);d=c+20|0;Nm(d,a,x[c+8>>2],x[c+12>>2]);$i(d,z[c+30>>1]);w[b>>1]=z[c+20>>1];fb=c+32|0}function dZ(a,b,c){var d=0;d=fb-16|0;fb=d;a=BC(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){qo(b,y[c|0]);b=x[a>>2]+1|0;x[a>>2]=b;continue}break}je(a);fb=d+16|0}function d2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ib[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Px(a,b,c,d,e){var f=0;a:{f=zu(4332);if(f){x[31609]=0;ha(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break a}}return f}a=N()|0;Db(f);Q(a|0);p()}function yA(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=xh(c+4|0,a,1);vq(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;jc(a);fb=c+16|0;return}gA(a,b)}function uV(a,b,c,d){a=Zb(a,b,c);b=x[a+4>>2];a:{if((d|0)>=0){b=b+d|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+d|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function nka(a,b){a=a|0;b=b|0;var c=0;a=og(a);c=Ti(x[b>>2]);b=Pf(b);x[31609]=0;S(847,a|0,c|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;VS(a);Q(b|0);p()}function iT(a,b,c){var d=0;d=c&15;if(d){v[b+824|0]=d}c=c&240;if(c){v[b+823|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;if(!(!d|!Ob(a+1074312|0,80))){v[b+824|0]=y[b+824|0]<<2}}function S5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+95344>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function KS(a,b){a=a|0;b=b|0;var c=0,d=0;c=Mc(a);d=Cb(x[a+4>>2],y[a+11|0]);if((c|0)==(d|0)){UB(a,c,1,c,c,0)}c=Kb(a);$l(c+d|0,1,b);b=d+1|0;lg(a,b);hd(b+c|0,0);return a|0}function Hm(a){a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function kr(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){qD(b);break a}mh(c+8|0,b);sd(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Qz(a,d,c,1);fb=d+16|0}function TL(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function Sja(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Dc(a+4|0,10281);x[31609]=0;W(62,b|0);c=x[31609];x[31609]=0;if((c|0)!=1){tb(b);fb=a+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function Lca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;b=x[b+4>>2];e=x[c+4>>2];c=x[c>>2];x[d>>2]=c;x[d+4>>2]=e;x[d+8>>2]=c;x[d+12>>2]=e;fP(a,b,d,1);fb=d+16|0}function Ev(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=y[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function l5(a,b,c){a=a|0;b=b|0;c=c|0;a=uJ(a,c);x[a>>2]=96668;b=Kb(b);x[31609]=0;O(1368,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;ky(a);Q(b|0);p()}function jd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=y[a|0];e=y[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function j5(a,b,c){a=a|0;b=b|0;c=c|0;a=tJ(a,c);x[a>>2]=96708;b=Kb(b);x[31609]=0;O(1369,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;ly(a);Q(b|0);p()}function fda(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Pz(a,d,c,1);fb=d+16|0}function YO(a,b){var c=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=(a+1074992|0)+D(b,872)|0;if(!(v[a+89|0]&1)){break a}c=E(E(y[a+842|0])*E(.0078125))}return c}function XO(a,b){var c=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=(a+1074992|0)+D(b,872)|0;if(!(v[a+89|0]&1)){break a}c=E(E(y[a+843|0])*E(.0078125))}return c}function MM(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Yo(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){jc(a);fb=c+16|0}else{b=b+1|0;x[a+4>>2]=b;continue}break}}function Goa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!FW(a,c)){break a}d=0;if(!EW(c)){break a}d=xe(a,b,DW(y[c+31|0],y[c+33|0]),hb)}fb=c+48|0;return d|0}function Apa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;sG(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<3)){rG(d+8|0,x[b>>2],x[b+4>>2]);sd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function yk(a,b){var c=0,d=0,e=0;a:{c=Ql(a,b);if((c|0)==255){break a}if(Fj(x[a>>2])){break a}d=xb(a+8|0,c);e=y[d|0]&223;v[d|0]=e;Ah(x[a>>2],x[a+4>>2],b,bv(c)|176,e)}}function ld(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Ef(b);d=Mc(a);if(c>>>0<=d>>>0){Xu(a,Ni(Kb(a),b,c),c);break a}e=a;a=Cb(x[a+4>>2],y[a+11|0]);Zp(e,d,c-d|0,a,0,a,c,b)}}function laa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;pz(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function kD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;YY(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<2)){XY(d+8|0,x[b>>2],x[b+4>>2]);sd(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function Zh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=es(b);d=Mc(a);if(c>>>0<=d>>>0){Xu(a,Ni(Kb(a),b,c),c);break a}e=a;a=Cb(x[a+4>>2],y[a+11|0]);Uq(e,d,c-d|0,a,0,a,c,b)}}function WH(a,b,c){var d=0;a:{if(!a){a=dc(8);x[31609]=0;c=R(c|0,a|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){break a}b=N()|0;lc(a);Q(b|0);p()}return}da(c|0,b|0,1e3);p()}function R1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function Ida(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Cb(x[b+4>>2],y[b+11|0]);e=a;a=Cb(x[c+4>>2],y[c+11|0]);b=Xg(Kb(Hz(e,d+a|0)),Kb(b),d)+d|0;$l(Xg(b,Kb(c),a)+a|0,1,0)}function HW(a,b){var c=0;c=fb-32|0;fb=c;sX(c+24|0,a);fe(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;return a}function pZ(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;b=gc(b);a=Dh(a,Ec(32),Og(d+8|0,b));b=x[a>>2]+16|0;w[b>>1]=z[x[c>>2]>>1];Fb(b+4|0);e=gc(a),f=1,v[e+4|0]=f;fb=d+16|0}function kV(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function iX(a){if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=541938512|(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))!=1162627398)){return 1}return 0}function e2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function GX(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1297239878){a=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))==1279545165}else{a=0}return a}function Dsa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],12)){w[c>>1]=0;PZ(a,6,c);break a}zr(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function A9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a=_y(Pa(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);fb=e+16|0;hb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function opa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){w[c>>1]=0;PZ(a,4,c);break a}_k(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function fL(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=zf(b),d=x[x[a>>2]+52>>2],ib[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return zf(b)}function _O(a,b){var c=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=(a+1074992|0)+D(b,872)|0;if(v[a+89|0]&1){break a}c=E(E(y[a+842|0])*E(.0078125))}return c}function WO(a,b){var c=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=(a+1074992|0)+D(b,872)|0;if(v[a+89|0]&1){break a}c=E(E(y[a+843|0])*E(.0078125))}return c}function Nd(a,b){var c=0;c=fb-32|0;fb=c;fe(c+24|0,a);a=pc(c+16|0,b);b=x[a+4>>2];x[c+8>>2]=x[a>>2];x[c+12>>2]=b;a=Ic(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;return a}function BT(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=uv(c+4|0,a,1);xs(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;jc(a);fb=c+16|0;return}WG(a,b)}function gpa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],5)){v[c|0]=0;Sh(a,5,c);break a}_j(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function QW(a){var b=0;if(!((y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1297236819|y[a+29|0]!=16)){b=((y[a+42|0]|y[a+43|0]<<8)-1&65535)>>>0<2}return b}function Pd(a,b){var c=0,d=0,e=0,f=E(0);c=fb-16|0;fb=c;x[c+8>>2]=1065353216;B[c+12>>2]=b;e=c,f=ag(a),B[e+4>>2]=f;d=Rv(c+4|0,c+12|0,c+8|0);fb=c+16|0;return B[d>>2]}function ypa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-80|0;fb=d;e=d+14|0;c=-1;a:{if(!G$(a,e)){break a}c=0;if(!zX(e)){break a}c=xe(a,b,yX(e),hb)}fb=d+80|0;return c|0}function uE(a){var b=0,c=0;a:{c=yb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=sE(x[b>>2],x[a>>2])?b:a;continue}}return x[a>>2]}function u4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;while(1){if((b|0)!=(c|0)){e=d,f=JI(v[b|0],x[a+8>>2]),x[e>>2]=f;d=d+4|0;b=b+1|0;continue}break}return c|0}function s3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=x[c>>2];a=ib[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}fb=d+16|0;return a|0}function rda(a,b){a=a|0;b=b|0;var c=0;a=dc(8);x[31609]=0;b=P(1051,a|0,12113)|0;c=x[31609];x[31609]=0;if((c|0)!=1){da(b|0,124900,162);p()}b=N()|0;lc(a);Q(b|0);p()}function lm(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){v[c|0]=0;Sh(a,4,c);break a}mh(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function lM(a,b){var c=0,d=0;c=Xc(x[a+4>>2],x[a+8>>2]);b=x[a+16>>2]+b|0;if(c>>>0<b>>>0){d=a+4|0;a:{if(c){a=ki(c);if(b>>>0<=a>>>0){break a}}a=mM(b,65536)}Jk(d,a)}}function Uja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=uh(b),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[Zj(c+12|0,c+8|0,42224)>>2],x[d+36>>2]=e;xq(a);fb=c+16|0}function U2(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=Cx(c+4|0,a);xs(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;jc(a);fb=c+16|0;return}WG(a,b)}function Tq(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function T8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e>>2]=c;x[e+4>>2]=d;x[e+8>>2]=c;x[e+12>>2]=d;a=UK(a,e,b);x[a>>2]=94260;fb=e+16|0;return a|0}function L_(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],6)){v[c|0]=0;Sh(a,6,c);break a}XD(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Ec(a){a=a|0;var b=0;a=a>>>0<=1?1:a;a:{while(1){b=Gd(a);if(b){break a}b=x[125431];if(b){ib[b|0]();continue}break}da(tn(dc(4))|0,124540,34);p()}return b|0}function kA(a,b){var c=0;c=fb-16|0;fb=c;a=Fn(c+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){tV(b);b=x[a>>2]+4|0;x[a>>2]=b;continue}break}je(a);fb=c+16|0}function eia(a){a=a|0;var b=0;b=fb-16|0;fb=b;uQ(b+8|0,a,0);if(x[b+12>>2]){a=x[a+20>>2];x[a+148>>2]=-1;tQ(a+4|0,wb(x[b+8>>2]),Yj(x[b+8>>2],x[b+12>>2]))}fb=b+16|0}function dS(a){var b=0,c=0,d=0;b=x[a+112>>2];if((b|0)>=11){b=378;while(1){if(b|c){cS(a);d=b;b=b-1|0;c=c-!d|0;continue}break}b=0}x[a+112>>2]=b+1;a=cS(a);return a}function MD(a){var b=0,c=0;b=fb-16|0;fb=b;w[b+14>>1]=a;Hf(b+14|0,4095);a=z[b+14>>1];c=LD(Ai(+((a&255)>>>0)*.00390625)*32768);fb=b+16|0;return c>>>15-(a>>>8|0)|0}function M0(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(eh(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=D0(a,b,x[Hb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function KE(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(eh(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=A0(a,b,x[Hb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function wS(a,b){var c=0;c=fb-32|0;fb=c;a=ye(c+8|0,a,b);a=Gu(c+16|0,x[a>>2],x[a+4>>2]);a=ye(c+24|0,x[a>>2],x[a+4>>2]);b=x[a>>2];fb=c+32|0;hb=x[a+4>>2];return b}function jW(a){if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1299020115){a=($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))|0)==1}else{a=0}return a}function ila(a,b){a=a|0;b=b|0;a=tc(a);v[a+534|0]=0;x[a+4>>2]=0;x[31609]=0;O(788,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;Gl(a);Q(b|0);p()}function WU(a,b,c,d){var e=0;e=fb-32|0;fb=e;fd(e+24|0,b,c);UU(e+16|0,x[e+24>>2],x[e+28>>2],d);b=LX(b,x[e+16>>2]);x[e+12>>2]=x[e+20>>2];qc(a,b,e+12|0);fb=e+32|0}function Rt(a){var b=0;a:{if((ff(a)|0)!=79){break a}if((ff(a)|0)!=103){break a}if((ff(a)|0)!=103){break a}b=(ff(a)|0)==83}if(!b){bc(a,30);return 0}return ML(a)}function Mw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],2)){v[c|0]=0;sF(a,c);break a}Cp(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function $D(a,b,c,d){var e=0;e=fb-32|0;fb=e;fd(e+24|0,b,c);cv(e+16|0,x[e+24>>2],x[e+28>>2],d);b=P_(b,x[e+16>>2]);x[e+12>>2]=x[e+20>>2];qc(a,b,e+12|0);fb=e+32|0}function vn(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(F(a)<2147483648){return~~a}b=-2147483648}return b}function dG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Nb(a+8|0);x[31609]=0;S(169,a|0,b|0,c|0);a=x[31609];x[31609]=0;if((a|0)!=1){break a}a=N()|0;fc(d);Q(a|0);p()}}function _M(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function YZ(a){var b=0;b=x[a+4>>2];if(!b){while(1){b=mi(a);a=x[a+8>>2];if(!b){continue}break}return a}a=b;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function w8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function uC(a){var b=0;a=Fe(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(F(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function jS(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=a+12|0;while(1){if(c>>>0<32){c=c+48|0;d=TA(126480);continue}break}x[b>>2]=d;Do(b);fb=a+16|0;return x[b>>2]}function j6(a){a=a|0;if(y[499944]){return x[124985]}if(!y[501096]){v[501096]=1}wd(501072,104244);wd(501084,104256);v[499944]=1;x[124985]=501072;return 501072}function O8(a,b){a=a|0;b=b|0;var c=0,d=0;b=KD(x[b>>2]);x[a+36>>2]=b;c=a,d=Lh(b),x[c+44>>2]=d;c=a,d=io(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){go(5563);p()}}function LP(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function Kia(a){a=a|0;var b=0;b=fb-16|0;fb=b;Qc(b+4|0,a+32|0,4);if(!Gb(x[x[b+4>>2]>>2],x[b+8>>2])){yy(a)}a=vb(b+12|0,wb(x[a+52>>2]));fb=b+16|0;return x[a>>2]}function Jia(a){a=a|0;var b=0;b=fb-16|0;fb=b;Qc(b+4|0,a+32|0,4);if(!Gb(x[x[b+4>>2]>>2],x[b+8>>2])){yy(a)}a=vb(b+12|0,wb(x[a+56>>2]));fb=b+16|0;return x[a>>2]}function G8(a,b){a=a|0;b=b|0;var c=0,d=0;b=Py(x[b>>2]);x[a+36>>2]=b;c=a,d=Lh(b),x[c+44>>2]=d;c=a,d=io(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){go(5563);p()}}function z8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function or(a){var b=0,c=0,d=0,e=0;c=x[a+4>>2];b=x[c>>2];x[a+4>>2]=b;if(b){wn(b,a)}b=x[a+8>>2];x[c+8>>2]=b;d=b+(mi(a)?0:4)|0,e=c,x[d>>2]=e;x[c>>2]=a;wn(a,c)}function nr(a){var b=0,c=0,d=0,e=0;c=x[a>>2];b=x[c+4>>2];x[a>>2]=b;if(b){wn(b,a)}b=x[a+8>>2];x[c+8>>2]=b;d=b+(mi(a)?0:4)|0,e=c,x[d>>2]=e;x[c+4>>2]=a;wn(a,c)}function Vb(a,b){a=a|0;b=b|0;var c=0;c=Mb(x[a>>2],x[a+8>>2],b);a:{if(c){b=x[a+8>>2]+b|0;break a}b=x[a>>2];b=ib[x[x[b>>2]+24>>2]](b)|0}x[a+8>>2]=b;return c|0}function Uaa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=1135;x[c+8>>2]=1136;x[c+4>>2]=1137;x[c>>2]=1138;ib[x[lq(c,sk(y[b+20|0]))>>2]](a,b);fb=c+16|0}function Rna(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-48|0;fb=d;c=-1;a:{if(!FW(a,d)){break a}c=0;if(!FV(d)){break a}c=xe(a,b,EV(y[d+47|0]),hb)}fb=d+48|0;return c|0}function Qe(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[gc(a)>>2];x[31609]=0;W(a|0,c|0);a=x[31609];x[31609]=0;if((a|0)==1){break a}}return}T(0)|0;Sb();p()}function JQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;while(1){if((b|0)==(c|0)){fb=d+16|0}else{x[d+12>>2]=x[b>>2];yA(a,d+12|0);b=b+4|0;continue}break}}function wla(a,b){a=a|0;b=b|0;a=Nb(a);v[a+16|0]=0;x[a+12>>2]=b;x[31609]=0;W(782,a|0);b=x[31609];x[31609]=0;if((b|0)!=1){return a|0}b=N()|0;_B(a);Q(b|0);p()}function c6(a){a=a|0;if(y[499936]){return x[124983]}if(!y[501064]){v[501064]=1}ld(501040,13958);ld(501052,13937);v[499936]=1;x[124983]=501040;return 501040}function Iu(a,b){var c=0,d=0,e=E(0);c=fb-16|0;fb=c;B[c+12>>2]=b;x[c+8>>2]=0;x[c+4>>2]=1065353216;d=a,e=B[Rv(c+12|0,c+8|0,c+4|0)>>2],B[d+144>>2]=e;fb=c+16|0}function zi(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function yj(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;C[a>>3]=C[a>>3]-c;C[a+8>>3]=C[a+8>>3]-d}function jz(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(a*E(B[((c&3)<<2)+81984>>2]*E(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function hr(a,b){var c=0,d=0;a:{if(!a){break a}c=Aua(a,0,b,0);d=hb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Gd(c);if(!(!a|!(y[a-4|0]&3))){Rb(a,0,c)}return a}function ej(a,b,c,d,e){a:{e=zu(e);if(e){x[31609]=0;ba(d|0,e|0,a|0,b|0,c|0)|0;a=x[31609];x[31609]=0;if((a|0)==1){break a}}return e}a=N()|0;Db(e);Q(a|0);p()}function c0(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function S1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function NZ(a,b){var c=0;c=Aua(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;hb=b>>>0<256?a+1|0:a;return b}function hga(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=CB(E(E(E(E(A[x[a+16>>2]+24620>>2])/E(3))+E(-80))/E(15920)),E(0),E(1)),B[b+4272>>2]=c;MP(a);LP(a)}function f2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function RV(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;qC(a+112|0,48e3);x[a+668>>2]=0;pC(a+724|0);pC(a+732|0);pC(a+740|0);Ng(a+788|0)}function RU(a,b,c,d){var e=0;e=fb-32|0;fb=e;fd(e+24|0,b,c);UU(e+16|0,x[e+24>>2],x[e+28>>2],d);b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(a,b,e+12|0);fb=e+32|0}function O2(a,b,c){a=a|0;b=b|0;c=c|0;a=Bs(a,x[b+28>>2]);YG(b+28|0,c);x[31609]=0;O(113,b|0,1);b=x[31609];x[31609]=0;if((b|0)==1){b=N()|0;_b(a);Q(b|0);p()}}function Iv(a,b,c,d){var e=0;e=fb-32|0;fb=e;fd(e+24|0,b,c);cD(e+16|0,x[e+24>>2],x[e+28>>2],d);b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(a,b,e+12|0);fb=e+32|0}function $B(a,b,c,d){var e=0;e=fb-32|0;fb=e;fd(e+24|0,b,c);cv(e+16|0,x[e+24>>2],x[e+28>>2],d);b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];qc(a,b,e+12|0);fb=e+32|0}function xU(a){var b=0,c=0,d=0;d=a+27|0;c=y[a+26|0];b=c+27|0;a=0;while(1){if((a|0)==(c|0)){a=b&65535}else{b=y[a+d|0]+b|0;a=a+1|0;continue}break}return a}function oo(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=Gd(b)}return c}function mX(a){var b=0;if(!((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=441273424|y[a+5|0]!=16|(y[a+54|0]-33&255)>>>0<224)){b=y[a+4|0]>95}return b}function zn(a,b){var c=0,d=0,e=0;dw(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function iW(a,b){var c=0,d=0,e=0;qr(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function K5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function Eoa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb+-64|0;fb=d;c=-1;a:{if(!d$(a,d)){break a}c=0;if(!zW(d)){break a}c=xe(a,b,yW(d),hb)}fb=d- -64|0;return c|0}function uta(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb+-64|0;fb=d;c=-1;a:{if(!d$(a,d)){break a}c=0;if(!c$(d)){break a}c=xe(a,b,b$(d),0)}fb=d- -64|0;return c|0}function po(a,b){x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Rb(a+32|0,0,40);kL(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function nZ(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;v[d+27|0]=0;x[d+12>>2]=1;sz(d+16|0,a,d+27|0,x[Hb(d+28|0,d+12|0)>>2]);v[b|0]=y[d+27|0];fb=d+32|0}function dd(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(!(ib[x[x[d>>2]+32>>2]](d,0,b)|0)){break a}}x[a+8>>2]=b;c=1}return c|0}function MW(a,b,c,d){var e=0;e=c&4;a:{if((b&255)!=4){b=e?16:8;break a}b=16;if(e){break a}b=8;if(c&2){break a}Zc(a,8,1,0,10);return}Zc(a,b,c&2|1,0,d^1)}function AO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;YL(i,b,c,d,e,f,g);Uc(a,h+20|0);$m(i);fb=h+32|0}function kT(a,b,c){var d=0,e=0;x[b+56>>2]=0;d=b,e=Go(a,z[b+70>>1],x[b+48>>2],c,0),w[d+68>>1]=e;if(!(!(y[a+480180|0]&5)|x[b+60>>2]==-1)){x[b+60>>2]=0}}function ex(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],3)){v[c|0]=0;Sh(a,3,c);break a}dx(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function a$(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){v[c|0]=0;Sh(a,8,c);break a}_k(c+8|0,a);sd(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Eq(a,b,c){var d=0;a:{if(b&67109888){break a}if(!Bj(c)){break a}b=y[c+34|0];if((b+5&255)>>>0<6){break a}d=x[$d(a+906300|0,b-1|0)>>2]}return d}function BJ(a){x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;w[a+20>>1]=0;x[a+16>>2]=-1;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0}function nh(a,b){var c=0;if(vd(y[a+11|0])){c=x[a>>2];Zi(x[a+8>>2]);Db(c)}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Ne(b,0);yd(b,0)}function kpa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!nX(a,d)){break a}c=0;if(!mX(d)){break a}c=xe(a,b,lX(d),hb)}fb=d+96|0;return c|0}function kO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=fb-16|0;fb=b;c=Zb(b+8|0,c,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a=Au(a,b,0);fb=b+16|0;return a|0}function QQ(a){var b=0,c=0;b=fb-16|0;fb=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;c=Rv(b+12|0,b+8|0,b+4|0);fb=b+16|0;return B[c>>2]}function QG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Dc(b+4|0,14821);if(_c(x[a+4>>2],y[a+11|0])){c=(Tg(a,13959)|0)!=-1}else{c=0}tb(a);fb=b+16|0;return c|0}function Noa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!nX(a,d)){break a}c=0;if(!QW(d)){break a}c=xe(a,b,PW(d),hb)}fb=d+96|0;return c|0}function JI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=rh(c+12|0,b);b=a&255;if(b>>>0>=128){b=(a|0)==-1?-1:x[x[124115]>>2]?-1:a&57343}qh(d);fb=c+16|0;return b}function H9(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=jg(a,b);x[31609]=0;P(71,a+12|0,c|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}}function CH(a,b,c){var d=0,e=0;while(1){if((a|0)!=(b|0)){e=y[a|0];d=e<<24>>24;if((d|0)>=0){d=x[(e<<2)+c>>2]}v[a|0]=d;a=a+1|0;continue}break}return b}function C5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function $w(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function ws(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;Eb(b);continue}break}c=x[a>>2];if(c){vs(a);Db(c)}}function sS(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=ye(c+8|0,Aua(b,b>>31,500654080,20),hb);d=x[b>>2];b=x[b+4>>2];fb=c+16|0;x[a>>2]=d;x[a+4>>2]=b;return a}function ix(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;x[a+8>>2]=b;Hp(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function cX(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;x[a+8>>2]=b;ar(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function bw(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;x[a+8>>2]=b;ub(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function aR(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;x[a+8>>2]=b;vk(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function YB(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;Ak(b);continue}break}c=x[a>>2];if(c){vs(a);Db(c)}}function Sq(a,b,c){a:{if(!Ob(c+1074312|0,102)){break a}c=z[a+692>>1]+1|0;w[a+784>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+784>>1]=c|32768}x[a+692>>2]=b}function PA(a){if(y[a+480224|0]==2){return+A[a+1074420>>2]/1e4}return+A[a+24620>>2]/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))*60}function N$(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;x[a+8>>2]=b;Hd(b);continue}break}c=x[a>>2];if(c){nc(a);Db(c)}}function BI(a,b,c){var d=0,e=0,f=0,g=0;d=QC(b);if(d>>>0<c>>>0){qI(a,b,d+1|0);return d}if(c){e=a;a=c-1|0;f=qI(e,b,a)+(a<<2)|0,g=0,x[f>>2]=g}return d}function B3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(lh(a,x[b+8>>2],f)){Wx(b,c,d,e);return}a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function yP(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=gu(Ec(12));x[c+8>>2]=b;x[c+4>>2]=a;x[c>>2]=47468;a=yf(d+12|0,c);fb=d+16|0;return x[a>>2]}function v_(a,b){var c=0;c=Aua(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;hb=b>>>0<11?a+1|0:a;return b}function lX(a){var b=0,c=0,d=0,e=0;d=y[a+4|0];e=y[a+92|0];c=y[a+94|0]|y[a+95|0]<<8;b=c+y[a+93|0]|0;a=0;b=b+e|0;a=(b<<2)+d|0;a=a-96|0;hb=0;return a}function i$(a){v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function ef(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!b){Qc(c+8|0,a+32|0,5);if(Gb(x[x[c+8>>2]>>2],x[c+12>>2])){break a}}x[a+28>>2]=x[a+28>>2]+1}fb=c+16|0}function eI(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Xs(a){var b=0,c=0,d=0;if(!a){return 0}d=108144;while(1){b=d;c=x[b>>2];if(c){d=b+4|0;if((a|0)!=(c|0)){continue}}break}return((c?b:0)|0)!=0}function Wia(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;w[c+30>>1]=b;b=c+30|0;Cp(c+20|0,b);d=x[c+20>>2];Cp(c+12|0,b);rl(a,d,x[c+16>>2]);fb=c+32|0}function TB(a,b,c){var d=0,e=0,f=0;d=Ql(a,b);if((d|0)!=255){e=ac(a+26|0,d),f=c,w[e>>1]=f;a=a+62|0;e=xb(a,b),f=255,v[e|0]=f;e=xb(a,c),f=d,v[e|0]=f}}function S8(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;ib[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function Es(a,b,c,d){var e=0;e=dc(8);x[31609]=0;a=P(d|0,e|0,a|0)|0;d=x[31609];x[31609]=0;if((d|0)!=1){da(a|0,c|0,b|0);p()}a=N()|0;lc(e);Q(a|0);p()}function Ega(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=1){c=Pd(c,E(0));if((b|0)==1){d=1;c=li(c)}e=yb(a+4208|0,d),f=c,B[e>>2]=f;SP(a)}}function kla(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;v[c+31|0]=b;b=c+31|0;Vr(c+20|0,b);d=x[c+20>>2];Vr(c+12|0,b);rl(a,d,x[c+16>>2]);fb=c+32|0}function hG(a){a=a|0;var b=0;a=Fb(a);x[31609]=0;R(168,a+12|0)|0;b=x[31609];x[31609]=0;if((b|0)!=1){tc(a+32|0);return a|0}b=N()|0;tb(a);Q(b|0);p()}function cP(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;YL(i,b,c,d,e,f,g);Uc(a,i);$m(i);fb=h+32|0}function Wi(a,b){var c=0;c=x[a>>2];if($c(c,x[a+4>>2])>>>0>b>>>0){a=x[a+24>>2];a=Je(x[a+484344>>2],x[a+484348>>2],z[ac(c,b)>>1])}else{a=0}return a}function LE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0}function JB(a){var b=0,c=0;b=fb-16|0;fb=b;x[b+12>>2]=a;c=b+12|0;a=1;while(1){if((a|0)>0){ah(c);a=a-1|0;continue}break}fb=b+16|0;return x[b+12>>2]}function zt(a){var b=0,c=0;b=fb-16|0;fb=b;c=-1;a:{if(At(a)){break a}if((ib[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}fb=b+16|0;return c}function jq(a,b){var c=0;a:{if(!TL(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=a>>>0<16^b>>>0>15}return c}function _ta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(eh(a,c+11|0)){x[c+4>>2]=y[c+11|0];$$(a,b,x[Hb(c+4|0,c+12|0)>>2])}fb=c+16|0}function DP(a,b){var c=0;if(a>.999999){c=0}else{a=a*a;b=hf(31415.926535897932/b);c=Si(32768/(1-a)*(1-(a*b+M((a+a)*(1-b)-a*a*(1-b*b)))))}return c}function im(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=Rr(a,e,d);break a}a=Rr(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function hl(a,b,c){if(a>>>0<b>>>0){zc(a,b,c);return}if(c){a=a+c|0;b=b+c|0;while(1){a=a-1|0;b=b-1|0;v[a|0]=y[b|0];c=c-1|0;if(c){continue}break}}}function dT(a,b){v[a+840|0]=b;v[a+812|0]=b;v[a+811|0]=b;v[a+809|0]=b;v[a+807|0]=b;v[a+806|0]=b;v[a+833|0]=b;v[a+826|0]=b>>>4;v[a+827|0]=b<<2&60}function Tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){Iz(a,0,0,0,0,0,0,c,d);return}Iz(a,x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2],x[b+24>>2],b,c,d)}function S0(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(eh(a,c+11|0)){x[c+4>>2]=y[c+11|0];F0(a,b,x[Hb(c+4|0,c+12|0)>>2])}fb=c+16|0}function zm(a,b){var c=0,d=0;d=x[a+4>>2];c=x[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;x[a+8>>2]=c;continue}break}b=x[a>>2];if(b){nc(a);Db(b)}}function oY(a){var b=0;if(!(jd(a,15101,3)|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-2147483647>>>0<2147484072)){b=y[a+3|0]<6}return b}function aF(a,b){var c=0;a:{if(!(y[a+2|0]|y[a+3|0]<<8)|(!y[a|0]|!y[a+1|0])){break a}c=1;if(b>>>0<9){break a}c=(y[a+4|0]-1&255)>>>0<32}return c}function Ws(a){if(a>>>0<=254){return(a+1&127)>>>0>32}return(a&65534)!=65534&a-65532>>>0<1048580|(a-57344>>>0<8185|a>>>0<8232|a-8234>>>0<47062)}function Mm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ef(b);e=a;a=Cb(x[c+4>>2],y[c+11|0]);b=Dg(Kb(Hz(e,d+a|0)),b,d)+d|0;$l(Dg(b,Kb(c),a)+a|0,1,0)}function Dpa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Rg(b);Rg(b);break a}a=gh(b);gh(b)}while(1){if(a){if(a&1){Vb(b,260)}a=a>>>1|0;continue}break}}function CL(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function yi(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function xR(a,b){var c=0;c=fb-16|0;fb=c;fe(c+8|0,a);fe(c,b);b=x[c>>2];a=rZ(x[c+8>>2],x[c+12>>2],b,x[c+4>>2]);fb=c+16|0;return vd(a?a>>31|1:0)}function pW(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){vs(a);Db(b)}}function _f(a){a=a|0;var b=0;x[a>>2]=42712;x[x[a+20>>2]>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;x[a+20>>2]=0;qQ(a+44|0);return a|0}function Zu(a,b){var c=0,d=0;d=Xj(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!Je(a,b,d&65535)){continue}}break}return c&65535}function Uu(a,b){var c=0;c=fb-16|0;fb=c;fe(c+8|0,a);fe(c,b);b=x[c>>2];a=o_(x[c+8>>2],x[c+12>>2],b,x[c+4>>2]);fb=c+16|0;return vd(a?a>>31|1:0)}function Ln(a,b){var c=0;a=Pn(a);x[a>>2]=78448;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function KV(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){vs(a);Db(b)}}function H$(a,b,c){var d=0;d=fb-16|0;fb=d;lm(d+12|0,b);x[d+8>>2]=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);ep(a,d+8|0,c);fb=d+16|0}function zO(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;ZL(h,b,c,d,e,f);Uc(a,g+20|0);$m(h);fb=g+32|0}function mE(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;w[c+14>>1]=1;d=c,e=cm(a,b),w[d+12>>1]=e;a=qe(c+14|0,c+12|0);fb=c+16|0;return z[a>>1]-1&65535}function dy(a,b){var c=0;c=fb-16|0;fb=c;b=rh(c+12|0,b);if(a>>>0>=128){a=(a&-128)!=57216?-1:x[x[124115]>>2]?-1:a&255}qh(b);fb=c+16|0;return a}function zb(a,b){var c=0;if(vd(y[a+11|0])){Db(x[a>>2])}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Ne(b,0);hd(b,0);return a}function vp(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=BF(a,b);break a}c=Rg(a);Vb(a,b-4|0)}return c}function nf(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=vb(d+12|0,a);c=x[b>>2];if(x[c>>2]){Nc(c);b=x[b>>2];c=x[b>>2];jt(b);Db(c)}fb=d+16|0;return a}function f_(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=b,d=$b(a),x[c+12>>2]=d;x[b+8>>2]=236;a=bd(b+12|0,b+8|0);fb=b+16|0;hb=0;return x[a>>2]-216|0}function Ow(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if((b|0)==1){c=AF(a,1);break a}c=gh(a);Vb(a,b-2|0)}return c}function Oe(a,b,c){v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a}function Lb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;if(b>>>0>=122){Qq(12226);p()}e=d+8|0;Jb(e,a,b);kf(e,c);fb=d+16|0;return a|0}function kL(a){var b=0,c=0;x[31609]=0;c=ca(1222)|0;b=x[31609];x[31609]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;pm(a);return}T(0)|0;Sb();p()}function iI(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=Tx(x[d>>2],c)}ib[x[x[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function V5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-16|0;fb=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Hb(a+12|0,a+8|0);fb=a+16|0;return x[b>>2]}function Jl(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=x[a+24>>2];d=x[a+40>>2];x[b+12>>2]=1;a=bd(a+20|0,b+12|0);fb=b+16|0;return D(x[a>>2],c+d|0)}function nQ(a,b){var c=0;c=x[b+4>>2];if(x[a>>2]==(b|0)){x[a>>2]=c}a=x[b+8>>2];if(c){x[c+8>>2]=a}if(a){x[a+4>>2]=c}x[b+4>>2]=0;x[b+8>>2]=0}function gd(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=Ye(b+8|0,Cd(b+12|0,b+4|0));fb=b+16|0;return w[a>>1]}function dia(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=x[a+20>>2];se(b,x[c+4>>2],x[c+8>>2]);sQ(a,Zb(b+8|0,x[b>>2],x[b+4>>2]),0);fb=b+16|0}function ck(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Qb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;fb=d+16|0}function bk(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Qb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;fb=d+16|0}function Y_(a){var b=0,c=0,d=0;c=fb-16|0;fb=c;b=c+13|0;ex(b,a);a=y[xb(b,0)|0];d=y[xb(b,1)|0];b=y[xb(b,2)|0];fb=c+16|0;return d<<8|a|b<<16}function Lka(a){a=a|0;var b=0;b=x[a>>2];if(ib[x[x[b>>2]+32>>2]](b,0,32)|0){a=x[a>>2];a=ib[x[x[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function GO(a,b){var c=0,d=0;a:{if(!Vt(b)){break a}c=x[a+484344>>2];if(!Je(c,x[a+484348>>2],b&65535)){break a}d=x[Wb(c,b)+12>>2]}return d}function DC(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=Ab(b),d=0,x[c>>2]=d;return a}function AC(a){a=50-(D(y[(a>>>4|0)+29872|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Gc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=$x(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function x4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=ay(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function DH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=x[a>>2];if(d>>>0<=127){d=x[(d<<2)+c>>2]}x[a>>2]=d;a=a+4|0;continue}break}return b}function y9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=Fx(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function id(a,b){var c=0,d=0,e=0;c=jh(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=ib[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function bP(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;ZL(h,b,c,d,e,f);Uc(a,h);$m(h);fb=g+32|0}function _C(a){var b=0;b=Bb(y[a+26|0]|y[a+27|0]<<8);return((y[a+24|0]>15)+(y[a+25|0]>64)|0)+(Bb(y[a+22|0]|y[a+23|0]<<8)<<1>>>0<b>>>0)|0}function Ey(a,b,c){var d=0;d=b-a>>2;a:{if(d){while(1){if(x[a>>2]==(c|0)){break a}a=a+4|0;d=d-1|0;if(d){continue}break}}a=0}return a?a:b}function $X(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;return a}function rW(a){var b=0,c=0;c=fb-16|0;fb=c;b=vb(c+12|0,a);a=x[b>>2];if(x[a>>2]){nW(a,x[a>>2]);a=x[b>>2];b=x[a>>2];cl(a);Db(b)}fb=c+16|0}function pka(a,b){a=a|0;b=b|0;a=iB(a);x[31609]=0;O(844,a|0,b|0);b=x[31609];x[31609]=0;if((b|0)==1){b=N()|0;Hq(a);Q(b|0);p()}return a|0}function on(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;x[a+8>>2]=b;continue}break}a=x[a>>2];if(a){Db(a)}}function j4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=pl(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function h4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=ut(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function Xha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Tc(c&255))){vQ(a,8,E(0))}a=xj(a);if(a){ib[x[x[a>>2]+96>>2]](a,b,c,d,e)}}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=hu(x[a+32>>2],b,c,d,2);if(a>>>0<=15){a=y[a+42128|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=hu(x[a+32>>2],b,c,d,3);if(a>>>0<=46){a=y[a+42080|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function Gu(a,b,c){var d=0;d=fb-16|0;fb=d;b=ye(d+8|0,Aua(b,c,1e6,0),hb);c=x[b>>2];b=x[b+4>>2];fb=d+16|0;x[a>>2]=c;x[a+4>>2]=b;return a}function Nca(a,b){a=a|0;b=b|0;var c=0;if((a|0)!=(b|0)){c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0}return a|0}function K0(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){sp(b)}v[a|0]=1}return a|0}function qi(a,b,c){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24;v[a+4|0]=c;v[a+5|0]=c>>>8;v[a+6|0]=c>>>16;v[a+7|0]=c>>>24}function cY(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-128;x[b+4>>2]=127;a=Ye(b+8|0,Cd(b+12|0,b+4|0));fb=b+16|0;return v[a|0]}function Tga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;if(b>>>0<=4){c=Pd(c,E(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=li(c)}B[d>>2]=c;UP(a)}}function Oka(a,b){a=a|0;b=b|0;a=AE(a,b);if(!a){v[b+6|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0}return a|0}function ii(a,b){var c=0,d=0;c=x[a>>2];d=x[a+4>>2];b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Pc(c,d,(b>>31&a)+b|0)>>2]}function bg(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=122){Qq(12191);p()}d=c+8|0;Jb(d,a,b);kf(d,0);fb=c+16|0;return a|0}function Uy(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return zf(v[b|0])|0}function Lt(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function tka(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=250){Qq(12226);p()}d=c+8|0;Jb(d,a,b);bp(d);fb=c+16|0;return a|0}function t9(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+1;a=zf(v[a|0])}else{a=-1}return a|0}function ji(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;o(+b);e=j(1)|0;j(0)|0;l(0,d|0);l(1,c&2147483647|e&-2147483648);return+n()}function Nt(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function OY(a,b){var c=0;c=fb-16|0;fb=c;a=xh(c+4|0,a,1);cp(x[a+4>>2],z[b>>1]|z[b+2>>1]<<16);x[a+4>>2]=x[a+4>>2]+4;jc(a);fb=c+16|0}function Eh(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=Ye(b+8|0,Cd(b+12|0,b+4|0));fb=b+16|0;return y[a|0]}function BL(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}_(14279,13274,1180,5734);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function cD(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=b;b=c-b|0;g=e,h=ZC(d,f,b>>2)+b|0,x[g+12>>2]=h;qc(a,c,e+12|0);fb=e+16|0}function UU(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=b;b=c-b|0;g=e,h=TU(d,f,b>>1)+b|0,x[g+12>>2]=h;qc(a,c,e+12|0);fb=e+16|0}function wH(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+8>>2]=a;x[d+12>>2]=b;x[d>>2]=c;x[d+4>>2]=0;a=Wr(d+8|0,d);fb=d+16|0;return x[a>>2]}function me(a){var b=0;a=x[a+4>>2];if(a){if(um(a)){a:{b=a+8|0;if(x[b>>2]){if((mx(b)|0)!=-1){break a}}ib[x[x[a>>2]+16>>2]](a)}}}}function jT(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(y[a+480180|0]&2){break a}}x[b+56>>2]=0;d=Go(a,z[b+70>>1],x[b+48>>2],c,0)}return d}function jK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=yt(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function h9(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+4;a=x[a>>2]}else{a=-1}return a|0}function fK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=tt(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function ez(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}zc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function dH(a,b,c,d){a=Nb(a);x[31609]=0;S(d|0,a|0,b|0,c|0);b=x[31609];x[31609]=0;if((b|0)!=1){return a}b=N()|0;wc(a);Q(b|0);p()}function NB(a,b){var c=0;c=x[a+484360>>2];b=b&255;if(Gj(c,x[a+484364>>2])>>>0<=b>>>0){return Xb(c,y[a+484376|0])}return Mj(c,b)}function M5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function EC(a,b){var c=0;c=fb-16|0;fb=c;a=Zb(c+8|0,(b>>>3&536870908)+a|0,1<<b);a=Gb(x[x[a>>2]>>2],x[a+4>>2]);fb=c+16|0;return a}function yC(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];cl(a);Db(b)}fb=c+16|0}function vr(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function tv(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];oC(a);Db(b)}fb=c+16|0}function qu(a){var b=0;b=C[a+4248>>3]/+A[x[a+16>>2]+24620>>2];C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*(C[a+4288>>3]/60)}}function ou(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];dA(a);Db(b)}fb=c+16|0}function oS(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];n$(a);Db(b)}fb=c+16|0}function ke(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Z$(b);a=x[a>>2];b=x[a>>2];tE(a);Db(b)}fb=c+16|0}function fS(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Du(b);a=x[a>>2];b=x[a>>2];Cu(a);Db(b)}fb=c+16|0}function cU(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){ZT(b);a=x[a>>2];b=x[a>>2];cl(a);Db(b)}fb=c+16|0}function cG(a,b){var c=0;c=x[b+4>>2];if(c){cc(a,c,x[b>>2]);return}c=x[b+8>>2];b=x[b+12>>2];if(!mc(c,b)){se(a,c,b);return}Md(a)}function aH(a,b,c){a=li(a);a:{if(a>=b){break a}c=0;if(a<=E(0)){break a}if(a<E(4294967296)&a>=E(0)){c=~~a>>>0;break a}}return c}function _o(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];NY(a);Db(b)}fb=c+16|0}function _R(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Lp(b);a=x[a>>2];b=x[a>>2];hx(a);Db(b)}fb=c+16|0}function _B(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){NU(b);a=x[a>>2];b=x[a>>2];Zo(a);Db(b)}fb=c+16|0}function Qi(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];Zo(a);Db(b)}fb=c+16|0}function JT(a){var b=0,c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];HB(a);Db(b)}fb=c+16|0}function HU(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){Bd(b,a)}if(c){Bd(c,a)}if(d){Bd(d,a)}if(e){Bd(e,a)}}function E5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function BS(a,b,c,d){pB(a,a+1074376|0,b,c,d);c=0-y[(D(b,872)+a|0)+1075804|0]|0;if(d){d=0}else{d=Ju(x[a+480180>>2])}Ao(a,b,c,d)}function z3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(lh(a,x[b+8>>2],0)){Ux(b,c,d);return}a=x[a+8>>2];ib[x[x[a>>2]+28>>2]](a,b,c,d)}function eO(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=gu(Ec(8));x[c+4>>2]=a;x[c>>2]=48416;a=yf(b+12|0,c);fb=b+16|0;return x[a>>2]}function cv(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=b;b=c-b|0;g=e,h=dC(d,f,b)+b|0,x[g+12>>2]=h;qc(a,c,e+12|0);fb=e+16|0}function Zx(a,b){var c=0,d=0,e=0,f=0;c=Ef(b);d=Ec(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=zc(nc(d),b,c+1|0),x[e>>2]=f}function XM(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=JM(Ec(8));x[c+4>>2]=a;x[c>>2]=73448;a=yf(b+12|0,c);fb=b+16|0;return x[a>>2]}function Nr(a,b){return Fk(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24),y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))?b:a}function MG(a){a=a|0;var b=0;a=Fb(a);x[31609]=0;O(130,a|0,13785);b=x[31609];x[31609]=0;if((b|0)==1){b=N()|0;tb(a);Q(b|0);p()}}function yY(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;if((cm(x[a>>2],x[a+4>>2])|0)!=65535){w0(a,c+14|0)}fb=c+16|0}function yT(a){tB(a);x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;a=og(a);og(a+12|0);v[a+24|0]=1}function kK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=yt(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function hK(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=tt(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function Wl(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(!(ib[x[x[a>>2]+32>>2]](a,0,b)|0)){break a}}x[a+12>>2]=b;c=1}return c}function Sc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}hb=c;return a}function Gg(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return No(a,d)}function Dl(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;zA(a,c,d)}function xia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=Bh(E(Pd(c,E(0))*E(255))),v[d|0]=e;su(a)}}function pr(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return ib[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function Dha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=Bh(E(Pd(c,E(0))*E(127))),v[d|0]=e;mu(a)}}function vR(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function uI(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|(e&2147418112)>>>16)<<16}function kp(a){x[a+32>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function _G(a,b){x[a>>2]=b;kL(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function IC(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Eu(a,b,c){c=c&255;while(1){a:{if(!b){a=0;break a}if(mc(y[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function CS(a,b,c,d){qB(a,a+1074376|0,b,c,d);c=y[(D(b,872)+a|0)+1075803|0];if(d){d=0}else{d=Ju(x[a+480180>>2])}Ao(a,b,c,d)}function oe(a,b){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))}function MX(a,b,c){c=c&65535;while(1){a:{if((a|0)!=(b|0)){if((c|0)!=z[a>>1]){break a}}else{a=b}return a}a=a+2|0;continue}}function Ge(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function Fp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function ph(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;x[f+12>>2]=e;c=rh(f+8|0,c);a=rt(a,b,d,x[f+12>>2]);qh(c);fb=f+16|0;return a}function pF(a,b){var c=0;c=Aua(b&255,0,1536,0);b=hb;a=Aua(a&255,0,25,0);c=a+c|0;b=hb+b|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function aY(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!jh(a,4)){qD(b);break a}mh(c+8|0,b);YC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function _U(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){ZU(a,1);ZU(a,0)}}function _K(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function ZV(a){var b=0;if(!(y[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){x[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function CW(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((y[a+b|0]-32&255)>>>0<95){continue}}break}return(b|0)==8}function $U(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){YU(a,1);YU(a,0)}}function zX(a){var b=0;if(!(jd(a,13926,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64))){b=(y[a+33|0]-1&255)>>>0<32}return b}function fu(a){a=a|0;var b=0;x[a>>2]=47628;Bd(a,0);b=x[a+8>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+8>>2]=0;return Pm(a)|0}function ff(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function dF(a){var b=0;b=0;a:{if(jd(a,14249,3)){break a}a=y[a+3|0];b=1;if((a|0)==1){break a}b=(a-8&255)>>>0<7}return b}function Z2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return ib[a|0](h|b,c,d,e,b|f,g)|0}function Wka(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=yf(b+12|0,Rb(Ec(6668),0,6668));fb=b+16|0;x[a>>2]=x[c>>2];return a|0}function Qfa(a){a=a|0;var b=0;b=fb-16|0;fb=b;if(a){a=pc(b+8|0,a);a=Sz(x[a>>2],x[a+4>>2])}else{a=0}fb=b+16|0;return a|0}function PZ(a,b,c){var d=0;while(1){if(b){d=y[c|0]|y[c+1|0]<<8;v[a|0]=d;v[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function $u(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function $S(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Yb(x[a>>2]+((D(c<<24>>24,(d^-1|-256)+b|0)|0)/2|0)|0,0,256),x[e>>2]=f}}function ri(a){var b=0;while(1){a:{if((b|0)!=47){if(y[b+42160|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function rK(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;b=rh(d+8|0,b);a=qK(a,9278,x[d+12>>2]);qh(b);fb=d+16|0;return a}function lga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=2){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;MP(a)}}function gha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=5){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;$P(a)}}function fH(a,b,c){a=Fe(a);a:{if(a>=b){break a}c=0;if(a<=0){break a}if(a<4294967296&a>=0){c=~~a>>>0;break a}}return c}function dga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=3){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;KP(a)}}function _ga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=4){c=Pd(c,E(0));d=yb(a+4208|0,b),e=c,B[d>>2]=e;XP(a)}}function Ss(a){if(a>>>0<=131071){return y[(a>>>3&31|y[(a>>>8|0)+112800|0]<<5)+112800|0]>>>(a&7)&1}return a>>>0<196606}function R8(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=KD(x[b>>2]);x[a+36>>2]=b;c=a,d=io(b),v[c+44|0]=d}function J8(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=Py(x[b>>2]);x[a+36>>2]=b;c=a,d=io(b),v[c+44|0]=d}function t8(a){a=a|0;var b=0,c=0;c=x[a+4>>2];b=x[a>>2];a=x[a+8>>2];b=b+(a>>1)|0;if(a&1){c=x[c+x[b>>2]>>2]}ib[c|0](b)}function qI(a,b,c){var d=0;if(c){d=a;while(1){x[d>>2]=x[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a}function gV(a){x[a+700>>2]=0;w[a+842>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function Z$(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Hd(b);continue}break}x[a+4>>2]=c}function U$(a){var b=0;if(!y[a+12|0]){b=fb-16|0;fb=b;vb(b+12|0,x[x[a+8>>2]>>2]);vb(b+8|0,x[x[a+4>>2]>>2]);fb=b+16|0}}function Lp(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Hp(b);continue}break}x[a+4>>2]=c}function Gh(a){var b=0;nn(a);b=pv(x[a>>2],Zk(z[a+34>>1]));x[a+20>>2]=b;if(!b){return 0}return Qk(x[a>>2],z[a+34>>1])}function uh(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=Hb(b+12|0,b+8|0);fb=b+16|0;return x[a>>2]}function qr(a){var b=0,c=0,d=0;if(x[a>>2]){Nc(a);b=x[a>>2];Vg(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function gR(a){var b=0,c=0,d=0;if(x[a>>2]){Nc(a);b=x[a>>2];hw(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function VU(a){var b=0,c=0,d=0;if(x[a>>2]){Nc(a);b=x[a>>2];Hn(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function VT(a){var b=0,c=0,d=0;if(x[a>>2]){Nc(a);b=x[a>>2];Sn(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function Hta(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-80|0;fb=b;c=-1;d=a;a=b+14|0;if(G$(d,a)){c=F$(a)}fb=b+80|0;return c|0}function zc(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function zL(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function iua(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+8|0;if(hk(d,a)){c=j0(a)}fb=b+16|0;return c|0}function gM(a,b){var c=0;c=fb-16|0;fb=c;a=Yo(c+4|0,a,1);qo(x[a+4>>2],y[b|0]);x[a+4>>2]=x[a+4>>2]+1;jc(a);fb=c+16|0}function b0(a,b,c,d,e){v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c;v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111}function Qpa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+4|0;if(dE(d,a)){c=GX(a)}fb=b+16|0;return c|0}function Eqa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+8|0;if(hk(d,a)){c=oY(a)}fb=b+16|0;return c|0}function vt(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}Tb(a,b);a=a+4|0;continue}}}function hT(a,b){var c=0;c=b&15;if(c){v[a+827|0]=c<<2}b=b&240;if(b){v[a+826|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function cL(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!mc(fL(c,b),-1)){break a}x[a>>2]=0}return a|0}function WR(a,b){var c=0;c=fb-16|0;fb=c;a=kC(c+4|0,a);vq(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;jc(a);fb=c+16|0}function WP(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function Hl(a,b){var c=0;c=b&15;if(c){v[a+824|0]=c<<2}b=b&240;if(b){v[a+823|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function Fda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=ib[x[x[b>>2]+8>>2]](b)|0;d=c,e=Cg(a?a:22292),x[d>>2]=e}}function Dm(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}rg(a,b);a=a+1|0;continue}}}function AR(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];if((c|0)==(d|0)){a=zR(x[a>>2],c,x[b>>2],d)}else{a=1}return!a}function VP(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;x[a+8>>2]=b;continue}break}}function _A(a,b){var c=0;c=fb-16|0;fb=c;a=ye(c+8|0,Bua(a,b,1e6,0),hb);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function TM(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(!Nd(c,x[a>>2])){break a}}else{a=b}return a}a=a+8|0;continue}}function Kl(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function xH(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=yb(c,a);a=a+1|0;x[d>>2]=a<<b;continue}break}}function wia(a,b){a=a|0;b=b|0;var c=E(0);if(b>>>0<=3){c=E(E(y[(a+b|0)+4264|0])/E(255))}else{c=E(0)}return E(c)}function lh(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!hi(x[a+4>>2],x[b+4>>2])}function kf(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function jw(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=(D(a,b)>>>0)/255;Ge(c+12|0,0,15);fb=c+16|0;return y[c+12|0]}function bm(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=Hb(b+12|0,b+8|0);fb=b+16|0;return z[a>>1]}function XQ(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=Hb(b+12|0,b+8|0);fb=b+16|0;return w[a>>1]}function Rs(a){if(a>>>0<=131071){a=y[(a>>>3&31|y[(a>>>8|0)+116704|0]<<5)+116704|0]>>>(a&7)&1}else{a=0}return a}function Dn(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function Cha(a,b){a=a|0;b=b|0;var c=E(0);if(b>>>0<=2){c=E(E(y[(a+b|0)+4232|0])/E(127))}else{c=E(0)}return E(c)}function wq(a,b){var c=0;c=fb-32|0;fb=c;mh(c+16|0,b);Nm(c+24|0,a,x[c+16>>2],x[c+20>>2]);mh(c+8|0,b);fb=c+32|0}function uS(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function q2(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;c=-1;d=a;a=b+8|0;if(JG(d,a)){c=IG(a)}fb=b+32|0;return c|0}function ew(a){var b=0;b=fb-16|0;fb=b;w[b+14>>1]=a;w[b+12>>1]=255;a=Oc(b+14|0,b+12|0);fb=b+16|0;return y[a|0]}function T3(){if(y[499812]){return x[124952]}Bs(499804,x[oH()>>2]);v[499812]=1;x[124952]=499804;return 499804}function Sx(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=Tx(x[e>>2],h)}ib[x[x[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function QP(a){a=a|0;var b=0;b=4960;while(1){b=b-24|0;wc(b+a|0);if((b|0)!=4504){continue}break}return _f(a)|0}function Ml(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+8>>2]=c;Zb(a,b,x[Hb(e+12|0,e+8|0)>>2]);fb=e+16|0}function K1(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;c=-1;d=a;a=b+8|0;if(hk(d,a)){c=eG(a)}fb=b+16|0;return c|0}function Ek(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=c+12|0;x[a>>2]=x[a>>2]+(b<<2);fb=c+16|0;return x[a>>2]}function iK(a,b,c,d,e){b=hj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:b>>>0<100?b+1900|0:b)-1900}}function hL(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return zf(v[b|0])}function eK(a,b,c,d,e){b=gj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:b>>>0<100?b+1900|0:b)-1900}}function EU(a){var b=0;b=x[a+4>>2];w[a+70>>1]=y[((z[b+20>>1]>>>6|z[b+22>>1]<<4)&65535)+27392|0]>>>z[a+68>>1]}function ufa(){var a=0;a=fb-16|0;fb=a;if($a(a+12|0,4)|0){Ht(x[31484],12726);p()}fb=a+16|0;return x[a+12>>2]}function si(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=255;a=Hb(b+12|0,b+8|0);fb=b+16|0;return y[a|0]}function rA(a,b){a=Nb(a);x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Nb(a+24|0);Fb(a+36|0);x[a+48>>2]=b;return a}function iV(a,b){a=a|0;b=b|0;var c=0;c=Cb(x[a+4>>2],y[a+11|0]);if(c>>>0<b>>>0){ys(a,b-c|0,0);return}UT(a,b)}function aea(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return SH(a,b,c,d,e,f,g,12993,1078)|0}function UX(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(b>=0){C[a+8>>3]=b;x[a+16>>2]=3}return a}function Tda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return SH(a,b,c,d,e,f,g,13061,1085)|0}function Ol(a,b,c,d){a=a&65535;c=c&65535;a=(a|0)!=(c|0)?a>>>0<c>>>0?-1:1:0;if(Lj(a)){a=TT(b,d)}return vd(a)}function OL(a,b,c,d){B[d+4>>2]=a+c;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=b+a}function Nqa(a,b){a=a|0;b=b|0;if(!JY(a,b)){v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0}}function Ax(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+12>>2]=x[b+12>>2]+12;fb=b+16|0;return Pp(x[b+12>>2])}function Sb(){var a=0;a=x[31483];x[31609]=0;X(a|0);a=x[31609];x[31609]=0;if((a|0)==1){Y(T(0)|0)|0}kI();p()}function Pu(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Do(a);continue}break}return a}function DW(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function xua(a){a=a|0;var b=0;b=x[a+76>>2];if(mc(-1,b)){b=oF(x[a+28>>2],32);x[a+76>>2]=b}return b<<24>>24}function sl(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function dI(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=0;return Jz(g|a,b,c,d,a|e,f)|0}function _I(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function Ps(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=Tx(x[d>>2],g)}ib[x[x[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function Ob(a,b){var c=0;c=fb-16|0;fb=c;VF(c+8|0,a,b);a=Gb(x[x[c+8>>2]>>2],x[c+12>>2]);fb=c+16|0;return a}function HN(a,b){a=a|0;b=b|0;a=Dj(a);x[a+4>>2]=0;x[a>>2]=47568;x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0;return a|0}function F$(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1179468868&(y[a+4|0]-1&255)>>>0<10}function zT(a,b,c){var d=E(0);a:{if(b>c){break a}d=B[a>>2];if(!(d<b)){b=c;if(!(d>b)){break a}}B[a>>2]=b}}function pX(a){var b=0;a=a&15;b=0;a:{if(!a){break a}b=12-a|0;if(a>>>0<=12){break a}b=24-a|0}return b&255}function oda(a){a=a|0;var b=0;b=fb-16|0;fb=b;fe(b+8|0,a);a=Sz(x[b+8>>2],x[b+12>>2]);fb=b+16|0;return a|0}function nW(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;yC(c);continue}break}x[a+4>>2]=b}function mz(a,b,c){b=(D(D(kz(a),lz(a,b)),125)>>>0)/(WL(a,b)>>>0)|0;a=(a&6)==6?b&134217724:b;return a?a:c}function el(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;x[c+12>>2]=x[c+12>>2]-b;fb=c+16|0;return x[c+12>>2]}function eS(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;vk(c);continue}break}x[a+4>>2]=b}function a0(a,b){a=qm(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];qm(a+12|0,x[b+12>>2],x[b+16>>2]);return a}function Yca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return xO(x[a+4>>2],b,c,d,e,f,g)|0}function YT(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;tf(c);continue}break}x[a+4>>2]=b}function Vca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return qO(x[a+4>>2],b,c,d,e,f,g)|0}function SE(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;ub(c);continue}break}x[a+4>>2]=b}function Pb(a,b,c){var d=0;c=c+x[a+4>>2]|0;d=b;b=x[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;x[a>>2]=b;x[a+4>>2]=c}function MU(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Ak(c);continue}break}x[a+4>>2]=b}function nj(a){a:{a=a&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function fv(a,b){b=Aua(a,a>>31,b,b>>31);a=hb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Gc(Bua(b,a,1e6,0),hb)}function My(a){if(!x[a+136>>2]){x[a+136>>2]=x[x[124115]>>2]?104928:104904}if(!x[a+72>>2]){x[a+72>>2]=1}}function FJ(a){var b=0,c=0;b=fb-16|0;fb=b;a=rh(b+12|0,a);c=x[x[124115]>>2];qh(a);fb=b+16|0;return c?4:1}function AT(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}C[a>>3]=d}}function op(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Nn(a,b+12|0)){c=$b(x[b+12>>2])}fb=b+16|0;return c|0}function Pk(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Dp(a,b+14|0)){c=Bb(z[b+14>>1])}fb=b+16|0;return c|0}function zv(a){var b=0;b=x[a+4>>2];a:{if((b|0)!=31){b=b+1|0;break a}x[a>>2]=x[a>>2]+4;b=0}x[a+4>>2]=b}function wV(a){if(((y[a+68|0]|y[a+69|0]<<8)-128&65535)>>>0>=65409){a=jd(a,18321,17)}else{a=1}return!a}function pS(a){a=Fb(a);Fb(a+12|0);Fb(a+24|0);Fb(a+36|0);Fb(a+48|0);Fc(a+60|0,0);x[a+64>>2]=0;return a}function dw(a){var b=0,c=0;if(x[a>>2]){Nc(a);Db(x[a>>2]);b=Ab(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function _v(a){a=a|0;var b=0;w[a+34>>1]=0;b=a+43|0;Qm(b,b+22|0,78544);x[a+20>>2]=0;nd(a,0);return a|0}function Rb(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function QZ(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Bb(b&65535),w[d+14>>1]=e;Wv(a,c+14|0);fb=c+16|0}function zV(a){ke(a+140|0);ub(a+120|0);ub(a+100|0);ub(a+80|0);ub(a+60|0);ub(a+40|0);ub(a+20|0);ub(a)}function u1(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;En(c+8|0,b);zp(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function tf(a){var b=0,c=0;b=fb-16|0;fb=b;a=x[vb(b+12|0,a)>>2];c=x[a>>2];if(c){Ab(a);Db(c)}fb=b+16|0}function tZ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){sZ(c+52|0);tb(c+40|0);wc(c+16|0);wc(c+4|0);Db(c)}}function s1(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);Xr(a,127);LF(a,127,y[b|0]);return a|0}function qqa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Dp(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)<<16>>16}function mS(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function bE(a,b){if(b>>>0<=126){Ve(((b<<5)+a|0)+480280|0);Qo((D(b,872)+a|0)+1074992|0,a,b,67108864)}}function Zha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=xj(a);if(a){ib[x[x[a>>2]+88>>2]](a,b,c,d,e)}}function OH(a,b,c){var d=0;d=fb-16|0;fb=d;c=Dc(d+4|0,c);a=sc(a,c);tb(c);x[a>>2]=b;fb=d+16|0;return a}function K9(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;E0(c+8|0,b);zp(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function Ig(a,b,c){var d=0;d=x[a>>2];c=x[a+4>>2]-(c+(d>>>0<b>>>0)|0)|0;b=d-b|0;x[a>>2]=b;x[a+4>>2]=c}function GE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0}function $k(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function py(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=rh(f+12|0,e);a=fq(a,b,c,d);qh(e);fb=f+16|0;return a}function ln(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=a;a=Zb(d+8|0,b,c);cc(e,x[a>>2],x[a+4>>2]);fb=d+16|0}function iJ(a,b,c){a:{if(!(y[b+120|0]|c>>>0>30)){v[b+120|0]=1;break a}b=AY(c)}x[a+4>>2]=c;x[a>>2]=b}function Vha(a,b,c){a=a|0;b=b|0;c=c|0;a=xj(a);if(!a){return 0}return ib[x[x[a>>2]+104>>2]](a,b,c)|0}function Uc(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];xx(b);return a}function U5(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[(c<<2)+95344>>2]&b)!=0}else{a=0}return a|0}function RR(a,b){if(b>>>0<=255){a=x[((b<<2)+a|0)+900380>>2];a=a?a+492|0:22292}else{a=22292}return a}function HF(a,b,c,d,e,f,g){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e);vb(a+16|0,f);vb(a+20|0,g)}function Di(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=rh(f+12|0,e);a=cK(a,b,c,d);qh(e);fb=f+16|0;return a}function Bda(a,b){a=a|0;b=b|0;var c=0;b=Kb(b);c=x[a+4>>2];if(c){ib[c|0](b,x[a+8>>2]);return}ku(b,a)}function $T(a,b,c){var d=0;d=fb-16|0;fb=d;a=vb(d+12|0,ST(b,c,de(a),gc(a)));fb=d+16|0;return x[a>>2]}function Pw(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=eh(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)<<24>>24}function qw(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Dc(c+4|0,b);Uc(d,a);tb(a);fb=c+16|0}function lt(a,b){a=a|0;b=b|0;b=x[b+68>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function gra(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Nn(a,b+12|0);fb=b+16|0;return E(a?B[b+12>>2]:E(0))}function gg(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=uc(c+4|0,b);Uc(d,a);tb(a);fb=c+16|0}function dea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return VH(a,b,c,d,e,f,10664,1075)|0}function YJ(a,b){a=a|0;b=b|0;b=x[b+64>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function WQ(a,b){var c=0;c=fb-16|0;fb=c;a=ye(c+8|0,a,b);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function TJ(a,b){a=a|0;b=b|0;b=x[b+72>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Rea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return VH(a,b,c,d,e,f,10709,1048)|0}function Od(){var a=0;if(y[499788]){return x[124946]}a=lk(14337);v[499788]=1;x[124946]=a;return a}function tS(a,b,c,d){return(a|0)!=(c|0)|(b|0)!=(d|0)?a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)?-1:1:0}function sz(a,b,c,d){var e=0;e=fb-16|0;fb=e;cc(e+8|0,c,d);YM(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function rua(a,b){a=a|0;b=b|0;if(!BE(a,b)){v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b|0]=0}}function q9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function p9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function o9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function n9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function m9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function Zz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function QD(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=s_(c+12|0,0-b|0);fb=c+16|0;return x[a>>2]}function Nm(a,b,c,d){var e=0;e=fb-16|0;fb=e;lf(e+8|0,c,d);YM(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function v0(a,b){a=a|0;b=b|0;if(!BE(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0}}function t3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(lh(a,x[b+8>>2],f)){Wx(b,c,d,e)}}function fca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;cP(a,x[b+4>>2],c,d,e,f,g)}function ax(a,b){a=$F(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];$F(a+12|0,x[b+12>>2],x[b+16>>2])}function aca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;AO(a,x[b+4>>2],c,d,e,f,g)}function Vaa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=yf(b+12|0,Tl(Ec(12),a));fb=b+16|0;return x[a>>2]}function Mja(a,b){a=a|0;b=b|0;Ki(a);Ki(a);a:{if(b>>>0>=60){Vb(a,4);break a}Ki(a)}return Ki(a)|0}function B2(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;TI(d,b);Qh(a,d);tb(d);fb=c+16|0}function AX(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function $8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function oK(a){var b=0;b=x[124115];if(a){x[124115]=(a|0)==-1?501692:a}return(b|0)==501692?-1:b}function Zd(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=eh(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)&255}function Yba(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;bP(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function Xba(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;zO(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function ND(a){var b=0,c=0;b=fb-16|0;fb=b;if(Dp(a,b+14|0)){c=ze(w[b+14>>1])}fb=b+16|0;return c}function L$(a){var b=0;if(!(jd(a,24724,20)|(y[a+25|0]-9&255)>>>0<248)){b=v[a+47|0]>=0}return b}function IW(a){var b=0,c=0;b=fb-16|0;fb=b;if($E(a,b+12|0)){c=$b(x[b+12>>2])}fb=b+16|0;return c}function DL(a){var b=0;b=+((a&2097151)>>>0);return E(ok(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function A$(a,b){return(Yb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((D(a&15,b)>>>0)/15|0,1,15))&255}function fD(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;pY(c+12|0,b);fb=c+16|0;return x[c+12>>2]}function _pa(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=a;a=Yh(b+12|0);mY(c,a,0,0);ub(a);fb=b+32|0}function U_(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;T_(c+12|0,b);fb=c+16|0;return x[c+12>>2]}function UY(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==1279544644&y[a+4|0]<32}function Qm(a,b,c){b=b-a|0;while(1){if((b|0)>0){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function Pm(a){a=a|0;var b=0;x[a>>2]=47588;b=x[a+4>>2];if(b){Db(tq(b))}x[a+4>>2]=0;return a|0}function Ic(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=o_(a,b,x[c>>2],d)}else{a=1}return!a}function $ba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return hu(x[x[a+4>>2]+24>>2],b,c,d,e)|0}function vf(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=yU(c+12|0,b);fb=c+16|0;return x[a>>2]}function j9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return ib[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function et(a){a=a|0;var b=0;x[a>>2]=95296;b=x[a+8>>2];if(!(!b|!y[a+12|0])){Db(b)}return a|0}function QC(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function KX(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=JX(c+12|0,b);fb=c+16|0;return x[a>>2]}function KQ(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;pY(b+12|0,-1);fb=b+16|0;return x[b+12>>2]}function sB(a){var b=0;x[a+84>>2]=0;x[a+88>>2]=0;b=x[a+80>>2];x[a+92>>2]=b;x[a+96>>2]=b<<12}function qy(a,b,c){var d=0;d=fb-16|0;fb=d;c=rh(d+12|0,c);a=It(a,b);qh(c);fb=d+16|0;return a}function j0(a){return(y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))==810369604&y[a+4|0]<4}function gh(a){var b=0;b=fb-16|0;fb=b;a=Dp(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)&65535}function eg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){bE(a,c);b=b+1|0;continue}break}}function _fa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;Iz(a,b,c,d,e,0,0,f,g)}function W4(a,b){a=a|0;b=b|0;a=xd(a,0);VI(a+8|0,b);x[a>>2]=100324;x[a>>2]=100608;return a|0}function UE(a){var b=0;b=x[a>>2];if(x[b>>2]){SE(b,x[b>>2]);a=x[a>>2];b=x[a>>2];TE(a);Db(b)}}function U4(a,b){a=a|0;b=b|0;a=xd(a,0);VI(a+8|0,b);x[a>>2]=100480;x[a>>2]=100724;return a|0}function PD(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=0;Bu(b+12|0,a);fb=b+16|0;return x[b+12>>2]}function GF(a,b){if((a&4088)>>>0>=520){b=Sw(0-Dua(b^1230262859,25)|0,4)^1247037516}return b}function Fpa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Xh(a,b+8|0);fb=b+16|0;return+(a?C[b+8>>3]:0)}function EN(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=DN(d);b=b+1|0}tU(a,b,c,d,e)}function vx(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=x[(b<<2)+22304>>2]}else{b=9758}uc(a,b)}function gL(a){var b=0;b=x[a>>2];if(b){if(!mc(hL(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function _ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=xj(a);if(a){ib[x[x[a>>2]+84>>2]](a,b,c,d)}}function Yha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=xj(a);if(a){ib[x[x[a>>2]+92>>2]](a,b,c,d)}}function RP(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function Fh(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function Am(a,b,c){var d=E(0);if(b>>>0<=c>>>0){d=B[yb(a+4208|0,b)>>2]}else{d=E(0)}return d}function $ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=xj(a);if(a){ib[x[x[a>>2]+76>>2]](a,b,c,d)}}function $F(a,b,c){var d=0;d=fb-16|0;fb=d;b=qm(d+8|0,b,c);CG(b,a);me(b);fb=d+16|0;return a}function wJ(a,b){a=xd(a,b);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=95296;x[a+8>>2]=95344;return a}function uU(a,b,c){while(1){if((b|0)!=(c|0)){rU(a,y[b|0]);b=b+1|0;continue}break}return a}function u$(a,b,c){var d=0;d=fb-16|0;fb=d;qi(d+8|0,b,c);fb=d+16|0;return x[d+8>>2]==(a|0)}function sy(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;a=rt(a,b,c,d);fb=e+16|0;return a}function sx(){var a=0,b=0;a=fb-16|0;fb=a;b=yf(a+12|0,Nb(Ec(12)));fb=a+16|0;return x[b>>2]}function oq(a){a=a|0;var b=0;x[a>>2]=47568;b=x[a+4>>2];if(b){Db(b);x[a+4>>2]=0}return a|0}function mA(a,b){if((a|0)>=0){return(a>>>0)%(b>>>0)|0}return(((a^-1)>>>0)%(b>>>0)^-1)+b|0}function iF(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;hb=b>>>0<2624?a+1|0:a;return b}function es(a){var b=0;while(1){if(!mc(y[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function N2(a,b,c){a=a|0;b=b|0;c=c|0;ib[x[x[b>>2]+8>>2]](b,c);Bs(a,x[b+4>>2]);YG(b+4|0,c)}function El(a,b,c){a=a+1074992|0;return x[(a+D(b,872)|0)+680>>2]>x[(a+D(c,872)|0)+680>>2]}function Dua(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function sX(a,b){var c=0;c=fb-16|0;fb=c;En(c+8|0,b);lZ(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function rn(a){var b=0;if(a>>>0>=2){b=HY(a+1|0);a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function nw(a,b){var c=0;c=fb-16|0;fb=c;a=vb(c+12|0,D(b,6)+a|0);fb=c+16|0;return x[a>>2]}function nS(a){var b=0;b=a+4e4|0;while(1){b=UA(b-160|0);if((b|0)!=(a|0)){continue}break}}function fn(a,b){var c=0;c=fb-16|0;fb=c;a=vb(c+12|0,(b<<1)+a|0);fb=c+16|0;return x[a>>2]}function bu(a){if(PM(a)){a=dc(4);x[a>>2]=0;a=Dj(a);x[a>>2]=124064;da(a|0,124100,34);p()}}function bia(a,b){a=a|0;b=b|0;a=xj(a);if(!a){return 1}return ib[x[x[a>>2]+68>>2]](a,b)|0}function XB(a,b){a=Tl(a,b);Uc(a+12|0,b+12|0);w[a+28>>1]=z[b+28>>1];x[a+24>>2]=x[b+24>>2]}function QS(a,b){var c=0;c=y[a+851|0];if(c&1){v[a+851|0]=c|64;x[a+852>>2]=x[a+852>>2]+b}}function Mx(a,b,c,d){var e=0;e=x[b>>2];x[a+8>>2]=b;x[a>>2]=e;x[a+4>>2]=(c<<d)+e;return a}function um(a){var b=0;b=mx(a+4|0);if((b|0)==-1){ib[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function ts(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=DN(d);b=b+1|0}EB(a,b,c,d)}function tJ(a,b){a=xd(a,b);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=96584;Fb(a+16|0);return a}function lW(a,b,c){var d=0;d=x[b>>2];x[a+8>>2]=b;x[a>>2]=d;x[a+4>>2]=D(c,12)+d;return a}function cea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return UH(a,b,c,d,e,12449,1076)|0}function V1(a){a=a|0;var b=0;b=x[a+4>>2];return(ib[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function SJ(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a=qK(a,11204,b);fb=c+16|0;return a}function Rv(a,b,c){var d=E(0);d=B[a>>2];if(!Qv(d,B[b>>2])){b=Qv(B[c>>2],d)?c:a}return b}function Qea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return UH(a,b,c,d,e,12549,1049)|0}function Ng(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function Fq(a,b,c){a=Jl(a)-x[a+16>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function DD(a){var b=0;b=nV(a);while(1){if((a|0)!=(b|0)){_$(a);a=a+32|0;continue}break}}function $l(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=c;Sh(a,b,d+15|0);fb=d+16|0;return a}function $K(a){var b=0;b=x[a>>2];if(b){if(!ko(sl(b))){return!x[a>>2]}x[a>>2]=0}return 1}function zU(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function oJ(a,b){a=xd(a,b);b=a+8|0;x[b>>2]=104276;x[a>>2]=99260;x[b>>2]=99308;return a}function nJ(a,b){a=xd(a,b);b=a+8|0;x[b>>2]=104312;x[a>>2]=99524;x[b>>2]=99572;return a}function ku(a,b){a=a|0;b=b|0;b=fb-16|0;fb=b;x[b>>2]=a;pP(18472,b);ju(125480);fb=b+16|0}function k0(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+24672|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function i5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[x[x[b>>2]+16>>2]](a,b,c,d,e,8)}function _da(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return RH(a,b,c,d,e,9642,1079)|0}function Sda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return RH(a,b,c,d,e,9714,1086)|0}function I5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+107120>>2]}return b<<24>>24}function HE(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;v[c+15|0]=b;Bw(a,c+15|0);fb=c+16|0}function G5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+105584>>2]}return b<<24>>24}function EV(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;hb=b>>>0<259?a+1|0:a;return b}function DG(a,b){var c=0;c=fb-16|0;fb=c;b=Ff(c+8|0,b);CG(b,a);me(b);fb=c+16|0;return a}function Ac(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;En(d,a);nm(d,b);fb=c+16|0;return a}function A2(){var a=0;a:{if(SG(20054022)){break a}if(QG()){break a}a=PG()^1}return a|0}function xk(a,b,c){var d=0;d=fb-16|0;fb=d;$B(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function uA(a,b,c){var d=0;d=fb-16|0;fb=d;jR(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function tA(a,b,c){var d=0;d=fb-16|0;fb=d;Iv(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function sI(a){return(a|0)!=0&(a|0)!=104904&(a|0)!=104928&(a|0)!=501600&(a|0)!=501624}function kJ(a){var b=0;b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];ny(it(a),x[a>>2],Vg(a))}}function aC(a,b,c){var d=0;d=fb-16|0;fb=d;RU(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function _7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return GH(b,c,d,e,f,1)|0}function Y7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return GH(b,c,d,e,f,0)|0}function Q7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return EH(b,c,d,e,f,1)|0}function OJ(a,b){var c=0,d=0;Qe(a,ne(b));b=gc(b);c=gc(a),d=x[b>>2],x[c>>2]=d;return a}function O7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return EH(b,c,d,e,f,0)|0}function Nv(a,b){var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;Jv(a+236|0,128,c+14|0);fb=c+16|0}function Nu(a,b){if(!(v[b+851|0]&1&x[a+480180>>2]==8)){IA(a,b,0);IA(a,b,1);IA(a,b,2)}}function LJ(a,b,c){var d=0;d=fb-16|0;fb=d;$D(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function Kv(a,b,c){var d=0;d=fb-16|0;fb=d;tY(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function E9(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function D9(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function Av(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function xC(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function t4(a,b,c){a=a|0;b=b|0;c=c|0;a=dy(b,x[a+8>>2]);return((a|0)==-1?c:a)<<24>>24}function jf(a){a=a|0;var b=0;b=x[a>>2];return(ib[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function Zj(a,b,c){var d=0;d=x[a>>2];if(!_q(d,x[b>>2])){b=_q(x[c>>2],d)?c:a}return b}function Zca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return wO(x[a+4>>2],b,c,d,e)|0}function Yg(a,b,c){var d=0;d=C[a>>3];if(!xV(d,C[b>>3])){b=xV(C[c>>3],d)?c:a}return b}function Wca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return pO(x[a+4>>2],b,c,d,e)|0}function TV(a,b,c,d,e,f){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e);vb(a+16|0,f)}function Rg(a){var b=0;b=fb-16|0;fb=b;a=Nn(a,b+12|0);fb=b+16|0;return a?x[b+12>>2]:0}function Mfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mP(a,b,c,d,0,0,0,0,e)|0}function Je(a,b,c){if(Bn(a,b,c)){a=_i(a,c);a=Ib(x[a>>2],x[a+4>>2])}else{a=0}return a}function Do(a){var b=0;b=a;a=x[a>>2];x[b>>2]=D(a,214013)+2531011;return a>>>16&32767}function wR(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[gc(a)+4|0]){Eb(b+16|0)}Db(b)}}function w$(a){var b=0;b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];hw(a);Db(b)}}function ry(a){a=a|0;x[a>>2]=96496;if(x[a+8>>2]!=(Od()|0)){jl(x[a+8>>2])}return a|0}function oia(a){a=a|0;v[a+4202|0]=1;x[a+4232>>2]=x[x[a+16>>2]+24620>>2];su(a);xQ(a)}function oZ(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[gc(a)+4|0]){Oj(b+16|0)}Db(b)}}function oW(a){var b=0;b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];Ab(a);Db(b)}}function lz(a,b){return y[(D(a>>>1&3,15)+D(a>>>3&1,45)+((b&240)>>>4)|0)+80881|0]<<1}function ie(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=48552;qc(a,48448,b+12|0);fb=b+16|0}function gq(a){a=a|0;x[a+56>>2]=93920;x[a>>2]=93900;Ct(a+4|0);ul(a+56|0);return a|0}function eW(a){var b=0;b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];kv(a);Db(b)}}function _l(a,b){var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=Te(Ai(b)*+(c>>>0)),x[d+24>>2]=e}function Yj(a,b){var c=0;c=fb-16|0;fb=c;a=vb(c+12|0,a+b|0);fb=c+16|0;return x[a>>2]}function XV(a){var b=0;b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];hx(a);Db(b)}}function WT(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[gc(a)+4|0]){XT(b+16|0)}Db(b)}}function W$(a,b,c){a=a|0;b=b|0;c=c|0;return V$(a,b,Kb(c),Cb(x[c+4>>2],y[c+11|0]))|0}function TA(a){var b=0;b=fb-16|0;fb=b;vb(b+12|0,a+116|0);a=dS(a);fb=b+16|0;return a}function Qga(a){a=a|0;v[a+4202|0]=1;x[a+4256>>2]=x[x[a+16>>2]+24620>>2];UP(a);TP(a)}function OF(a){var b=0;b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];Hn(a);Db(b)}}function MQ(a){var b=0;b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];Vg(a);Db(b)}}function Gf(a){a=a|0;x[a+60>>2]=94084;x[a>>2]=94064;Ct(a+8|0);ul(a+60|0);return a|0}function Ff(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function EG(a){var b=0;b=x[a>>2];if(x[b>>2]){Nc(b);a=x[a>>2];b=x[a>>2];Sn(a);Db(b)}}function lv(a,b){a=Bb(a&65535);b=Bb(b&65535);return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function gT(a,b){var c=0;c=b&15;if(c){v[a+830|0]=c}b=b&240;if(b){v[a+829|0]=b>>>4}}function Up(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<d);return a}function Sp(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,d);return a}function GL(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function zda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ks(a,b,c,d,e,1101)|0}function xda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ks(a,b,c,d,e,1103)|0}function wda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ks(a,b,c,d,e,1105)|0}function pg(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,gc(a));fb=b+16|0;return x[a>>2]}function pP(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;tL(125480,a,b,0,0);fb=c+16|0}function Xo(a,b){a=zc(a,b,34);w[a+34>>1]=z[b+34>>1];zc(a+36|0,b+36|0,68);return a}function Ti(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,wb(a));fb=b+16|0;return x[a>>2]}function Sca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return YH(a,b,c,d,e,1116)|0}function RQ(a,b,c){while(1){if(b){B[a>>2]=B[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Pf(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,pg(a));fb=b+16|0;return x[a>>2]}function O6(){var a=0,b=0,c=0;a=xd(501152,1);x[a>>2]=96496;b=a,c=Od(),x[b+8>>2]=c}function Ls(a,b,c,d){if(b>>>0>=d>>>0){Sj();p()}c=Ec(D(b,c));x[a+4>>2]=b;x[a>>2]=c}function Jv(a,b,c){while(1){if(b){w[a>>1]=z[c>>1];b=b-1|0;a=a+2|0;continue}break}}function JF(a,b,c){while(1){if(b){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function I_(a,b){var c=0;c=Kb(a);return H_(c,(Cb(x[a+4>>2],y[a+11|0])+c|0)+1|0,b)}function FV(a){if((y[a+14|0]-53&255)>>>0>=252){a=jd(a,15644,14)}else{a=1}return!a}function BC(a,b,c){var d=0;d=x[b>>2];x[a+8>>2]=b;x[a>>2]=d;x[a+4>>2]=c+d;return a}function sfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ks(a,b,c,d,e,994)|0}function qM(a){a=Pn(a);x[a>>2]=77596;Nb(a+4|0);v[a+20|0]=0;x[a+16>>2]=0;return a}function gO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Js(a,b,c,d,e,1100)|0}function dO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Js(a,b,c,d,e,1102)|0}function cO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Js(a,b,c,d,e,1104)|0}function bO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Js(a,b,c,d,e,1020)|0}function _2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ib[a|0](b,c,d)|0;gb=hb;return a|0}function Xg(a,b,c){var d=0;d=fb-16|0;fb=d;$B(d+8|0,b,b+c|0,a);fb=d+16|0;return a}function UN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ox(a,b,c,d,e,1101)|0}function TN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Gs(a,b,c,d,e,1101)|0}function SN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ox(a,b,c,d,e,1103)|0}function RN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Gs(a,b,c,d,e,1103)|0}function QN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Ox(a,b,c,d,e,1105)|0}function PN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Gs(a,b,c,d,e,1105)|0}function Ok(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;hc(a+8|0,b+8|0)}function HX(a){var b=0;while(1){if((b|0)!=512){dh(a+b|0);b=b+1|0;continue}break}}function zH(a,b){x[a>>2]=b;Ub(a+52|0);Ub(a+40|0);Ub(a+28|0);tb(a+16|0);return a}function yH(a,b){x[a>>2]=b;tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);return a}function ti(a){return(gk(x[a>>2],x[a+4>>2])|0)!=(0-gk(x[a+12>>2],x[a+16>>2])|0)}function rU(a,b){var c=0;c=a;a=x[a>>2];x[c>>2]=a<<8^x[((a>>>24^b)<<2)+27532>>2]}function og(a){var b=0,c=0;tc(a+4|0);Fc(a+8|0,0);b=a,c=gc(a),x[b>>2]=c;return a}function lP(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return YH(a,b,c,d,e,995)|0}function hsa(a,b,c){a=a|0;b=b|0;c=c|0;Uc(a,qZ(b,Kb(c),Cb(x[c+4>>2],y[c+11|0])))}function fd(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;qn(a,b,d+12|0);fb=d+16|0}function f$(a,b,c){while(1){if(b){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function cg(a){var b=0;b=xb(a,2);return y[xb(a,1)|0]<<8|y[b|0]<<16|y[xb(a,0)|0]}function b3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[a|0](b,c,d,e,f)}function VR(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;KC(d,1,b);Cc(a,d);fb=c+16|0}function Ub(a){var b=0;if(vd(y[a+11|0])){b=x[a>>2];Zi(x[a+8>>2]);Db(b)}return a}function Nx(a,b,c,d){if(b>>>0>=d>>>0){Sj();p()}c=Ec(b<<c);x[a+4>>2]=b;x[a>>2]=c}function NN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Gs(a,b,c,d,e,994)|0}function Jf(a,b,c){if((c|0)>=0){a=(x[((c&255)<<2)+a>>2]&b)!=0}else{a=0}return a}function Hx(a,b){b=a+b|0;while(1){b=tb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Cba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return lN(a-88|0,b,c,d,e)|0}function CK(){var a=0;a=fb-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function xw(a,b){return Te(Ai((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function qD(a){var b=0;while(1){if((b|0)!=4){dh(a+b|0);b=b+1|0;continue}break}}function i6(a){a=a|0;if(!y[500040]){un(500028,96812);v[500040]=1}return 500028}function h6(a){a=a|0;if(!y[500072]){un(500060,96896);v[500072]=1}return 500060}function g6(a){a=a|0;if(!y[499976]){un(499964,96740);v[499976]=1}return 499964}function f6(a){a=a|0;if(!y[500008]){un(499996,96776);v[500008]=1}return 499996}function b6(a){a=a|0;if(!y[500024]){Dc(500012,13633);v[500024]=1}return 500012}function _5(a){a=a|0;if(!y[499992]){Dc(499980,13827);v[499992]=1}return 499980}function Zw(a,b){var c=0;if((b|0)<0){Sj();p()}c=Ec(b<<1);x[a+4>>2]=b;x[a>>2]=c}function X2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ib[a|0](b,c,d,e)|0}function Wo(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function V_(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Ab(a)>>2]){gM(a,b);return}bM(a,b)}function L4(a,b){a=a|0;b=b|0;a=Dj(a);x[a>>2]=124592;Zx(a+4|0,Kb(b));return a|0}function I3(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[501720]){v[501720]=1}Zb(a,c,125924)}function DA(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Ab(a)>>2]){WR(a,b);return}gA(a,b)}function Aca(a,b){a=a|0;b=b|0;a=x[a+4>>2];return EO(x[a+24>>2],B[a+48>>2],b)|0}function $9(a){a=a|0;a=x[a+24>>2];return hM(x[(x[x[a>>2]-12>>2]+a|0)+16>>2])^1}function zj(a){if(Ob(a+1074312|0,7)){a=xn(x[a+480180>>2])^1}else{a=0}return a}function zB(a){var b=0;if(!(y[a+2|0]|(y[a|0]|y[a+1|0]))){b=!y[a+3|0]}return b}function y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(lh(a,x[b+8>>2],0)){Ux(b,c,d)}}function xB(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Il(Il(c,a),D(a,-100)+b|0)}function wb(a){var b=0;b=fb-16|0;fb=b;a=vb(b+12|0,a);fb=b+16|0;return x[a>>2]}function uB(a,b){var c=0;c=a;a=(b>>>0)/1e4|0;return xB(Il(c,a),D(a,-1e4)+b|0)}function sf(a){if(vd(y[a+11|0])){hd(x[a>>2],0);Bd(a,0);return}hd(a,0);Ne(a,0)}function qj(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}Db(b)}function mba(a,b){a=a|0;b=b|0;sp(x[a+4>>2]);oG(pG(x[a+4>>2],b));sp(x[a+4>>2])}function iA(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function hA(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function gm(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;E0(d,a);nm(d,b);fb=c+16|0}function a6(a){a=a|0;if(!y[500056]){Dc(500044,9269);v[500056]=1}return 500044}function Zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Wn(a,b,c,d,12950,1080)|0}function YR(a,b){a=a|0;b=b|0;if(A[a+4>>2]<A[Ab(a)>>2]){WR(a,b);return}gA(a,b)}function Xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Wn(a,b,c,d,13024,1082)|0}function Sga(a,b){a=a|0;b=b|0;return E(b>>>0<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function Qu(a,b){var c=0;c=a;a=(b>>>0)/1e6|0;return uB(Il(c,a),D(a,-1e6)+b|0)}function Qj(a){var b=0;b=fb-16|0;fb=b;a=yf(b+12|0,a);fb=b+16|0;return x[a>>2]}function NT(a){x[a>>2]=0;x[a+4>>2]=0;x[a>>2]=-2078137563;x[a+4>>2]=-873292572}function Be(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Tw(d,a);nm(d,b);fb=c+16|0}function $5(a){a=a|0;if(!y[499960]){Dc(499948,5265);v[499960]=1}return 499948}function uK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+32>>2]](a,b,c,d)|0}function uJ(a,b){a=xd(a,b);w[a+8>>1]=11310;x[a>>2]=96544;Fb(a+12|0);return a}function nK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+48>>2]](a,b,c,d)|0}function he(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];Vb(b,c);px(a,b,d,c)}function bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Wn(a,b,c,d,9436,1077)|0}function Ze(a){var b=0;b=fb-16|0;fb=b;Mn(b+8|0,a);fb=b+16|0;return x[b+8>>2]}function Yda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Wn(a,b,c,d,9597,1081)|0}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Wn(a,b,c,d,9675,1083)|0}function Uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Wn(a,b,c,d,9467,1084)|0}function Q5(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+107120>>2]}return b|0}function O5(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+105584>>2]}return b|0}function MS(a,b,c){var d=0;return!b|!(y[a+35|0]&4?!a|(c|0)!=1:1)?d:y[b+34|0]}function vC(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function pU(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);iU(a,b,0,0,b+-1,0)}function jQ(a){a=a|0;x[a>>2]=44684;wc(a+4276|0);wc(a+4264|0);return _f(a)|0}function a8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return HH(b,c,d,e,1)|0}function Z7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return HH(b,c,d,e,0)|0}function Yo(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function YK(a,b,c,d,e,f,g,h){return ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function WL(a,b){a=a^-1;return x[(b&12)+80884>>2]>>>(a>>>3&1)>>>(a>>>4&1)|0}function U8(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){VK(a,c);return}Dc(a,7920)}function S7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FH(b,c,d,e,1)|0}function P7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FH(b,c,d,e,0)|0}function Ih(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function vG(a,b){a=a|0;b=b|0;a=Dj(a);x[a>>2]=124592;Zx(a+4|0,b);return a|0}function dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return vO(x[a+4>>2],b,c,d)|0}function cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return tO(x[a+4>>2],b,c,d)|0}function ai(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return uO(x[a+4>>2],b,c,d)|0}function _ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return yO(x[a+4>>2],b,c,d)|0}function Xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rO(x[a+4>>2],b,c,d)|0}function Pha(a,b){a=a|0;b=b|0;a=x[a+20>>2];v[a+24|0]=y[a+24|0]&253|(b?2:0)}function L3(a,b,c){a=a|0;b=b|0;c=c|0;return mc(a,x[b+4>>2])&x[b>>2]==(c|0)}function Jp(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0}function Ck(a){var b=0;b=z[a+172>>1];a=z[a+156>>1];return(AV(a)?b:a)&65535}function $ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return sO(x[a+4>>2],b,c,d)|0}function xz(a,b){var c=0,d=0;c=vb(a,x[x[b>>2]-12>>2]+b|0),d=b,x[c+4>>2]=d}function wc(a){var b=0;b=fb-16|0;fb=b;MQ(vb(b+12|0,a));fb=b+16|0;return a}function uG(a,b){a=Ff(a,b);x[a+8>>2]=x[b+8>>2];Ff(a+12|0,b+12|0);return a}function pG(a,b){a=a|0;b=b|0;return CF(a,Kb(b),Cb(x[b+4>>2],y[b+11|0]))|0}function oj(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+12>>2]](a,b,c)|0}function np(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+48>>2]](a,b,c)|0}function kd(a,b){a=DG(a,b);x[a+8>>2]=x[b+8>>2];DG(a+12|0,b+12|0);return a}function fc(a){var b=0;b=fb-16|0;fb=b;DZ(vb(b+12|0,a));fb=b+16|0;return a}function Zc(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function VX(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function Mb(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+32>>2]](a,b,c)|0}function Kb(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=vd(y[a+11|0]),d?b:c}function IF(a,b){while(1){if(b){x[a>>2]=0;b=b-1|0;a=a+4|0;continue}break}}function Cra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=vp(a,b),x[d>>2]=e}function Bra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Ow(a,b),w[d>>1]=e}function nL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ai(a,-1,-1)}function Oy(a,b){var c=0;c=Ut(a+4|0);x[a>>2]=94712;x[c>>2]=94732;po(c,b)}function Ny(a,b){var c=0;c=NK(a+4|0);x[a>>2]=95080;x[c>>2]=95100;po(c,b)}function Lm(a,b){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function zI(a,b,c){var d=0;d=c;c=Ef(b);if(d>>>0>c>>>0){jO(a,b)}return c}function vda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1107)|0}function v$(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1109)|0}function uN(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1111)|0}function sda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Hs(a,b,c,d,1113)|0}function r3(a){a=a|0;if(!a){return 0}return(hB(a,124148,124292)|0)!=0|0}function pc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=Ef(b),x[c+4>>2]=d;return a}function jua(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){ua();p()}}function hE(a,b,c){var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function eQ(a){a=a|0;return E(E(E(B[yb(a+4208|0,5)>>2]*E(198))+E(-99)))}function bz(a){return((Nh(a)+(Nh(a)<<8)|0)+(Nh(a)<<16)|0)+(Nh(a)<<24)|0}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return NH(a,b,c,d,1116)|0}function Mc(a){if(vd(y[a+11|0])){a=Zi(x[a+8>>2])-1|0}else{a=10}return a}function Koa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;eH(a,b,c,d,e,133)}function GU(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function AU(a){if(a>>>0<=8){return y[a+27520|0]}return y[a+27511|0]|256}function $p(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function vD(a,b){if(b){vD(a,x[b>>2]);vD(a,x[b+4>>2]);Oj(b+16|0);Db(b)}}function uD(a,b){if(b){uD(a,x[b>>2]);uD(a,x[b+4>>2]);Oj(b+16|0);Db(b)}}function sn(a){if(vd(y[a+11|0])){a=Zi(x[a+8>>2])-1|0}else{a=1}return a}function nv(a,b){a=a&255;b=b&255;return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function jB(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];v[a+6|0]=y[b+6|0]}function esa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;eH(a,b,c,d,e,91)}function ds(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function bi(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function bC(a,b){a=Nb(a);Fb(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function aO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Is(a,b,c,d,1106)|0}function _W(a,b,c,d){x[a>>2]=b;x[a+4>>2]=c;Zb(a+8|0,x[d>>2],x[d+4>>2])}function _N(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Is(a,b,c,d,1110)|0}function YN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Is(a,b,c,d,1112)|0}function Vx(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function Vs(a){return a>>>0<32|a-127>>>0<33|(a&-2)==8232|a-65529>>>0<3}function Sj(){var a=0;a=tn(dc(4));x[a>>2]=124476;da(a|0,124552,34);p()}function Rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return NH(a,b,c,d,995)|0}function Mq(a,b){if(b){Mq(a,x[b>>2]);Mq(a,x[b+4>>2]);XT(b+16|0);Db(b)}}function MN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Fs(a,b,c,d,1107)|0}function LN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Fs(a,b,c,d,1109)|0}function KN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Fs(a,b,c,d,1111)|0}function JN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Fs(a,b,c,d,1113)|0}function FB(a,b){if(b){FB(a,x[b>>2]);FB(a,x[b+4>>2]);$m(b+16|0);Db(b)}}function CA(a,b){if(b){CA(a,x[b>>2]);CA(a,x[b+4>>2]);Eb(b+16|0);Db(b)}}function Bqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Qx(a,b,c,d,586)|0}function $N(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Is(a,b,c,d,1108)|0}function qx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Qx(a,b,c,d,163)|0}function my(a){a=a|0;if(x[a+8>>2]!=(Od()|0)){jl(x[a+8>>2])}return a|0}function iq(a){if(y[a+2|0]&2){a=(y[a+1|0]&6)==6?4:1}else{a=0}return a}function bU(a,b,c){if(Je(a,b,c)){a=x[Wb(a,c)+12>>2]}else{a=1}return a}function aS(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function __(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Qx(a,b,c,d,339)|0}function VM(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){uo(c+120|0);Db(c)}}function UV(a,b,c,d,e){a=vb(a,b);vb(a+4|0,c);vb(a+8|0,d);vb(a+12|0,e)}function DZ(a){var b=0;b=x[a>>2];if(x[b>>2]){Nc(b);Db(x[x[a>>2]>>2])}}function $2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[a|0](b,c,d,e)}function u8(a){a=a|0;var b=0;b=x[124954]+1|0;x[124954]=b;x[a+4>>2]=b}function a7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;jg(a,f)}function Y2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ib[a|0](b,c,d)|0}function IY(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];hc(a+8|0,b+8|0)}function $6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;aq(a,f)}function yu(a,b,c){var d=0;d=fb-16|0;fb=d;RU(d+8|0,a,b,c);fb=d+16|0}function vO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return QH(a,b,c,d,4)|0}function uO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return QH(a,b,c,d,2)|0}function tO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return PH(a,b,c,d,4)|0}function t0(a,b){return ft(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function sO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return PH(a,b,c,d,2)|0}function eD(a,b,c){var d=0;d=fb-16|0;fb=d;Iv(d+8|0,a,b,c);fb=d+16|0}function aI(a,b,c,d,e,f,g){return Ja(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function aE(a,b,c){var d=0;d=fb-16|0;fb=d;$D(d+8|0,a,b,c);fb=d+16|0}function XU(a,b,c){var d=0;d=fb-16|0;fb=d;WU(d+8|0,a,b,c);fb=d+16|0}function Wr(a,b){return Rw(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function TY(a){v[a+4|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function Sr(a,b,c){if($c(a,b)>>>0<=c>>>0){Iw();p()}return(c<<1)+a|0}function Pc(a,b,c){if(oc(a,b)>>>0<=c>>>0){Iw();p()}return(c<<2)+a|0}function PS(a,b){x[a+852>>2]=x[a+852>>2]+b;v[a+851|0]=y[a+851|0]|64}function Bm(a,b){return b?a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24):a}function qg(a,b){a=a|0;b=b|0;var c=0;c=Ec(b);x[a+4>>2]=b;x[a>>2]=c}function pd(a){a=(a|0)>=32767?32767:a;return(a|0)<=-32768?-32768:a}function p4(a,b){a=a|0;b=b|0;a=XI(a,b,1);x[a>>2]=104348;return a|0}function ny(a,b,c){a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}Db(b)}}function jia(a,b){a=a|0;b=b|0;if(!x[31609]){x[31609]=a;x[31610]=b}}function gga(a,b,c){a=a|0;b=b|0;c=c|0;return ej(a,b,c,975,86224)|0}function bV(a,b){var c=0,d=0;c=vb(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function Nj(a,b){a=a|0;b=b|0;var c=0;c=AY(b);x[a+4>>2]=b;x[a>>2]=c}function L5(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function K4(a,b){a=a|0;b=b|0;a=WI(a,b,1);x[a>>2]=104444;return a|0}function yga(a,b,c){a=a|0;b=b|0;c=c|0;return ej(a,b,c,972,5048)|0}function yL(a,b){a=wL(a-1|0);if(!a){a=wL(b);a=a?a+32|0:0}return a}function wm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+32>>2]](a,0,b)|0}function so(a,b){if(A[a+4>>2]<A[Ab(a)>>2]){gM(a,b);return}bM(a,b)}function sN(a){a=a|0;return+(+x[x[a+32>>2]+1074456>>2]*.00390625)}function qp(a,b){x[a>>2]=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];return a}function pk(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+52>>2]](a,b,0)|0}function oga(a,b,c){a=a|0;b=b|0;c=c|0;return ej(a,b,c,974,4276)|0}function nla(a,b){a=a|0;b=b|0;a=aw(a,b);x[a>>2]=124800;return a|0}function mY(a,b,c,d){a=He(a,b);w[a+22>>1]=d;w[a+20>>1]=c;return a}function lia(a,b,c){a=a|0;b=b|0;c=c|0;return ej(a,b,c,948,4304)|0}function lha(a,b,c){a=a|0;b=b|0;c=c|0;return ej(a,b,c,967,4280)|0}function cha(a,b,c){a=a|0;b=b|0;c=c|0;return ej(a,b,c,968,4276)|0}function cI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kO(a,b,c,d)|0}function Wga(a,b,c){a=a|0;b=b|0;c=c|0;return ej(a,b,c,969,4268)|0}function W1(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+16>>2]](a)|0}function Vj(a,b){if(Mg(x[a>>2],x[a+4>>2])>>>0>b>>>0){v[a+16|0]=b}}function Kp(a,b,c){a=Ff(a,b);x[a+8>>2]=0;Ff(a+12|0,c);me(c);me(b)}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;return ej(a,b,c,971,4228)|0}function Fha(a,b,c){a=a|0;b=b|0;c=c|0;return ej(a,b,c,964,4236)|0}function Dh(a,b,c){a=vb(a,b);mr(a+4|0,x[c>>2],x[c+4>>2]);return a}function Cia(a,b,c){a=a|0;b=b|0;c=c|0;return ej(a,b,c,940,4268)|0}function $sa(a,b){a=a|0;b=b|0;a=aw(a,b);x[a>>2]=124748;return a|0}function xv(a){var b=0;b=fb-16|0;fb=b;oW(vb(b+12|0,a));fb=b+16|0}function vz(a){var b=0;b=fb-16|0;fb=b;bN(vb(b+12|0,a));fb=b+16|0}function oy(a){var b=0;b=fb-16|0;fb=b;kJ(vb(b+12|0,a));fb=b+16|0}function od(a){var b=0;b=fb-16|0;fb=b;OF(vb(b+12|0,a));fb=b+16|0}function kn(a){var b=0;b=fb-16|0;fb=b;eW(vb(b+12|0,a));fb=b+16|0}function iY(a){var b=0;b=fb-16|0;fb=b;bY(vb(b+12|0,a));fb=b+16|0}function h_(a,b){a=a|0;b=b|0;a=aw(a,b);x[a>>2]=124612;return a|0}function ft(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function fW(a){var b=0;b=fb-16|0;fb=b;XV(vb(b+12|0,a));fb=b+16|0}function er(a,b,c){a=Bb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function eca(a,b){a=a|0;b=b|0;return E(_O(x[x[a+4>>2]+24>>2],b))}function dca(a,b){a=a|0;b=b|0;return E(ZO(x[x[a+4>>2]+24>>2],b))}function cca(a,b){a=a|0;b=b|0;return E(WO(x[x[a+4>>2]+24>>2],b))}function at(a){a=a|0;x[a>>2]=96376;jl(x[a+16>>2]);return et(a)|0}function _ba(a,b){a=a|0;b=b|0;return E(YO(x[x[a+4>>2]+24>>2],b))}function Zs(a){var b=0;b=fb-16|0;fb=b;qh(rh(b+12|0,a));fb=b+16|0}function Zba(a,b){a=a|0;b=b|0;return E(XO(x[x[a+4>>2]+24>>2],b))}function Yfa(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function YA(a){tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);tb(a)}function X1(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+8>>2]](a)|0}function Td(a){var b=0;b=fb-16|0;fb=b;KH(vb(b+12|0,a));fb=b+16|0}function Rc(a){var b=0;b=fb-16|0;fb=b;UE(vb(b+12|0,a));fb=b+16|0}function NP(a){return E(E(B[yb(a+4208|0,11)>>2]*E(19980))+E(20))}function Mk(a){var b=0;b=fb-16|0;fb=b;w$(vb(b+12|0,a));fb=b+16|0}function Ce(a){var b=0;b=fb-16|0;fb=b;EG(vb(b+12|0,a));fb=b+16|0}function AG(a,b,c){a=Pn(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=78448}function xsa(a,b){a=a|0;b=b|0;a=SZ(a,b);if(!a){RZ(b)}return a|0}function km(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+28>>2]](a,b)|0}function kca(a,b){a=a|0;b=b|0;return GO(x[x[a+4>>2]+24>>2],b)|0}function eu(a,b){var c=0;c=G(a)+32|0;a=G(b);return(a|0)==32?c:a}function ah(a){var b=0,c=0;b=a,c=YZ(x[a>>2]),x[b>>2]=c;return a}function Wc(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){tu(b)}return a}function U6(a){a=a|0;a=x[a+8>>2];if(!a){return 1}return FJ(a)|0}function Rw(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function Qka(a,b){a=a|0;b=b|0;a=QY(a,b);if(!a){PY(b)}return a|0}function Os(a){var b=0;b=fb-16|0;C[b+8>>3]=a;return C[b+8>>3]*a}function OP(a){return E(E(B[yb(a+4208|0,0)>>2]*E(1e4))+E(-1e4))}function Lx(a){var b=0;b=fb-16|0;B[b+12>>2]=a;return B[b+12>>2]}function Ky(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+12>>2]](a,b)|0}function Cg(a){var b=0;b=hr(Ef(a)+1|0,1);if(b){jO(b,a)}return b}function Bt(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+44>>2]](a,b)|0}function Bo(a,b,c,d){a=nv(a,c);if(Lj(a)){a=TT(b,d)}return vd(a)}function Ag(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function yr(a,b){a=a|0;b=b|0;a=g$(a,b);if(!a){fw(b)}return a|0}function x0(a,b){a=a|0;b=b|0;a=AE(a,b);if(!a){GE(b)}return a|0}function vi(a,b){a=a|0;b=b|0;a=Xh(a,b);if(!a){$k(b)}return a|0}function vha(a,b,c){a=a|0;b=b|0;c=c|0;return Px(a,b,c,0,966)|0}function s7(a,b){a=a|0;b=b|0;NS(a,Uy(x[b>>2])<<24>>24,x[b>>2])}function rS(a,b,c,d){w[a>>1]=b;v[a+2|0]=y[c|0];v[a+3|0]=y[d|0]}function ps(a,b){a=a|0;b=b|0;a=gG(a,b);if(!a){ux(b)}return a|0}function nl(a){return wb(Kb(a)+(Cb(x[a+4>>2],y[a+11|0])<<2)|0)}function jh(a,b){return ib[x[x[a>>2]+32>>2]](a,x[a+12>>2],b)|0}function gx(a,b){a=Uc(a,b);hc(a+12|0,b+12|0);re(a+32|0,b+32|0)}function gp(a,b){a=a|0;b=b|0;a=e$(a,b);if(!a){i$(b)}return a|0}function cx(a,b){a=a|0;b=b|0;a=_F(a,b);if(!a){cs(b)}return a|0}function cQ(a){a=a|0;return Bk(E(B[yb(a+4208|0,4)>>2]*E(4)))|0}function bda(a,b,c){a=a|0;b=b|0;c=c|0;return+oO(x[a+4>>2],b,c)}function X$(a,b){if(!b){return-1}b=sq(a,b,0);return b?b-a|0:-1}function SR(a,b){return b>>>0>=4e3?22292:((b<<5)+a|0)+946304|0}function Pr(a,b){a=a|0;b=b|0;a=Nn(a,b);if(!a){Cn(b)}return a|0}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;return Px(a,b,c,0,970)|0}function NW(a){return y[a+15|0]<<12|y[a+14|0]<<4|y[a+13|0]<<20}function NR(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function Mp(a,b){a=a|0;b=b|0;a=lx(a,b);if(!a){kx(b)}return a|0}function Iga(a,b,c){a=a|0;b=b|0;c=c|0;return Px(a,b,c,1,970)|0}function CT(a,b){a=a|0;b=b|0;a=x$(a,b);if(!a){Dr(b)}return a|0}function CD(a,b){a=a|0;b=b|0;a=bZ(a,b);if(!a){rD(b)}return a|0}function $r(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function vca(a){a=a|0;return x[x[x[a+4>>2]+24>>2]+1074416>>2]}function qm(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){pm(c)}return a}function mha(a){a=a|0;return E(E(B[yb(a+4208|0,6)>>2]*E(20)))}function mM(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function lI(a,b){var c=0;c=a;a=x[a>>2]+b|0;x[c>>2]=a;return a}function iba(a,b){a=a|0;b=b|0;x[a>>2]=x[b>>2];jg(a+4|0,b+4|0)}function gka(a){a=a|0;a=aw(a,22292);x[a>>2]=124692;return a|0}function gS(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(Gl(c))}}function b$(a){return(y[a+47|0]+y[a+45|0]|0)+(y[a+46|0]<<5)|0}function Zsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gH(a,b,c,d,363)}function Wha(a){a=a|0;a=xj(a);if(a){ib[x[x[a>>2]+100>>2]](a)}}function Ql(a,b){a=v[xb(a+62|0,b)|0];return((a|0)<0?-1:a)&255}function Ora(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gH(a,b,c,d,474)}function Kta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nH(a,b,c,d,133)}function Ik(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){gc(a);Db(b)}}function Hca(a){a=a|0;return x[x[x[a+4>>2]+24>>2]+1074424>>2]}function FG(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(fc(c))}}function AY(a){if(a>>>0>=1073741824){Sj();p()}return Ec(a<<2)}function $b(a){return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function wN(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function wL(a){var b=0,c=0,d=0;return b=zua(a),c=0,d=a,d?b:c}function sm(a){a=BG(a,0);x[a+8>>2]=0;x[a>>2]=120944;return a}function pj(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function kY(a){var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b}
function kS(a){x[a>>2]=0;Nb(a+4|0);Rb(a+16|0,0,144);return a}function hh(a,b,c,d){hb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function dQ(a){a=a|0;return E(E(B[yb(a+4208|0,2)>>2]*E(10)))}function aw(a,b){a=Dj(a);x[a>>2]=124572;Zx(a+4|0,b);return a}function _z(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function Tb(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function Qra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nH(a,b,c,d,91)}function P5(a,b,c){a=a|0;b=b|0;c=c|0;return DH(b,c,107120)|0}function O1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cc(a,x[d>>2],0)}function N5(a,b,c){a=a|0;b=b|0;c=c|0;return DH(b,c,105584)|0}function Jga(a){a=a|0;return E(E(B[yb(a+4208|0,6)>>2]*E(4)))}function H5(a,b,c){a=a|0;b=b|0;c=c|0;return CH(b,c,107120)|0}function F5(a,b,c){a=a|0;b=b|0;c=c|0;return CH(b,c,105584)|0}function DR(a,b){var c=0;c=z[a>>1];w[a>>1]=z[b>>1];w[b>>1]=c}function Ct(a){a=a|0;x[a>>2]=93384;tb(a+32|0);return ho(a)|0}function yo(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function y1(a){a=a|0;a=wG(a,13438);x[a>>2]=24492;return a|0}function xl(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(nf(b))}}function uz(a,b,c,d,e,f){return LH(a,b,c,d,e,f,73508,74304)}function tz(a,b,c,d,e,f){return LH(a,b,c,d,e,f,74352,75116)}function tC(a,b){if(b){tC(a,x[b>>2]);tC(a,x[b+4>>2]);Db(b)}}function sq(a,b,c){if(!b){return 0}return rq(a,c<<24>>24,b)}function sC(a,b){if(b){sC(a,x[b>>2]);sC(a,x[b+4>>2]);Db(b)}}function rh(a,b){var c=0,d=0;c=a,d=oK(b),x[c>>2]=d;return a}function r0(a,b,c){a=a|0;b=b|0;c=c|0;return sH(a,b,c,262)|0}function pba(a,b,c){a=a|0;b=b|0;c=c|0;Uc(a,V$(c,0,b,Ef(b)))}function mx(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function mZ(a){if(Fk(-1,a)^1){a=Fk(a,0)^1}else{a=0}return a}function kw(a,b,c){a=a|0;b=b|0;c=c|0;return sH(a,b,c,322)|0}function jM(a,b){a=Pn(a);x[a+4>>2]=b;x[a>>2]=77132;return a}function hqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cH(a,b,c,d,3)}function hD(a,b){if(b){hD(a,x[b>>2]);hD(a,x[b+4>>2]);Db(b)}}function fx(a,b){return bS(a,Kb(b),Cb(x[b+4>>2],y[b+11|0]))}function dt(a){a=a|0;x[a>>2]=96428;jl(x[a+8>>2]);return a|0}function dba(a){a=a|0;Kz(a,2,100);Vj(x[a+24>>2]+484360|0,0)}function cF(a){return!jd(a,14245,3)&(y[a+3|0]-10&255)>>>0<5}function a3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[a|0](b,c,d)}function _s(a,b){var c=0,d=0;c=a,d=lk(b),x[c>>2]=d;return a}function Yy(a,b){return Jt(a,Kb(b),Cb(x[b+4>>2],y[b+11|0]))}function WS(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(kB(b))}}function Npa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cH(a,b,c,d,2)}function Mu(a,b){if(b){Mu(a,x[b>>2]);Mu(a,x[b+4>>2]);Db(b)}}function Lu(a,b){if(b){Lu(a,x[b>>2]);Lu(a,x[b+4>>2]);Db(b)}}function LM(a,b){a=a|0;b=b|0;return Sd(x[b>>2],x[b+4>>2])|0}function KM(a,b){a=a|0;b=b|0;return Pj(x[b>>2],x[b+4>>2])|0}function ID(a,b){if(b){ID(a,x[b>>2]);ID(a,x[b+4>>2]);Db(b)}}function HD(a,b){if(b){HD(a,x[b>>2]);HD(a,x[b+4>>2]);Db(b)}}function Eja(a,b,c){a=a|0;b=b|0;c=c|0;return dH(a,b,c,63)|0}function CI(a){a=a|0;x[a>>2]=95264;jl(x[a+8>>2]);return a|0}function Ar(a){return x[a+20>>2]+(x[a+8>>2]-x[a+24>>2]|0)|0}function AI(a){a=a|0;x[a>>2]=95232;jl(x[a+8>>2]);return a|0}function zp(a,b,c){a=a|0;b=b|0;c=c|0;Xl(a,b,Fi(b,b+c|0,0))}function zA(a,b,c){C[a>>3]=C[a>>3]+b;C[a+8>>3]=C[a+8>>3]+c}function yz(a){return(Kb(a)+Cb(x[a+4>>2],y[a+11|0])|0)-1|0}function k2(a){a=a|0;a=wG(a,8720);x[a>>2]=28836;return a|0}function bp(a){var b=0;b=x[a>>2];x[b>>2]=x[b>>2]|x[a+4>>2]}function bI(a,b,c){b=La(1005,a|0,b|0,c|0)|0;hb=gb;return b}function Vn(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function O3(a){a=a|0;a=h_(a,7956);x[a>>2]=40200;return a|0}function MO(a){return Hj(Xb(x[a+484360>>2],y[a+484376|0]))}function H_(a,b,c){if(Fk(c,a)){a=0}else{a=Fk(c,b)}return a}function FR(a,b){return((b|0)==2?740:(b|0)==1?732:724)+a|0}function D5(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function C8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hb=0;return 0}function zra(a,b,c){a=a|0;b=b|0;c=c|0;Xl(a,b,Xc(b,c)+b|0)}function yea(a,b){a=a|0;b=b|0;return Xn(a,b,11798,1057)|0}function xea(a,b){a=a|0;b=b|0;return XH(a,b,13410,1058)|0}function pea(a,b){a=a|0;b=b|0;return Xn(a,b,11833,1065)|0}function nea(a,b){a=a|0;b=b|0;return Xn(a,b,11863,1067)|0}function md(a,b,c,d){return Yc(a,D(z[b+480188>>1],c)+d|0)}function lg(a,b){if(vd(y[a+11|0])){Bd(a,b);return}Ne(a,b)}function lK(a,b,c){a=a|0;b=b|0;c=c|0;Fu(a,b,c);return a|0}function hea(a,b){a=a|0;b=b|0;return Xn(a,b,11959,1070)|0}function gz(a,b){return x[((a>>>24^b)<<2)+495328>>2]^a<<8}function eea(a,b){a=a|0;b=b|0;return Xn(a,b,11927,1071)|0}function Yf(a){var b=0;VP(a);b=x[a>>2];if(b){Uz(a);Db(b)}}function UM(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){tu(c)}}function To(a){x[a>>2]=0;x[a+4>>2]=0;Fc(a+8|0,0);return a}function S$(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0];return a}function Pea(a,b){a=a|0;b=b|0;return Xn(a,b,11895,1050)|0}function LL(a){while(1){if((St(a)|0)!=-1){continue}break}}function KF(a,b){var c=0;c=Ec(b<<2);x[a+4>>2]=b;x[a>>2]=c}function JA(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(c)}}function Gc(a,b){return uH(a,b,2147483647,-2147483648,-1)}function Ex(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function Df(a){return wb(Kb(a)+Cb(x[a+4>>2],y[a+11|0])|0)}function zM(a,b){a=a|0;b=b|0;dl(a,b,1172,1171,1170,1169)}function yM(a,b){a=a|0;b=b|0;dl(a,b,1184,1183,1182,1181)}function xM(a,b){a=a|0;b=b|0;dl(a,b,1180,1179,1178,1177)}function uM(a,b){a=a|0;b=b|0;dl(a,b,1192,1191,1190,1189)}function tM(a,b){a=a|0;b=b|0;dl(a,b,1188,1187,1186,1185)}function rj(a){return ff(a)|ff(a)<<8|ff(a)<<16|ff(a)<<24}function rg(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function ox(a){a=a|0;x[a>>2]=124592;hI(a+4|0);return a|0}function oha(a){a=a|0;return B[yb(a+4208|0,3)>>2]<E(1)|0}function mL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ai(a,-1,-1)}function ly(a){a=a|0;x[a>>2]=96584;tb(a+16|0);return a|0}function lC(a,b){Tb(a,b);Tb(a+4|0,b+4|0);Tb(Ab(a),Ab(b))}function l2(a,b,c){a=a|0;b=b|0;c=c|0;px(a,b,x[b+8>>2],c)}function ky(a){a=a|0;x[a>>2]=96544;tb(a+12|0);return a|0}function ida(a,b,c){a=a|0;b=b|0;c=c|0;Kz(x[a+4>>2],b,c)}
function hla(a,b,c){a=a|0;b=b|0;c=c|0;return Mb(a,b,c)|0}function YG(a,b){pm(x[b>>2]);um(x[a>>2]);x[a>>2]=x[b>>2]}function YD(a,b){v[x[a>>2]]=y[b|0];v[x[a+4>>2]]=y[b+1|0]}function TS(a,b){a=SS(a,b);SS(a+12|0,b+12|0);v[a+24|0]=1}function PB(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function Oh(a,b,c){v[a|0]=y[a|0]|b;x[a+4>>2]=x[a+4>>2]|c}function Mv(a){wc(a+88|0);wc(a+68|0);wc(a+48|0);return a}function Lga(a){a=a|0;return B[yb(a+4208|0,1)>>2]<E(1)|0}function J_(a){a=a|0;x[a>>2]=124572;hI(a+4|0);return a|0}function G9(a,b,c){a=a|0;b=b|0;c=c|0;return Gd(D(b,c))|0}function EM(a,b){a=a|0;b=b|0;dl(a,b,1168,1167,1166,1165)}function DM(a,b){a=a|0;b=b|0;dl(a,b,1163,1162,1161,1160)}function Cn(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function Bga(a){a=a|0;SP(a);v[a+4202|0]=1;x[a+4224>>2]=0}function BV(a,b,c,d){Zb(Zb(a,b,c)+8|0,x[d>>2],x[d+4>>2])}function AM(a,b){a=a|0;b=b|0;dl(a,b,1176,1175,1174,1173)}function yja(a,b,c){a=a|0;b=b|0;c=c|0;ZG(a,b,c,910,909)}function tG(a){a=a|0;x[a>>2]=41504;me(a+4|0);return a|0}function qn(a,b,c){x[a>>2]=b;x[a+4>>2]=x[c>>2];return a}function pR(a){return(a|0)==1179012417|(a|0)==538987841}function pM(a){a=a|0;x[a>>2]=77596;fc(a+4|0);return a|0}function jJ(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){um(b)}}function ho(a){a=a|0;x[a>>2]=93256;_b(a+4|0);return a|0}function hg(a,b,c,d,e){return Na(a|0,b|0,c|0,d|0,e|0)|0}function hI(a){a=bl(x[a>>2]);if((mx(a+8|0)|0)<0){Db(a)}}function eM(a){a=a|0;x[a>>2]=77984;fc(a+8|0);return a|0}function ZW(a,b,c,d){return!((a|0)==(c|0)&(b|0)==(d|0))}function VL(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function Rn(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function OD(a){a=a&255;return Tc(a)^1|(a-49&255)>>>0<36}function Nw(a,b){return((b|0)==2?88:(b|0)==1?68:48)+a|0}function Nb(a){x[a>>2]=0;x[a+4>>2]=0;tc(a+8|0);return a}function MT(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(b)}}function Lfa(a,b){a=a|0;b=b|0;return XH(a,b,6432,998)|0}function Ld(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function LO(a){return Zu(x[a+484344>>2],x[a+484348>>2])}function Kca(a,b,c){a=a|0;b=b|0;c=c|0;OO(a,x[b+4>>2],c)}function Jka(a,b,c){a=a|0;b=b|0;c=c|0;ZG(a,b,c,834,833)}function Fi(a,b,c){a=rq(a,c<<24>>24,b-a|0);return a?a:b}function EK(a,b,c){a=vb(a,b);vb(a+4|0,x[c>>2]);return a}function Dt(a){a=a|0;x[a>>2]=93320;_b(a+4|0);return a|0}function Dka(a,b,c){a=a|0;b=b|0;c=c|0;_H(a,b,c,838,839)}function $t(a){a=a|0;x[a>>2]=48636;vz(a+4|0);return a|0}function zna(a,b){a=a|0;b=b|0;if(!tX(a,b)){Rb(b,0,40)}}function yra(a,b){a=a|0;b=b|0;return Dc(a,b?b:22292)|0}function xha(a,b,c){a=a|0;b=b|0;c=c|0;Zb(a,b+4228|0,7)}function x8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eq(a,c,d)}function uua(a,b){a=a|0;b=b|0;Mh(a,b,260,1025,-1284,2)}function taa(a,b){a=a|0;b=b|0;BT(x[a>>2],b);return a|0}function tR(a,b){return D(b&65535,a&65535)+7>>>3&65535}function sh(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+20>>2]](a,b)}function sca(a,b){a=a|0;b=b|0;return IO(x[a+4>>2],b)|0}function s6(){xd(501384,1);hJ(501392);x[125346]=100324}function qna(a,b){a=a|0;b=b|0;Mh(a,b,587,1058,-1332,3)}function q6(){xd(501400,1);hJ(501408);x[125350]=100480}function nia(a,b,c){a=a|0;b=b|0;c=c|0;Zb(a,b+4260|0,8)}function l7(a,b){a=a|0;b=b|0;Zb(a,_K(x[b>>2]),x[b>>2])}function kz(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function jL(a){a=a|0;return Ft(x[x[a>>2]-12>>2]+a|0)|0}function hda(a,b){a=a|0;b=b|0;mO(x[x[a+4>>2]+24>>2],b)}function ei(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+24>>2]](a,b)}function eL(a){a=a|0;return Et(x[x[a>>2]-12>>2]+a|0)|0}function dsa(a,b){a=a|0;b=b|0;Mh(a,b,415,1042,-1332,2)}function di(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+28>>2]](a,b)}function _8(a){a=a|0;return gq(x[x[a>>2]-12>>2]+a|0)|0}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function Y8(a){a=a|0;return Gf(x[x[a>>2]-12>>2]+a|0)|0}function Xta(a,b){a=a|0;b=b|0;Mh(a,b,295,1058,-1332,2)}function TT(a,b){return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function Poa(a,b){a=a|0;b=b|0;Mh(a,b,260,1042,-1332,2)}function Nh(a){var b=0;b=St(a);x[a+1396>>2]=0;return b}function Em(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function A8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Xl(a,c,d)}function zca(a){a=a|0;return DO(x[x[a+4>>2]+24>>2])|0}function xd(a,b){a=BG(a,b-1|0);x[a>>2]=96952;return a}function wca(a){a=a|0;return VO(x[x[a+4>>2]+24>>2])|0}function w4(a,b){a=a|0;b=b|0;return JI(b,x[a+8>>2])|0}function v2(a,b,c){a=a|0;b=b|0;c=c|0;_H(a,b,c,74,147)}function uca(a){a=a|0;return SO(x[x[a+4>>2]+24>>2])|0}function uc(a,b){a=a|0;b=b|0;fG(a,b,es(b));return a|0}function tb(a){if(vd(y[a+11|0])){Db(x[a>>2])}return a}function qQ(a){wc(a+36|0);wc(a+24|0);ou(a+12|0);ou(a)}function ns(a,b){a=hc(a,b);Rb(a+20|0,0,1040);return a}function nca(a){a=a|0;return qq(x[x[a+4>>2]+24>>2])|0}function ml(a,b){return ib[x[x[a>>2]+36>>2]](a,b,0)|0}function mj(a){a=a|0;return ib[x[x[a>>2]+16>>2]](a)|0}function mT(a,b,c,d){return gd(Go(a,b,c,d,0)-32768|0)}function lj(a){a=a|0;return ib[x[x[a>>2]+12>>2]](a)|0}function lR(a,b){return(b>>>0>15?63:v[a+b|0])<<24>>24}function kR(a,b){return(b>>>0>46?63:v[a+b|0])<<24>>24}function kB(a){Hq(a+223860|0);fc(a+223848|0);return a}function k4(a,b){a=a|0;b=b|0;return pl(b&255)<<24>>24}function i4(a,b){a=a|0;b=b|0;return ut(b&255)<<24>>24}function fg(a,b,c,d){b=b+d|0;hb=a+c>>>0<c>>>0?b+1|0:b}function fea(a,b){a=a|0;b=b|0;Mh(a,b,79,1025,-1284,4)}function eE(a,b){a=He(a,b);Rb(a+20|0,0,1040);return a}function dD(a,b){a=a|0;b=b|0;Mh(a,b,587,1058,-1332,2)}function bf(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function bca(a){a=a|0;return TO(x[x[a+4>>2]+24>>2])|0}function af(a,b,c,d){cc(a,md(b,c,d,0),z[c+480188>>1])}function Vda(a,b){a=a|0;b=b|0;Mh(a,b,13,1025,-1284,2)}function VN(a,b){hb=0-(((a|0)!=0)+b|0)|0;return 0-a|0}function Uha(a){a=a|0;v[a+4202|0]=1;qu(a);Yz(a);rQ(a)}function Oda(a,b){a=a|0;b=b|0;Mh(a,b,79,1025,-1284,2)}function Lh(a){a=a|0;return ib[x[x[a>>2]+24>>2]](a)|0}function Jca(a){a=a|0;return MO(x[x[a+4>>2]+24>>2])|0}function Hv(a,b){a=a|0;b=b|0;Mh(a,b,588,1058,-1332,2)}function Gra(a,b){a=a|0;b=b|0;Mh(a,b,79,1042,-1332,2)}function Fqa(a,b,c){a=a|0;b=b|0;c=c|0;Uc(a,W$(c,0,b))}function Fca(a){a=a|0;return pq(x[x[a+4>>2]+24>>2])|0}function Dda(a,b){a=a|0;b=b|0;Mh(a,b,80,1025,-1284,2)}function Dca(a){a=a|0;return xo(x[x[a+4>>2]+24>>2])|0}function Dc(a,b){a=a|0;b=b|0;Fu(a,b,Ef(b));return a|0}function Cca(a){a=a|0;return LO(x[x[a+4>>2]+24>>2])|0}function BK(a,b,c){a=oI(a,b,c,0,-2147483648);return a}function zua(a){if(a){return 31-G(a-1^a)|0}return 32}function zQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function xu(a){a=a|0;a=Yh(a);x[a+20>>2]=0;return a|0}function wr(a,b,c,d,e){Zb(a,b+d|0,(e|0)==-1?c-d|0:e)}function wX(a){var b=0;a=a+8|0;hb=a>>>0<8|b;return a}function sY(a,b,c){if(c){hl(a,b,(c<<2)-1|0)}return a}function q$(a,b,c,d){return Tp(a,b,c,d,40,107374183)}function nha(a){a=a|0;return E(B[yb(a+4208|0,1)>>2])}function nda(a){a=a|0;return Sz(x[a>>2],x[a+4>>2])|0}function lG(a,b,c,d){return Tp(a,b,c,d,36,119304648)}function fe(a,b){Zb(a,Kb(b),Cb(x[b+4>>2],y[b+11|0]))}function fC(a){a=Nb(a);x[a+12>>2]=0;w[a+16>>1]=65280}function ee(a,b,c){v[a|0]=b;v[a+1|0]=y[c|0];return a}function bx(a){a=a|0;return ib[x[x[a>>2]+8>>2]](a)|0}function bo(a,b,c,d){return(a|0)==(c|0)&(b|0)==(d|0)}function UF(a,b){return(y[b+34|0]&8)>>>3&(a&2050)==2}function O$(a,b,c,d){return Tp(a,b,c,d,28,153391690)}function Ns(a,b,c,d,e,f){Ka(a|0,b|0,c|0,d|0,e|0,f|0)}function Mr(a,b,c){if(b){dP(a+36|0,b,Fi(b,b+c|0,0))}}function Kga(a){a=a|0;return E(B[yb(a+4208|0,3)>>2])}function Gba(a,b,c){a=a|0;b=b|0;c=c|0;pN(a-88|0,b,c)}function GJ(a,b,c,d){return Tp(a,b,c,d,24,178956971)}function F4(a,b){a=a|0;b=b|0;Mh(a,b,13,1058,-1332,2)}function Eba(a,b,c){a=a|0;b=b|0;c=c|0;nN(a-88|0,b,c)}function BG(a,b){x[a+4>>2]=b;x[a>>2]=124044;return a}function zG(a){return vL(a,E(2524354896707238e-44))}function yx(a,b){a=a|0;b=b|0;return bS(a,b,es(b))|0}function yp(a,b,c){Zb(a,(c>>>3&536870908)+b|0,c&31)}function wl(a,b,c){x[a>>2]=b;x[a+4>>2]=c-b;return a}function wba(a,b,c){a=a|0;b=b|0;c=+c;hN(a-92|0,b,c)}function uba(a,b,c){a=a|0;b=b|0;c=+c;fN(a-92|0,b,c)}function spa(a,b){a=a|0;b=b|0;return Jx(a,b,1100)|0}function rm(a){a=a|0;a=nc(a);ib[x[x[a>>2]>>2]](a)|0}function pca(a){a=a|0;return+RO(x[x[a+4>>2]+24>>2])}function pC(a){v[a+6|0]=0;w[a+4>>1]=65535;x[a>>2]=0}function oua(a,b,c){a=a|0;b=b|0;c=c|0;Wp(a,b,c,261)}function ne(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function nU(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function lsa(a,b){a=a|0;b=b|0;return Cs(a,b,1228)|0}function gda(a,b){a=a|0;b=+b;return+nO(x[a+4>>2],b)}function gca(a){a=a|0;return+PA(x[x[a+4>>2]+24>>2])}function fQ(a){a=a|0;return E(B[yb(a+4208|0,0)>>2])}function eua(a,b){a=a|0;b=b|0;Ix(a,b,260,274,-1332)}function eqa(a,b,c){a=a|0;b=b|0;c=c|0;Ds(a,b,c,595)}function dqa(a,b,c){a=a|0;b=b|0;c=c|0;Ds(a,b,c,596)}function csa(a,b,c){a=a|0;b=b|0;c=c|0;Wp(a,b,c,416)}function c3(a){a=a|0;a=ib[a|0]()|0;gb=hb;return a|0}function Zpa(a,b,c){a=a|0;b=b|0;c=c|0;tH(a,b,c,303)}function ZA(a,b){x[a>>2]=b;x[a+4>>2]=b>>31;return a}function Ypa(a,b,c){a=a|0;b=b|0;c=c|0;$G(a,b,c,303)}function Y1(a,b){a=a|0;b=b|0;return CF(a,b,Ef(b))|0}function Woa(a,b){a=a|0;b=b|0;return Cs(a,b,1224)|0}function VF(a,b,c){Zb(a,(c>>>3&536870908)+b|0,1<<c)}function Tta(a,b,c){a=a|0;b=b|0;c=c|0;Ds(a,b,c,298)}function Taa(a,b){a=a|0;b=b|0;return Cs(a,b,1227)|0}function RG(a){return vL(a,E(15845632502852868e13))}function Qta(a,b,c){a=a|0;b=b|0;c=c|0;iH(a,b,c,303)}function Pna(a,b,c){a=a|0;b=b|0;c=c|0;Uc(a,yx(b,c))}function Osa(a,b,c){a=a|0;b=b|0;c=c|0;n_(a,c,b,0,0)}function Kj(a){if(!a){return 0}return x[a+44>>2]!=0}function Jqa(a,b,c){a=a|0;b=b|0;c=c|0;mH(a,b,c,256)}function J9(a,b,c){a=a|0;b=b|0;c=c|0;Ds(a,b,c,1210)}function Iba(a,b,c){a=a|0;b=b|0;c=+c;rN(a-88|0,b,c)}function IT(a,b,c,d){return Tp(a,b,c,d,7,613566757)}function Gpa(a,b){a=a|0;b=b|0;return _h(a,b,1030)|0}function Fba(a,b){a=a|0;b=b|0;return oN(a-88|0,b)|0}function Dba(a,b){a=a|0;b=b|0;return mN(a-88|0,b)|0}function Bj(a){if(!a){return 0}return Jj(y[a+31|0])}function BN(a){a=a|0;a=x[a+4>>2];return(a?a:5011)|0}function $pa(a,b,c){a=a|0;b=b|0;c=c|0;lH(a,b,c,502)}function yda(a,b,c){a=a|0;b=b|0;c=c|0;Wp(a,b,c,81)}function wG(a,b){a=vG(a,b);x[a>>2]=124852;return a}function vsa(a,b){a=a|0;b=b|0;return _h(a,b,308)|0}function vqa(a,b){a=a|0;b=b|0;return _h(a,b,826)|0}function vY(a,b,c){a=a|0;b=b|0;c=c|0;Uc(a,Yy(b,c))}function uja(a,b){a=a|0;b=b|0;return _h(a,b,225)|0}function sJ(a,b){a=xd(a,b);x[a>>2]=100840;return a}function rja(a,b){a=a|0;b=b|0;return _h(a,b,326)|0}function rga(a,b){a=a|0;b=b|0;return E(Am(a,b,12))}function rJ(a,b){a=xd(a,b);x[a>>2]=100988;return a}function qJ(a,b){a=xd(a,b);x[a>>2]=101104;return a}function pda(a,b,c){a=a|0;b=b|0;c=c|0;Wp(a,b,c,82)}function pJ(a,b){a=xd(a,b);x[a>>2]=101220;return a}function nua(a,b,c){a=a|0;b=b|0;c=c|0;tH(a,b,c,47)}function nba(a){a=a|0;x[a>>2]=48416;return gu(a)|0}function mJ(a,b){a=xd(a,b);x[a>>2]=102408;return a}function lJ(a,b){a=xd(a,b);x[a>>2]=102528;return a}function _y(a){if(!a){return 0}x[31484]=a;return-1}function Ym(a){Aj(a+724|0);Aj(a+732|0);Aj(a+740|0)}function Yk(a,b){return(a&65535)>>>0<(b&65535)>>>0}function Sna(a,b,c){a=a|0;b=b|0;c=c|0;iH(a,b,c,47)}function Q2(a,b){a=a|0;b=b|0;return Cs(a,b,1226)|0}function Gca(a,b,c){a=a|0;b=b|0;c=c|0;$G(a,b,c,47)}function GG(a,b,c){a=a|0;b=b|0;c=c|0;Uc(a,fx(b,c))}function Er(a,b,c){a=a|0;b=b|0;c=c|0;lH(a,b,c,123)}function Aqa(a,b){a=a|0;b=b|0;return _h(a,b,422)|0}function ye(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function yJ(a,b){a=xd(a,b);x[a>>2]=98308;return a}function xja(a,b){a=a|0;b=b|0;return _h(a,b,73)|0}function xJ(a,b){a=xd(a,b);x[a>>2]=98340;return a}function vba(a,b){a=a|0;b=b|0;return+gN(a-92|0,b)}function vJ(a,b){a=xd(a,b);x[a>>2]=97008;return a}function th(a,b){a=a|0;b=b|0;return gL(a)^gL(b)^1}function tba(a,b){a=a|0;b=b|0;return+eN(a-92|0,b)}function tE(a){return(x[Ab(a)>>2]-x[a>>2]|0)/28|0}function sqa(a,b){a=a|0;b=b|0;return _h(a,b,41)|0}function sha(a,b){a=a|0;b=b|0;return E(Am(a,b,6))}function qR(a,b){return(a|0)==1179011410&b>>>0>80}function q1(a,b,c){a=a|0;b=b|0;c=c|0;Wp(a,b,c,18)}function pja(a,b){a=a|0;b=b|0;return _h(a,b,60)|0}function n$(a){return(x[Ab(a)>>2]-x[a>>2]|0)/40|0}function kga(a,b){a=a|0;b=b|0;return E(Am(a,b,2))}function jt(a){return(x[Ab(a)>>2]-x[a>>2]|0)/24|0}function jF(a){return!jd(a,24576,25)&y[a+34|0]<65}function ipa(a,b){a=a|0;b=b|0;return _h(a,b,71)|0}function hx(a){return(x[Ab(a)>>2]-x[a>>2]|0)/36|0}function fi(a,b){a=a|0;b=b|0;return $K(a)^$K(b)^1}function fha(a,b){a=a|0;b=b|0;return E(Am(a,b,5))}function fO(a){x[a+4>>2]=0;x[a>>2]=47588;return a}function fI(a){return(a<<1)+16777216>>>0<16777217}function dX(a){return(x[Ab(a)>>2]-x[a>>2]|0)/56|0}function cl(a){return(x[Ab(a)>>2]-x[a>>2]|0)/12|0}function cga(a,b){a=a|0;b=b|0;return E(Am(a,b,3))}function bn(a,b,c){x[a+4>>2]=c;w[a>>1]=b;return a}function ara(a,b){a=a|0;b=b|0;return _h(a,b,91)|0}function a2(a,b){a=a|0;b=b|0;Ix(a,b,13,257,-1284)}function Zga(a,b){a=a|0;b=b|0;return E(Am(a,b,4))}function Zb(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function Xqa(a,b){a=a|0;b=b|0;if(!QY(a,b)){PY(b)}}function W_(a,b){a=a|0;b=b|0;return hH(a,b,345)|0}function TE(a){return(x[Ab(a)>>2]-x[a>>2]|0)/20|0}function Pl(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function NY(a){return(x[Ab(a)>>2]-x[a>>2]|0)/33|0}function Kpa(a,b){a=a|0;b=b|0;if(!AE(a,b)){GE(b)}}function KZ(a){if(!(a&255)){return 1}return Tc(a)}function Jq(a,b){x[a+4>>2]=256;x[a>>2]=b;return a}function Hba(a,b){a=a|0;b=b|0;return+qN(a-88|0,b)}function G4(a,b){a=a|0;b=b|0;Ix(a,b,13,290,-1332)}function Fja(a,b){a=a|0;b=b|0;if(!gG(a,b)){ux(b)}}function FZ(a,b){a=a|0;b=b|0;return hH(a,b,322)|0}function Dga(a,b){a=a|0;b=b|0;return E(Am(a,b,1))}function Cu(a){return(x[Ab(a)>>2]-x[a>>2]|0)/52|0}function Csa(a,b){a=a|0;b=b|0;if(!SZ(a,b)){RZ(b)}}function Bsa(a,b){a=a|0;b=b|0;return _h(a,b,78)|0}function $n(a){return a-48>>>0<10|(a|32)-97>>>0<6}function xx(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0}function ww(a,b){a=a|0;b=b|0;if(!Dp(a,b)){rp(b)}}function wQ(a){a=a|0;fc(a+4208|0);return _f(a)|0}function uu(a){a=a|0;wc(a+4208|0);return _f(a)|0}function s_(a,b){x[a>>2]=x[a>>2]+D(b,6);return a}function lD(a,b){a=a|0;b=b|0;if(!bZ(a,b)){rD(b)}}function kE(a,b){a=a|0;b=b|0;if(!x$(a,b)){Dr(b)}}function jp(a,b){a=a|0;b=b|0;if(!Xh(a,b)){$k(b)}}function iw(a){return(a|0)<=0?1:a>>>0>=120?120:a}function iR(a,b,c){if(c){hl(a,b,D(c,6))}return a}function hw(a){return(x[Ab(a)>>2]-x[a>>2]|0)/6|0}function h$(a,b){a=a|0;b=b|0;if(!g$(a,b)){fw(b)}}function fta(a,b){a=a|0;b=b|0;Vp(a,b,362,361,8)}
function eF(a,b){a=$E(a,b);if(!a){Cn(b)}return a}function aQ(a){a=a|0;wc(a+4256|0);return _f(a)|0}function ZZ(a,b){a=a|0;b=b|0;if(!_F(a,b)){cs(b)}}function Yl(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function VB(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function Qn(a,b,c){a=Md(a);x[a+4>>2]=c;x[a>>2]=b}function NS(a,b,c){x[a+4>>2]=c;v[a|0]=b;return a}function L0(a,b){a=a|0;b=b|0;if(!C0(a,b)){IE(b)}}function JX(a,b){x[a>>2]=x[a>>2]+(b<<1);return a}function HB(a){return(x[Ab(a)>>2]-x[a>>2]|0)/7|0}function Ew(a,b){a=a|0;b=b|0;if(!lx(a,b)){kx(b)}}function Eda(a){a=a|0;return OH(a,47528,12605)|0}function E$(a,b){a=l$(a,b);if(!a){oE(b)}return a}function Az(a,b){x[a>>2]=x[b>>2];Uc(a+4|0,b+4|0)}function $h(a,b,c){return Fa(1010,a|0,b|0,c|0)|0}function z0(a,b){return(b&255)==2&(a&255)>>>0<3}function x5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499624))}function v5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499632))}function upa(a,b){a=a|0;b=b|0;Vp(a,b,649,648,8)}function u5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499828))}function tB(a){if(y[a+24|0]){XS(a);v[a+24|0]=0}}function t5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499820))}function s5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499836))}function qe(a,b){return Yk(z[a>>1],z[b>>1])?b:a}function q5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499844))}function pua(a,b,c){a=a|0;b=b|0;c=c|0;s0(a,b,c)}function pga(a){a=a|0;PP(a);Tz(a);v[a+4202|0]=1}function p5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499852))}function p1(a,b){a=a|0;b=b|0;Rp(a,b);return a|0}function oL(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function o5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499868))}function n5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499860))}function m5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499876))}function k5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499884))}function jca(a){a=a|0;return+C[x[a+4>>2]+16>>3]}function io(a){return ib[x[x[a>>2]+28>>2]](a)|0}function hY(a){var b=0;b=x[a>>2];we(a);return b}function hJ(a){var b=0,c=0;b=a,c=Od(),x[b>>2]=c}function h5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499892))}function gua(a,b){a=a|0;b=b|0;Vp(a,b,297,296,8)}function f5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499704))}function dla(a,b,c){a=a|0;b=b|0;c=c|0;he(a,b,c)}function dha(a){a=a|0;v[a+4202|0]=1;ZP(a);$P(a)}function d5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499712))}function cra(a,b){a=a|0;b=b|0;Vp(a,b,520,519,6)}function cpa(a,b){a=a|0;b=b|0;Vp(a,b,682,681,8)}function bd(a,b){return Fk(x[a>>2],x[b>>2])?b:a}function b5(a,b){a=a|0;b=b|0;ad(a,b,Vc(499720))}function _aa(a,b){a=a|0;b=b|0;Uc(a,iO(b,18281))}function Z4(a,b){a=a|0;b=b|0;ad(a,b,Vc(499672))}function Ye(a,b){return _q(x[a>>2],x[b>>2])?b:a}function Xz(a,b){return Qv(B[a>>2],B[b>>2])?b:a}function Xga(a){a=a|0;v[a+4202|0]=1;XP(a);WP(a)}function X4(a,b){a=a|0;b=b|0;ad(a,b,Vc(499680))}function Wj(a,b){a=a|0;b=b|0;Y$(a,x[a+16>>2]|b)}function V4(a,b){a=a|0;b=b|0;ad(a,b,Vc(499688))}function T4(a,b){a=a|0;b=b|0;ad(a,b,Vc(499696))}function Sv(a,b){a=a|0;b=b|0;return Mb(a,b,1)^1}function S4(a,b){a=a|0;b=b|0;ad(a,b,Vc(499768))}function Rm(a,b){return Qv(B[b>>2],B[a>>2])?b:a}function R4(a,b){a=a|0;b=b|0;ad(a,b,Vc(499776))}function Oc(a,b){return Yk(z[b>>1],z[a>>1])?b:a}function Kt(a,b){if(!a){return 0}return It(a,b)}function Kk(a){return ib[x[x[a>>2]+36>>2]](a)|0}function Il(a,b){return _m((b<<1)+121136|0,2,a)}function Hb(a,b){return Fk(x[b>>2],x[a>>2])?b:a}function Cda(a){a=a|0;return OH(a,47548,8191)|0}function Cd(a,b){return _q(x[b>>2],x[a>>2])?b:a}function $4(a,b){a=a|0;b=b|0;ad(a,b,Vc(499728))}function yE(a,b,c){a=a|0;b=b|0;c=c|0;$$(a,b,c)}function wea(a){a=a|0;return TH(a,6626,1062)|0}function vU(a){QB(a);Rb(a+27|0,0,255);return a}function tpa(a,b){a=a|0;b=b|0;return tX(a,b)|0}function tn(a){a=Dj(a);x[a>>2]=124456;return a}function ni(a,b){return(D(b,104)+a|0)+484380|0}function nP(a){x[a>>2]=0;x[a+4>>2]=-1;return a}function mf(a,b){v[a+4|0]=1;x[a>>2]=b;return a}function ica(a){a=a|0;return x[x[a+4>>2]+8>>2]}function haa(a){a=a|0;x[a>>2]=77232;return a|0}function daa(a){a=a|0;x[a>>2]=76732;return a|0}function cja(a,b){a=a|0;b=b|0;QA(eR(a+24|0,b))}function bv(a){return(a>>>0<9?a:a-9|256)&65535}function baa(a,b){a=a|0;b=b|0;IH(a,b,1204,292)}function _t(a,b){return(a&255)>>>0<(b&255)>>>0}function ZC(a,b,c){if(c){hl(a,b,c<<2)}return a}function Yn(a,b,c,d,e){Oa(a|0,b|0,c|0,d|0,e|0)}function Ui(a,b){return y[a+b|0]!=63&b>>>0<=46}function TU(a,b,c){if(c){hl(a,b,c<<1)}return a}function Og(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function Oea(a){a=a|0;return TH(a,7109,1054)|0}function N3(a,b,c){a=a|0;b=b|0;c=c|0;Zb(a,c,b)}function Ms(a,b,c,d,e){Ea(a|0,b|0,c|0,d|0,e|0)}function Kf(a,b,c){if(!(y[a|0]&32)){Rr(b,c,a)}}function In(a){return(a>>>0<=127?-1:a^128)&255}function Hg(a,b,c){a=Bua(a,b,c,c>>31);return a}function D$(a,b,c){a=a|0;b=b|0;c=c|0;D0(a,b,c)}function Cka(a,b){a=a|0;b=b|0;return Yy(a,b)|0}function CZ(a,b,c){a=a|0;b=b|0;c=c|0;A0(a,b,c)}function $v(a,b){return y[a+b|0]!=63&b>>>0<=15}function $da(a,b){a=a|0;b=b|0;return fx(a,b)|0}function yca(a,b){a=a|0;b=b|0;CO(a,x[b+4>>2])}function xca(a,b){a=a|0;b=b|0;aP(a,x[b+4>>2])}function xc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function ui(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function tW(a){return Te(443250/+(a>>>0)*1e4)}function ssa(a,b){a=a|0;b=b|0;Kx(a,b,17,3,16)}function rca(a,b){a=a|0;b=b|0;HO(a,x[b+4>>2])}function rP(a,b){a=a|0;b=b|0;return iO(a,b)|0}function qca(a,b){a=a|0;b=b|0;BO(a,x[b+4>>2])}function qaa(a,b){a=a|0;b=b|0;IH(a,b,1200,36)}function nu(a,b){a=a|0;b=b|0;return jg(a,b)|0}function naa(a){a=a|0;nM(a);return x[a+16>>2]}function lca(a,b){a=a|0;b=b|0;PO(a,x[b+4>>2])}function kda(a,b){a=a|0;b=b|0;Lz(x[a+4>>2],b)}function iL(a){a=a|0;Vy(x[x[a>>2]-12>>2]+a|0)}function gv(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function gu(a){a=a|0;x[a>>2]=48396;return a|0}function dua(a,b){a=a|0;b=b|0;Kx(a,b,44,2,44)}function dL(a){a=a|0;Ty(x[x[a>>2]-12>>2]+a|0)}function dA(a){return x[Ab(a)>>2]-x[a>>2]>>11}function cf(a,b){return _t(y[a|0],y[b|0])?b:a}function b2(a){a=a|0;x[a>>2]=78312;return a|0}function Z9(a){a=a|0;x[a>>2]=78040;return a|0}function Z8(a){a=a|0;XK(x[x[a>>2]-12>>2]+a|0)}function X8(a){a=a|0;WK(x[x[a>>2]-12>>2]+a|0)}function Wsa(a,b){a=a|0;b=b|0;pH(a,b,366,365)}function VY(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Ut(a){a=PL(a);x[a>>2]=94552;return a}function UW(a){a=Aua(a&65535,0,80,0);return a}function U9(a){a=a|0;x[a>>2]=77652;return a|0}function Qb(a,b){return _t(y[b|0],y[a|0])?b:a}function Q1(a){a=a|0;x[a>>2]=41368;return a|0}function Nta(a,b){a=a|0;b=b|0;pH(a,b,306,305)}function NK(a){a=PL(a);x[a>>2]=94944;return a}function N1(a){a=a|0;x[a>>2]=41128;return a|0}function Md(a){x[a>>2]=0;x[a+4>>2]=0;return a}function Lq(a){return(a-65&255)>>>0<26?a|32:a}function JJ(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Iy(a,b,c){a=oI(a,b,c,-1,-1);return a}function Hf(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function Eca(a,b){a=a|0;b=b|0;JO(a,x[b+4>>2])}function D_(a){a=(a&65535)-98|0;hb=0;return a}function C2(a,b){a=a|0;b=b|0;return yx(a,b)|0}function C$(a){v[a+12|0]=y[a+12|0]|2;return a}function z6(a){a=a|0;ad(a,501312,Vc(499728))}function y6(a){a=a|0;ad(a,501320,Vc(499736))}function x6(a){a=a|0;ad(a,501328,Vc(499744))}function w6(a){a=a|0;ad(a,501336,Vc(499752))}function v6(a){a=a|0;ad(a,501344,Vc(499760))}function uY(a,b,c){w[a>>1]=b;v[a+2|0]=y[c|0]}function u6(a){a=a|0;ad(a,501352,Vc(499672))}function t6(a){a=a|0;ad(a,501368,Vc(499680))}function sk(a){a=a&255;return(a|0)==255?-1:a}function r6(a){a=a|0;ad(a,501384,Vc(499688))}function p6(a){a=a|0;ad(a,501400,Vc(499696))}function oca(a){a=a|0;return UO(x[a+4>>2])|0}function oaa(a){a=a|0;nM(a);return x[a+4>>2]}function oC(a){return x[Ab(a)>>2]-x[a>>2]>>8}function o6(a){a=a|0;ad(a,501416,Vc(499768))}function n6(a){a=a|0;ad(a,501424,Vc(499776))}function mi(a){return x[x[a+8>>2]>>2]==(a|0)}function mI(a,b,c){a=a|0;b=b|0;c=c|0;VK(a,c)}function lZ(a,b,c){Zb(a,b,Fi(b,b+c|0,0)-b|0)}function kv(a){return x[Ab(a)>>2]-x[a>>2]>>4}function iB(a){v[a+24|0]=0;v[a|0]=0;return a}function Zo(a){return x[Ab(a)>>2]-x[a>>2]>>5}function Vz(a){return E(E(a*E(7900))+E(100))}function Vg(a){return x[Ab(a)>>2]-x[a>>2]>>2}function Uz(a){return x[nc(a)>>2]-x[a>>2]>>2}function T6(a){a=a|0;ad(a,501104,Vc(499624))}function Sn(a){return x[Ab(a)>>2]-x[a>>2]>>3}function S6(a){a=a|0;ad(a,501112,Vc(499632))}function R6(a){a=a|0;ad(a,501120,Vc(499828))}function Q6(a){a=a|0;ad(a,501136,Vc(499820))}function P6(a){a=a|0;ad(a,501144,Vc(499836))}function N6(a){a=a|0;ad(a,501152,Vc(499844))}function M6(a){a=a|0;ad(a,501168,Vc(499852))}function L6(a){a=a|0;ad(a,501176,Vc(499868))}function K6(a){a=a|0;ad(a,501184,Vc(499860))}function J6(a){a=a|0;ad(a,501192,Vc(499876))}function I6(a){a=a|0;ad(a,501200,Vc(499884))}function Hn(a){return x[Ab(a)>>2]-x[a>>2]>>1}function H6(a){a=a|0;ad(a,501224,Vc(499892))}function Gp(a,b,c,d){a=Bua(a,b,c,d);return a}function G6(a){a=a|0;ad(a,501256,Vc(499640))}function F6(a){a=a|0;ad(a,501264,Vc(499648))}function E6(a){a=a|0;ad(a,501272,Vc(499656))}function D6(a){a=a|0;ad(a,501280,Vc(499664))}function Cb(a,b){if(!vd(b)){a=Hh(b)}return a}function CQ(a){x[a>>2]=x[a>>2]-2048;return a}function C9(a){a=a|0;return Ba(x[a+60>>2])|0}function C6(a){a=a|0;ad(a,501288,Vc(499704))}function Bk(a){return aH(a,E(4294967296),-1)}function Bca(a){a=a|0;return KO(x[a+4>>2])|0}function B6(a){a=a|0;ad(a,501296,Vc(499712))}function A6(a){a=a|0;ad(a,501304,Vc(499720))}function $z(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function yU(a,b){x[a>>2]=x[a>>2]+b;return a}function y4(a,b){a=a|0;b=b|0;return ay(b)|0}function tu(a){a=a|0;ib[x[x[a>>2]+4>>2]](a)}function ria(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function jo(a){a=a|0;_K(x[a>>2]);return a|0}function dC(a,b,c){if(c){hl(a,b,c)}return a}function cp(a,b){w[a>>1]=b;w[a+2>>1]=b>>>16}function ap(a){return x[Ab(a)>>2]-x[a>>2]|0}function Yw(a,b){if(b){Dc(a,b);return}Fb(a)}function Yq(a,b){return a<<16>>16<b<<16>>16}function Tv(){da(tn(dc(4))|0,124540,34);p()}function SO(a){return A[a+1074420>>2]/1e4|0}function Rl(a,b){return Yq(z[a>>1],z[b>>1])}function PV(a){x[a>>2]=x[a>>2]-256;return a}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;Md(a)}function Of(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function Hi(a,b){a=a|0;b=b|0;return E(E(0))}function Fm(a){a=a|0;Uy(x[a>>2]);return a|0}function DB(a){v[a+4|0]=0;v[a|0]=0;return a}function Bn(a,b,c){return Xj(a,b)>>>0>c>>>0}function A4(a,b){a=a|0;b=b|0;return $x(b)|0}function zoa(a,b){a=a|0;b=b|0;kH(a,b,2,31)}function yba(a,b){a=a|0;b=b|0;jN(a-92|0,b)}function xm(a){x[a>>2]=x[a>>2]+12;return a}function xba(a,b){a=a|0;b=b|0;iN(a-92|0,b)}function vk(a){tb(a+36|0);wc(a+24|0);Mk(a)}function vL(a,b){return E(Lx(a?E(-b):b)*b)}function uf(a,b,c){a=Aua(c,0,a,b);return a}function r9(a){a=a|0;return Th(a,499640)|0}function pw(a){x[a>>2]=x[a>>2]-28;return a}function nn(a){cC(x[a+20>>2]);x[a+20>>2]=0}function mca(a){a=a|0;return+QO(x[a+4>>2])}function m$(a){x[a>>2]=x[a>>2]-40;return a}function ll(a,b){ib[x[x[b>>2]+44>>2]](a,b)}function kt(a,b){ib[x[x[b>>2]+40>>2]](a,b)}function kl(a,b){ib[x[x[b>>2]+32>>2]](a,b)}function k9(a){a=a|0;return Th(a,499656)|0}function jk(a){x[a>>2]=x[a>>2]-12;return a}function jG(a){x[a>>2]=x[a>>2]-36;return a}function h2(a){a=a|0;return x[a+4>>2]!=0|0}function gt(a){x[a>>2]=x[a>>2]-24;return a}function go(a){a=a|0;Es(a,162,124900,1051)}function fA(a){x[a>>2]=x[a>>2]+24;return a}function dm(a){x[a>>2]=x[a>>2]+28;return a}function dW(a,b,c,d){Zb(a,b,(d|0)==-1?c:d)}function bX(a){x[a>>2]=x[a>>2]-56;return a}function ar(a){tf(a+24|0);fc(a+12|0);fc(a)}function _Q(a){x[a>>2]=x[a>>2]-52;return a}function Zta(a,b){a=a|0;b=b|0;FE(a+36|0,b)}function Zq(a){x[a>>2]=x[a>>2]+32;return a}function Xq(a){x[a>>2]=x[a>>2]-16;return a}function Wja(a,b){a=a|0;b=b|0;rs(a+40|0,b)}function Vt(a){return(a|0)<=65535&(a|0)>=0}function Vo(a){x[a>>2]=x[a>>2]+16;return a}function Uo(a){x[a>>2]=x[a>>2]-32;return a}function Ul(a){x[a>>2]=x[a>>2]+52;return a}function Ry(a){a=a|0;return Th(a,499820)|0}function Qf(a){x[a>>2]=x[a>>2]+20;return a}function Qba(a,b){a=a|0;b=b|0;zN(a-88|0,b)}function Py(a){a=a|0;return Th(a,499836)|0}function Pba(a,b){a=a|0;b=b|0;yN(a-88|0,b)}function OS(a,b){return wH(a,b,2147483647)}function M4(a){a=a|0;Es(a,162,124900,1231)}function Ly(a){a=a|0;return Th(a,499884)|0}function LY(a){x[a>>2]=x[a>>2]-33;return a}function Kg(a){return E(F(a))==E(Infinity)}function KD(a){a=a|0;return Th(a,499844)|0}function Hp(a){os(a+32|0);ub(a+12|0);tb(a)}function HP(a){return E(E(a*E(96))+E(-96))}function G_(a){x[a>>2]=x[a>>2]-20;return a}function GI(a){a=a|0;return zH(a,101648)|0}function Fy(a){a=a|0;return Th(a,499892)|0}function Fw(a){a=a|0;return Th(a,499828)|0}function FI(a){a=a|0;return zH(a,101544)|0}function EI(a){a=a|0;return yH(a,101440)|0}function DI(a){a=a|0;return yH(a,101336)|0}function Bba(a,b){a=a|0;b=b|0;kN(a-88|0,b)}function ze(a){return Bb(a&65535)<<16>>16}function yha(a){a=a|0;v[a+4202|0]=1;lQ(a)}function wj(a){x[a>>2]=x[a>>2]-4;return a}function we(a){x[a>>2]=x[a>>2]+1;return a}function vy(a,b){a=a|0;b=b|0;jg(a,b+12|0)}function uga(a){a=a|0;return x[a+4260>>2]}function ty(a,b){a=a|0;b=b|0;jg(a,b+16|0)}function tl(a){a=a|0;return hL(a)<<24>>24}function tg(a){x[a>>2]=x[a>>2]+6;return a}function sba(a){a=a|0;return nq(a-96|0)|0}function sW(a){x[a>>2]=x[a>>2]-1;return a}function qsa(a,b){a=a|0;b=b|0;xi(a,b,282)}function qba(a,b){a=a|0;b=+b;dN(a-96|0,b)}function oz(a,b,c){Zb(a,(c<<12)+b|0,4096)}function nz(a,b){a=a|0;b=b|0;jg(a,b+36|0)}function nq(a){a=a|0;tq(a+8|0);return a|0}function jN(a,b){a=a|0;b=b|0;MH(a,b,2048)}function iN(a,b){a=a|0;b=b|0;MH(a,b,4096)}function gs(a){x[a>>2]=x[a>>2]-8;return a}function ge(a){x[a>>2]=x[a>>2]+2;return a}function ev(a){Qm(a,So(a),78544);return a}function eZ(a){x[a>>2]=x[a>>2]-6;return a}function _J(a,b){a=a|0;b=b|0;jg(a,b+48|0)}function Xe(a){x[a>>2]=x[a>>2]+4;return a}function XJ(a,b){a=a|0;b=b|0;aq(a,b+28|0)}function Wk(a){x[a>>2]=x[a>>2]-2;return a}function WJ(a,b){a=a|0;b=b|0;aq(a,b+40|0)}function Vta(a,b){a=a|0;b=b|0;xi(a,b,136)}function VJ(a,b){a=a|0;b=b|0;aq(a,b+52|0)}function Um(a){return E(F(a))<E(Infinity)}function Sba(a){a=a|0;return nq(a-88|0)|0}function Rf(a){a=a|0;Yh(a+8|0);return a|0}function RO(a){return+A[a+1074420>>2]/1e4}function Oba(a,b){a=a|0;b=+b;xN(a-88|0,b)}function OB(a){x[a>>2]=x[a>>2]+8;return a}function NC(a,b,c){return LX(a,MX(a,b,c))}function Mba(a,b){a=a|0;b=+b;vN(a-88|0,b)}function M9(a,b){a=a|0;b=b|0;vm(a,b+12|0)}function Kba(a,b){a=a|0;b=+b;tN(a-88|0,b)}function Jpa(a,b){a=a|0;b=b|0;xi(a,b,274)}function Iq(a,b){v[a|0]=b+48;return a+1|0}function IP(a){a=a|0;Rb(a+4296|0,0,81928)}function Ft(a){a=a|0;ul(a+8|0);return a|0}function Et(a){a=a|0;ul(a+4|0);return a|0}function Dg(a,b,c){xk(b,b+c|0,a);return a}function DT(a){x[a>>2]=x[a>>2]-7;return a}function Bs(a,b){x[a>>2]=b;pm(b);return a}function Bpa(a,b){a=a|0;b=b|0;xi(a,b,106)}function BB(a,b){if(B[a>>2]>b){B[a>>2]=b}}function Ata(a,b){a=a|0;b=b|0;kH(a,b,3,8)}function Aba(a){a=a|0;return nq(a-92|0)|0}function $J(a,b){a=a|0;b=b|0;jg(a,b+24|0)}function $H(a){a=Da(a|0)|0;hb=gb;return a}function zpa(a,b){a=a|0;b=b|0;xi(a,b,72)}function ut(a){return a-65>>>0<26?a|32:a}function rsa(a,b){a=a|0;b=b|0;Mr(a,b,17)}function qia(a){a=a|0;return y[a+4201|0]}function pl(a){return a-97>>>0<26?a&95:a}function pia(a){a=a|0;return y[a+4202|0]}function of(a,b){x[a+8>>2]=b|-2147483648}function no(a,b,c){return ib[c|0](a,b)|0}function mr(a,b,c){x[a>>2]=b;x[a+4>>2]=c}function le(a,b){return(b|0)!=0&(a|0)!=0}function kg(a,b){a=Bua(0,a,b,0);return a}function jc(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function fl(a){return(a|0)==32|a-9>>>0<5}function bua(a,b){a=a|0;b=b|0;rH(a,b,28)}function ata(a,b){a=a|0;b=b|0;xi(a,b,34)}function Zk(a){return D(Jn(a),_d(a))&255}function Z5(a,b){a=a|0;b=b|0;un(a,96616)}function Y5(a,b){a=a|0;b=b|0;un(a,96636)}function Xx(a){return a-501744>>>2&65535}function X5(a,b){a=a|0;b=b|0;Dc(a,11296)}function Wfa(a){a=a|0;return(a|0)==277|0}function W5(a,b){a=a|0;b=b|0;Dc(a,11413)}function Qr(a,b,c,d,e){vH(a,b,c,d,e,256)}function Jw(a,b,c,d,e){vH(a,b,c,d,e,128)}function Iqa(a,b){a=a|0;b=b|0;xi(a,b,42)}function CG(a,b){Tb(a,b);Tb(a+4|0,b+4|0)}function BY(a,b){a=a|0;b=b|0;xi(a,b,284)}function As(a,b){x[a+24>>2]=x[a+24>>2]+b}function Aj(a){w[a+4>>1]=65535;x[a>>2]=0}function $i(a,b){v[a|0]=b;v[a+1|0]=b>>>8}function yZ(a,b){a=a|0;b=b|0;Mr(a,b,32)}function tm(a){a=x[a+8>>2];if(a){Db(a)}}function pY(a,b){x[a>>2]=x[a>>2]+(b<<2)}function p0(a,b,c){return!jd(a,c,b-a|0)}function oi(a){return(a&65535)>>>0<3999}function jI(a){return(z[a+2>>1]<<2)+a|0}function h0(a,b){a=a|0;b=b|0;xi(a,b,50)}function gY(a,b){a=a|0;b=b|0;return b|0}function ega(a){a=a|0;return-2013527448}function bK(a,b){a=a|0;b=b|0;rf(a,1,45)}function b1(a,b){a=a|0;b=b|0;xi(a,b,59)}function aK(a,b){a=a|0;b=b|0;Ay(a,1,45)}function _m(a,b,c){return xk(a,a+b|0,c)}function _g(a,b,c){v[a+4|0]=c;x[a>>2]=b}function Zv(a,b,c){return a<b?b:a>c?c:a}function Wqa(a,b){a=a|0;b=b|0;F0(a,b,8)}function T$(a,b){x[a>>2]=x[a>>2]+(b<<1)}function RI(a){a=a|0;return ud(a-8|0)|0}function Qs(a){return(a|0)==32|(a|0)==9}function QI(a){a=a|0;return jy(a-8|0)|0}function Q0(a,b){a=a|0;b=b|0;Mr(a,b,11)}function PI(a){a=a|0;return iy(a-8|0)|0}function OK(a){x[a+4>>2]=x[a+4>>2]|8192}function OI(a){a=a|0;return hy(a-8|0)|0}function Nba(a){a=a|0;return+wN(a-88|0)}function NI(a){a=a|0;return gy(a-8|0)|0}function MI(a){a=a|0;return fy(a-8|0)|0}function Lba(a){a=a|0;return+uN(a-88|0)}function LI(a){a=a|0;return ey(a-8|0)|0}function LD(a){return fH(a,65535,65535)}function Jba(a){a=a|0;return+sN(a-88|0)}function GS(a,b){return(Ql(a,b)|0)!=255}function F3(a){a=a|0;if(a){lI(il(a),1)}}function Cj(a,b){return rB(a&255,b&255)}function CB(a,b,c){return a<b?b:a>c?c:a}function Bb(a){return(a<<8|a>>>8)&65535}function $y(a){return(q(a),j(2))>>>20|0}function wx(a,b){x[a+4>>2]=3;x[a>>2]=b}function wP(a,b,c){return dH(a,b,c,68)}function vga(a){a=a|0;return-275227023}function uy(a){a=a|0;return x[a+12>>2]}function uv(a,b,c){return Sp(a,b,c,12)}function uj(a,b){x[a+4>>2]=1;x[a>>2]=b}function uha(a){a=a|0;return-270114148}function uX(a,b){a=a|0;b=b|0;rH(a,b,4)}function t$(a,b,c){return Sp(a,b,c,40)}function se(a,b,c){wl(a,b,Xc(b,c)+b|0)}function pna(a){a=a|0;OW(a);return a|0}function mt(a){a=a|0;return 2147483647}function mga(a){a=a|0;return 302837129}function kk(a,b){x[a+4>>2]=2;x[a>>2]=b}function je(a){x[x[a+8>>2]>>2]=x[a>>2]}function jaa(a){a=a|0;return y[a+40|0]}function iha(a){a=a|0;return-285139079}function iE(a){return a>>>0>=120?120:a}function hia(a){a=a|0;return 542066252}function cy(a,b){x[a+4>>2]=4;x[a>>2]=b}function aha(a){a=a|0;return-284078960}function Zfa(a,b){a=a|0;b=b|0;return 3}function ZJ(a){a=a|0;return x[a+60>>2]}function Xu(a,b,c){lg(a,c);hd(b+c|0,0)}function Xfa(a,b){a=a|0;b=b|0;return 2}function Wd(a,b){return Kb(a)+(b<<2)|0}function Uga(a){a=a|0;return-281111764}function UJ(a){a=a|0;return x[a+64>>2]}function U1(a){a=a|0;return x[a+16>>2]}function Tu(a,b){return uH(a,b,-1,0,0)}function TZ(a,b,c){Yl(a,b&65535,c&255)}function SM(a){return a?(a|0)==2?3:2:1}function Q4(a,b){a=a|0;b=b|0;BH(a,b,0)}function P4(a,b){a=a|0;b=b|0;BH(a,b,1)}function O4(a,b){a=a|0;b=b|0;AH(a,b,0)}function Nga(a){a=a|0;return-271958638}function N4(a,b){a=a|0;b=b|0;AH(a,b,1)}function K2(a,b){a=a|0;b=b|0;ys(a,1,b)}function IK(a,b){return(fo(a,b)|0)!=-1}function Fga(a){a=a|0;return-620920304}function Dw(a,b,c){return Sp(a,b,c,20)}function Dj(a){x[a>>2]=125152;return a}function CJ(a,b,c){return Sp(a,b,c,24)}function Bh(a){return aH(a,E(255),255)}function BQ(a){a=a|0;return 1869112133}function xn(a){return(a&740327453)!=0}function xh(a,b,c){return Up(a,b,c,2)}function xP(a,b){a=a|0;b=b|0;return 0}function tj(a,b,c){Uc(Uc(a,b)+12|0,c)}function tT(a,b){return(0-b|0)!=(a|0)}function ska(a,b){a=a|0;b=b|0;hU(a,b)}function rka(a,b){a=a|0;b=b|0;KS(a,b)}function rG(a,b,c){cc(a,b,ih(b,c)<<3)}function qh(a){a=x[a>>2];if(a){oK(a)}}function oR(a,b){Zc(a,b&4?16:8,1,0,0)}function ms(a){a=a|0;return x[a+4>>2]}function mC(a,b,c){return Up(a,b,c,5)}function ls(a){a=a|0;return x[a+8>>2]}function jv(a,b,c){return Up(a,b,c,4)}function jY(a){hz(a);Ke(x[a+80>>2],a)}function ip(a,b){w[a+8>>1]=b;return a}function iO(a,b){return Jt(a,b,Ef(b))}function hs(a,b,c){return Up(a,b,c,3)}function gla(a,b){a=a|0;b=b|0;Vb(a,b)}function gl(a){a=x[a>>2];if(a){jl(a)}}function bj(a,b,c){return Up(a,b,c,1)}function aA(a,b){a=a|0;b=b|0;return 1}function _Y(a,b,c){eD(a,(b<<2)+a|0,c)}function YI(a){a=E(a-a);return E(a/a)}function Xj(a,b){return hm(a,b)&65535}function XY(a,b,c){cc(a,b,oc(b,c)<<2)}function We(a,b){x[a+4>>2]=b;return a}function VO(a){return z[a+1074448>>1]}function VG(a,b){Ls(a,b,12,357913942)}function Us(a){return(ay(a)|0)!=(a|0)}function Ts(a){return($x(a)|0)!=(a|0)}function Sl(a,b){return v[a|0]<v[b|0]}function Rz(a){a=a|0;WH(a,47448,1001)}function Rta(a,b){a=a|0;b=b|0;Yy(a,b)}function Ri(a,b,c){_Y(b,c,a);return a}function RE(a,b){Ls(a,b,20,214748365)}function Pn(a){x[a>>2]=77184;return a}function PL(a){x[a>>2]=94580;return a}function M8(a){a=a|0;return LK(a,0)|0}function Lha(a,b){a=a|0;b=b|0;vF(a,b)}function LW(a){return(a|0)>=120?120:a}function L8(a){a=a|0;return LK(a,1)|0}function Jj(a){return(a-1&255)>>>0<17}function JM(a){x[a>>2]=48716;return a}function IV(a,b,c){return Mx(a,b,c,5)}function Gt(a,b){a=a|0;b=b|0;return-1}function Fz(a){x[a>>2]=48232;return a}function Fn(a,b,c){return Mx(a,b,c,2)}function FM(a){x[a>>2]=74328;return a}function F8(a){a=a|0;return JK(a,0)|0}function Ez(a){x[a>>2]=48256;return a}function E8(a){a=a|0;return JK(a,1)|0}function Dz(a){x[a>>2]=48336;return a}function Cz(a){x[a>>2]=48376;return a}function Cr(a,b,c){return Sp(a,b,c,6)}function CP(a){return Si(EP(a)*32768)}function Bp(a,b,c){return Mx(a,b,c,1)}function Bka(a,b){a=a|0;b=b|0;Gr(a,b)}function AV(a){return(a&65535)==65534}function yka(a){a=a|0;return Lh(a)|0}function xy(a){a=a|0;return v[a+8|0]}function xo(a){return z[a+480188>>1]}function wy(a){a=a|0;return v[a+9|0]}function vF(a,b){a=a|0;b=b|0;t_(a,b)}function s2(a,b){a=a|0;b=b|0;ao(a,b)}function qq(a){return z[a+480192>>1]}function qG(a,b){Nx(a,b,3,536870912)}function pq(a){return z[a+480190>>1]}function pm(a){x[a+4>>2]=x[a+4>>2]+1}function ota(a){a=a|0;return Y_(a)|0}function kP(a){a=a|0;WH(a,47392,999)}function jC(a,b,c,d,e){tU(a,b,c,d,e)}function ita(a){a=a|0;return Ec(a)|0}function hv(a){return x[Ab(a)>>2]<<5}function hZ(a,b){Ls(a,b,6,715827883)}function hC(a,b){a=a|0;b=b|0;iV(a,b)}function cz(a){return!jd(a,125472,6)}function cW(a,b){return D(b,872)+a|0}function bT(a){return(a+5&255)>>>0<2}function bR(a,b){Ls(a,b,52,82595525)}function ao(a,b){a=a|0;b=b|0;Tk(a,b)}function ZD(a,b,c){vb(vb(a,b)+4|0,c)}function Yx(a){return(a<<2)+501744|0}function VQ(a,b){return Ek(a,b-a>>2)}function Uf(a,b){a=a|0;b=b|0;jg(a,b)}function Tr(a,b){a=a|0;b=b|0;ex(a,b)}function Tk(a,b){a=a|0;b=b|0;vm(a,b)}function TO(a){return z[a+480214>>1]}function T2(a,b){a=a|0;b=b|0;Gx(a,b)}function Q3(a,b){a=a|0;b=b|0;fx(a,b)}function Pja(a){a=a|0;return Ki(a)|0}function P9(a,b){a=a|0;b=b|0;nu(a,b)}function OC(a,b){if(!TX(a,b)){IX(b)}}function Lsa(a){a=a|0;return ND(a)|0}function LX(a,b){return KX(a,b-a>>1)}function LV(a,b){Nx(a,b,4,268435456)}function L2(a,b){a=a|0;b=b|0;zs(a,b)}function JW(a){return(a&255)>>>0<129}function JV(a,b){Nx(a,b,5,134217728)}function Gr(a,b){a=a|0;b=b|0;Uf(a,b)}function FP(a){x[a>>2]=0;x[a+4>>2]=0}function E2(a,b){a=a|0;b=b|0;Op(a,b)}function DO(a){return x[a+480272>>2]}function Ch(a){nf(a+52|0);fc(a+40|0)}function Aga(a){a=a|0;x[a+4224>>2]=0}function Af(a){return F(a)==Infinity}function AQ(a,b,c){a=a|0;b=b|0;c=c|0}function $d(a,b){return D(b,160)+a|0}function zJ(a){if(!y[a+4|0]){kJ(a)}}function xA(a,b){return D(b,28)+a|0}function wv(a){if(!y[a+4|0]){oW(a)}}function wf(a,b){return D(b,24)+a|0}function vb(a,b){x[a>>2]=b;return a}function tca(a,b){a=a|0;b=b|0;NO(a)}function sv(a,b){return D(b,36)+a|0}function rq(a,b,c){return Mz(a,b,c)}function rl(a,b,c){return lK(a,b,c)}function re(a,b){return Fc(a,ne(b))}function qY(a,b,c){return Kv(a,b,c)}function ot(a,b,c){return jd(a,b,c)}function o2(a){a=a|0;return Rg(a)|0}function mc(a,b){return(a|0)==(b|0)}function jy(a){a=a|0;return a+184|0}function jr(a){return(a&255)==1?1:2}function iy(a){a=a|0;return a+472|0}function i0(a){a=a|0;return bx(a)|0}function hy(a){a=a|0;return a+496|0}function hm(a,b){return(b-a|0)/52|0}function hR(a,b,c){return uA(a,b,c)}function gy(a){a=a|0;return a+508|0}function fy(a){a=a|0;return a+520|0}function fs(a,b){return(b-a|0)/36|0}function fj(a,b){return(b-a|0)/24|0}function fY(a){if(!y[a+4|0]){bY(a)}}function f9(a){a=a|0;return sl(a)|0}function ey(a){a=a|0;return a+532|0}function dU(a){if(!y[a+4|0]){eW(a)}}function cm(a,b){return bm($c(a,b))}function ch(a,b){return D(b,20)+a|0}function cN(a){if(!y[a+4|0]){bN(a)}}function bh(a){if(!y[a+4|0]){MQ(a)}}function bL(a){a=a|0;return ul(a)|0}function am(a){if(!y[a+4|0]){w$(a)}}function aM(a){if(!y[a+4|0]){KH(a)}}function aD(a,b){return vf(a,0-b|0)}function _u(a){if(!y[a+4|0]){EG(a)}}function _i(a,b){return D(b,52)+a|0}function _D(a,b){return vf(a,b-a|0)}function _6(a){a=a|0;return ry(a)|0}function Zl(a){return fH(a,255,255)}function Zia(a){a=a|0;Mr(a,22292,1)}function YV(a){if(!y[a+4|0]){XV(a)}}function Xi(a){if(!y[a+4|0]){DZ(a)}}function Xb(a,b){return Pe(a,b&255)}function Ww(a){v[a+2|0]=0;w[a>>1]=0}function Vd(a,b){return D(b,12)+a|0}function Vba(a,b){a=a|0;b=b|0;$O(a)}function VE(a){if(!y[a+4|0]){UE(a)}}function Ud(a,b){return(b-a|0)/12|0}function TK(a){a=a|0;return ox(a)|0}function TG(a,b,c){return ot(a,b,c)}function Sf(a,b){return(b-a|0)/20|0}function SY(a,b){return D(b,33)+a|0}function SU(a,b,c){return aC(a,b,c)}function Rj(a){if(!y[a+4|0]){OF(a)}}function RF(a){a=a|0;return gh(a)|0}function Q_(a,b,c){return xk(a,b,c)}function Ov(a,b){return(b-a|0)/33|0}function Ni(a,b,c){return dC(a,b,c)}function M1(a){a=a|0;hG(Rb(a,0,36))}function L1(a){a=a|0;return Yh(a)|0}function Kw(a,b){w[a>>1]=b;return a}function Ju(a){return!(a&204473357)}function Hr(a,b){return(b-a|0)/28|0}function Hq(a){if(y[a+24|0]){XS(a)}}function Gj(a,b){return Mg(a,b)&255}function Fl(a){return v$(a,251,255)}function Fk(a,b){return a>>>0<b>>>0}function Fd(a,b){return(a|0)!=(b|0)}function FC(a,b){return D(b,56)+a|0}function Eka(a){a=a|0;ZH(a,115,114)}function De(a,b,c){return EK(a,b,c)}function DF(a){a=a|0;return Zd(a)|0}function Bv(a,b){return(b-a|0)/56|0}function Br(a,b){return(b-a|0)/40|0}function zy(a,b){return!(b>>>31|0)}function zl(a,b){return(a+b|0)-1|0}function yF(a){return(a&255)+704|0}function wu(a,b){return(a-b|0)/6|0}function vo(a,b){x[a+1298472>>2]=b}function vd(a){return(a&128)>>>7|0}function ud(a){a=a|0;return a+16|0}function rp(a){v[a|0]=0;v[a+1|0]=0}function ql(a){return(a&255)>>>0>1}function nG(a,b){return Yo(a,b,36)}function kq(a,b){v[a|0]=b;return a}function gK(a){C[(fb-16|0)+8>>3]=a}function ci(a,b){a=a|0;b=b|0;Fb(a)}function cT(a){Ce(a+8|0);WS(a+4|0)}function as(a,b){return(b<<11)+a|0}function _q(a,b){return(a|0)<(b|0)}function Zi(a){return a&2147483647}function Yc(a,b){return D(b,6)+a|0}function SZ(a,b){return Jx(a,b,56)}function Qy(a){return mc(a,-1)?0:a}function Qk(a,b){return D(Zk(b),a)}function QY(a,b){return Jx(a,b,18)}function QJ(a){return Th(a,499712)}function Q$(a,b){return Yo(a,b,28)}function PM(a){return(sk(a)|0)==-1}function PJ(a){return Th(a,499704)}function OM(a,b){a=a|0;b=b|0;Wm(b)}function No(a,b){return(b<<13)+a|0}function NM(a,b){a=a|0;b=b|0;fc(b)}function NJ(a){return Th(a,499728)}function MJ(a){return Th(a,499720)}function Hk(a,b){return(b-a|0)/6|0}function Gi(a){a=a|0;v[a+4202|0]=0}function GB(a,b){return(b-a|0)/7|0}function F9(a,b){a=a|0;b=b|0;Db(b)}function Cx(a,b){return Yo(a,b,12)}function Bc(a,b){return wH(a,b,-1)}function zz(a,b){return vR(a,b)^1}function yb(a,b){return(b<<2)+a|0}function wt(a,b){return EK(a,0,b)}function tc(a){x[a>>2]=0;return a}function p3(a){a=a|0;return 13108}function n3(a){a=a|0;return 10825}function mO(a,b){x[a+480272>>2]=b}function kC(a,b){return Yo(a,b,4)}function hn(a,b){return(b<<8)+a|0}function fqa(a){a=a|0;gg(a,16854)}function ec(a,b){return Kb(a)+b|0}function de(a){return x[gc(a)>>2]}function cC(a){if(a){Db(a+-64|0)}}function bka(a){a=a|0;vg(a,Hj(a))}function bF(a){return a>>>0>8?5:4}function apa(a){a=a|0;yY(a,65535)}function ag(a){return a!=a?E(0):a}function ac(a,b){return(b<<1)+a|0}function aL(a){return _G(a,93320)}function _n(a){return a-48>>>0<10}function _L(a){return a+1298412|0}function Yd(a,b){return(b<<4)+a|0}function Xk(a){w[a>>1]=0;return a}function Vh(a){x[a>>2]=1;return a}function V8(a){a=a|0;return 10422}function UA(a){fc(a+4|0);return a}function Tx(a,b){return x[a+b>>2]}function Tc(a){return v$(a,1,120)}function Se(a,b){return(b<<3)+a|0}function SF(a){return(a&16)>>>4|0}function R$(a){Es(a,17,124780,33)}function Qq(a){Es(a,17,124832,51)}function Pt(a){return _G(a,93256)}function Pra(a){a=a|0;gg(a,16251)}function Pe(a,b){return(b<<5)+a|0}function PT(a,b){return Yo(a,b,8)}function K3(a){a=a|0;return 13222}function J3(a){a=a|0;return 10302}function Ib(a,b){return mc(a,b)^1}function Eo(a){return a+1074328|0}function An(a){x[a>>2]=2;return a}function zqa(a){a=a|0;qw(a,3863)}function zba(a){a=a|0;du(a-92|0)}function zY(a,b){zc(a,b+4|0,256)}function xqa(a){a=a|0;qw(a,4887)}function w2(a){a=a|0;gg(a,16881)}function vv(a){v[a|0]=0;return a}function vua(a){a=a|0;gg(a,4358)}function ug(a,b,c,d){bf(a,c,d,b)}function uF(a,b,c,d){px(a,b,c,d)}function u2(a){a=a|0;ZH(a,50,49)}function rba(a){a=a|0;du(a-96|0)}function q3(a){a=a|0;return 9861}function ow(a,b,c){mH(a,b,c,128)}function oQ(a){return(a&8)>>>3|0}function m3(a){a=a|0;return 5720}function lta(a){a=a|0;gg(a,3872)}function lf(a,b,c){wl(a,b,b+c|0)}function kF(a){Qm(a,Np(a),78544)}function gqa(a){a=a|0;gg(a,3985)}function XN(a){a=a|0;fu(a);Db(a)}function TF(a){return(a&2)>>>1|0}function Sw(a,b){return Dua(a,b)}function Rba(a){a=a|0;du(a-88|0)}function RK(a){x[a+72>>2]=496676}function PK(a){x[a+72>>2]=496760}function P3(a){a=a|0;return 6920}function Ne(a,b){v[a+11|0]=b&127}function Lra(a){a=a|0;gg(a,4484)}function Loa(a){a=a|0;gg(a,4165)}function Lg(a,b){vb(tc(a)+4|0,b)}function IN(a){a=a|0;Pm(a);Db(a)}function Hra(a){a=a|0;gg(a,4378)}function G3(a){a=a|0;return 6901}function FN(a){a=a|0;oq(a);Db(a)}function CV(a,b,c,d){BV(a,b,c,d)}function Aw(a,b,c,d){EB(a,b,c,d)}function zd(a){return wb(Kb(a))}function yh(a,b){return _c(a,b)}function yf(a,b){return Fc(a,b)}function xt(a,b){return Ud(a,b)}function xg(a){tb(a+20|0);tb(a)}function xE(a,b,c){bf(a,c,30,b)}function x2(a){a=a|0;gg(a,4532)}function wi(a,b){return Fd(a,b)}function wga(a){a=a|0;Db(QP(a))}function ub(a){me(a+12|0);me(a)}function tga(a){a=a|0;return 13}function sE(a,b){return Fk(a,b)}function rE(a,b){return lp(b,a)}function pi(a,b,c){bf(a,c,20,b)}function nt(a){a=a|0;return 127}function m4(a){a=a|0;Db(II(a))}
function lq(a,b){return yb(a,b)}function lA(a,b){return VQ(a,b)}function kj(a,b){return a>>>b&1}function jl(a){if(sI(a)){Db(a)}}function jha(a){a=a|0;Db(aQ(a))}function it(a){return Ab(a+8|0)}function iia(a){a=a|0;Db(wQ(a))}function hc(a,b){return uG(a,b)}function gk(a,b){return b-a>>11}function dk(a,b,c){bf(a,c,13,b)}function c_(a,b,c){bf(a,c,24,b)}function _c(a,b){return Cb(a,b)}function Zg(a,b){return Ib(a,b)}function X_(a,b){return zk(b,a)}function XS(a){VS(a+12|0);US(a)}function XL(a,b){return ih(a,b)}function Wh(a,b){return Nw(a,b)}function Wg(a){return bT(a&255)}function Wb(a,b){return _i(a,b)}function Vi(a,b,c){bf(a,c,28,b)}function Ue(a,b,c){bf(a,c,32,b)}function UG(a,b){return Uc(a,b)}function Te(a){return vr(Fe(a))}function Si(a){return vn(Fe(a))}function Sd(a,b){return oc(a,b)}function Ru(a){_T(a+12|0);cU(a)}function Rk(a,b,c){bf(a,c,22,b)}function Qw(a,b){return BF(a,b)}function Pj(a,b){return Xc(a,b)}function Paa(a){a=a|0;Db($t(a))}function P_(a,b){return _D(a,b)}function Ot(a,b,c){Zb(a,b,1<<c)}function NE(a){return(a&255)==1}function Mj(a,b){return Pe(a,b)}function Mi(a,b){return(a|b)!=0}function Me(a){a=a|0;return a|0}function MA(a){w[a+480214>>1]=0}function Lk(a,b,c){bf(a,c,12,b)}function LT(a,b){return $c(a,b)}function KC(a,b,c){bf(a,c,64,b)}function Jy(a,b){return oh(a,b)}function Jg(a){return Oi(a)?0:a}function Id(a){return(a&255)!=0}function He(a,b){return a0(a,b)}function Hc(a,b){return as(a,b)}function HR(a,b){return FR(a,b)}function Gl(a){JA(a,0);return a}function Gb(a,b){return(a&b)!=0}function Fc(a,b){return vb(a,b)}function FF(a,b){return AF(a,b)}function Co(a,b){return _t(a,b)}function Bf(a,b){return eh(a,b)}function Ak(a){tb(a+12|0);od(a)}function Ad(a,b){return!Cb(a,b)}function $o(a,b){return Yk(a,b)}function $m(a){tb(a+12|0);tb(a)}function xG(a){return a+1024|0}function wC(a){return a+4096|0}function rB(a,b){return a<<8|b}function pu(a){return a>>>27^a}function pE(a){return el(a,28)}function oc(a,b){return b-a>>2}function oM(a){a=a|0;Db(pM(a))}function nV(a){return a+4896|0}function lu(a){a=a|0;Db(_f(a))}function lp(a,b){return a-b>>1}function ko(a){return(a|0)==-1}function ih(a,b){return b-a>>3}function iQ(a){a=a|0;Db(jQ(a))}function iG(a){return el(a,36)}function ht(a){a=a|0;Db(my(a))}function hha(a){a=a|0;return 6}function hO(a){a=a|0;Db(oq(a))}function gia(a){a=a|0;return 9}function gJ(a){a=a|0;Db(ly(a))}function fX(a,b){Kx(a,b,5,3,4)}function fJ(a){a=a|0;Db(ky(a))}function e4(a){a=a|0;Db(GI(a))}function du(a){a=a|0;Db(nq(a))}function d4(a){a=a|0;Db(FI(a))}function cZ(a,b){wl(a,b,ud(b))}function cA(a){a=a|0;Db(uu(a))}function c4(a){a=a|0;Db(EI(a))}function bc(a,b){x[a+100>>2]=b}function b4(a){a=a|0;Db(DI(a))}function aX(a){return el(a,56)}function a9(a){a=a|0;Db(Ct(a))}function _d(a){return a&64?2:1}function _3(a){a=a|0;Db(CI(a))}function Zn(a){a=a|0;Db(J_(a))}function ZQ(a){return el(a,52)}function Z1(a){a=a|0;Db(tG(a))}function Xy(a){a=a|0;Db(ul(a))}function XK(a){a=a|0;Db(gq(a))}function X9(a){a=a|0;Db(eM(a))}function Wy(a){a=a|0;Db(ho(a))}function WK(a){a=a|0;Db(Gf(a))}function W3(a){a=a|0;Db(AI(a))}function Vy(a){a=a|0;Db(Ft(a))}function UT(a,b){Xu(a,Kb(a),b)}function Ty(a){a=a|0;Db(Et(a))}function Sy(a){a=a|0;Db(Dt(a))}function Rh(a,b){return b-a>>8}function Pp(a){return el(a,12)}function On(a){a=a|0;Db(ox(a))}function Nk(a){return a>>>0<11}function Mg(a,b){return b-a>>5}function Lv(a,b){return a-b>>2}function Ke(a,b){if(!a){Db(b)}}function KI(a){a=a|0;Db(dt(a))}function JU(a){return el(a,32)}function J5(a){a=a|0;Db(et(a))}function I4(a){a=a|0;Db(SI(a))}function HJ(a){a=a|0;Db(ry(a))}function HI(a){a=a|0;Db(at(a))}function F_(a){return el(a,20)}function FO(a,b){bH(a,b,22292)}function Dk(a,b){return b-a>>4}function DQ(a){return a-2048|0}function CN(a,b){bH(a,b,13618)}function Bz(a){return el(a,16)}function B5(a){a=a|0;Db(ZI(a))}function $c(a,b){return b-a>>1}function zo(a){a=a|0;return 4}function zk(a,b){return a-b|0}function xb(a,b){return a+b|0}function vX(a,b){cc(a,b,1108)}function vP(){return 20054022}function ur(a){return a+256|0}function up(a){return a>>>0<5}function uk(a){return a+4e4|0}function uR(a,b,c){Pl(a,b,-c)}function pp(a,b){zb(a+12|0,b)}function pD(a,b){cc(a,b,4896)}function o0(a,b){cc(a,b,1954)}function nk(a){return(a&5)!=0}function mV(a){return a+512|0}function mQ(a){a=a|0;return 3}function lL(a){a=a|0;return-1}function l0(a,b){bf(a,b,13,1)}function ic(a){a=a|0;return 0}function hX(a,b){bf(a,b,33,1)}function hQ(a){a=a|0;return 7}function hM(a){return nk(a)^1}function fr(a){return a>>>0<2}function cu(a,b){x[a+32>>2]=b}function ay(a){return pI(a,0)}function ZY(a){kp(Rb(a,0,40))}function Yr(a,b){bf(a,b,26,3)}function YP(a){a=a|0;return 5}function Xc(a,b){return b-a|0}function SC(a,b){cc(a,b,1024)}function QV(a){return a-256|0}function PC(a){return a+128|0}function Oo(a,b){x[a+36>>2]=b}function Lj(a){return!(a&255)}function Le(a){a=a|0;return 2}function Jn(a){return a&1?2:1}function Ie(a){a=a|0;return 1}function Fj(a){return Ed(a)^1}function Fb(a){xx(a);return a}function Ed(a){return(a|0)!=0}function A_(a,b){bf(a,b,40,2)}function $x(a){return pI(a,1)}function $e(a,b){w[a+28>>1]=b}function zq(a,b){v[a+33|0]=b}function zP(a){return a+48|0}function zE(a,b){cc(a,b,512)}function zD(a,b,c){ee(a,b,c)}function xF(a,b){cc(a,b,772)}function wn(a,b){x[a+8>>2]=b}function vW(a,b){cc(a,b,204)}function vA(a,b){JA(a,ne(b))}function u_(a,b){cc(a,b,218)}function tF(a,b){bf(a,b,8,3)}function sw(a,b){cc(a,b,192)}function sV(a,b){cc(a,b,263)}function rx(a,b){FG(a,ne(b))}function rd(a,b){return a>>b}function qc(a,b,c){qn(a,b,c)}function q_(a,b){cc(a,b,157)}function nc(a){return a+12|0}function nF(a,b){cc(a,b,497)}function nC(a){return a-16|0}function mp(a,b){He(a,b+8|0)}function k_(a,b){cc(a,b,206)}function il(a){return a-24|0}function gw(a){return a-40|0}function gr(a,b){return a<<b}function en(a){return a-32|0}function e_(a,b){cc(a,b,236)}function eX(a){return a-56|0}function dp(a){return a+14|0}function cj(a){return a-36|0}function cc(a,b,c){Zb(a,b,c)}function bl(a){return a-12|0}function a_(a){return a+10|0}function aW(a,b){zc(a,b,128)}function ZT(a){YT(a,x[a>>2])}function XW(a,b){cc(a,b,146)}function WZ(a,b){cc(a,b,102)}function WC(a,b){cc(a,b,130)}function TW(a,b){cc(a,b,608)}function So(a){return a+32|0}function Sh(a,b,c){f$(a,b,c)}function Re(a,b){a=a|0;b=b|0}function RD(a,b){bf(a,b,8,2)}function Qc(a,b,c){Ot(a,b,c)}function QX(a,b){cc(a,b,600)}function OT(a,b,c){ye(a,b,c)}function Np(a){return a+20|0}function Nc(a){Bd(a,x[a>>2])}function NU(a){MU(a,x[a>>2])}function NG(a,b,c){gf(a,c,b)}function MZ(a,b){cc(a,b,576)}function MY(a){return a-33|0}function MR(a){return a+24|0}function K$(a,b){cc(a,b,610)}function Jb(a,b,c){VF(a,b,c)}function JZ(a,b){cc(a,b,674)}function IS(a,b,c){mr(a,b,c)}function IB(a){v[a+6152|0]=0}function HY(a){return a+3&-4}function GA(a,b){v[a+34|0]=b}function G0(a,b,c){df(a,c,b)}function Fr(a){return a-28|0}function FA(a,b){v[a+32|0]=b}function EX(a,b){cc(a,b,126)}function EA(a,b){v[a+35|0]=b}function Du(a){eS(a,x[a>>2])}function Bq(a,b){B[a+8>>2]=b}function Bd(a,b){x[a+4>>2]=b}function BZ(a){return a+36|0}function Aq(a,b){B[a+4>>2]=b}function $q(a,b,c){yp(a,b,c)}function $Y(a,b){cc(a,b,128)}function zr(a,b){cc(a,b,12)}function zf(a){return a&255}function xf(a){return a-4|0}function x_(a,b){cc(a,b,48)}function xW(a){return a-1|0}function xV(a,b){return a<b}function wp(a,b){v[a+1|0]=b}function wg(a,b){v[a+3|0]=b}function wE(a,b){qH(a,b,32)}function vu(a){Rb(a,0,2048)}function vE(a){x[a+12>>2]=0}function uP(){return 524288}function sU(a,b){cc(a,b,27)}function s$(a,b){zc(a,b,40)}function rw(a,b){qH(a,b,64)}function pf(){R$(11050);p()}function nD(a,b){cc(a,b,33)}function n0(a){Rb(a,0,1954)}function mw(a,b){cc(a,b,64)}function mda(a){a=a|0;sP(a)}function lw(a,b){cc(a,b,66)}function jx(a,b){cc(a,b,20)}function jX(a,b){cc(a,b,96)}function hF(a,b){cc(a,b,38)}function gc(a){return a+4|0}function gD(a,b){cc(a,b,40)}function fZ(a){return a-6|0}function fF(a,b){xi(a,b,37)}function fE(a,b){cc(a,b,16)}function dn(){Qq(11050);p()}function cw(a,b){cc(a,b,22)}function bs(a,b){cc(a,b,36)}function b_(a){return a+6|0}function aZ(a,b){cc(a,b,80)}function _e(a){return a+2|0}function Yi(a){return a+3|0}function VA(a){Rb(a,0,4096)}function Tw(a,b){Zb(a,b,22)}function Qv(a,b){return a<b}function PE(a,b){cc(a,b,32)}function Lw(a,b){cc(a,b,11)}function Jc(a){return a+1|0}function Ip(a){return a-8|0}function Hh(a){return a&127}function HG(a,b){cc(a,b,24)}function Gv(a,b){cc(a,b,30)}function Gn(a){return a-2|0}function En(a,b){Zb(a,b,32)}function EY(a,b){cc(a,b,52)}function ET(a){return a-7|0}function E0(a,b){Zb(a,b,20)}function Dq(a){Rb(a,0,8192)}function DN(a){return 0-a|0}function Cw(a,b){cc(a,b,65)}function C_(a,b){cc(a,b,98)}function B0(a,b){cc(a,b,17)}function Ab(a){return a+8|0}function yg(a){v[a+12|0]=1}function yd(a,b){x[a>>2]=b}function yc(a){x[a+8>>2]=0}function yR(a){CA(a,de(a))}function wF(a){Rb(a,0,772)}function vc(a){a=a|0;Db(a)}function uZ(a){uD(a,de(a))}function uW(a){Rb(a,0,204)}function tk(a,b){B[a>>2]=b}function ss(a){a=a|0;us(a)}function sZ(a){vD(a,de(a))}function sF(a,b){Sh(a,2,b)}function p_(a){Rb(a,0,157)}function mn(a,b){yp(a,b,0)}function mh(a,b){cc(a,b,4)}function mF(a){Rb(a,0,497)}function j_(a){Rb(a,0,206)}function iD(a){hD(a,de(a))}function gQ(a,b){RQ(a,3,b)}function ed(){R$(7718);p()}function dx(a,b){cc(a,b,3)}function d_(a){Rb(a,0,236)}function ct(a){jl(x[a>>2])}function _k(a,b){cc(a,b,8)}function _j(a,b){cc(a,b,5)}function _b(a){um(x[a>>2])}function _T(a){Mq(a,de(a))}function Yv(a){HD(a,de(a))}function Xia(a){a=a|0;gb=a}function XD(a,b){cc(a,b,6)}function WW(a){Rb(a,0,146)}function WV(a){sC(a,de(a))}function W0(a){a=a|0;Yh(a)}function Vr(a,b){cc(a,b,1)}function VV(a){tC(a,de(a))}function VS(a){Lu(a,de(a))}function UZ(a){ID(a,de(a))}function US(a){Mu(a,de(a))}function SW(a){Rb(a,0,608)}function Rfa(a){a=a|0;fb=a}function PX(a){Rb(a,0,600)}function Oi(a){return a!=a}function OV(a){Rb(a,0,256)}function Nl(a){FB(a,de(a))}function MC(a){Rb(a,0,130)}function LZ(a){Rb(a,0,576)}function Jr(a,b){cc(a,b,7)}function J$(a){Rb(a,0,610)}function Iw(){Qq(7718);p()}function GZ(a){Rb(a,0,192)}function DX(a){Rb(a,0,126)}function Cp(a,b){cc(a,b,2)}function $ga(){return fb|0}function y_(a){Rb(a,0,48)}function rD(a){Rb(a,0,80)}function oE(a){Rb(a,0,66)}function lO(){return 2048}function kX(a){Rb(a,0,96)}function hd(a,b){v[a|0]=b}function gF(a){Rb(a,0,38)}function fw(a){Rb(a,0,64)}function cs(a){Rb(a,0,36)}function RZ(a){Rb(a,0,56)}function Qd(a){v[a+4|0]=1}function KY(a){Rb(a,0,33)}function Jh(a){tb(a+16|0)}function Ep(a){return a&1}function EQ(a){zm(a,2048)}function DY(a){Rb(a,0,52)}function B_(a){Rb(a,0,98)}function xs(a,b){UG(a,b)}function wU(a,b){Ih(a,b)}function vq(a,b){vb(a,b)}function qo(a,b){kq(a,b)}function qE(a,b){Ok(a,b)}function oX(a,b){He(a,b)}function mm(a,b){Kw(a,b)}function mD(a,b){IY(a,b)}function kW(a,b){Tl(a,b)}function ig(a,b){Y$(a,b)}function eA(a,b){re(a,b)}function dR(a,b){eS(a,b)}function cd(a,b){Bs(a,b)}function XT(a){Ce(a+8|0)}function WD(a,b){hc(a,b)}function Vu(a,b){PR(a,b)}function T_(a,b){yU(a,b)}function Sg(a){a=a|0;p()}function Ro(a,b){Uc(a,b)}function Rd(a,b){Og(a,b)}function Qh(a,b){Ro(a,b)}function Oj(a){tb(a+4|0)}function Mn(a,b){cG(a,b)}function LU(a,b){MU(a,b)}function Kc(a){fc(a+8|0)}function KT(a,b){T$(a,b)}function Jd(a,b){Bd(a,b)}function IU(a,b){ng(a,b)}function Hd(a){ub(a+8|0)}function Ei(a,b){gi(a,b)}function yI(a){Hx(a,48)}function xp(a){xH(a,11)}function o$(a){zm(a,40)}function fp(a){xH(a,16)}function dh(a){v[a|0]=0}function Zja(){ua();p()}function Tn(a){Hx(a,36)}function DJ(a){zm(a,24)}function Bg(a){Hx(a,24)}function wh(a){WM(a,0)}function vh(a){UM(a,0)}function os(a){FG(a,0)}function mg(a){tZ(a,0)}function kI(){va();p()}function is(a){zm(a,8)}function iZ(a){zm(a,6)}function aj(a){zm(a,2)}function XA(a){hS(a,0)}function WA(a){gS(a,0)}function Lc(a){Qe(a,0)}function KR(a){lS(a,0)}function GT(a){zm(a,7)}function D3(){kI();p()}function Al(a){VM(a,0)}function vs(a){nc(a)}function tV(a){tc(a)}function qX(a){vv(a)}function mW(a){Nb(a)}function hV(a){we(a)}function gW(a){Xe(a)}function _w(a){Xk(a)}function Wm(a){wc(a)}function RT(a){To(a)}function Nf(a){a=a|0}function LC(a){tg(a)}function Eb(a){tb(a)}
// EMSCRIPTEN_END_FUNCS
e=y;var ib=c([null,uc,GG,vm,j2,yG,a2,Y1,P1,pG,oG,pe,t1,q1,vF,l1,h_,J_,Sna,Mna,Jna,K0,xua,tw,Wj,jua,Z,Osa,Fw,km,cL,Lh,np,$sa,Me,Yna,Dc,A5,KD,Jk,pr,un,hsa,n_,Xl,iV,hC,Uma,pma,hU,_ka,nla,qg,kka,Nj,cka,Zja,Tja,Sja,yA,Eja,wja,iga,Nia,JQ,x9,w9,Ht,JQ,ufa,dP,jg,Mea,fea,$da,Vda,Oda,Ida,Dda,yda,pda,Gca,eda,Uy,ua,Mb,i5,G4,F4,v4,n4,ao,X3,ska,Q3,rka,O3,da,l3,W2,V2,U2,T2,S2,oH,R2,Q2,P2,O2,N2,L2,K2,M2,S8,zs,Rp,qg,J2,QG,PG,I2,zx,H2,OG,Uf,G2,E2,C2,ss,rs,Zh,gg,z2,Op,B2,A2,y2,F2,x2,KG,w2,KG,D2,MG,v2,u2,t2,s2,r2,dd,Mb,o2,Mp,n2,Lh,m2,sd,l2,al,sd,qx,k2,ox,nx,M1,i2,$1,_1,L1,I1,F1,E1,bx,hG,D1,C1,Nja,Oja,BT,Lja,Mja,DA,xu,Vb,Pja,he,dG,z1,y1,RF,w1,v1,RF,DF,Pw,p1,Pg,DF,Mw,_ia,ija,Zia,jf,zka,x1,sg,mua,yka,yta,_E,ZE,e1,d1,YE,c1,dg,b1,a1,Cc,Ew,$0,_0,Z0,Tf,Y0,jm,X0,WE,W0,T0,KE,S0,R0,Q0,yw,P0,lF,JE,O0,N0,M0,L0,J0,HE,H0,x0,Dd,FE,vua,uua,EE,DE,tua,sua,rua,Ew,qua,w0,pua,zw,oua,nua,Vk,gua,Ir,fua,Lb,bg,gg,eua,yE,dua,ld,Pk,cua,bua,aua,i0,h0,nd,$ta,op,_ta,Zta,Yta,e0,d0,Jk,qw,Xta,Wta,rla,Vta,fh,Uta,Tta,Nta,Uj,Qta,Pta,Ota,Sta,Rta,Uf,W$,Xh,Rf,Kta,Jta,Ita,Fta,Uj,Tj,Eta,Dta,Cta,lE,D$,kE,Bta,Ata,zta,Vk,k$,h$,vta,qta,__,to,pta,vg,I$,ota,yw,nta,mta,cE,lta,Z_,nx,kta,W_,V_,i_,jta,Vk,fta,Ir,$j,eta,dta,h0,cta,bta,ata,M_,L_,lm,_sa,Zsa,Ysa,Wsa,Uj,K_,Xsa,Xh,Rf,jE,Rsa,Er,Z_,Ksa,Jsa,Isa,Hsa,Esa,Ir,Dsa,Csa,jp,M_,Bsa,Asa,gg,zsa,ysa,xsa,wsa,vsa,$Z,usa,tsa,lK,_Z,ssa,rsa,v0,ZZ,qsa,psa,osa,xla,nsa,XZ,msa,XZ,Lsa,ksa,Uj,lsa,Xh,Rf,ak,esa,dsa,csa,bsa,_ra,Zra,Yra,Xra,Wra,jp,Vra,Ura,Tra,CD,r1,Sra,Rra,Qra,Pra,Ora,FZ,Nra,o1,Mra,Lra,Kra,Jra,EZ,Ira,fsa,Hra,Gra,gg,Fra,nE,Era,gsa,Dra,Cra,Bra,yD,yD,CZ,Ara,zra,AZ,yD,xZ,yra,N8,xra,wra,vra,ura,tra,sra,rra,wZ,sd,kr,gra,Wv,qra,Kia,Jia,Iia,Hia,Gia,Fia,pra,ora,ng,nra,mra,lra,kra,GG,qla,ola,Wia,gja,hja,jra,vZ,ira,hra,Yja,Dia,Tk,OG,lla,tla,kla,jla,Tv,cra,bra,ara,$qa,_qa,Zqa,Yqa,Xqa,Wqa,Vqa,Uqa,Sqa,Rqa,Tqa,JY,Rf,BY,lD,Oqa,kD,Nqa,Mqa,Lqa,Kqa,jD,Jqa,Pw,YE,Iqa,yY,xY,Hqa,Pr,Gqa,rf,Fqa,vY,jp,ww,jp,ZZ,Tr,gg,_E,jp,to,Cqa,Bqa,Aqa,zqa,dD,Hv,yqa,xqa,wqa,vqa,uqa,tqa,sqa,rqa,qqa,pqa,oqa,nqa,mqa,lqa,kqa,wD,jqa,iqa,hqa,gg,zZ,yZ,ED,gqa,fqa,EE,nx,eqa,dqa,cqa,bqa,aqa,Wka,Vka,Uka,Ypa,Zpa,Gr,_pa,$pa,kw,XX,Vpa,xka,$ka,Yu,wka,vka,vT,Su,pT,uka,fT,BU,tka,RB,Ej,vi,Opa,Npa,yr,Wpa,Sv,Kpa,r0,Jpa,Ipa,BX,kr,Hpa,Gpa,Fpa,Epa,Dpa,Gw,Cpa,vZ,Bpa,Apa,xr,zpa,JC,upa,HC,tpa,spa,uX,zp,rpa,Uj,Xh,Rf,vi,opa,npa,mpa,lpa,kD,ipa,hpa,xr,gpa,jm,jja,dpa,cpa,Tj,rX,HC,zw,bpa,uX,apa,$oa,_oa,Dv,Zoa,Dv,Yoa,wm,s1,Voa,Uj,Xoa,CC,$W,Woa,Xh,Rf,yr,Soa,Poa,lD,Ooa,Loa,Koa,OW,Gw,CD,Joa,EE,gg,Aoa,zoa,Ew,yoa,xoa,woa,voa,_v,uoa,op,roa,qoa,poa,ooa,noa,moa,jn,hW,loa,koa,joa,ioa,hoa,goa,foa,eoa,doa,coa,boa,aoa,$na,kD,_na,Zna,Xna,Sv,Wna,Vna,Una,Ir,Lka,Mp,i0,Ska,Rka,Ir,Qka,vi,Mp,Pka,Oka,Nka,Tna,SV,Pna,Ona,Nna,Lna,Kna,Xr,Gna,Fna,Ena,Dna,Cna,Bna,Ana,zna,yna,xna,wna,o3,TI,vna,gg,una,tna,Xka,yla,ita,OU,vla,ula,sla,pla,mla,CU,fla,hla,gla,ela,Zd,dla,qU,cla,bla,ala,fU,eU,Mo,aU,Zka,Yka,Tka,gp,Jka,Tj,CT,ps,Kja,Jja,Ija,Aka,Hja,u1,Gja,cx,ps,x0,Fja,CT,Hka,Dja,Mka,Uj,Xh,Rf,Kka,Uj,Xh,Rf,Ika,Uj,Xh,Rf,Fka,Cka,Bka,Me,H0,qka,pka,oka,nka,mka,lka,wla,pna,JP,jka,Ec,hka,bja,gka,q2,K1,B1,H1,eka,dka,A1,J1,p2,G1,ZR,bka,aka,$ja,YR,XR,SA,_ja,ila,Xja,Wja,Vja,Uja,YQ,Uia,kja,yx,KS,yG,LG,DA,YR,Qja,Tk,ys,Or,Eka,Gka,zja,yja,Tj,xja,HC,vja,uja,tja,yr,sja,vi,rja,qja,pja,oja,nja,Uj,Xh,Rf,Aja,fja,eja,dja,cja,gi,Om,aja,$ia,Yia,Sia,Ria,Qia,Pia,Oia,UQ,Via,xq,TQ,ol,gi,ng,Lia,Eia,l9,Mia,Tia,Bia,Aia,Sha,zia,yia,GQ,Zf,SQ,kia,Tha,pn,Nha,Cja,Mha,Kha,Jha,Iha,DA,Lha,te,nu,nu,Hha,Gha,Eha,tQ,kQ,kha,bha,Vga,Oga,Gga,xga,zga,nga,fga,yP,ku,$fa,_fa,raa,saa,tP,Tfa,sP,rP,Rja,uaa,Ofa,yP,Nfa,aba,Qaa,dba,lP,cM,kP,Rz,Kfa,Eda,oq,Cda,Mm,jP,Zaa,gP,Yaa,hP,Xaa,fP,lK,pba,Ffa,_aa,Qz,vY,Pz,Oz,Nz,vfa,sfa,kP,Rz,pfa,ofa,nfa,mfa,lfa,kfa,jfa,ifa,hfa,gfa,ffa,efa,dfa,cfa,bfa,afa,$ea,_ea,Zea,Yea,Xea,Wea,Vea,Uea,Tea,cP,bP,aP,vG,K9,eba,$O,QO,Vaa,PO,OO,oba,N9,O9,NO,T9,KO,JO,nz,HO,Rz,EO,CO,BO,wo,M9,L9,AO,zO,yO,xO,wO,vO,uO,tO,sO,rO,qO,pO,Lz,oO,nO,UR,Fv,Kz,Jz,Jda,kO,Hda,Gda,Fda,eO,zda,lP,xda,Tca,wda,Sca,vda,Rca,uda,Qca,tda,Pca,sda,Oca,qda,caa,cM,br,Dka,Gx,qs,eU,kba,jba,iba,gba,cba,ika,$aa,Taa,Waa,v9,k9,j9,Uaa,OM,NM,OM,NM,jm,Vk,Vk,LM,KM,LM,KM,au,Re,au,Re,Raa,au,Re,au,Re,fka,bba,lba,fba,vx,CM,Kaa,CM,Jaa,_,BM,Iaa,BM,Haa,rz,rz,rz,Eaa,Xt,Xt,Xt,Xt,wM,Baa,wM,Aaa,vM,zaa,vM,yaa,qz,qz,qz,vaa,Wt,Wt,Wt,Wt,taa,ZM,XM,Jz,sM,qaa,paa,gaa,iM,baa,aaa,Y9,S9,R9,Q9,P9,J9,I9,H9,OR,qna,G9,F9,E9,D9,z9,y9,UK,TK,T3,r9,q9,p9,o9,n9,m9,Me,H3,L4,T8,TK,Py,Ly,ei,di,yt,Db,Tv,th,tl,Ky,Fm,u8,t8,mj,sh,uK,lj,S3,Ry,Fy,ei,di,tt,fi,f9,km,jo,mj,sh,nK,lj,$7,R3,W7,ZK,R7,Bt,np,M7,pt,Nf,u7,go,t7,s7,r7,RJ,p7,Jt,n7,m7,oj,l7,RJ,j7,qZ,h7,g7,d7,c7,T6,S6,R6,Q6,P6,O6,N6,M6,L6,K6,J6,I6,H6,G6,F6,E6,D6,C6,B6,A6,z6,y6,x6,w6,v6,u6,t6,s6,r6,q6,p6,o6,n6,AJ,m6,z5,y5,x5,w5,v5,XI,u5,WI,t5,s5,r5,q5,p5,o5,n5,m5,l5,k5,j5,h5,g5,f5,e5,d5,c5,b5,a5,$4,_4,Z4,Y4,X4,W4,V4,U4,T4,S4,R4,M4,$3,a4,Q4,P4,O4,N4,Cm,aq,p4,o4,K4,J4,r4,q4,pk,g4,f4,eq,Ay,Xl,On,ms,ona,nna,mna,lna,kna,jna,ina,hna,gna,fna,ena,dna,cna,bna,ana,$ma,_ma,Zma,Yma,Xma,Wma,Vma,Tma,Sma,Rma,Qma,Pma,Oma,Nma,Mma,Lma,Kma,Jma,Ima,Hma,Gma,Fma,Ema,Dma,Cma,Bma,Ama,zma,yma,xma,wma,vma,uma,tma,sma,rma,qma,oma,nma,mma,lma,kma,jma,ima,hma,gma,fma,ema,dma,cma,bma,ama,$la,_la,Zla,Yla,Xla,Wla,Vla,Ula,Tla,Sla,Rla,Qla,Pla,Ola,Nla,Mla,Lla,Kla,Jla,Ila,Hla,Gla,Fla,Ela,Dla,Cla,Bla,Ala,zla,On,Ina,Hna,asa,$ra,Noa,Moa,Goa,Foa,Qqa,Pqa,ypa,xpa,era,dra,iua,hua,Vsa,Usa,V0,U0,yua,wua,qpa,ppa,Roa,Qoa,Rna,Qna,Hta,Gta,xta,wta,i1,h1,g1,f1,fpa,epa,Uoa,Toa,Mpa,Lpa,fra,VY,Qsa,Psa,jsa,isa,Mta,Lta,hta,gta,kpa,jpa,Bja,mja,lja,Gsa,Fsa,Nsa,Msa,Qpa,Ppa,toa,soa,wpa,vpa,Tsa,Ssa,Ioa,Hoa,Coa,Boa,sta,rta,Eoa,Doa,Xpa,Spa,Rpa,k1,j1,n1,m1,lua,kua,Eqa,Dqa,uta,tta,Upa,Tpa,sna,rna,Zn,ms,N1,vc,rm,xP,vc,Me,vc,ic,Ie,Ie,ic,ic,O1,d2,c2,Q1,vc,rm,vc,tG,Z1,X1,Ie,W1,V1,U1,T1,S1,R1,uu,cA,tu,BQ,ic,Nf,ic,ic,ic,Re,zo,xia,wia,via,uia,tia,Hi,aA,aA,$z,AQ,$z,zQ,$z,zQ,Nf,VY,sia,ria,qia,pia,oia,Gi,xQ,Pha,ic,ic,Ie,_z,Le,Le,Ie,nia,mia,Re,Nf,Re,Nf,wQ,iia,hia,ic,Nf,ic,ic,ic,Re,gia,vQ,fia,eia,dia,cia,Hi,bia,aia,$ha,_ha,Zha,Yha,Xha,Wha,Vha,Uha,Gi,rQ,ic,ic,Ie,Le,Le,Ie,uQ,sQ,_f,Sg,D3,Rha,bA,Qha,ic,Oha,AQ,vha,lha,cha,Wga,Pga,Hga,yga,oga,gga,Iga,Cia,lia,Fha,uu,cA,BQ,ic,Nf,ic,ic,ic,Re,mQ,Dha,Cha,Bha,Aha,zha,Hi,yha,Gi,lQ,ic,ic,Ie,Le,Le,Ie,xha,wha,aQ,jha,iha,ic,Nf,ic,ic,ic,Re,hha,gha,fha,eha,Hi,dha,Gi,ZP,ic,ic,Ie,Le,Le,lu,aha,ic,Nf,ic,ic,ic,Re,YP,_ga,Zga,Yga,Hi,Xga,Gi,WP,ic,ic,Ie,Le,Le,uu,cA,Uga,ic,Nf,ic,ic,ic,Re,YP,Tga,Sga,Rga,Hi,Qga,Gi,TP,ic,ic,Ie,Le,Le,jQ,iQ,Nga,ic,Nf,ic,ic,ic,Re,hQ,Mga,sha,rha,Hi,qha,Gi,pha,ic,ic,Ie,Le,Le,Re,Nf,fQ,Lga,Kga,eQ,Jga,dQ,cQ,iQ,uha,hQ,tha,fQ,oha,nha,eQ,mha,dQ,cQ,lu,Fga,ic,Nf,ic,ic,ic,Re,Le,Ega,Dga,Cga,Hi,Bga,Gi,Aga,ic,ic,Ie,Le,Le,QP,wga,vga,ic,Nf,ic,ic,uga,Re,tga,sga,rga,qga,Hi,pga,Gi,Tz,ic,ic,Ie,Le,Le,Re,Nf,lu,mga,ic,Nf,ic,ic,ic,Re,mQ,lga,kga,jga,Hi,hga,Gi,LP,ic,ic,Ie,Le,Le,lu,ega,ic,Nf,ic,ic,ic,Re,zo,dga,cga,bga,Hi,aga,Gi,IP,ic,ic,Ie,Le,Le,gu,vc,Bda,hO,BN,hO,FN,Pm,IN,fu,XN,nq,du,Uba,Tba,zN,yN,xN,wN,vN,uN,tN,sN,rN,qN,pN,oN,nN,mN,lN,kN,jN,iN,hN,gN,fN,eN,dN,Sba,Rba,Qba,Pba,Oba,Nba,Mba,Lba,Kba,Jba,Iba,Hba,Gba,Fba,Eba,Dba,Cba,Bba,Aba,zba,yba,xba,wba,vba,uba,tba,sba,rba,qba,Me,Sg,Me,Sg,Me,Sg,Me,Sg,Sg,nba,vc,mba,$t,Paa,hba,Me,Sg,Me,vc,Oaa,Naa,Sg,vc,Saa,Me,vc,Maa,Laa,vc,EM,DM,Sg,vc,Gaa,Faa,vc,AM,zM,vc,Daa,Caa,vc,yM,xM,vc,xaa,waa,vc,uM,tM,daa,vc,rm,vc,vc,Ie,Ie,ic,ic,ms,faa,eaa,Sg,Sg,haa,vc,rm,vc,pM,oM,Ie,ic,Ie,oaa,naa,maa,laa,kaa,jaa,iaa,Sg,U9,vc,rm,vc,eM,X9,W9,V9,Sg,Z9,vc,rm,vc,oM,$9,_9,b2,vc,rm,vc,vc,h2,Ie,Ie,ms,ls,g2,f2,e2,C9,B9,A9,ho,Wy,Re,oL,nL,mL,ic,ic,u9,lL,t9,Gt,s9,Gt,Dt,Sy,Re,oL,nL,mL,ic,ic,i9,lL,h9,Gt,g9,Gt,Ct,a9,b9,$8,e9,d9,c9,gq,XK,_8,Z8,Et,Ty,eL,dL,Gf,WK,Y8,X8,Ft,Vy,jL,iL,Me,vc,V8,N3,M3,L3,U8,On,Wy,G8,F8,E8,D8,bL,Xy,ul,Xy,Wy,J8,MK,I8,H8,Sy,O8,M8,L8,K8,Ft,Vy,jL,iL,bL,Xy,Sy,R8,MK,Q8,P8,Et,Ty,eL,dL,W8,ic,C8,ZI,B5,tu,AI,W3,V3,U3,z8,CI,_3,Z3,Y3,w8,et,J5,I5,H5,G5,F5,gY,E5,D5,C5,at,HI,k4,j4,i4,h4,dt,KI,E4,D4,C4,B4,A4,z4,y4,x4,w4,u4,t4,s4,ry,HJ,Z6,Y6,X6,W6,ic,V6,U6,ky,fJ,xy,wy,vy,X5,W5,ly,gJ,ls,uy,ty,Z5,Y5,fJ,gJ,Me,vc,vc,U5,T5,S5,R5,Q5,P5,O5,N5,gY,M5,L5,K5,vc,_I,_I,$p,Ie,Ie,V5,Ie,vc,bJ,aJ,$p,ic,ic,$I,zo,vc,bJ,aJ,$p,ic,ic,$I,zo,vc,eJ,dJ,$p,ic,ic,cJ,zo,vc,eJ,dJ,$p,ic,ic,cJ,zo,Me,vc,B8,A8,Me,vc,y8,x8,vc,v8,s8,r8,q8,yK,yK,p8,o8,n8,m8,l8,vc,k8,j8,i8,h8,mK,mK,g8,f8,e8,d8,c8,vc,b8,a8,_7,Z7,Y7,X7,V7,U7,vc,T7,S7,Q7,P7,O7,N7,L7,K7,Me,vc,Le,J7,I7,H7,G7,F7,E7,e6,d6,c6,b6,a6,$5,_5,Me,vc,Le,D7,C7,B7,A7,z7,y7,l6,k6,j6,i6,h6,g6,f6,II,m4,l4,ud,jy,iy,hy,gy,fy,ey,RI,QI,PI,OI,NI,MI,LI,SI,I4,H4,ud,jy,iy,hy,gy,fy,ey,RI,QI,PI,OI,NI,MI,LI,my,ht,x7,my,ht,w7,ht,ht,vc,nt,nt,ci,ci,ci,bK,ic,bi,bi,vc,nt,nt,ci,ci,ci,bK,ic,bi,bi,vc,mt,mt,ci,ci,ci,aK,ic,bi,bi,vc,mt,mt,ci,ci,ci,aK,ic,bi,bi,DI,b4,xy,wy,vy,$J,nz,_J,ZJ,YJ,lt,EI,c4,xy,wy,vy,$J,nz,_J,ZJ,YJ,lt,FI,d4,ls,uy,ty,XJ,WJ,VJ,UJ,lt,TJ,GI,e4,ls,uy,ty,XJ,WJ,VJ,UJ,lt,TJ,vc,v7,q7,vc,o7,k7,vc,i7,f7,vc,e7,b7,vc,JJ,a7,Re,vc,JJ,$6,Re,vc,vc,Me,vc,_6,HJ,Me,vc,Me,vc,Me,vc,Me,vc,HI,KI,Me,Sg,vc,P3,vc,K3,mI,vc,J3,I3,mI,On,Sg,vc,G3,va,Me,vc,Nf,Nf,C3,u3,w3,x3,vc,p3,vc,n3,Zn,On,Zn,Zn,Zn,Zn,On,vc,m3,vc,t3,v3,y3,vc,B3,A3,z3,vc,q3]);function jb(){return u.byteLength/65536|0}function ob(pb){pb=pb|0;var kb=jb()|0;var lb=kb+pb|0;if(kb<lb&&lb<65536){var mb=new ArrayBuffer(D(lb,65536));var nb=new Int8Array(mb);nb.set(v);v=new Int8Array(mb);w=new Int16Array(mb);x=new Int32Array(mb);y=new Uint8Array(mb);z=new Uint16Array(mb);A=new Uint32Array(mb);B=new Float32Array(mb);C=new Float64Array(mb);u=mb;t.buffer=u;e=y}return kb}return{"va":I0,"wa":uP,"xa":uP,"ya":vP,"za":vP,"Aa":vc,"Ba":Db,"Ca":Ufa,"Da":tP,"Ea":Sfa,"Fa":Qfa,"Ga":ku,"Ha":Re,"Ia":Wfa,"Ja":Vfa,"Ka":Zfa,"La":aA,"Ma":Xfa,"Na":xP,"Oa":Yfa,"Pa":Me,"Qa":BP,"Ra":AP,"Sa":BP,"Ta":lO,"Ua":k3,"Va":j3,"Wa":i3,"Xa":Pfa,"Ya":oP,"Za":Mfa,"_a":mP,"$a":Bfa,"ab":Pda,"bb":Qda,"cb":zfa,"db":yfa,"eb":xfa,"fb":Afa,"gb":Rda,"hb":gea,"ib":Kda,"jb":iea,"kb":zea,"lb":Mda,"mb":kea,"nb":Nda,"ob":jea,"pb":Lda,"qb":Uda,"rb":Sda,"sb":Tda,"tb":bea,"ub":_da,"vb":aea,"wb":Wda,"xb":Xda,"yb":Yda,"zb":Zda,"Ab":wea,"Bb":xea,"Cb":Hea,"Db":Cea,"Eb":Bea,"Fb":Aea,"Gb":Gea,"Hb":Fea,"Ib":Dea,"Jb":Eea,"Kb":Lea,"Lb":Nea,"Mb":Iea,"Nb":Kea,"Ob":Jea,"Pb":qea,"Qb":vea,"Rb":tea,"Sb":sea,"Tb":uea,"Ub":rea,"Vb":eea,"Wb":Pea,"Xb":pea,"Yb":nea,"Zb":yea,"_b":hea,"$b":oea,"ac":mea,"bc":lea,"cc":Qea,"dc":cea,"ec":Rea,"fc":dea,"gc":Oea,"hc":Lfa,"ic":Jfa,"jc":h3,"kc":Ifa,"lc":Hfa,"mc":Gfa,"nc":Efa,"oc":g3,"pc":Dfa,"qc":Cfa,"rc":wfa,"sc":tfa,"tc":rfa,"uc":Sea,"vc":qfa,"wc":sc,"xc":BN,"yc":oq,"zc":Gd,"Ac":GN,"Bc":HN,"Cc":Mca,"Dc":Nca,"Ec":FN,"Fc":mda,"Gc":oda,"Hc":nda,"Ic":WN,"Jc":WN,"Kc":lO,"Lc":dI,"Mc":dI,"Nc":cI,"Oc":cI,"Pc":f3,"Qc":JN,"Rc":MN,"Sc":UN,"Tc":TN,"Uc":KN,"Vc":QN,"Wc":PN,"Xc":LN,"Yc":SN,"Zc":RN,"_c":NN,"$c":Pm,"ad":IN,"bd":kda,"cd":ica,"dd":hda,"ed":zca,"fd":mca,"gd":gda,"hd":jca,"id":bda,"jd":Aca,"kd":ida,"ld":Xca,"md":Wca,"nd":Vca,"od":_ca,"pd":Zca,"qd":Yca,"rd":$ca,"sd":cda,"td":ada,"ud":dda,"vd":tca,"wd":Kca,"xd":gca,"yd":vca,"zd":uca,"Ad":pca,"Bd":wca,"Cd":oca,"Dd":Hca,"Ed":bca,"Fd":dca,"Gd":eca,"Hd":cca,"Id":_ba,"Jd":Zba,"Kd":Bca,"Ld":Dca,"Md":Jca,"Nd":Cca,"Od":nca,"Pd":Fca,"Qd":qca,"Rd":xca,"Sd":Eca,"Td":rca,"Ud":lca,"Vd":yca,"Wd":sca,"Xd":kca,"Yd":$ba,"Zd":Yba,"_d":Xba,"$d":fca,"ae":aca,"be":Vba,"ce":Wba,"de":Ica,"ee":e3,"fe":hca,"ge":Lca,"he":Uca,"ie":jda,"je":d3,"ke":fda,"le":lda,"me":YN,"ne":_N,"oe":$N,"pe":aO,"qe":cO,"re":dO,"se":gO,"te":bO,"ue":fu,"ve":XN,"we":ZN,"xe":rda,"ye":Ada,"ze":sc,"Ae":GN,"Be":HN,"Ce":oq,"De":JN,"Ee":MN,"Fe":UN,"Ge":TN,"He":KN,"Ie":QN,"Je":PN,"Ke":LN,"Le":SN,"Me":RN,"Ne":NN,"Oe":Pm,"Pe":YN,"Qe":_N,"Re":$N,"Se":aO,"Te":cO,"Ue":dO,"Ve":gO,"We":bO,"Xe":fu,"Ye":ZN,"Ze":ib,"_e":jia,"$e":Xia,"af":$ga,"bf":Rfa,"cf":E3,"df":F3,"ef":s3,"ff":r3,"gf":c3,"hf":b3,"jf":$2,"kf":X2,"lf":a3,"mf":$2,"nf":_2,"of":Y2,"pf":Z2,"qf":Y2,"rf":X2,"sf":X2}}return qb(sb)}
// EMSCRIPTEN_END_ASM


)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];
